select '../rhn/start.sql' sql_file from dual;
-- SQL relevant contents from file ../rhn/start.sql
whenever sqlerror exit failure;

select '../rhn/packages/rhn_bel.pks' sql_file from dual;
-- SQL relevant contents from file ../rhn/packages/rhn_bel.pks
create or replace
package rhn_bel
is
	function find_state_of_org (
		org_id_in in number
	) return varchar2;
	function is_state_legacy_unclassified (
		org_id_in in number
	) return number;
	function is_org_paid (
		org_id_in in number
	) return number;
	function lookup_email_state (
		state_in in varchar2
	) return number;
	function lookup_org_state (
		state_in in varchar2
	) return number;
	procedure validate_org_state_change(
		from_state_in in number,
		to_state_in in number
	);
	procedure join_rhn (
		org_id_in in number
	);
	procedure set_org_paid(
		org_id_in in number
	);
	procedure set_org_unpaid(
		org_id_in in number
	);
end;
/
show errors

select '../rhn/tables/rhnServerArch.sql' sql_file from dual;
-- SQL relevant contents from file ../rhn/tables/rhnServerArch.sql
create table
rhnServerArch
(
	id		number
			constraint rhn_sarch_id_nn not null,
	label		varchar2(32)
			constraint rhn_sarch_label_nn not null,
	name		varchar2(64)
			constraint rhn_sarch_name_nn not null,
	created		date default(sysdate)
			constraint rhn_sarch_created_nn not null,
	modified	date default(sysdate)
			constraint rhn_sarch_modified_nn not null
)
	storage( freelists 16 )
	initrans 32;
create sequence rhn_server_arch_id_seq start with 1000;
create index rhn_sarch_id_l_n_idx
	on rhnServerArch(id,label,name)
	tablespace [[2m_tbs]]
	storage( freelists 16 )
	initrans 32;
alter table rhnServerArch add constraint rhn_sarch_id_pk primary key (id);
create index rhn_sarch_l_id_n_idx
	on rhnServerArch(label,id,name)
	tablespace [[2m_tbs]]
	storage( freelists 16 )
	initrans 32;
alter table rhnServerArch add constraint rhn_sarch_label_uq unique ( label );
create or replace trigger
rhn_sarch_mod_trig
before insert or update on rhnServerArch
for each row
begin
        :new.modified := sysdate;
end;
/
show errors

select '../web/tables/web_customer.sql' sql_file from dual;
-- SQL relevant contents from file ../web/tables/web_customer.sql
create table
web_customer
(
	id		number
			constraint web_customer_id_nn not null
			constraint web_customer_id_pk primary key
				using index tablespace [[web_index_tablespace_2]]
				storage(pctincrease 1),
	name		varchar2(128)
			constraint web_customer_name_nn not null,
	password	varchar2(48)
			constraint web_customer_pw_nn not null,
	oracle_customer_id number
			constraint web_customer_ocid_unq unique
				using index tablespace [[web_index_tablespace_2]]
				storage(pctincrease 1),
	oracle_customer_number number
			constraint web_customer_ocn_unq unique
				using index tablespace [[web_index_tablespace_2]]
				storage(pctincrease 1),
	customer_type	char(1) default ('P')
			constraint web_customer_type_nn not null
			constraint web_customer_type_list
				check (customer_type in ('B', 'P')),
        credit_application_completed varchar2(1),
	created		date default(sysdate)
			constraint web_customer_created_nn not null,
	modified	date default(sysdate)
			constraint web_customer_modified_nn not null
)
tablespace [[web_tablespace_2]]
storage(pctincrease 1);
create sequence web_customer_id_seq;

select '../web/tables/web_contact.sql' sql_file from dual;
-- SQL relevant contents from file ../web/tables/web_contact.sql
create table
web_contact
(
	id		number
			constraint web_contact_pk primary key
				using index tablespace [[web_index_tablespace_2]]
				storage(pctincrease 1),
	org_id		number
			constraint web_contact_org_nn not null
			constraint web_contact_org_fk
				references web_customer(id),
	login	   	varchar2(64)
			constraint web_contact_login_nn not null,
	login_uc	varchar2(64)
			constraint web_contact_login_uc_nn not null
			constraint web_contact_login_uc_unq unique
				using index tablespace [[web_index_tablespace_2]]
				storage(pctincrease 1),
	password	varchar2(38)
			constraint web_contact_password_nn not null,
	old_password	varchar2(38),
	created		date default(sysdate)
			constraint web_contact_created_nn not null,
	modified	date default(sysdate)
			constraint web_contact_modified_nn not null,
	oracle_contact_id number
			constraint web_contact_ocid_unq unique
				using index tablespace [[web_index_tablespace_2]]
				storage(pctincrease 1),
	ignore_flag	char(1) default('N')
			constraint web_contact_ignore_nn not null
			constraint web_contact_ignore_ck
				check (ignore_flag in ('N','Y'))
)
tablespace [[web_tablespace_2]]
storage(pctincrease 1);
create sequence web_contact_id_seq;

select '../rhn/tables/rhnProvisionState.sql' sql_file from dual;
-- SQL relevant contents from file ../rhn/tables/rhnProvisionState.sql
create sequence rhn_provstate_id_seq;
create table
rhnProvisionState
(
	id		number
			constraint rhn_provstate_id_nn not null
			constraint rhn_provstate_id_pk primary key,
	label		varchar2(32)
			constraint rhn_provstate_label_nn not null,
	description	varchar2(256)
			constraint rhn_provstate_desc_nn not null,
	created		date default(sysdate)
			constraint rhn_provstate_creat_nn not null,
	modified	date default(sysdate)
			constraint rhn_provstate_mod_nn not null
)
	storage ( freelists 16 )
	initrans 32;
create index rhn_provstate_l_id_idx
	on rhnProvisionState(label, id)
	tablespace [[64k_tbs]]
	storage ( freelists 16 )
	initrans 32;
alter table rhnProvisionState add constraint rhn_provstate_l_uq
	unique ( label );
create or replace trigger
rhn_provstate_mod_trig
before insert or update on rhnProvisionState
for each row
begin
	:new.modified := sysdate;
end;
/
show errors

select '../rhn/tables/rhnServer.sql' sql_file from dual;
-- SQL relevant contents from file ../rhn/tables/rhnServer.sql
create table
rhnServer
(
        id              number
			constraint rhn_server_id_nn not null
                        constraint rhn_server_id_pk primary key
	                        using index tablespace [[4m_tbs]]
				storage( pctincrease 1 freelists 16 ),
        org_id          number
                        constraint rhn_server_oid_nn not null
                        constraint rhn_server_oid_fk
                                references web_customer(id)
				on delete cascade,
        digital_server_id varchar(64)
			constraint rhn_server_dsi_nn not null,
	server_arch_id	number
			constraint rhn_server_said_nn not null
			constraint rhn_server_said_fk
				references rhnServerArch(id),
        os              varchar(64)
			constraint rhn_server_os_nn not null,
        release         varchar(64)
			constraint rhn_server_release_nn not null,
        name            varchar(128),
        description     varchar(256),
        info            varchar(128),
        secret          varchar(32)
			constraint rhn_server_secret_nn not null,
	creator_id	number
			constraint rhn_server_creator_fk
				references web_contact(id)
				on delete set null,
	auto_deliver	char(1) default 'N'
	    	    	constraint rhn_server_auto_deliver_nn not null
			constraint rhn_server_deliver_ck
				check (auto_deliver in ('Y', 'N')),
	auto_update     char(1) default 'N'
	    	    	constraint rhn_server_auto_update_nn not null
			constraint rhn_server_update_ck
				check (auto_update in ('Y', 'N')),
	running_kernel  varchar2(64),
        last_boot       number default 0
			constraint rhn_server_lb_nn not null,
	provision_state_id number
			constraint rhn_server_psid_fk
				references rhnProvisionState(id),
        created         date default (sysdate)
			constraint rhn_server_created_nn not null,
        modified        date default (sysdate)
			constraint rhn_server_modified_nn not null
)
	storage ( pctincrease 1 freelists 16 )
	initrans 32;
create sequence rhn_server_id_seq start with 1000010000 order;
create unique index rhn_server_dsid_uq
	on rhnServer(digital_server_id)
	tablespace [[8m_tbs]]
	storage( pctincrease 1 freelists 16 )
	initrans 32;
create index rhn_server_oid_id_idx
	on rhnServer(org_id,id)
        tablespace [[4m_tbs]]
	storage( pctincrease 1 freelists 16 )
	initrans 32
	nologging;
create index rhn_server_created_id_idx
	on rhnServer(created,id)
        tablespace [[4m_tbs]]
	storage( pctincrease 1 freelists 16 )
	initrans 32
	nologging;
create index rhn_server_creator_idx
	on rhnServer(creator_id)
	tablespace [[2m_tbs]]
	storage ( pctincrease 1 freelists 16 )
	initrans 32
	nologging;
create or replace trigger
rhn_server_mod_trig
before insert or update on rhnServer
for each row
begin
        :new.modified := sysdate;
end;
/
show errors

select '../rhn/tables/rhnChannelArch.sql' sql_file from dual;
-- SQL relevant contents from file ../rhn/tables/rhnChannelArch.sql
create table
rhnChannelArch
(
	id		number
			constraint rhn_carch_id_nn not null,
	label		varchar2(16)
			constraint rhn_carch_label_nn not null,
	name		varchar2(64)
			constraint rhn_carch_name_nn not null,
	created		date default(sysdate)
			constraint rhn_carch_created_nn not null,
	modified	date default(sysdate)
			constraint rhn_carch_modified_nn not null
)
	storage ( freelists 16 )
	initrans 32;
create sequence rhn_channel_arch_id_seq start with 500;
create index rhn_carch_id_l_n_idx
	on rhnChannelArch(id,label,name)
	tablespace [[2m_tbs]]
	storage ( freelists 16 )
	initrans 32;
alter table rhnChannelArch add constraint rhn_carch_id_pk primary key (id);
create index rhn_carch_l_id_n_idx
	on rhnChannelArch(label,id,name)
	tablespace [[2m_tbs]]
	storage ( freelists 16 )
	initrans 32;
alter table rhnChannelArch add constraint rhn_carch_label_uq unique ( label );
create or replace trigger
rhn_carch_mod_trig
before insert or update on rhnChannelArch
for each row
begin
        :new.modified := sysdate;
end;
/
show errors

select '../rhn/tables/rhnChannel.sql' sql_file from dual;
-- SQL relevant contents from file ../rhn/tables/rhnChannel.sql
create table
rhnChannel
(
	id		number
			constraint rhn_channel_id_nn not null
			constraint rhn_channel_id_pk primary key
				using index tablespace [[64k_tbs]],
	parent_channel	number
			constraint rhn_channel_parent_ch_fk
				references rhnChannel(id),
	org_id		number
			constraint rhn_channel_org_fk
				references web_customer(id),
        channel_arch_id number
			constraint rhn_channel_caid_nn not null
			constraint rhn_channel_caid_fk
				references rhnChannelArch(id),
	label		varchar2(128)
			constraint rhn_channel_label_nn not null,
	basedir		varchar2(256)
			constraint rhn_channel_basedir_nn not null,
	name		varchar2(64)
			constraint rhn_channel_name_nn not null,
	summary		varchar2(500)
			constraint rhn_channel_summary_nn not null,
	description	varchar2(4000),
    	gpg_key_url     varchar2(256),
	gpg_key_id	varchar2(14),
	gpg_key_fp	varchar2(50),
	end_of_life     date,
	last_modified	date default (sysdate)
			constraint rhn_channel_lm_nn not null,
	created		date default (sysdate)
			constraint rhn_channel_created_nn not null,
	modified	date default (sysdate)
			constraint rhn_channel_modified_nn not null
)
	storage ( freelists 16 )
	initrans 32;
create sequence rhn_channel_id_seq start with 101;
create unique index rhn_channel_label_uq
	on rhnChannel(label)
	tablespace [[64k_tbs]]
	storage ( freelists 16 )
	initrans 32;
create unique index rhn_channel_name_uq
	on rhnChannel(name)
	tablespace [[64k_tbs]]
	storage ( freelists 16 )
	initrans 32;
create index rhn_channel_org_idx
	on rhnChannel(org_id, id)
	tablespace [[64k_tbs]]
	storage ( freelists 16 )
	initrans 32
	nologging;
create index rhn_channel_url_id_idx
	on rhnChannel(label, id)
	tablespace [[64k_tbs]]
	storage ( freelists 16 )
	initrans 32
	nologging;
create index rhn_channel_parent_id_idx
	on rhnChannel(parent_channel, id)
	tablespace [[64k_tbs]]
	storage ( freelists 16 )
	initrans 32
	nologging;

select '../rhn/tables/rhnServerChannel.sql' sql_file from dual;
-- SQL relevant contents from file ../rhn/tables/rhnServerChannel.sql
create table rhnServerChannel
(
	server_id	number
			constraint rhn_sc_sid_nn not null 
			constraint rhn_sc_sid_fk
				references rhnServer(id) on delete cascade,
	channel_id	number
			constraint rhn_sc_cid_nn not null 
			constraint rhn_sc_cid_fk
				references rhnChannel(id),
	created		date default(sysdate)
			constraint rhn_sc_created_nn not null,
	modified	date default(sysdate)
			constraint rhn_sc_modified_nn not null
)
	storage( freelists 16 )
	initrans 32;
create unique index rhn_sc_sid_cid_uq
	on rhnServerChannel(server_id, channel_id)
	tablespace [[8m_tbs]]
	storage( freelists 16 )
	initrans 32;
create index rhn_sc_cid_sid_idx
	on rhnServerChannel(channel_id, server_id)
	tablespace [[8m_tbs]]
	storage( freelists 16 )
	initrans 32
	nologging;

select '../rhn/tables/rhnChannelFamily.sql' sql_file from dual;
-- SQL relevant contents from file ../rhn/tables/rhnChannelFamily.sql
create table
rhnChannelFamily
(
	id		number
			constraint rhn_channel_family_id_nn not null
			constraint rhn_channel_family_id_pk primary key
				using index tablespace [[64k_tbs]],
	org_id		number
			constraint rhn_channel_family_org_fk
				references web_customer(id)
				on delete cascade,
	name		varchar2(128)
			constraint rhn_channel_family_name_nn not null,
	label		varchar2(128)
			constraint rhn_channel_family_label_nn not null,
	product_url     varchar2(128) default 'http://www.redhat.com/products/'
			constraint rhn_channel_family_url_nn not null,
	created		date default (sysdate)
			constraint rhn_channel_family_created_nn not null,
	modified	date default (sysdate)
			constraint rhn_channel_family_modified_nn not null
)
	storage ( freelists 16 )
	initrans 32;
create sequence rhn_channel_family_id_seq start with 1000;
create unique index rhn_channel_family_label_uq
	on rhnChannelFamily(label)
	tablespace [[64k_tbs]]
	storage ( freelists 16 )
	initrans 32;
create unique index rhn_channel_family_name_uq
	on rhnChannelFamily(name)
	tablespace [[64k_tbs]]
	storage ( freelists 16 )
	initrans 32;
create or replace trigger
rhn_channel_family_mod_trig
before insert or update on rhnChannelFamily
for each row
begin
	:new.modified := sysdate;
end;
/
show errors

select '../rhn/tables/rhnChannelFamilyPermissions.sql' sql_file from dual;
-- SQL relevant contents from file ../rhn/tables/rhnChannelFamilyPermissions.sql
create table
rhnChannelFamilyPermissions
(
	channel_family_id number
			constraint rhn_cfperm_cid_nn not null 
			constraint rhn_cfperm_cid_fk
				references rhnChannelFamily(id),
	org_id  	number
			constraint rhn_cfperm_oid_fk
				references web_customer(id)
				on delete cascade,
        max_members     number,
	current_members number default 0
                        constraint rhn_cfperm_curmembers_nn not null,
	created		date default (sysdate)
			constraint rhn_cfperm_created_nn not null,
	modified	date default (sysdate)
			constraint rhn_cfperm_modified_nn not null
)
	storage ( freelists 16 )
	initrans 32;
create unique index rhn_cfperm_ce_uq
	on rhnChannelFamilyPermissions(org_id,channel_family_id)
	tablespace [[2m_tbs]]
	storage ( freelists 16 )
	initrans 32;
create index rhn_cfperm_co_idx on
	rhnChannelFamilyPermissions(channel_family_id, org_id)
	tablespace [[2m_tbs]]
	storage ( freelists 16 )
	initrans 32
	nologging;

select '../rhn/packages/rhn_channel.pks' sql_file from dual;
-- SQL relevant contents from file ../rhn/packages/rhn_channel.pks
CREATE OR REPLACE
PACKAGE rhn_channel
IS
    CURSOR server_base_subscriptions(server_id_in NUMBER) IS
    	   SELECT C.id
	     FROM rhnChannel C, rhnServerChannel SC
	    WHERE C.id = SC.channel_id
	      AND SC.server_id = server_id_in
	      AND C.parent_channel IS NULL;
    CURSOR check_server_subscription(server_id_in NUMBER, channel_id_in NUMBER) IS 
           SELECT channel_id 
	     FROM rhnServerChannel 
	    WHERE server_id = server_id_in 
	      AND channel_id = channel_id_in;
    CURSOR check_server_parent_membership(server_id_in NUMBER, channel_id_in NUMBER) IS
    	   SELECT C.id
	     FROM rhnChannel C, rhnServerChannel SC
	    WHERE C.parent_channel = channel_id_in
	      AND C.id = SC.channel_id
	      AND SC.server_id = server_id_in;
    CURSOR channel_family_perm_cursor(channel_family_id_in NUMBER, org_id_in NUMBER) IS
           SELECT *
	     FROM rhnChannelFamilyPermissions
	    WHERE channel_family_id = channel_family_id_in
	      AND (org_id = org_id_in OR org_id IS NULL);
    PROCEDURE license_consent(channel_id_in IN NUMBER, user_id_in IN NUMBER, server_id_in IN NUMBER);
    FUNCTION get_license_path(channel_id_in IN NUMBER) RETURN VARCHAR2;
    PROCEDURE unsubscribe_server(server_id_in IN NUMBER, channel_id_in NUMBER, immediate_in NUMBER := 1, unsubscribe_children_in number := 0);
    PROCEDURE subscribe_server(server_id_in IN NUMBER, channel_id_in NUMBER, immediate_in NUMBER := 1, user_id_in number := null);
    FUNCTION guess_server_base(server_id_in IN NUMBER) RETURN NUMBER;
    FUNCTION base_channel_for_release_arch(release_in in varchar2, 
	server_arch_in in varchar2, org_id_in in number := -1, 
	user_id_in in number := null) RETURN number;
    FUNCTION base_channel_rel_archid(release_in in varchar2, 
	server_arch_id_in in number, org_id_in in number := -1, 
	user_id_in in number := null) RETURN number;
    PROCEDURE bulk_subscribe_server(channel_id_in IN NUMBER, set_label_in IN VARCHAR2, set_uid_in IN NUMBER);
    PROCEDURE bulk_unsubscribe_server(channel_id_in IN NUMBER, set_label_in IN VARCHAR2, set_uid_in IN NUMBER);
    PROCEDURE bulk_server_base_change(channel_id_in IN NUMBER, set_label_in IN VARCHAR2, set_uid_in IN NUMBER);
    procedure bulk_server_basechange_from(
	set_label_in in varchar2,
	set_uid_in in number,
	old_channel_id_in in number,
	new_channel_id_in in number);
    procedure bulk_guess_server_base(
	set_label_in in varchar2,
	set_uid_in in number);
    procedure bulk_guess_server_base_from(
	set_label_in in varchar2,
	set_uid_in in number,
	channel_id_in in number);
    PROCEDURE clear_subscriptions(server_id_in IN NUMBER);
    FUNCTION subscription_count(channel_id_in NUMBER) RETURN VARCHAR2;
    FUNCTION available_family_subscriptions(channel_family_id_in IN NUMBER, org_id_in IN NUMBER) RETURN NUMBER;
    PROCEDURE update_family_counts(channel_family_id_in IN NUMBER, org_id_in IN NUMBER);
    FUNCTION family_for_channel(channel_id_in IN NUMBER) RETURN NUMBER;
    FUNCTION available_chan_subscriptions(channel_id_in IN NUMBER, org_id_in IN NUMBER) RETURN NUMBER;
    procedure entitle_customer(customer_id_in in number, channel_family_id_in in number, quantity_in in number);
    procedure set_family_maxmembers(customer_id_in in number, channel_family_id_in in number, quantity_in in number);
    procedure unsubscribe_server_from_family(server_id_in in number, channel_family_id_in in number);
    procedure delete_server_channels(server_id_in in number);
    procedure refresh_newest_package(channel_id_in in number, caller_in in varchar2 := '(unknown)');
    function get_org_id(channel_id_in in number) return number;
    PRAGMA RESTRICT_REFERENCES(get_org_id, WNDS, RNPS, WNPS);
    function get_org_access(channel_id_in in number, org_id_in in number) return number;
    PRAGMA RESTRICT_REFERENCES(get_org_access, WNDS, RNPS, WNPS);
    function get_cfam_org_access(cfam_id_in in number, org_id_in in number) return number;
    function user_role_check_debug(channel_id_in in number, user_id_in in number, role_in in varchar2, reason_out out varchar2)
    	RETURN NUMBER;
    PRAGMA RESTRICT_REFERENCES(user_role_check_debug, WNDS, RNPS, WNPS);
    function user_role_check(channel_id_in in number, user_id_in in number, role_in in varchar2)
    	RETURN NUMBER;
    PRAGMA RESTRICT_REFERENCES(user_role_check, WNDS, RNPS, WNPS);
    function loose_user_role_check(channel_id_in in number, user_id_in in number, role_in in varchar2)
    	RETURN NUMBER;
    PRAGMA RESTRICT_REFERENCES(loose_user_role_check, WNDS, RNPS, WNPS);
    function direct_user_role_check(channel_id_in in number, user_id_in in number, role_in in varchar2)
    	RETURN NUMBER;
    PRAGMA RESTRICT_REFERENCES(direct_user_role_check, WNDS, RNPS, WNPS);
    function org_channel_setting(channel_id_in in number, org_id_in in number, setting_in in varchar2)
    	RETURN NUMBER;
    PRAGMA RESTRICT_REFERENCES(org_channel_setting, WNDS, RNPS, WNPS);
END rhn_channel;
/
SHOW ERRORS

select '../rhn/packages/rhn_config.pks' sql_file from dual;
-- SQL relevant contents from file ../rhn/packages/rhn_config.pks
create or replace package
rhn_config
is
	procedure prune_org_configs (
		org_id_in in number,
		total_in in number
	);
	function insert_revision (
		revision_in in number,
		config_file_id_in in number,
		config_content_id_in in number,
		config_info_id_in in number,
		delim_start_in in varchar2 := '{@',
		delim_end_in in varchar2 := '@}'
	) return number;
	procedure delete_revision (
		config_revision_id_in in number,
		org_id_in in number := -1
	);
	function get_latest_revision (
		config_file_id_in in number
	) return number;
	function insert_file (
		config_channel_id_in in number,
		name_in in varchar2
	) return number;
	procedure delete_file (
		config_file_id_in in number
	);
	function insert_channel (
		org_id_in in number,
		type_in in varchar2,
		name_in in varchar2,
		label_in in varchar2,
		description_in in varchar2
	) return number;
	procedure delete_channel (
		config_channel_id_in in number
	);
end rhn_config;
/
show errors

select '../rhn/packages/rhn_config_channel.pks' sql_file from dual;
-- SQL relevant contents from file ../rhn/packages/rhn_config_channel.pks
CREATE OR REPLACE
PACKAGE rhn_config_channel
IS
    FUNCTION get_user_chan_access(config_channel_id_in IN NUMBER, user_id_in IN NUMBER) RETURN NUMBER;
    FUNCTION get_user_revision_access(config_revision_id_in IN NUMBER, user_id_in IN NUMBER) RETURN NUMBER;
    FUNCTION get_user_file_access(config_file_id_in IN NUMBER, user_id_in IN NUMBER) RETURN NUMBER;
    FUNCTION get_config_channel_server(config_channel_id_in IN NUMBER, config_channel_type_in IN VARCHAR2) RETURN NUMBER;
    FUNCTION action_diff_revision_status(action_config_revision_id_in IN NUMBER) RETURN VARCHAR2;
END rhn_config_channel;
/
SHOW ERRORS

select '../rhn/packages/rhn_date_manip.pks' sql_file from dual;
-- SQL relevant contents from file ../rhn/packages/rhn_date_manip.pks
create or replace
package rhn_date_manip
is
	periods_ago number;
	function get_reporting_period_start return date;
	function get_reporting_period_end return date;
end rhn_date_manip;
/
show errors

select '../rhn/packages/rhn_entitlements.pks' sql_file from dual;
-- SQL relevant contents from file ../rhn/packages/rhn_entitlements.pks
create or replace
package rhn_entitlements
is
    	function entitlement_grants_service (
	    	entitlement_in in varchar2,
		service_level_in in varchar2
	) return number;
	function lookup_entitlement_group (
		org_id_in in number,
		type_label_in in varchar2 := 'sw_mgr_entitled'
	) return number;
	function create_entitlement_group (
		org_id_in in number,
		type_label_in in varchar2 := 'sw_mgr_entitled'
	) return number;
	procedure entitle_server (
		server_id_in in number,
		type_label_in in varchar2 := 'sw_mgr_entitled'
	);
	procedure unentitle_server (
		server_id_in in number,
		type_label_in in varchar2 := 'sw_mgr_entitled'
	);
	procedure upgrade_server (
		server_id_in in number
	);
	function get_server_entitlement (
		server_id_in in number
	) return varchar2;
    procedure set_customer_enterprise (
		customer_id in number
	);
	procedure set_customer_provisioning (
		customer_id_in in number
	);
    procedure unset_customer_enterprise (
		customer_id in number
	);
	procedure unset_customer_provisioning (
		customer_id_in in number
	);
    procedure set_group_count (
		customer_id_in in number,	-- customer_id
		type_in in char,			-- 'U' or 'S'
		group_type_in in number,	-- rhn[User|Server]GroupType.id
		quantity_in in number		-- quantity
    );
    procedure set_family_count (
		customer_id_in in number,		-- customer_id
		channel_family_id_in in number,	-- 246
		quantity_in in number			-- 3
    );
    procedure entitle_last_modified_servers (
		customer_id_in in number,	-- customer_id
		type_label_in in varchar2,	-- 'enterprise_entitled'
		quantity_in in number		-- 3
    );
	procedure get_available_slots (
		customer_id_in in number,
		type_label_in in varchar2,
		server_group_id_out out number,
		available_out out number,
		upgrade_out out number
	);
	procedure prune_everything (
		customer_id_in in number
	);
	procedure subscribe_newest_servers (
		customer_id_in in number
	);
end rhn_entitlements;
/
show errors

select '../rhn/tables/rhnException.sql' sql_file from dual;
-- SQL relevant contents from file ../rhn/tables/rhnException.sql
create table rhnException
(
    id	        number
    	    	constraint rhn_exc_id_nn not null
		constraint rhn_exc_id_pk primary key
		    using index tablespace [[64k_tbs]],
    label       varchar2(128)
    	    	constraint rhn_exc_label_nn not null,
    message     varchar2(2000)
                constraint rhn_exc_msg_nn not null
)
	storage ( freelists 16 )
	initrans 32;
create unique index rhn_exc_label_uq
	on rhnException(label)
	tablespace [[64k_tbs]]
	storage ( freelists 16 )
	initrans 32;

select '../rhn/packages/rhn_exception.pks' sql_file from dual;
-- SQL relevant contents from file ../rhn/packages/rhn_exception.pks
CREATE OR REPLACE
PACKAGE rhn_exception
IS
    CURSOR exception_details(exception_label_in VARCHAR2) IS
        SELECT id, label, message
          FROM rhnException
         WHERE label = exception_label_in;
    PROCEDURE raise_exception(exception_label_in IN VARCHAR2);
    procedure raise_exception_val(
	exception_label_in in varchar2,
        val_in in number
    );
    PROCEDURE lookup_exception(exception_label_in IN VARCHAR2, exception_id_out OUT NUMBER, exception_message_out OUT VARCHAR2);
END rhn_exception;
/
SHOW ERRORS

select '../rhn/tables/rhnServerGroupType.sql' sql_file from dual;
-- SQL relevant contents from file ../rhn/tables/rhnServerGroupType.sql
create table
rhnServerGroupType
(
        id              number
			constraint rhn_servergrouptype_id_nn not null
                        constraint rhn_servergrouptype_id_pk primary key
                                using index tablespace [[64k_tbs]],
        label           varchar2(32)
                        constraint rhn_servergrouptype_label_nn not null,
        name            varchar2(64)
                        constraint rhn_servergrouptype_name_nn not null,
        created         date default(sysdate)
                        constraint rhn_servergrouptype_created_nn not null,
        modified        date default(sysdate)
                        constraint rhn_servergrouptype_mod_nn not null
)
	storage ( freelists 16 )
	initrans 32;
create sequence rhn_servergroup_type_seq;
create unique index rhn_servergrouptype_label_uq 
	on rhnServerGroupType(label)
	tablespace [[64k_tbs]]
	storage ( freelists 16 )
	initrans 32;

select '../rhn/packages/rhn_exception.pkb' sql_file from dual;
-- SQL relevant contents from file ../rhn/packages/rhn_exception.pkb
CREATE OR REPLACE
PACKAGE BODY rhn_exception
IS
    PROCEDURE lookup_exception(exception_label_in IN VARCHAR2, exception_id_out OUT NUMBER, exception_message_out OUT VARCHAR2)
    IS
        return_string     VARCHAR2(2000);
    BEGIN
        FOR exc IN exception_details(exception_label_in)
        LOOP
            exception_id_out := exc.id;
            exception_message_out := '(' || exc.label || ')' || ' - ' || exc.message;
        END LOOP exception_details;
        IF exception_message_out IS NULL
        THEN
            RAISE NO_DATA_FOUND;
        END IF;
    END lookup_exception;
    PROCEDURE raise_exception(exception_label_in IN VARCHAR2)
    IS
        exception_id        NUMBER;
        exception_message   VARCHAR2(2000);
    BEGIN
        lookup_exception(exception_label_in, exception_id, exception_message);
        RAISE_APPLICATION_ERROR(exception_id, exception_message);    
    EXCEPTION
        WHEN NO_DATA_FOUND
        THEN
        RAISE_APPLICATION_ERROR(-20001, 'Unable to lookup exception with label (' || exception_label_in || ')');    
    END raise_exception;
    procedure raise_exception_val(
	exception_label_in in varchar2,
	val_in in number
    ) is
	exception_id        NUMBER;
	exception_message   VARCHAR2(2000);
    begin
	lookup_exception(exception_label_in, exception_id, exception_message);
	RAISE_APPLICATION_ERROR(exception_id, exception_message || ' (' || val_in || ')');
    exception
	when no_data_found then
	RAISE_APPLICATION_ERROR(-20001, 'Unable to lookup exception with label (' || exception_label_in || ')');
    end raise_exception_val;
END rhn_exception;
/
SHOW ERRORS

select '../rhn/tables/rhnServerGroup.sql' sql_file from dual;
-- SQL relevant contents from file ../rhn/tables/rhnServerGroup.sql
create table
rhnServerGroup
(
        id              number
                        constraint rhn_servergroup_id_nn not null
                        constraint rhn_servergroup_id_pk primary key
                                using index tablespace [[4m_tbs]]
				storage(pctincrease 1),
        name            varchar2(64)
                        constraint rhn_servergroup_name_nn not null,
        description     varchar2(1024)
                        constraint rhn_servergroup_desc_nn not null,
        max_members     number,
	current_members number default 0
                        constraint rhn_servergroup_curmembers_nn not null,
        group_type      number
                        constraint rhn_servergroup_type_fk
                                references rhnServerGroupType(id),
        org_id          number
                        constraint rhn_servergroup_oid_nn not null
                        constraint rhn_servergroup_oid_fk
                                references web_customer(id)
				on delete cascade,
        created         date default(sysdate)
                        constraint rhn_servergroup_created_nn not null,
        modified        date default(sysdate)
                        constraint rhn_servergroup_modified_nn not null
)
	storage( pctincrease 1 freelists 16 )
	initrans 32;
create sequence rhn_server_group_id_seq;
create unique index rhn_servergroup_oid_name_uq
	on rhnServerGroup(org_id, name)
	tablespace [[4m_tbs]]
	storage( pctincrease 1 freelists 16 )
	initrans 32;

select '../rhn/packages/rhn_org.pks' sql_file from dual;
-- SQL relevant contents from file ../rhn/packages/rhn_org.pks
CREATE OR REPLACE
PACKAGE rhn_org
IS
    CURSOR server_group_by_label(org_id_in NUMBER, group_label_in VARCHAR2) IS
    	   SELECT SG.*
	     FROM rhnServerGroupType SGT,
	     	  rhnServerGroup SG
	    WHERE SG.group_type = SGT.id
	      AND SGT.label = group_label_in
	      AND SG.org_id = org_id_in;
    FUNCTION find_server_group_by_type(org_id_in NUMBER, group_label_in VARCHAR2) RETURN NUMBER;
    PROCEDURE update_errata_cache(org_id_in NUMBER, threshold_in NUMBER);
	procedure delete_user(user_id_in number);
END rhn_org;
/
SHOW ERRORS

select '../rhn/tables/rhnPackageName.sql' sql_file from dual;
-- SQL relevant contents from file ../rhn/tables/rhnPackageName.sql
CREATE TABLE
rhnPackageName
(
        id              number
			constraint rhn_pn_id_nn not null
                        constraint rhn_pn_id_pk primary key
			using index tablespace [[2m_tbs]],
        name            varchar2(128)
			constraint rhn_pn_name_nn not null
)
	storage ( freelists 16 )
	initrans 32;
create unique index rhn_pn_name_uq
	on rhnPackageName(name)
	tablespace [[2m_tbs]]
	storage ( freelists 16 )
	initrans 32;
create sequence rhn_pkg_name_seq;

select '../rhn/packages/rpm.pks' sql_file from dual;
-- SQL relevant contents from file ../rhn/packages/rpm.pks
CREATE OR REPLACE PACKAGE rpm AS
    FUNCTION vercmp(
        e1 VARCHAR2, v1 VARCHAR2, r1 VARCHAR2, 
        e2 VARCHAR2, v2 VARCHAR2, r2 VARCHAR2)
    RETURN NUMBER
        DETERMINISTIC
        PARALLEL_ENABLE;
    PRAGMA RESTRICT_REFERENCES(vercmp, WNDS, RNDS);
    FUNCTION vercmpCounter
    return NUMBER
        DETERMINISTIC
        PARALLEL_ENABLE;
    PRAGMA RESTRICT_REFERENCES(vercmpCounter, WNDS, RNDS);
    FUNCTION vercmpResetCounter
    return NUMBER
        DETERMINISTIC
        PARALLEL_ENABLE;
    PRAGMA RESTRICT_REFERENCES(vercmpResetCounter, WNDS, RNDS);
END rpm;
/
SHOW ERRORS;

select '../rhn/packages/rpm.pkb' sql_file from dual;
-- SQL relevant contents from file ../rhn/packages/rpm.pkb
CREATE OR REPLACE PACKAGE BODY rpm AS
    vercmp_counter NUMBER := 0;
    FUNCTION isdigit(ch CHAR)
    RETURN BOOLEAN
    IS
    BEGIN
        if ascii(ch) between ascii('0') and ascii('9')
        then
            return TRUE;
        end if;
        return FALSE;
    END isdigit;
    FUNCTION isalpha(ch CHAR)
    RETURN BOOLEAN
    IS
    BEGIN
        if ascii(ch) between ascii('a') and ascii('z') or 
            ascii(ch) between ascii('A') and ascii('Z')
        then
            return TRUE;
        end if;
        return FALSE;
    END isalpha;
    FUNCTION isalphanum(ch CHAR)
    RETURN BOOLEAN
    IS
    BEGIN
        if ascii(ch) between ascii('a') and ascii('z') or 
            ascii(ch) between ascii('A') and ascii('Z') or
            ascii(ch) between ascii('0') and ascii('9')
        then
            return TRUE;
        end if;
        return FALSE;
    END isalphanum;
    FUNCTION rpmstrcmp (string1 IN VARCHAR2, string2 IN VARCHAR2)
    RETURN NUMBER
    IS
        digits CHAR(10) := '0123456789';
        lc_alpha CHAR(27) := 'abcdefghijklmnopqrstuvwxyz';
        uc_alpha CHAR(27) := 'ABCDEFGHIJKLMNOPQRSTUVWXYZ';
        alpha CHAR(54) := lc_alpha || uc_alpha;
        str1 VARCHAR2(32767) := string1;
        str2 VARCHAR2(32767) := string2;
        one VARCHAR2(32767);
        two VARCHAR2(32767);
        isnum BOOLEAN;
    BEGIN
        if str1 is NULL or str2 is NULL
        then
            raise VALUE_ERROR;
        end if;
        if str1 = str2
        then
            return 0;
        end if;
        one := str1;
        two := str2;
        <<segment_loop>>
        while one is not null and two is not null
        loop
            declare
                segm1 VARCHAR2(32767);
                segm2 VARCHAR2(32767);
            begin
                while one is not null and not isalphanum(one)
                loop
                    one := substr(one, 2);
                end loop;
                while two is not null and not isalphanum(two)
                loop
                    two := substr(two, 2);
                end loop;
                str1 := one;
                str2 := two;
                /* grab first completely alpha or completely numeric segment */
                /* leave one and two pointing to the start of the alpha or numeric */
                /* segment and walk str1 and str2 to end of segment */
                if str1 is not null and isdigit(str1)
                then
                    str1 := ltrim(str1, digits);
                    str2 := ltrim(str2, digits);
                    isnum := true;
                else
                    str1 := ltrim(str1, alpha);
                    str2 := ltrim(str2, alpha);
                    isnum := false;
                end if;
                if str1 is not null
                then segm1 := substr(one, 1, length(one) - length(str1));
                else segm1 := one;
                end if;
                if str2 is not null
                then segm2 := substr(two, 1, length(two) - length(str2));
                else segm2 := two;
                end if;
                /* take care of the case where the two version segments are */
                /* different types: one numeric and one alpha */
                if segm1 is null then return -1; end if; /* arbitrary */
                if segm2 is null then
					if isnum then
						return 1;
					else
						return -1;
					end if;
				end if;
                if isnum
                then
                    /* this used to be done by converting the digit segments */
                    /* to ints using atoi() - it's changed because long */
                    /* digit segments can overflow an int - this should fix that. */
                    /* throw away any leading zeros - it's a number, right? */
                    segm1 := ltrim(segm1, '0');
                    segm2 := ltrim(segm2, '0');
                    /* whichever number has more digits wins */
                    if segm1 is null and segm2 is not null
                    then
                        return -1;
                    end if;
                    if segm1 is not null and segm2 is null
                    then
                        return 1;
                    end if;
                    if length(segm1) > length(segm2) then return 1; end if;
                    if length(segm2) > length(segm1) then return -1; end if;
                end if;
                /* strcmp will return which one is greater - even if the two */
                /* segments are alpha or if they are numeric.  don't return  */
                /* if they are equal because there might be more segments to */
                /* compare */
                if segm1 < segm2 then return -1; end if;
                if segm1 > segm2 then return 1; end if;
                one := str1;
                two := str2;
            end;
        end loop segment_loop;
        /* this catches the case where all numeric and alpha segments have */
        /* compared identically but the segment sepparating characters were */
        /* different */
        if one is null and two is null then return 0; end if;
        /* whichever version still has characters left over wins */
        if one is null then return -1; end if;
        return 1;
    END rpmstrcmp;
    FUNCTION vercmp(
        e1 VARCHAR2, v1 VARCHAR2, r1 VARCHAR2, 
        e2 VARCHAR2, v2 VARCHAR2, r2 VARCHAR2)
    RETURN NUMBER
    IS
        rc NUMBER;
    BEGIN
        vercmp_counter := vercmp_counter + 1;
        if e1 is not null and e2 is null then return 1; end if;
        if e1 is null and e2 is not null then return -1; end if;
        if e1 is not null and e2 is not null
        then
            DECLARE
                ep1 NUMBER;
                ep2 NUMBER;
            BEGIN
                ep1 := TO_NUMBER(e1);
                ep2 := TO_NUMBER(e2);
                if ep1 < ep2 then return -1; end if;
                if ep1 > ep2 then return 1; end if;
            END;
        end if;
        rc := rpmstrcmp(v1, v2);
        if rc != 0 then return rc; end if;
        return rpmstrcmp(r1, r2);
    END vercmp;
    FUNCTION vercmpCounter
    RETURN NUMBER
    IS
    BEGIN
        return vercmp_counter;
    END vercmpCounter;
    FUNCTION vercmpResetCounter
    RETURN NUMBER
    IS
        result NUMBER;
    BEGIN
        result := vercmp_counter;
        vercmp_counter := 0;
        return result;
    END vercmpResetCounter;
END rpm;
/
SHOW ERRORS;

select '../rhn/class/evr_t.sql' sql_file from dual;
-- SQL relevant contents from file ../rhn/class/evr_t.sql
create or replace type evr_t AS OBJECT (
        epoch           varchar2(16),
        version         varchar2(64),
        release         varchar2(64),
        ORDER MEMBER FUNCTION compare (other_in IN evr_t)
          RETURN INTEGER,
        MEMBER FUNCTION as_vre RETURN VARCHAR2,
        MEMBER FUNCTION as_vre_simple RETURN VARCHAR2
);
/
show errors
create or replace type body evr_t
as
order member function compare (other_in IN evr_t)
  return integer
is
begin
        return rpm.vercmp(SELF.epoch, SELF.version, SELF.release,
                          other_in.epoch, other_in.version, other_in.release);
end;
member function as_vre
  return varchar2
is
begin
        return self.version || '-' || SELF.release || ':' || SELF.epoch;
end;
member function as_vre_simple
  return VARCHAR2
is
    vre_out VARCHAR2(256);
begin
    vre_out := self.version || '-' || self.release;
    if self.epoch is not null
    then
        vre_out := vre_out || ':' || self.epoch;
    end if;
    return vre_out;
end;
end;
/
show errors

select '../rhn/tables/rhnPackageEVR.sql' sql_file from dual;
-- SQL relevant contents from file ../rhn/tables/rhnPackageEVR.sql
create table
rhnPackageEVR
(
        id              number
			constraint rhn_pe_id_nn not null
                        constraint rhn_pe_id_pk primary key,
        epoch           varchar2(16),
        version         varchar2(64)
			constraint rhn_pe_version_nn not null,
        release         varchar2(64)
			constraint rhn_pe_release_nn not null,
        evr             evr_t
			constraint rhn_pe_evr_nn not null
)
	storage ( freelists 16 )
	initrans 32;
create sequence rhn_pkg_evr_seq;
create unique index rhn_pe_v_r_e_uq
	on rhnPackageEVR(version, release, epoch)
	tablespace [[2m_tbs]]
	storage ( freelists 16 )
	initrans 32;

select '../rhn/tables/rhnPackageArch.sql' sql_file from dual;
-- SQL relevant contents from file ../rhn/tables/rhnPackageArch.sql
create table
rhnPackageArch
(
	id		number
			constraint rhn_parch_id_nn not null,
	label		varchar2(16)
			constraint rhn_parch_label_nn not null,
	name		varchar2(64)
			constraint rhn_parch_name_nn not null,
	created		date default(sysdate)
			constraint rhn_parch_created_nn not null,
	modified	date default(sysdate)
			constraint rhn_parch_modified_nn not null
)
	storage ( freelists 16 )
	initrans 32;
create sequence rhn_package_arch_id_seq start with 100;
create index rhn_parch_id_l_n_idx
	on rhnPackageArch(id,label,name)
	tablespace [[2m_tbs]]
	storage ( freelists 16 )
	initrans 32;
alter table rhnPackageArch add constraint rhn_parch_id_pk primary key (id);
create index rhn_parch_l_id_n_idx
	on rhnPackageArch(label,id,name)
	tablespace [[2m_tbs]]
	storage ( freelists 16 )
	initrans 32;
alter table rhnPackageArch add constraint rhn_parch_label_uq unique ( label );
create or replace trigger
rhn_parch_mod_trig
before insert or update on rhnPackageArch
for each row
begin
        :new.modified := sysdate;
end;
/
show errors

select '../rhn/tables/rhnPackageGroup.sql' sql_file from dual;
-- SQL relevant contents from file ../rhn/tables/rhnPackageGroup.sql
create table
rhnPackageGroup
(
        id              number
			constraint rhn_package_group_id_nn not null
                        constraint rhn_package_group_id_pk primary key
                        using index tablespace [[2m_tbs]],
        name            varchar2(100)
			constraint rhn_package_group_name_nn not null,
        created         date default(sysdate)
			constraint rhn_package_group_created_nn not null,
        modified        date default(sysdate)
			constraint rhn_package_group_modified_nn not null
)
	storage ( freelists 16 )
	initrans 32;
create sequence rhn_package_group_id_seq;
create unique index rhn_package_group_name_uq
	on rhnPackageGroup(name)
	tablespace [[64k_tbs]]
	storage ( freelists 16 )
	initrans 32;
create or replace trigger
rhn_package_group_mod_trig
before insert or update on rhnPackageGroup
for each row
begin
        :new.modified := sysdate;
end;
/
show errors

select '../rhn/tables/rhnSourceRPM.sql' sql_file from dual;
-- SQL relevant contents from file ../rhn/tables/rhnSourceRPM.sql
create table
rhnSourceRPM
(
	id		number
			constraint rhn_sourceRPM_id_nn not null
			constraint rhn_sourceRPM_id_pk primary key
			using index tablespace [[64k_tbs]],
	name		varchar2(128)
			constraint rhn_sourcerpm_name_nn not null
)
	storage ( freelists 16 )
	initrans 32;
create unique index rhn_srpm_name_uq
	on rhnSourceRPM(name)
	tablespace [[64k_tbs]]
	storage ( freelists 16 )
	initrans 32;
create sequence rhn_sourcerpm_id_seq;

select '../rhn/tables/rhnPackage.sql' sql_file from dual;
-- SQL relevant contents from file ../rhn/tables/rhnPackage.sql
create table
rhnPackage
(
        id              number
			constraint rhn_package_id_nn not null
                        constraint rhn_package_id_pk primary key
				using index tablespace [[4m_tbs]]
				storage(pctincrease 1),
        org_id          number
                        constraint rhn_package_oid_fk
				references web_customer(id)
				on delete cascade,
        name_id         number
			constraint rhn_package_nid_nn not null
                        constraint rhn_package_nid_fk
				references rhnPackageName(id),
        evr_id          number
			constraint rhn_package_eid_nn not null
                        constraint rhn_package_eid_fk
				references rhnPackageEvr(id),
	package_arch_id	number
			constraint rhn_package_paid_nn not null
			constraint rhn_package_paid_fk
				references rhnPackageArch(id),
        package_group   number
			constraint rhn_package_group_nn not null
                        constraint rhn_package_group_fk
				references rhnPackageGroup(id),
        rpm_version     varchar2(16)
			constraint rhn_package_rpm_ver_nn not null,
        description     varchar2(4000),
        summary         varchar2(4000),
        package_size    number
			constraint rhn_package_pkg_size_nn not null,
        payload_size    number
			constraint rhn_package_paysize_nn not null,
        build_host      varchar2(256)
			constraint rhn_package_bh_nn not null,
        build_time      date
			constraint rhn_package_bt_nn not null,
	source_rpm_id	number
	    	    	constraint rhn_package_srcrpmid_nn not null
			constraint rhn_package_srcrpmid_fk
				references rhnSourceRPM(id),
        md5sum          varchar2(64)
			constraint rhn_package_md5_nn not null,
        vendor          varchar2(64)
			constraint rhn_package_vendor_nn not null,
        payload_format  varchar2(32)
			constraint rhn_package_pf_nn not null,
        compat          smallint default 0
			constraint rhn_package_compat_nn not null
                        constraint rhn_package_compat_check
                                check (compat in (1,0)),
        path            varchar2(1000),
	header_sig	varchar2(64),
	copyright	varchar2(64),
	cookie		varchar2(128),
	last_modified	date default (sysdate)
			constraint rhn_package_lm_nn not null,
        created         date default (sysdate)
			constraint rhn_package_created_nn not null,
        modified        date default (sysdate)
			constraint rhn_package_modified_nn not null
)
	storage( pctincrease 1 freelists 16 )
	initrans 32;
create sequence rhn_package_id_seq;
create unique index rhn_package_n_e_pa_o_uq
	on rhnPackage(name_id, evr_id, package_arch_id, org_id)
	tablespace [[2m_tbs]]
	storage( pctincrease 1 freelists 16 )
	initrans 32;
create unique index rhn_package_md5_nid_eid_oid_uq
	on rhnPackage(md5sum, name_id, evr_id, org_id)
	tablespace [[2m_tbs]]
	storage( pctincrease 1 freelists 16 )
	initrans 32;
create index rhn_package_oid_id_idx
	on rhnPackage(org_id, id)
	tablespace [[64k_tbs]]
	storage( pctincrease 1 freelists 16 )
	initrans 32
	nologging;
create index rhn_package_id_nid_paid_idx
	on rhnPackage(id,name_id, package_arch_id)
	tablespace [[2m_tbs]]
	storage( pctincrease 1 freelists 16 )
	initrans 32
	nologging;
create index rhn_package_nid_id_idx
	on rhnPackage(name_id,id)
	tablespace [[2m_tbs]]
	storage( pctincrease 1 freelists 16 )
	initrans 32
	nologging;
create or replace trigger
rhn_package_mod_trig
before insert or update on rhnPackage
for each row
begin
	if :new.last_modified = :old.last_modified then
		:new.last_modified := sysdate;
	end if;       
	:new.modified := sysdate;
end;
/
show errors

select '../rhn/tables/rhnChannelPackage.sql' sql_file from dual;
-- SQL relevant contents from file ../rhn/tables/rhnChannelPackage.sql
create table
rhnChannelPackage
(
	channel_id	number
			constraint rhn_cp_cid_nn not null 
			constraint rhn_cp_cid_fk
				references rhnChannel(id) on delete cascade,
	package_id	number
			constraint rhn_cp_pid_nn not null
			constraint rhn_cp_pid_fk
				references rhnPackage(id),
	created		date default (sysdate)
			constraint rhn_cp_created_nn not null,
	modified	date default (sysdate)
			constraint rhn_cp_modified_nn not null
)
	storage ( freelists 16 )
	initrans 32;
create unique index rhn_cp_cp_uq
	on rhnChannelPackage(channel_id,package_id)
	tablespace [[64k_tbs]]
	storage ( freelists 16 )
	initrans 32;
create index rhn_cp_pc_idx 
       on rhnChannelPackage(package_id, channel_id)
       tablespace [[64k_tbs]]
       storage ( freelists 16 )
       initrans 32
       nologging;

select '../rhn/packages/rhn_package.pks' sql_file from dual;
-- SQL relevant contents from file ../rhn/packages/rhn_package.pks
CREATE OR REPLACE
PACKAGE rhn_package
IS
    CURSOR channel_occupancy_cursor(package_id_in IN NUMBER) IS
    SELECT C.id channel_id, C.name channel_name
      FROM rhnChannel C,
      	   rhnChannelPackage CP
     WHERE C.id = CP.channel_id
       AND CP.package_id = package_id_in
     ORDER BY C.name DESC;
    FUNCTION canonical_name(name_in IN VARCHAR2, evr_in IN EVR_T, 
    	                    arch_in IN VARCHAR2 := NULL)
      RETURN VARCHAR2;
    FUNCTION channel_occupancy_string(package_id_in IN NUMBER, separator_in VARCHAR2 := ', ') 
      RETURN VARCHAR2;
END rhn_package;
/
SHOW ERRORS

select '../rhn/packages/rhn_qos.pks' sql_file from dual;
-- SQL relevant contents from file ../rhn/packages/rhn_qos.pks
create or replace package rhn_qos is
	function slot_count(org_id_in in number, label_in in varchar2) return number;
	function basic_slot_count(org_id_in in number) return number;
	function workgroup_slot_count(org_id_in in number) return number;
	function channel_slot_count(org_id_in in number, label_in in number) return number;
	function as_slot_count(org_id_in in number) return number;
end rhn_qos;
/
show errors

select '../rhn/packages/rhn_quota.pks' sql_file from dual;
-- SQL relevant contents from file ../rhn/packages/rhn_quota.pks
create or replace package
rhn_quota
is
	function recompute_org_quota_used (
		org_id_in in number
	) return number;
	function get_org_for_config_content (
		config_content_id_in in number
	) return number;
	procedure set_org_quota_total (
		org_id_in in number,
		total_in in number
	);
	procedure update_org_quota (
		org_id_in in number
	);
end rhn_quota;
/
show errors

select '../rhn/packages/rhn_server.pks' sql_file from dual;
-- SQL relevant contents from file ../rhn/packages/rhn_server.pks
create or replace
package rhn_server
is
    function system_service_level(
    	server_id_in in number,
	service_level_in in varchar2
    ) return number;	    
    function can_change_base_channel(
    	server_id_in in number
    ) return number;
    procedure set_custom_value(
    	server_id_in in number,
	user_id_in in number,
	key_label_in varchar2,
     	value_in in varchar2
    );
    procedure bulk_set_custom_value(
    	key_label_in in varchar2,
	value_in in varchar2,
	set_label_in in varchar2,
	set_uid_in in number
    );
    procedure snapshot_server(
    	server_id_in in number,
	reason_in in varchar2
    );
    procedure bulk_snapshot(
    	reason_in in varchar2,
    	set_label_in in varchar2,
	set_uid_in in number
    );
    procedure tag_snapshot(
    	snapshot_id_in in number,
	org_id_in in number,
    	tagname_in in varchar2
    );
    procedure bulk_snapshot_tag(
    	org_id_in in number,
    	tagname_in varchar2,
	set_label_in in varchar2,
	set_uid_in in number
    );
    procedure remove_action(
	server_id_in in number,
	action_id_in in number
    );
    function check_user_access(server_id_in in number, user_id_in in number) return number;
    procedure insert_into_servergroup (
	server_id_in in number,
	server_group_id_in in number
    );
    function insert_into_servergroup_maybe (
	server_id_in in number,
	server_group_id_in in number
    ) return number;
	procedure insert_set_into_servergroup (
	server_group_id_in in number,
	user_id_in in number,
	set_label_in in varchar2
	);
    procedure delete_from_servergroup (
	server_id_in in number,
	server_group_id_in in number
    );
	procedure delete_set_from_servergroup (
	server_group_id_in in number,
	user_id_in in number,
	set_label_in in number
	);
	procedure clear_servergroup (
	server_group_id_in in number
	);
	procedure delete_from_org_servergroups (
	server_id_in in number
	);
end rhn_server;
/
SHOW ERRORS

select '../rhn/tables/rhnSet.sql' sql_file from dual;
-- SQL relevant contents from file ../rhn/tables/rhnSet.sql
create table
rhnSet
(
	user_id		number
			constraint rhn_set_user_nn not null
			constraint rhn_set_user_fk
				   references web_contact(id)
				   on delete cascade,
	label		varchar2(32)
			constraint rhn_set_label_nn not null,
	element		number
			constraint rhn_set_elem_nn not null,
	element_two	number,
	constraint	rhn_set_user_label_elem_unq
		UNIQUE(user_id, label, element, element_two)
		using index tablespace [[8m_tbs]]
)
	storage ( freelists 16 )
	initrans 32;
alter table rhnSet nologging;

select '../rhn/packages/rhn_set.pks' sql_file from dual;
-- SQL relevant contents from file ../rhn/packages/rhn_set.pks
CREATE OR REPLACE
PACKAGE rhn_set
IS
    CURSOR set_iterator(set_label_in IN VARCHAR2, set_user_id_in IN NUMBER) IS
    	   SELECT user_id, label, element, element_two
	     FROM rhnSet
	    WHERE label = set_label_in
	      AND user_id = set_user_id_in;
END rhn_set;
/
SHOW ERRORS

select '../rhn/packages/rhn_user.pks' sql_file from dual;
-- SQL relevant contents from file ../rhn/packages/rhn_user.pks
create or replace
package rhn_user
is
    function check_role(user_id_in in number, role_in in varchar2) return number;
    PRAGMA RESTRICT_REFERENCES(check_role, WNDS, RNPS, WNPS);
    function check_role_implied(user_id_in in number, role_in in varchar2) return number;
    PRAGMA RESTRICT_REFERENCES(check_role_implied, WNDS, RNPS, WNPS);
    function get_org_id(user_id_in in number) return number;
    PRAGMA RESTRICT_REFERENCES(get_org_id, WNDS, RNPS, WNPS);
end rhn_user;
/
SHOW ERRORS

select '../rhn/synonyms/rhnUser.satellite.sql' sql_file from dual;
-- SQL relevant contents from file ../rhn/synonyms/rhnUser.satellite.sql
create synonym rhnUser for web_contact;

select '../rhn/types/channel_name_t.sql' sql_file from dual;
-- SQL relevant contents from file ../rhn/types/channel_name_t.sql
create or replace type channel_name_t as table of varchar(64)
/

select '../rhn/types/user_group_id_t.sql' sql_file from dual;
-- SQL relevant contents from file ../rhn/types/user_group_id_t.sql
create or replace type user_group_id_t as table of NUMBER
/

select '../rhn/types/user_group_label_t.sql' sql_file from dual;
-- SQL relevant contents from file ../rhn/types/user_group_label_t.sql
create or replace type user_group_label_t as table of varchar(64)
/

select '../rhn/types/user_group_name_t.sql' sql_file from dual;
-- SQL relevant contents from file ../rhn/types/user_group_name_t.sql
create or replace type user_group_name_t as table of varchar(64)
/

select '../rhn/tables/PXTSessions.sql' sql_file from dual;
-- SQL relevant contents from file ../rhn/tables/PXTSessions.sql
create table PXTSessions (
        id              number,
        web_user_id     number
                        constraint pxtsessions_user
	                        references web_contact(id) on delete cascade,
        expires         number default 0
                        constraint pxtsessions_expires_nn not null,
        value           varchar2(4000)
                        constraint pxtsessions_value_nn not null
)
	organization heap
	storage	( freelists 16 )
	initrans	32
	nocache nomonitoring nologging;
create unique index pxt_sessions_pk
	on PXTSessions(id)
	tablespace [[8m_tbs]]
	storage ( freelists 16 )
	initrans 32
	nologging;
alter table PXTSessions add constraint pxt_sessions_pk
	primary key (id);
create sequence pxt_id_seq;
create index PXTSessions_user
	on PXTSessions(web_user_id) 
	tablespace [[4m_tbs]]
	storage ( freelists 16 )
	initrans 32
	nologging;
create index PXTSessions_expires
	on PXTSessions(expires)
	tablespace [[8m_tbs]]
	storage ( freelists 16 )
	initrans 32
	nologging;

select '../rhn/tables/rhnActionType.sql' sql_file from dual;
-- SQL relevant contents from file ../rhn/tables/rhnActionType.sql
create table
rhnActionType
(
	id			number
				constraint rhn_action_type_id_nn not null
				constraint rhn_action_type_pk primary key
					using index tablespace [[64k_tbs]],
	label			varchar2(48)
				constraint rhn_action_type_label_nn not null,
	name			varchar2(96)
				constraint rhn_action_type_name_nn not null,
	trigger_snapshot	char(1) default('N')
				constraint rhn_action_type_trigsnap_nn not null
				constraint rhn_action_type_trigsnap_ck
					check (trigger_snapshot in ('Y','N')),
	unlocked_only   	char(1) default('N')
				constraint rhn_action_type_unlck_nn not null
				constraint rhn_action_type_unlck_ck
					check (unlocked_only in ('Y','N'))
)
	storage ( freelists 16 )
	initrans 32;
create unique index rhn_action_type_label_uq
	on rhnActionType(label)
	tablespace [[64k_tbs]]
	storage ( freelists 16 )
	initrans 32;
create unique index rhn_action_type_name_uq
	on rhnActionType(name)
	tablespace [[64k_tbs]]
	storage ( freelists 16 )
	initrans 32;

select '../rhn/tables/rhnAction.sql' sql_file from dual;
-- SQL relevant contents from file ../rhn/tables/rhnAction.sql
create table
rhnAction
(
	id		number
			constraint rhn_action_id_nn not null
			constraint rhn_action_pk primary key
			using index tablespace [[4m_tbs]],
	org_id		number
			constraint rhn_action_oid_nn not null
			constraint rhn_action_oid_fk
				references web_customer(id)
				on delete cascade,
	action_type	number
			constraint rhn_action_at_nn not null
			constraint rhn_action_at_fk
				references rhnActionType(id),
	name            varchar2(128),
	scheduler	number
			constraint rhn_action_scheduler_fk
				references web_contact(id)
				on delete set null,
	earliest_action	date 
			constraint rhn_action_ea_nn not null,
	version		number default 0
			constraint rhn_action_version_nn not null,
	archived        number default 0
	    	    	constraint rhn_action_archived_nn not null
			constraint rhn_action_archived_ck
				check (archived in (0, 1)),
        prerequisite    number
                        constraint rhn_action_prereq_fk
                                references rhnAction(id) on delete cascade,
	created		date default (sysdate) 
			constraint rhn_action_created_nn not null,
	modified	date default (sysdate)
			constraint rhn_action_modified_nn not null
)
	storage ( freelists 16 )
	initrans 32;
create sequence rhn_event_id_seq;
create index rhn_action_oid_idx
	on rhnAction(org_id)
	tablespace [[8m_tbs]]
	storage ( freelists 16 )
	initrans 32
	nologging;
create index rhn_action_scheduler_idx
	on rhnAction(scheduler)
	tablespace [[8m_tbs]]
	storage ( freelists 16 )
	initrans 32
	nologging;
create index rhn_action_prereq_id_idx
        on rhnAction(prerequisite, id)
	tablespace [[8m_tbs]]
	storage ( freelists 16 )
	initrans 32
	nologging;
create or replace trigger
rhn_action_mod_trig
before insert or update on rhnAction
for each row
begin
        :new.modified := sysdate;
end;
/
show errors

select '../rhn/tables/rhnActionStatus.sql' sql_file from dual;
-- SQL relevant contents from file ../rhn/tables/rhnActionStatus.sql
create table
rhnActionStatus
(
	id		number
			constraint rhn_action_status_id_nn not null
			constraint rhn_action_status_pk primary key
				using index tablespace [[64k_tbs]],
	name		varchar(16),
	created		date default (sysdate)
			constraint rhn_action_status_created_nn not null,
	modified	date default (sysdate)
			constraint rhn_action_status_modified_nn not null
)
	storage ( freelists 16 )
	initrans 32;

select '../rhn/tables/rhnServerAction.sql' sql_file from dual;
-- SQL relevant contents from file ../rhn/tables/rhnServerAction.sql
create table
rhnServerAction
(
        server_id       number
			constraint rhn_server_action_sid_nn not null
                        constraint rhn_server_action_sid_fk
                        references rhnServer(id) on delete cascade,
        action_id       number
			constraint rhn_server_action_aid_nn not null
                        constraint rhn_server_action_aid_fk
                        references rhnAction(id) on delete cascade,
        status          number
			constraint rhn_server_action_status_nn not null
                        constraint rhn_server_action_status_fk
                        references rhnActionStatus(id),
        result_code     number,
        result_msg      varchar(1024),
        pickup_time     date,
	remaining_tries	number default(5)
			constraint rhn_server_action_remaining_nn not null,
        completion_time	date,
        created         date default (sysdate)
			constraint rhn_server_action_created_nn not null,
        modified        date default (sysdate)
			constraint rhn_server_action_modified_nn not null
)
	storage( freelists 16 )
	initrans 32;
create index rhn_server_action_sid_aid_idx
	on rhnServerAction(server_id, action_id)
	tablespace [[8m_tbs]]
	storage( freelists 16 )
	initrans 32;
alter table rhnServerAction
	add constraint rhn_server_action_sid_aid_uq
	unique ( server_id, action_id );
create index rhn_server_action_aid_sid_idx
	on rhnServerAction(action_id, server_id)
	tablespace [[8m_tbs]]
	storage( freelists 16 )
	initrans 32
	nologging;
create or replace trigger
rhn_server_action_mod_trig
before insert or update on rhnServerAction
for each row
declare
	handle_status	number;
begin
	:new.modified := sysdate;
	handle_status := 0;
	if updating then
		if :new.status != :old.status then
			handle_status := 1;
		end if;
	else
		handle_status := 1;
	end if;
	if handle_status = 1 then
		if :new.status = 1 then
			:new.pickup_time := sysdate;
		elsif :new.status = 2 then
			:new.completion_time := sysdate;
		end if;
	end if;
end;
/
show errors

select '../rhn/tables/rhnConfigChannelType.sql' sql_file from dual;
-- SQL relevant contents from file ../rhn/tables/rhnConfigChannelType.sql
create sequence rhn_confchantype_id_seq;
create table
rhnConfigChannelType
(
	id		number
			constraint rhn_confchantype_id_nn not null
			constraint rhn_confchantype_id_pk primary key
				using index tablespace [[64k_tbs]],
	label		varchar2(64)
			constraint rhn_confchantype_label_nn not null,
	name		varchar2(64)
			constraint rhn_confchantype_name_nn not null,
        priority        number default(0)
	                constraint rhn_confchantype_pri_nn not null,
	created		date default(sysdate)
			constraint rhn_confchantype_creat_nn not null,
	modified	date default(sysdate)
			constraint rhn_confchantype_mod_nn not null
)
	storage ( freelists 16 )
	initrans 32;
create index rhn_confchantype_label_id_idx
	on rhnConfigChannelType( label, id )
	tablespace [[64k_tbs]]
	storage ( freelists 16 )
	initrans 32;
alter table rhnConfigChannelType add constraint rhn_confchantype_label_uq
	unique ( label );
create or replace trigger
rhn_confchantype_mod_trig
before insert or update on rhnConfigChannelType
for each row
begin
	:new.modified := sysdate;
end;
/
show errors

select '../rhn/tables/rhnConfigChannel.sql' sql_file from dual;
-- SQL relevant contents from file ../rhn/tables/rhnConfigChannel.sql
create sequence rhn_confchan_id_seq;
create table
rhnConfigChannel
(
	id			number
				constraint rhn_confchan_id_nn not null
				constraint rhn_confchan_id_pk primary key
					using index tablespace [[2m_tbs]],
	org_id			number
				constraint rhn_confchan_oid_nn not null
				constraint rhn_confchan_oid_fk
					references web_customer(id),
	confchan_type_id	number
				constraint rhn_confchan_ctid_nn not null
				constraint rhn_confchan_ctid_fk
					references rhnConfigChannelType(id),
	name			varchar2(128)
				constraint rhn_confchan_name_nn not null,
	label			varchar2(64)
				constraint rhn_confchan_label_nn not null,
	description		varchar2(1024)
				constraint rhn_confchan_desc_nn not null,
	created			date default(sysdate)
				constraint rhn_confchan_creat_nn not null,
	modified		date default(sysdate)
				constraint rhn_confchan_mod_nn not null
)
	storage ( freelists 16 )
	initrans 32;
create unique index rhn_confchan_oid_label_uq
	on rhnConfigChannel( org_id, label )
	tablespace [[4m_tbs]]
	storage ( freelists 16 )
	initrans 32;

select '../rhn/tables/rhnActionConfigChannel.sql' sql_file from dual;
-- SQL relevant contents from file ../rhn/tables/rhnActionConfigChannel.sql
create table
rhnActionConfigChannel
(
	action_id		number
				constraint rhn_actioncc_aid_nn not null
				constraint rhn_actioncc_aid_fk
					references rhnAction(id),
	server_id		number
				constraint rhn_actioncc_sid_nn not null
				constraint rhn_actioncc_sid_fk
					references rhnServer(id),
        config_channel_id       number
				constraint rhn_actioncc_ccid_nn not null
				constraint rhn_actioncc_ccid_fk
					references rhnConfigChannel(id)
						on delete cascade,
	created			date default(sysdate)
				constraint rhn_actioncc_creat_nn not null,
	modified		date default(sysdate)
				constraint rhn_actioncc_mod_nn not null
)
	storage ( freelists 16 )
	initrans 32;
alter table rhnActionConfigChannel 
	add constraint rhn_actioncc_sid_aid_fk
	foreign key (server_id, action_id) references
	    rhnServerAction(server_id, action_id) on delete cascade;
create unique index rhn_actioncc_aid_sid_uq
	on rhnActionConfigChannel ( action_id, server_id )
	tablespace [[4m_tbs]]
	storage ( freelists 16 )
	initrans 32;
create index rhn_actioncc_sid_aid_ccid_idx
	on rhnActionConfigChannel ( server_id, action_id, config_channel_id )
	tablespace [[4m_tbs]]
	storage ( freelists 16 )
	initrans 32;
create or replace trigger
rhn_actioncc_mod_trig
before insert or update on rhnActionConfigChannel
for each row
begin
	:new.modified := sysdate;
end;
/
show errors

select '../rhn/tables/rhnActionConfigDateFile.sql' sql_file from dual;
-- SQL relevant contents from file ../rhn/tables/rhnActionConfigDateFile.sql
create table
rhnActionConfigDateFile
(
	action_id		number
				constraint rhn_actioncd_file_aid_nn not null
				constraint rhn_actioncd_file_aid_fk
					references rhnAction(id)
					on delete cascade,
	file_name		varchar2(512)
				constraint rhn_actioncd_file_fn_nn not null,
	file_type		char(1)
				constraint rhn_actioncd_file_ft_nn not null
				constraint rhn_actioncd_file_ft_ck
					check (file_type in ('W','B')),
	created			date default(sysdate)
				constraint rhn_actioncd_file_creat_nn not null,
	modified		date default(sysdate)
				constraint rhn_actioncd_file_mod_nn not null
)
	storage ( freelists 16 )
	initrans 32;
create index rhn_actioncd_file_aid_fn_idx
	on rhnActionConfigDateFile(action_id, file_name)
	tablespace [[4m_tbs]]
	storage ( freelists 16 )
	initrans 32;
create or replace trigger
rhn_actioncd_file_mod_trig
before insert or update on rhnActionConfigDateFile
for each row
begin
	:new.modified := sysdate;
end;
/
show errors

select '../rhn/tables/rhnActionConfigDate.sql' sql_file from dual;
-- SQL relevant contents from file ../rhn/tables/rhnActionConfigDate.sql
create table
rhnActionConfigDate
(
	action_id		number
				constraint rhn_actioncd_aid_nn not null
				constraint rhn_actioncd_aid_fk
					references rhnAction(id),
	start_date		date
				constraint rhn_actioncd_start_nn not null,
	end_date		date,
	import_contents		char(1)
				constraint rhn_actioncd_file_ic_nn not null
				constraint rhn_actioncd_file_ic_ck
					check (import_contents in ('Y','N')),
	created			date default(sysdate)
				constraint rhn_actioncd_creat_nn not null,
	modified		date default(sysdate)
				constraint rhn_actioncd_mod_nn not null
)
	storage ( freelists 16 )
	initrans 32;
create unique index rhn_actioncd_aid_uq
	on rhnActionConfigDate( action_id )
	tablespace [[2m_tbs]]
	storage ( freelists 16 )
	initrans 32;
create or replace trigger
rhn_actioncd_mod_trig
before insert or update on rhnActionConfigDate
for each row
begin
	:new.modified := sysdate;
end;
/
show errors

select '../rhn/tables/rhnConfigFileName.sql' sql_file from dual;
-- SQL relevant contents from file ../rhn/tables/rhnConfigFileName.sql
create sequence rhn_cfname_id_seq;
create table
rhnConfigFileName
(
	id		number
			constraint rhn_cfname_id_nn not null,
	path		varchar2(1024)
			constraint rhn_cfname_path_nn not null,
	created		date default(sysdate)
			constraint rhn_cfname_created_nn not null,
	modified	date default(sysdate)
			constraint rhn_cfname_modified_nn not null
)
	storage ( freelists 16 )
	initrans 32;
create index rhn_cfname_id_pk
	on rhnConfigFileName ( id )
	tablespace [[2m_tbs]]
	storage ( freelists 16 )
	initrans 32;
alter table rhnConfigFileName add constraint
	rhn_cfname_id_pk primary key ( id );
create unique index rhn_cfname_path_uq
	on rhnConfigFileName ( path )
	tablespace [[4m_tbs]]
	storage ( freelists 16 )
	initrans 32;
create or replace trigger
rhn_cfname_mod_trig
before insert or update on rhnConfigFileName
for each row
begin
	:new.modified := sysdate;
end;
/

select '../rhn/tables/rhnConfigFileFailure.sql' sql_file from dual;
-- SQL relevant contents from file ../rhn/tables/rhnConfigFileFailure.sql
create sequence rhn_conffile_failure_id_seq;
create table
rhnConfigFileFailure
(
	id			number
				constraint rhn_conffile_fail_id_nn not null
				constraint rhn_conffile_fail_id_pk 
					primary key 
					using index tablespace [[64k_tbs]],
	label			varchar2(64)
				constraint rhn_conffile_fail_label_nn not null
				constraint rhn_conffile_fail_label_uq unique
					using index tablespace [[64k_tbs]],
	name			varchar2(256)
				constraint rhn_conffile_fail_name_nn not null
				constraint rhn_conffile_fail_name_uq unique
					using index tablespace [[64k_tbs]],
	created			date default(sysdate)
				constraint rhn_conffile_fail_creat_nn not null,
	modified		date default(sysdate)
				constraint rhn_conffile_fail_mod_nn not null
)
	storage ( freelists 16 )
	initrans 32;
create or replace trigger
rhn_conffile_fail_mod_trig
before insert or update on rhnConfigFileFailure
for each row
begin
	:new.modified := sysdate;
end;
/
show errors

select '../rhn/tables/rhnConfigFileState.sql' sql_file from dual;
-- SQL relevant contents from file ../rhn/tables/rhnConfigFileState.sql
create sequence rhn_cfstate_id_seq;
create table
rhnConfigFileState
(
	id		number
			constraint rhn_cfstate_id_nn not null
			constraint rhn_cfstate_id_pk primary key
				using index tablespace [[2m_tbs]],
	label		varchar2(32)
			constraint rhn_cfstate_label_nn not null,
	name		varchar2(256)
			constraint rhn_cfstate_name_nn not null,
	created		date default(sysdate)
			constraint rhn_cfstate_creat_nn not null,
	modified	date default(sysdate)
			constraint rhn_cfstate_mod_nn not null
)
	storage ( freelists 16 )
	initrans 32;
create unique index rhn_cfstate_label_id_uq
	on rhnConfigFileState( label, id )
	tablespace [[4m_tbs]]
	storage ( freelists 16 )
	initrans 32;
create or replace trigger
rhn_cfstate_mod_trig
before insert or update on rhnConfigFileState
for each row
begin
	:new.modified := sysdate;
end;
/
show errors

select '../rhn/tables/rhnConfigFile.sql' sql_file from dual;
-- SQL relevant contents from file ../rhn/tables/rhnConfigFile.sql
create sequence rhn_conffile_id_seq;
create table rhnConfigFile
(
	id			number
				constraint rhn_conffile_id_nn not null
				constraint rhn_conffile_id_pk primary key
					using index tablespace [[2m_tbs]],
	config_channel_id	number
				constraint rhn_conffile_ccid_nn not null
				constraint rhn_conffile_ccid_fk
					references rhnConfigChannel(id),
	config_file_name_id	number
				constraint rhn_conffile_cfnid_nn not null
				constraint rhn_conffile_cfnid_fk
					references rhnConfigFileName(id),
	latest_config_revision_id number
				,
	state_id		number
				constraint rhn_conffile_sid_nn not null
				constraint rhn_conffile_sid_fk
					references rhnConfigFileState(id),
	created			date default(sysdate)
				constraint rhn_conffile_creat_nn not null,
	modified		date default(sysdate)
				constraint rhn_conffile_mod_nn not null
)
	storage ( freelists 16 )
	initrans 32;
create index rhn_conffile_cc_cfn_s_idx
	on rhnConfigFile( config_channel_id, config_file_name_id, state_id )
	tablespace [[8m_tbs]]
	storage ( freelists 16 )
	initrans 32;
alter table rhnConfigFile add constraint rhn_conffile_ccid_cfnid_uq
	unique ( config_channel_id, config_file_name_id );
create or replace trigger
rhn_conffile_mod_trig
before insert or update on rhnConfigFile
for each row
begin
	:new.modified := sysdate;
end;
/
show errors

select '../rhn/tables/rhnConfigInfo.sql' sql_file from dual;
-- SQL relevant contents from file ../rhn/tables/rhnConfigInfo.sql
create sequence rhn_confinfo_id_seq;
create table
rhnConfigInfo
(
	id			number
				constraint rhn_confinfo_id_nn not null
				constraint rhn_confinfo_id_pk primary key
					using index tablespace [[2m_tbs]],
	username		varchar2(32)
				constraint rhn_confinfo_username_nn not null,
	groupname		varchar2(32)
				constraint rhn_confinfo_groupname_nn not null,
	filemode		number
				constraint rhn_confinfo_filemode_nn not null,
	created			date default(sysdate)
				constraint rhn_confinfo_creat_nn not null,
	modified		date default(sysdate)
				constraint rhn_confinfo_mod_nn not null
)
	storage ( freelists 16 )
	initrans 32;
create unique index rhn_confinfo_ugf_uq
	on rhnConfigInfo( username, groupname, filemode )
	tablespace [[4m_tbs]]
	storage ( freelists 16 )
	initrans 32;
create or replace trigger
rhn_confinfo_mod_trig
before insert or update on rhnConfigInfo
for each row
begin
	:new.modified := sysdate;
end;
/
show errors

select '../rhn/tables/rhnConfigContent.sql' sql_file from dual;
-- SQL relevant contents from file ../rhn/tables/rhnConfigContent.sql
create sequence rhn_confcontent_id_seq;
create table
rhnConfigContent
(
	id			number
				constraint rhn_confcontent_id_nn not null
				constraint rhn_confcontent_id_pk primary key
					using index tablespace [[2m_tbs]],
	contents		blob,
	file_size		number,
	md5sum			varchar2(64)
				constraint rhn_confcontent_md5_nn not null,
	is_binary	        char(1) default('N')
				constraint rhn_confcontent_isbin_nn not null
				constraint rhn_confcontent_isbin_ck
					check (is_binary in ('Y','N')),
	created			date default(sysdate)
				constraint rhn_confcontent_creat_nn not null,
	modified		date default(sysdate)
				constraint rhn_confcontent_mod_nn not null
)
	tablespace [[blob]]
	storage ( freelists 16 )
	initrans 32;
create index rhn_confcontent_md5_uq
	on rhnConfigContent( md5sum )
	tablespace [[2m_tbs]]
	storage ( freelists 16 )
	initrans 32;
create or replace trigger
rhn_confcontent_mod_trig
before insert or update on rhnConfigContent
for each row
begin
	:new.modified := sysdate;
end;
/
show errors

select '../rhn/tables/rhnConfigRevision.sql' sql_file from dual;
-- SQL relevant contents from file ../rhn/tables/rhnConfigRevision.sql
create sequence rhn_confrevision_id_seq;
create table
rhnConfigRevision
(
	id			number
				constraint rhn_confrevision_id_nn not null
				constraint rhn_confrevision_id_pk primary key
					using index tablespace [[4m_tbs]],
	revision		number
				constraint rhn_confrevision_rev_nn not null,
	config_file_id		number
				constraint rhn_confrevision_cfid_nn not null
				constraint rhn_confrevision_cfid_fk
					references rhnConfigFile(id),
	config_content_id	number
				constraint rhn_confrevision_ccid_nn not null
				constraint rhn_confrevision_ccid_fk
					references rhnConfigContent(id),
	config_info_id		number
				constraint rhn_confrevision_ciid_nn not null
				constraint rhn_confrevision_ciid_fk
					references rhnConfigInfo(id),
	delim_start		varchar2(16)
				constraint rhn_confrevision_dstart_nn not null,
	delim_end		varchar2(16)
				constraint rhn_confrevision_dend_nn not null,
	created			date default(sysdate)
				constraint rhn_confrevision_creat_nn not null,
	modified		date default(sysdate)
				constraint rhn_confrevision_mod_nn not null
)
	storage ( freelists 16 )
	initrans 32;
create unique index rhn_confrevision_cfid_rev_uq
	on rhnConfigRevision( config_file_id, revision )
	tablespace [[2m_tbs]]
	storage ( freelists 16 )
	initrans 32;

select '../rhn/tables/rhnActionConfigFileName.sql' sql_file from dual;
-- SQL relevant contents from file ../rhn/tables/rhnActionConfigFileName.sql
create table
rhnActionConfigFileName
(
	action_id		number
				constraint rhn_actioncf_name_aid_nn not null,
	server_id		number
				constraint rhn_actioncf_name_sid_nn not null,
	config_file_name_id	number
				constraint rhn_actioncf_name_cfnid_nn not null
				constraint rhn_actioncf_name_cfnid_fk
					references rhnConfigFileName(id),
	config_revision_id	number
				constraint rhn_actioncf_name_crid_fk
					references rhnConfigRevision(id)
					on delete set null,
	failure_id		number
				constraint rhn_actioncf_failure_id_fk
					references rhnConfigFileFailure(id),
	created			date default(sysdate)
				constraint rhn_actioncf_creat_nn not null,
	modified		date default(sysdate)
				constraint rhn_actioncf_mod_nn not null
)
	storage ( freelists 16 )
	initrans 32;
alter table rhnActionConfigFileName
	add constraint rhn_actioncf_name_aid_sid_fk
	foreign key ( server_id, action_id )
	references rhnServerAction( server_id, action_id )
	on delete cascade;
create unique index rhn_actioncf_name_asc_uq
	on rhnActionConfigFileName ( action_id, server_id, config_file_name_id )
	tablespace [[2m_tbs]]
	storage ( freelists 16 )
	initrans 32;
create or replace trigger
rhn_actioncf_name_mod_trig
before insert or update on rhnActionConfigFileName
for each row
begin
	:new.modified := sysdate;
end;
/
show errors

select '../rhn/tables/rhnActionConfigRevision.sql' sql_file from dual;
-- SQL relevant contents from file ../rhn/tables/rhnActionConfigRevision.sql
create sequence rhn_actioncr_id_seq;
create table
rhnActionConfigRevision
(
	id			number
				constraint rhn_actioncr_id_nn not null
				constraint rhn_actioncr_id_pk primary key
					using index tablespace [[2m_tbs]],
	action_id		number
				constraint rhn_actioncr_aid_nn not null
				constraint rhn_actioncr_aid_fk
					references rhnAction(id)
					on delete cascade,
	server_id		number
				constraint rhn_actioncr_sid_nn not null
				constraint rhn_actioncr_sid_fk
					references rhnServer(id)
					on delete cascade,
	config_revision_id	number
				constraint rhn_actioncr_crid_nn not null
				constraint rhn_actioncr_crid_fk
					references rhnConfigRevision(id)
					on delete cascade,
        failure_id              number
				constraint rhn_actioncr_failid_fk
					references rhnConfigFileFailure(id),
	created			date default(sysdate)
				constraint rhn_actioncr_creat_nn not null,
	modified		date default(sysdate)
				constraint rhn_actioncr_mod_nn not null
)
	storage ( freelists 16 )
	initrans 32;
create unique index rhn_actioncr_aid_sid_crid_uq
	on rhnActionConfigRevision( action_id, server_id, config_revision_id )
	tablespace [[4m_tbs]]
	storage ( freelists 16 )
	initrans 32;
create index rhn_actioncr_sid_aid_idx
	on rhnActionConfigRevision( server_id, action_id )
	tablespace [[2m_tbs]]
	storage ( freelists 16 )
	initrans 32;
create or replace trigger
rhn_actioncr_mod_trig
before insert or update on rhnActionConfigRevision
for each row
begin
	:new.modified := sysdate;
end;
/
show errors

select '../rhn/tables/rhnActionConfigRevisionResult.sql' sql_file from dual;
-- SQL relevant contents from file ../rhn/tables/rhnActionConfigRevisionResult.sql
create table rhnActionConfigRevisionResult
(
	action_config_revision_id number
				constraint rhn_actioncfr_acrid_nn not null
				constraint rhn_actioncfr_acrid_fk
					references rhnActionConfigRevision(id)
					on delete cascade,
	result			blob,
	created			date default(sysdate)
				constraint rhn_actioncfr_creat_nn not null,
	modified		date default(sysdate)
				constraint rhn_actioncfr_mod_nn not null
)
	storage ( freelists 16 )
	initrans 32;
create unique index rhn_actioncfr_acrid_uq
	on rhnActionConfigRevisionResult( action_config_revision_id )
	tablespace [[2m_tbs]]
	storage ( freelists 16 )
	initrans 32;
create or replace trigger
rhn_actioncfr_mod_trig
before insert or update on rhnActionConfigRevisionResult
for each row
begin
	:new.modified := sysdate;
end;
/
show errors

select '../rhn/tables/rhnErrata.sql' sql_file from dual;
-- SQL relevant contents from file ../rhn/tables/rhnErrata.sql
create table
rhnErrata
(
        id              number
			constraint rhn_errata_id_nn not null
                        constraint rhn_errata_id_pk primary key
                        using index tablespace [[64k_tbs]],
        advisory        varchar2(32) -- advisory code
			constraint rhn_errata_advisory_nn not null,
        advisory_type   varchar2(32) -- plain text type of advisory
			constraint rhn_errata_adv_type_nn not null
			constraint rhn_errata_adv_type_ck
			           check (advisory_type in ('Bug Fix Advisory',
				                            'Product Enhancement Advisory',
							    'Security Advisory')),
      	advisory_name	varchar2(32)  -- advisory name and version
			constraint rhn_errata_advisory_name_nn not null,
	advisory_rel	number
			constraint rhn_errata_advisory_rel_nn not null,
        product         varchar2(64)
                        constraint rhn_errata_product_nn not null,
        description     varchar2(4000), -- description
        synopsis        varchar2(4000) -- Short description
                        constraint rhn_errata_synopsis_nn not null,
        topic           varchar2(4000), -- Problem description
        solution        varchar2(4000) -- how to resolve it
                        constraint rhn_errata_solution_nn not null,
        issue_date      date default (sysdate)
			constraint rhn_errata_issue_nn not null,
        update_date     date default (sysdate)
			constraint rhn_errata_update_nn not null,
        refers_to	varchar2(4000),
        notes           varchar2(4000),
        org_id          number
                        constraint rhn_errata_oid_fk
                                references web_customer(id)
				on delete cascade,
       locally_modified char(1)
			constraint rhn_errata_lm_ck check
				(locally_modified in ('Y','N')),
        created         date default (sysdate)
			constraint rhn_errata_created_nn not null,
        modified        date default (sysdate)
			constraint rhn_errata_modified_nn not null
)
	storage ( freelists 16 )
	initrans 32;
create sequence rhn_errata_id_seq;
create unique index rhn_errata_advisory_uq
	on rhnErrata(advisory)
	tablespace [[64k_tbs]]
	storage ( freelists 16 )
	initrans 32;
create unique index rhn_errata_advisory_name_uq
	on rhnErrata(advisory_name)
	tablespace [[64k_tbs]]
	storage ( freelists 16 )
	initrans 32;
create or replace trigger
rhn_errata_mod_trig
before insert or update on rhnErrata
for each row
begin
        :new.modified := sysdate;
end;
/
show errors

select '../rhn/tables/rhnActionErrataUpdate.sql' sql_file from dual;
-- SQL relevant contents from file ../rhn/tables/rhnActionErrataUpdate.sql
create table
rhnActionErrataUpdate
(
	action_id       number
			constraint rhn_act_eu_act_nn not null
			constraint rhn_act_eu_act_fk 
				references rhnAction(id)
				on delete cascade,
	errata_id       number
			constraint rhn_act_eu_err_nn not null
			constraint rhn_act_eu_err_fk 
				references rhnErrata(id)
				on delete cascade
)
	storage ( freelists 16 )
	initrans 32;
create index rhn_act_eu_aid_eid_idx
	on rhnActionErrataUpdate(action_id, errata_id)
	tablespace [[8m_tbs]]
	storage ( freelists 16 )
	initrans 32;
create index rhn_act_eu_eid_aid_idx
	on rhnActionErrataUpdate(errata_id, action_id)
	tablespace [[8m_tbs]]
	storage ( freelists 16 )
	initrans 32;

select '../rhn/tables/rhnKSTreeType.sql' sql_file from dual;
-- SQL relevant contents from file ../rhn/tables/rhnKSTreeType.sql
create table
rhnKSTreeType
(
        id              number
			constraint rhn_kstreetype_id_nn not null
                        constraint rhn_kstreetype_id_pk primary key
                                using index tablespace [[64k_tbs]],
        label           varchar2(32)
                        constraint rhn_kstreetype_label_nn not null,
        name            varchar2(64)
                        constraint rhn_kstreetype_name_nn not null,
        created         date default(sysdate)
                        constraint rhn_kstreetype_created_nn not null,
        modified        date default(sysdate)
                        constraint rhn_kstreetype_mod_nn not null
)
	storage ( freelists 16 )
	initrans 32;
create sequence rhn_kstree_type_seq;
create unique index rhn_kstreetype_label_uq 
	on rhnKSTreeType(label)
	tablespace [[64k_tbs]]
	storage ( freelists 16 )
	initrans 32;

select '../rhn/tables/rhnKSInstallType.sql' sql_file from dual;
-- SQL relevant contents from file ../rhn/tables/rhnKSInstallType.sql
create sequence rhn_ksinstalltype_id_seq;
create table
rhnKSInstallType
(
        id              number
			constraint rhn_ksinstalltype_id_nn not null
                        constraint rhn_ksinstalltype_id_pk primary key
                                using index tablespace [[64k_tbs]],
        label           varchar2(32)
                        constraint rhn_ksinstalltype_label_nn not null,
        name            varchar2(64)
                        constraint rhn_ksinstalltype_name_nn not null,
        created         date default(sysdate)
                        constraint rhn_ksinstalltype_created_nn not null,
        modified        date default(sysdate)
                        constraint rhn_ksinstalltype_mod_nn not null
)
	storage ( freelists 16 )
	initrans 32;
create unique index rhn_ksinstalltype_label_uq 
	on rhnKSInstallType( label )
	tablespace [[64k_tbs]]
	storage ( freelists 16 )
	initrans 32;
create or replace trigger
rhn_ksinstalltype_mod_trig
before insert or update on rhnKSInstallType
for each row
begin
	:new.modified := sysdate;
end;
/
show errors

select '../rhn/tables/rhnKickstartableTree.sql' sql_file from dual;
-- SQL relevant contents from file ../rhn/tables/rhnKickstartableTree.sql
create sequence rhn_kstree_id_seq;
create table
rhnKickstartableTree
(
	id		number
			constraint rhn_kstree_id_nn not null,
        org_id          number
                        constraint rhn_kstree_oid_fk
                                references web_customer(id)
				on delete cascade,
	label		varchar2(64)
			constraint rhn_kstree_label_nn not null,
	base_path	varchar2(256)
			constraint rhn_kstree_bp_nn not null,
	channel_id	number
			constraint rhn_kstree_cid_nn not null
			constraint rhn_kstree_cid_fk
				references rhnChannel(id),
	boot_image	varchar2(128),
        kstree_type     number
                        constraint rhn_kstree_kstreetype_nn not null
                        constraint rhn_kstree_kstreetype_fk
                                references rhnKSTreeType(id),
        install_type    number
                        constraint rhn_kstree_it_nn not null
                        constraint rhn_kstree_it_fk
                                references rhnKSInstallType(id),
	created		date default(sysdate)
			constraint rhn_kstree_created_nn not null,
	modified	date default(sysdate)
			constraint rhn_kstree_modified_nn not null
)
	storage ( freelists 16 )
	initrans 32;
create index rhn_kstree_id_pk
	on rhnKickstartableTree( id )
	tablespace [[4m_tbs]]
	storage ( freelists 16 )
	initrans 32;
alter table rhnKickstartableTree add constraint rhn_kstree_id_pk
	primary key ( id );
create unique index rhn_kstree_label_uq
	on rhnKickstartableTree( label )
	tablespace [[8m_tbs]]
	storage ( freelists 16 )
	initrans 32;
create or replace trigger
rhn_kstree_mod_trig
before insert or update on rhnKickstartableTree
for each row
begin
	:new.modified := sysdate;
end;
/
show errors

select '../rhn/tables/rhnActionKickstart.sql' sql_file from dual;
-- SQL relevant contents from file ../rhn/tables/rhnActionKickstart.sql
create table
rhnActionKickstart
(
	action_id		number
				constraint rhn_actionks_aid_nn not null
				constraint rhn_actionks_aid_fk
					references rhnAction(id),
	append_string		varchar2(1024),
	kstree_id		number
				constraint rhn_actionks_kstid_nn not null
				constraint rhn_actionks_kstid_fk
					references rhnKickstartableTree(id)
					on delete cascade,
        static_device           varchar2(32),
	created			date default(sysdate)
				constraint rhn_actionks_creat_nn not null,
	modified		date default(sysdate)
				constraint rhn_actionks_mod_nn not null
)
	storage ( freelists 16 )
	initrans 32;
create unique index rhn_actionks_aid_uq
	on rhnActionKickstart ( action_id )
	tablespace [[8m_tbs]]
	storage ( freelists 16 )
	initrans 32;
create or replace trigger
rhn_actionks_mod_trig
before insert or update on rhnActionKickstart
for each row
begin
	:new.modified := sysdate;
end;
/
show errors

select '../rhn/tables/rhnPackageDelta.sql' sql_file from dual;
-- SQL relevant contents from file ../rhn/tables/rhnPackageDelta.sql
create sequence rhn_packagedelta_id_seq;
create table
rhnPackageDelta
(
	id		number
			constraint	rhn_packagedelta_id_nn not null,
	label		varchar2(32)
			constraint	rhn_packagedelta_label_nn not null,
	created		date default(sysdate)
			constraint	rhn_packagedelta_created_nn not null,
	modified	date default(sysdate)
			constraint	rhn_packagedelta_modified_nn not null
)
	storage ( freelists 16 )
	initrans 32;
create index rhn_packagedelta_label_id_idx
	on rhnPackageDelta(label, id)
	tablespace [[8m_tbs]]
	storage ( freelists 16 )
	initrans 32;
alter table rhnPackageDelta add
	constraint rhn_packagedelta_id_pk primary key (id)
	using index tablespace [[4m_tbs]];
create or replace trigger
rhn_packagedelta_mod_trig
before insert or update on rhnPackageDelta
for each row
begin
	:new.modified := sysdate;
end;
/
show errors

select '../rhn/tables/rhnActionPackageDelta.sql' sql_file from dual;
-- SQL relevant contents from file ../rhn/tables/rhnActionPackageDelta.sql
create table
rhnActionPackageDelta
(
	action_id		number
				constraint rhn_act_pd_aid_nn not null
				constraint rhn_act_pd_aid_fk
					references rhnAction(id)
					on delete cascade,
	package_delta_id	number
				constraint rhn_act_pd_pdid_nn not null
				constraint rhn_act_pd_pdid_fk
					references rhnPackageDelta(id)
					on delete cascade
)
	storage ( freelists 16 )
	initrans 32;
create unique index rhn_act_pd_aid_pdid_idx
	on rhnActionPackageDelta(action_id, package_delta_id)
	tablespace [[8m_tbs]]
	storage ( pctincrease 1 freelists 16 )
	initrans 32
	nologging;

select '../rhn/tables/rhnPackageCapability.sql' sql_file from dual;
-- SQL relevant contents from file ../rhn/tables/rhnPackageCapability.sql
create table
rhnPackageCapability
(
	id		number
			constraint rhn_pkg_capability_id_nn not null
			constraint rhn_pkg_capability_id_pk primary key
				using index tablespace [[4m_tbs]],
	name		varchar(256)
                        constraint rhn_pkg_capability_name_nn not null,
	version		varchar(64), -- I really hate this.
	created		date default (sysdate)
			constraint rhn_pkg_capability_created_nn not null,
	modified	date default (sysdate)
			constraint rhn_pkg_capability_modified_nn not null
)
	storage ( freelists 16 )
	initrans 32;
create sequence rhn_pkg_capability_id_seq;
create unique index rhn_pkg_cap_name_version_uq
	on rhnPackageCapability(name, version)
	tablespace [[32m_tbs]]
	storage ( freelists 16 )
	initrans 32;
create or replace trigger
rhn_pkg_capability_mod_trig
before insert or update on rhnPackageCapability
for each row
begin
        :new.modified := sysdate;
end;
/
show errors

select '../rhn/tables/rhnActionPackageRemovalFailure.sql' sql_file from dual;
-- SQL relevant contents from file ../rhn/tables/rhnActionPackageRemovalFailure.sql
create table
rhnActionPackageRemovalFailure
(
	server_id		number
				constraint rhn_apr_failure_sid_nn not null
				constraint rhn_apr_failure_sid_fk
					references rhnServer(id)
					on delete cascade,
	action_id		number
				constraint rhn_apr_failure_aid_nn not null
				constraint rhn_apr_failure_aid_fk
					references rhnAction(id)
					on delete cascade,
	name_id			number
				constraint rhn_apr_failure_nid_nn not null
				constraint rhn_apr_failure_nid_fk
					references rhnPackageName(id),
	evr_id			number
				constraint rhn_apr_failure_eid_nn not null
				constraint rhn_apr_failure_eid_fk
					references rhnPackageEVR(id),
	capability_id		number
				constraint rhn_apr_failure_capid_nn not null
				constraint rhn_apr_failure_capid_fk
					references rhnPackageCapability(id),
	flags			number
				constraint rhn_apr_failure_flags_nn not null,
	suggested		number
				constraint rhn_apr_failure_suggested_fk
					references rhnPackageName(id),
	sense			number
				constraint rhn_apr_failure_sense_nn not null
)
	storage ( freelists 16 )
	initrans 32;
create index rhn_apr_failure_aid_sid_idx
	on rhnActionPackageRemovalFailure ( action_id, server_id )
	tablespace [[4m_tbs]]
	storage ( freelists 16 )
	initrans 32;

select '../rhn/tables/rhnActionPackage.sql' sql_file from dual;
-- SQL relevant contents from file ../rhn/tables/rhnActionPackage.sql
create table
rhnActionPackage
(
	action_id	number
			constraint rhn_act_p_act_nn not null
			constraint rhn_act_p_act_fk
				references rhnAction(id) on delete cascade,
	parameter       varchar2(128) default 'upgrade'
			constraint rhn_act_p_param_nn not null
			constraint rhn_act_p_param_ck
			    CHECK(parameter IN ('upgrade', 'install', 'remove', 'downgrade')),
	name_id		number
			constraint rhn_act_p_name_nn not null
			constraint rhn_act_p_name_fk
				references rhnPackageName(id),
	evr_id		number
			constraint rhn_act_p_evr_fk
				references rhnPackageEvr(id),
	package_arch_id	number
			constraint rhn_act_p_paid_fk
				references rhnPackageArch(id)
)
	storage ( freelists 16 )
	initrans 32;
create index rhn_act_p_aid_idx
	on rhnActionPackage(action_id)
	tablespace [[4m_tbs]]
	storage( pctincrease 1 freelists 16 )
	initrans 32
	nologging;

select '../rhn/tables/rhnActionStatus_data.sql' sql_file from dual;
-- SQL relevant contents from file ../rhn/tables/rhnActionStatus_data.sql
insert into rhnActionStatus values (0, 'Queued', sysdate, sysdate);
insert into rhnActionStatus values (1, 'Picked Up', sysdate, sysdate);
insert into rhnActionStatus values (2, 'Completed', sysdate, sysdate);
insert into rhnActionStatus values (3, 'Failed', sysdate, sysdate);
commit;

select '../rhn/tables/rhnActionStatus_triggers.sql' sql_file from dual;
-- SQL relevant contents from file ../rhn/tables/rhnActionStatus_triggers.sql
create or replace trigger
rhn_action_statusmod_trig
before insert or update on rhnActionStatus
for each row
begin
        :new.modified := sysdate;
end;
/
show errors

select '../rhn/tables/rhnTransaction.sql' sql_file from dual;
-- SQL relevant contents from file ../rhn/tables/rhnTransaction.sql
create table
rhnTransaction
(
	id		number
			constraint rhn_trans_id_nn not null,
	server_id	number
			constraint rhn_trans_sid_nn not null
			constraint rhn_trans_sid_fk
				references rhnServer(id) on delete cascade,
	timestamp	date
			constraint rhn_trans_ts_nn not null,
	rpm_trans_id	number
			constraint rhn_trans_rti_nn not null,
	label		varchar2(32),
	created		date default(sysdate)
			constraint rhn_trans_created_nn not null,
	modified	date default(sysdate)
			constraint rhn_trans_modified_nn not null,
	constraint	rhn_trans_sid_rti_unq
			unique(server_id, rpm_trans_id)
			using index tablespace [[8m_tbs]]
)
	storage ( freelists 16 )
	initrans 32;
create sequence rhn_transaction_id_seq;
create index rhn_trans_id_sid_ts_rtid_idx
	on rhnTransaction(id,server_id,timestamp, rpm_trans_id)
	storage ( freelists 16 )
	initrans 32;
alter table rhnTransaction add constraint rhn_trans_id_pk primary key (id)
	using index tablespace [[8m_tbs]];

select '../rhn/tables/rhnActionTransactions.sql' sql_file from dual;
-- SQL relevant contents from file ../rhn/tables/rhnActionTransactions.sql
create table
rhnActionTransactions
(
	action_id	number
			constraint rhn_at_aid_nn not null
			constraint rhn_at_aid_fk
				references rhnAction(id)
				on delete cascade,
	from_trans_id	number
			constraint rhn_at_ftid_nn not null
			constraint rhn_at_ftid_fk
				references rhnTransaction(id)
				on delete cascade,
	to_trans_id	number
			constraint rhn_at_ttid_nn not null
			constraint rhn_at_ttid_fk
				references rhnTransaction(id)
				on delete cascade
)
	storage ( freelists 16 )
	initrans 32;
create unique index rhn_at_aid_ftid_ttid_uq
	on rhnActionTransactions(action_id, from_trans_id, to_trans_id)
	tablespace [[64k_tbs]]
	storage ( freelists 16 )
	initrans 32;

select '../rhn/tables/rhnActionType_data.sql' sql_file from dual;
-- SQL relevant contents from file ../rhn/tables/rhnActionType_data.sql
insert into rhnActionType values (1, 'packages.refresh_list', 'Package List Refresh', 'Y', 'N');
insert into rhnActionType values (2, 'hardware.refresh_list', 'Hardware List Refresh', 'N', 'N');
insert into rhnActionType values (3, 'packages.update', 'Package Install', 'Y', 'Y');
insert into rhnActionType values (4, 'packages.remove', 'Package Removal', 'Y', 'Y');
insert into rhnActionType values (5, 'errata.update', 'Errata Update', 'Y', 'Y');
insert into rhnActionType values (6, 'up2date_config.get', 'Get server up2date config', 'Y', 'Y');
insert into rhnActionType values (7, 'up2date_config.update', 'Update server up2date config', 'Y', 'Y');
insert into rhnActionType values (8, 'packages.delta', 'Package installation and removal in one RPM transaction', 'Y', 'Y');
insert into rhnActionType values (9, 'reboot.reboot', 'System reboot', 'N', 'Y');
insert into rhnActionType values (10, 'rollback.config', 'Enable or Disable RPM Transaction Rollback', 'N', 'Y');
insert into rhnActionType values (11, 'rollback.listTransactions', 'Refresh server-side transaction list', 'N', 'N');
insert into rhnActionType values (12, 'rollback.rollback', 'RPM Transaction Rollback', 'Y', 'Y');
insert into rhnActionType values (13, 'packages.autoupdate', 'Automatic package installation', 'Y', 'Y');
insert into rhnActionType values (14, 'packages.runTransaction', 'Package Synchronization', 'Y', 'Y');
insert into rhnActionType values (15, 'configfiles.upload', 'Upload config file data to server', 'N', 'N');
insert into rhnActionType values (16, 'configfiles.deploy', 'Deploy config files to system', 'Y', 'Y');
insert into rhnActionType values (17, 'configfiles.verify', 'Verify deployed config files', 'N', 'N');
insert into rhnActionType values (18, 'configfiles.diff', 'Show differences between profiled config files and deployed config files', 'N', 'N');
insert into rhnActionType values (19, 'kickstart.initiate', 'Initiate a kickstart', 'N', 'Y');
insert into rhnActionType values (20, 'kickstart.schedule_sync', 'Schedule a package sync for kickstarts', 'N', 'N');
insert into rhnActionType values (21, 'activation.schedule_pkg_install', 'Schedule a package install for activation key', 'N', 'N');
insert into rhnActionType values (22, 'activation.schedule_deploy', 'Schedule a config deploy for activation key', 'N', 'N');
insert into rhnActionType values (23, 'configfiles.mtime_upload', 'Upload config file data based upon mtime to server', 'N', 'N');
commit;

select '../rhn/tables/rhnActionVerifyResult.sql' sql_file from dual;
-- SQL relevant contents from file ../rhn/tables/rhnActionVerifyResult.sql
create table
rhnActionVerifyResult
(
	action_id			number
					constraint rhn_actionvr_aid_nn not null
					constraint rhn_actionvr_aid_fk
						references rhnAction(id),
	package_name_id			number
					constraint rhn_actionvr_pnid_nn not null
					constraint rhn_actionvr_pnid_fk
						references rhnPackageName(id),
	package_evr_id			number
					constraint rhn_actionvr_peid_nn not null
					constraint rhn_actionvr_peid_fk
						references rhnPackageEVR(id),
	package_capability_id		number
					constraint rhn_actionvr_pcid_nn not null
					constraint rhn_actionvr_pcid_fk
						references rhnPackageCapability(id),
	attribute			char(1)
					constraint rhn_actionvr_attr_ck
						check (attribute in ('c','d','g','l','r')),
	size_differs			char(1)
					constraint rhn_actionvr_size_nn not null
					constraint rhn_actionvr_size_ck
						check (size_differs in ('Y','N')),
	mode_differs			char(1)
					constraint rhn_actionvr_mode_nn not null
					constraint rhn_actionvr_mode_ck
						check (mode_differs in ('Y','N')),
	md5_differs			char(1)
					constraint rhn_actionvr_md5_nn not null
					constraint rhn_actionvr_md5_ck
						check (md5_differs in ('Y','N')),
	devnum_differs			char(1)
					constraint rhn_actionvr_devnum_nn not null
					constraint rhn_actionvr_devnum_ck
						check (devnum_differs in ('Y','N')),
	readlink_differs			char(1)
					constraint rhn_actionvr_readlink_nn not null
					constraint rhn_actionvr_readlink_ck
						check (readlink_differs in ('Y','N')),
	uid_differs			char(1)
					constraint rhn_actionvr_uid_nn not null
					constraint rhn_actionvr_uid_ck
						check (uid_differs in ('Y','N')),
	gid_differs			char(1)
					constraint rhn_actionvr_gid_nn not null
					constraint rhn_actionvr_gid_ck
						check (gid_differs in ('Y','N')),
	mtime_differs			char(1)
					constraint rhn_actionvr_mtime_nn not null
					constraint rhn_actionvr_mtime_ck
						check (mtime_differs in ('Y','N')),
	created				date default(sysdate)
					constraint rhn_actionvr_creat_nn not null,
	modified			date default(sysdate)
					constraint rhn_actionvr_mod_nn not null
)
	storage ( freelists 16 )
	initrans 32;
create unique index rhn_actionvr_aid_ne_uq
	on rhnActionVerifyResult( action_id, package_name_id, package_evr_id )
	tablespace [[4m_tbs]]
	storage ( freelists 16 )
	initrans 32;
create or replace trigger
rhn_actionvr_mod_trig
before insert or update on rhnActionVerifyResult
for each row
begin
	:new.modified := sysdate;
end;
/
show errors

select '../rhn/tables/rhnRegToken.sql' sql_file from dual;
-- SQL relevant contents from file ../rhn/tables/rhnRegToken.sql
create table
rhnRegToken
(
	id		number
			constraint rhn_reg_token_id_nn not null
			constraint rhn_reg_token_pk primary key,
	org_id		number
			constraint rhn_reg_token_oid_nn not null
			constraint rhn_reg_token_oid_fk
				references web_customer(id)
				on delete cascade,
	user_id		number
			constraint rhn_reg_token_uid_fk
				references web_contact(id)
				on delete cascade,
	server_id	number
			constraint rhn_reg_token_sid_fk
				references rhnServer(id)
				on delete cascade,
	entitlement_level
	    	    	number
			constraint rhn_reg_token_el_nn not null
			constraint rhn_reg_token_el_fk 
			    references rhnServerGroupType(id),
	note		varchar2(2048)
			constraint rhn_reg_token_note_nn not null,
	usage_limit     number default 0,
        disabled        number default 0
	    	    	constraint rhn_reg_token_def_nn not null,
	deploy_configs	char(1) default('Y')
			constraint rhn_reg_token_deployconfs_nn not null
			constraint rhn_reg_token_deployconfs_ck
				check (deploy_configs in ('Y','N'))
)
	storage( freelists 16 )
	initrans 32;
create index rhn_reg_token_org_id_idx
	on rhnRegToken(org_id, id)
	tablespace [[64k_tbs]]
	storage( freelists 16 )
	initrans 32
	nologging;
create index rhn_reg_token_uid_idx
	on rhnRegToken ( user_id )
	tablespace [[64k_tbs]]
	storage( freelists 16 )
	initrans 32
	nologging;
create sequence rhn_reg_token_seq;

select '../rhn/tables/rhnKSData.sql' sql_file from dual;
-- SQL relevant contents from file ../rhn/tables/rhnKSData.sql
create sequence rhn_ks_id_seq;
create table
rhnKSData
(
	id			number
				constraint rhn_ks_id_nn not null
				constraint rhn_ks_id_pk primary key
					using index tablespace [[8m_tbs]],
	org_id			number
				constraint rhn_ks_oid_nn not null
				constraint rhn_ks_oid_fk
					references web_customer(id)
					on delete cascade,
	is_org_default          char(1) default('N')
				constraint rhn_ks_default_nn not null
				constraint rhn_ks_default_ck
					check (is_org_default in ('Y','N')),
	label			varchar2(64)
				constraint rhn_ks_label_nn not null,
	name			varchar2(128)
				constraint rhn_ks_name_nn not null,
	comments		varchar2(4000),
	active			char(1) default('Y')
				constraint rhn_ks_active_nn not null
				constraint rhn_ks_active_ck
					check (active in ('Y','N')),
	pre			blob,
	post			blob,
        nochroot_post           blob,
	static_device           varchar2(32),
        kernel_params           varchar2(128),
	created			date default(sysdate)
				constraint rhn_ks_created_nn not null,
	modified		date default(sysdate)
				constraint rhn_ks_modified_nn not null
)
	storage ( freelists 16 )
	initrans 32;
create index rhn_ks_oid_label_id_idx
	on rhnKSData( org_id, label, id )
	tablespace [[8m_tbs]]
	storage ( freelists 16 )
	initrans 32;
alter table rhnKSData add constraint rhn_ks_oid_label_uq
	unique ( org_id, label );
alter table rhnKSData add constraint rhn_ks_oid_name_uq
	unique ( org_id, name );
create or replace trigger
rhn_ks_mod_trig
before insert or update on rhnKSData
for each row
begin
	:new.modified := sysdate;
end;
/
show errors

select '../rhn/tables/rhnKickstartSessionState.sql' sql_file from dual;
-- SQL relevant contents from file ../rhn/tables/rhnKickstartSessionState.sql
create sequence rhn_ks_session_state_id_seq;
create table
rhnKickstartSessionState
(
	id			number
				constraint rhn_ks_session_state_id_nn not null
				constraint rhn_ks_session_state_id_pk primary key
					using index tablespace [[64k_tbs]],
	label			varchar2(64)
				constraint rhn_ks_session_state_label_nn not null,
	name			varchar2(128)
				constraint rhn_ks_session_state_name_nn not null,
	description		varchar2(1024)
				constraint rhn_ks_session_state_desc_nn not null,
	created			date default(sysdate)
				constraint rhn_ks_session_state_creat_nn not null,
	modified		date default(sysdate)
				constraint rhn_ks_session_state_mod_nn not null
)
	storage ( freelists 16 )
	initrans 32;
create unique index rhn_ks_session_state_label_uq
	on rhnKickstartSessionState(label)
	tablespace [[64k_tbs]]
	storage ( freelists 16 )
	initrans 32;
create or replace trigger
rhn_ks_session_state_mod_trig
before insert or update on rhnKickstartSessionState
for each row
begin
	:new.modified := sysdate;
end;
/
show errors

select '../rhn/tables/rhnServerProfileType.sql' sql_file from dual;
-- SQL relevant contents from file ../rhn/tables/rhnServerProfileType.sql
create sequence rhn_sproftype_id_seq;
create table
rhnServerProfileType
(
	id		number
			constraint rhn_sproftype_id_nn not null
			constraint rhn_sproftype_id_pk primary key
				using index tablespace [[64k_tbs]],
	label		varchar2(64)
			constraint rhn_sproftype_label_nn not null,
	name		varchar2(64)
			constraint rhn_sproftype_name_nn not null,
	created		date default(sysdate)
			constraint rhn_sproftype_creat_nn not null,
	modified	date default(sysdate)
			constraint rhn_sproftype_mod_nn not null
)
	storage ( freelists 16 )
	initrans 32;
create index rhn_sproftype_label_id_idx
	on rhnServerProfileType( label, id )
	tablespace [[64k_tbs]]
	storage ( freelists 16 )
	initrans 32;
alter table rhnServerProfileType add constraint rhn_sproftype_label_uq
	unique ( label );
create or replace trigger
rhn_sproftype_mod_trig
before insert or update on rhnServerProfileType
for each row
begin
	:new.modified := sysdate;
end;
/
show errors

select '../rhn/tables/rhnServerProfile.sql' sql_file from dual;
-- SQL relevant contents from file ../rhn/tables/rhnServerProfile.sql
create table
rhnServerProfile
(
        id              number
			constraint rhn_server_profile_id_nn not null,
        org_id          number
                        constraint rhn_server_profile_oid_nn not null
                        constraint rhn_server_profile_oid_fk
                                references web_customer(id)
				on delete cascade,
	base_channel    number
	    	    	constraint rhn_server_profile_bcid_nn not null
	    	    	constraint rhn_server_profile_bcid_fk
			    	references rhnChannel(id),
        name            varchar(128),
        description     varchar(256),
        info            varchar(128),
	profile_type_id number
	    	    	constraint rhn_server_profile_ptype_nn not null
	    	    	constraint rhn_server_profile_ptype_fk
			    	references rhnServerProfileType(id),
        created         date default (sysdate)
			constraint rhn_server_profile_created_nn not null,
        modified        date default (sysdate)
			constraint rhn_server_profile_modified_nn not null
)
	storage ( freelists 16 )
	initrans 32;
create sequence rhn_server_profile_id_seq;
create unique index rhn_server_profile_noid_uq
    	on rhnServerProfile(org_id,name)
	tablespace [[64k_tbs]]
	storage ( freelists 16 )
	initrans 32;
create index rhn_sprofile_id_oid_bc_idx
	on rhnServerProfile(id,org_id,base_channel)
	tablespace [[64k_tbs]]
	storage ( freelists 16 )
	initrans 32;
alter table rhnServerProfile add
	constraint rhn_server_profile_id_pk primary key (id);
create index rhn_server_profile_o_id_bc_idx
	on rhnServerProfile(org_id,id,base_channel)
	tablespace [[64k_tbs]]
	storage ( freelists 16 )
	initrans 32
	nologging;
create index rhn_server_profile_bc_idx
	on rhnServerProfile(base_channel)
	tablespace [[64k_tbs]]
	storage ( freelists 16 )
	initrans 32
	nologging;

select '../rhn/tables/rhnKickstartSession.sql' sql_file from dual;
-- SQL relevant contents from file ../rhn/tables/rhnKickstartSession.sql
create sequence rhn_ks_session_id_seq;
create table
rhnKickstartSession
(
	id			number
				constraint rhn_ks_session_id_nn not null
				constraint rhn_ks_session_id_pk primary key
					using index tablespace [[8m_tbs]],
	kickstart_id		number
				constraint rhn_ks_session_ksid_fk
					references rhnKSData(id)
					on delete cascade,
        kickstart_mode          varchar2(32),
	kstree_id               number
				constraint rhn_ks_session_kstid_fk
				        references rhnKickstartableTree(id)
					on delete set null,
	org_id			number
				constraint rhn_ks_session_oid_nn not null
				constraint rhn_ks_session_oid_fk
					references web_customer(id)
					on delete cascade,
    	scheduler               number
	    	    	    	constraint rhn_ks_session_sched_fk
				    	references web_contact(id)
					on delete set null,
	old_server_id		number
				constraint rhn_ks_session_osid_fk
					references rhnServer(id),
	new_server_id		number
				constraint rhn_ks_session_nsid_fk
					references rhnServer(id),
	action_id		number
				constraint rhn_ks_session_aid_fk
					references rhnAction(id)
					on delete set null,
	state_id		number
				constraint rhn_ks_session_ksssid_nn not null
				constraint rhn_ks_session_ksssid_fk
					references rhnKickstartSessionState(id),
	server_profile_id	number
				constraint rhn_ks_session_spid_fk
					references rhnServerProfile(id)
					on delete set null,
	last_action		date default(sysdate)
				constraint rhn_ks_session_last_action_nn not null,
        package_fetch_count     number default 0
				constraint rhn_ks_session_pfc_nn not null,
        last_file_request       varchar2(2048),
    	system_rhn_host         varchar2(256),
	created			date default(sysdate)
				constraint rhn_ks_session_created_nn not null,
	modified		date default(sysdate)
				constraint rhn_ks_session_modified_nn not null
)
	storage ( freelists 16 )
	initrans 32;
create index rhn_ks_session_oid_idx
	on rhnKickstartSession( org_id )
	tablespace [[8m_tbs]]
	storage ( freelists 16 )
	initrans 32;
create index rhn_ks_session_osid_aid_idx
	on rhnKickstartSession( old_server_id, action_id )
	tablespace [[4m_tbs]]
	storage ( freelists 16 )
	initrans 32;
create index rhn_ks_session_nsid_idx
	on rhnKickstartSession( new_server_id )
	tablespace [[4m_tbs]]
	storage ( freelists 16 )
	initrans 32;

select '../rhn/tables/rhnActivationKey.sql' sql_file from dual;
-- SQL relevant contents from file ../rhn/tables/rhnActivationKey.sql
create table
rhnActivationKey
(
	token		varchar2(48)
			constraint rhn_act_key_token_nn not null
			constraint rhn_act_key_token_uq unique,
	reg_token_id	number
			constraint rhn_act_key_reg_tid_nn not null
			constraint rhn_act_key_reg_tid_fk
				references rhnRegToken(id)
				on delete cascade,
	ks_session_id	number
			constraint rhn_act_key_ks_sid_fk
				references rhnKickstartSession(id)
				on delete cascade,
	created		date default sysdate
			constraint rhn_act_key_created_nn not null,
	modified	date default sysdate
			constraint rhn_act_key_modified_nn not null
)
	storage( freelists 16 )
	initrans 32;
create or replace trigger
rhn_act_key_mod_trig
before insert or update on rhnActivationKey
for each row
begin
        :new.modified := sysdate;
end;
/
show errors

select '../rhn/tables/rhnBeehivePathMap.sql' sql_file from dual;
-- SQL relevant contents from file ../rhn/tables/rhnBeehivePathMap.sql
create table rhnBeehivePathMap
(
    path            varchar2(128)
                    constraint rhn_beehive_path_map_p_nn not null
                    constraint rhn_beehive_path_map_p_pk primary key
                        using index tablespace [[64k_tbs]],
    beehive_path    varchar2(128)
                    constraint rhn_beehive_path_map_bp_nn not null,
    ftp_path        varchar2(128)
                    constraint rhn_beehive_path_map_fp_nn not null,
    created         date default SYSDATE,
    modified        date default SYSDATE
)
	storage ( freelists 16 )
	initrans 32;
create or replace trigger
rhn_beehive_path_map_mod_trig
before insert or update on rhnBeehivePathMap
for each row
begin
    :new.modified := SYSDATE;
end rhn_beehive_mod_trig;
/
show errors

select '../rhn/tables/rhnBeehivePathMap_data.sql' sql_file from dual;
-- SQL relevant contents from file ../rhn/tables/rhnBeehivePathMap_data.sql
insert into rhnBeehivePathMap (path, beehive_path, ftp_path) values
   ('6.2/en/os/noarch',
    'beehive/updates/dist/6.2/noarch',
    'redhat/linux/updates/6.2/en/os/noarch');
insert into rhnBeehivePathMap (path, beehive_path, ftp_path) values
   ('6.2/en/os/i386',
    'beehive/updates/dist/6.2/i386',
    'redhat/linux/updates/6.2/en/os/i386');
insert into rhnBeehivePathMap (path, beehive_path, ftp_path) values
   ('6.2/en/os/i586',
    'beehive/updates/dist/6.2/i586',
    'redhat/linux/updates/6.2/en/os/i586');
insert into rhnBeehivePathMap (path, beehive_path, ftp_path) values
   ('6.2/en/os/i686',
    'beehive/updates/dist/6.2/i686',
    'redhat/linux/updates/6.2/en/os/i686');
insert into rhnBeehivePathMap (path, beehive_path, ftp_path) values
   ('6.2/en/os/alpha',
    'beehive/updates/dist/6.2/alpha',
    'redhat/linux/updates/6.2/en/os/alpha');
insert into rhnBeehivePathMap (path, beehive_path, ftp_path) values
   ('6.2/en/os/sparc',
    'beehive/updates/dist/6.2/sparc',
    'redhat/linux/updates/6.2/en/os/sparc');
insert into rhnBeehivePathMap (path, beehive_path, ftp_path) values
   ('6.2/en/os/sparcv9',
    'beehive/updates/dist/6.2/sparcv9',
    'redhat/linux/updates/6.2/en/os/sparcv9');
insert into rhnBeehivePathMap (path, beehive_path, ftp_path) values
   ('6.2/en/os/sparc64',
    'beehive/updates/dist/6.2/sparc64',
    'redhat/linux/updates/6.2/en/os/sparc64');
insert into rhnBeehivePathMap (path, beehive_path, ftp_path) values
   ('6.2/en/os/SRPMS',
    'beehive/updates/dist/6.2/SRPMS',
    'redhat/linux/updates/6.2/en/os/SRPMS');
insert into rhnBeehivePathMap (path, beehive_path, ftp_path) values
   ('6.2/en/powertools/noarch',
    'beehive/updates/powertools/6.2/noarch',
    'redhat/linux/updates/6.2/en/powertools/noarch');
insert into rhnBeehivePathMap (path, beehive_path, ftp_path) values
   ('6.2/en/powertools/i386',
    'beehive/updates/powertools/6.2/i386',
    'redhat/linux/updates/6.2/en/powertools/i386');
insert into rhnBeehivePathMap (path, beehive_path, ftp_path) values
   ('6.2/en/powertools/alpha',
    'beehive/updates/powertools/6.2/alpha',
    'redhat/linux/updates/6.2/en/powertools/alpha');
insert into rhnBeehivePathMap (path, beehive_path, ftp_path) values
   ('6.2/en/powertools/sparc',
    'beehive/updates/powertools/6.2/sparc',
    'redhat/linux/updates/6.2/en/powertools/sparc');
insert into rhnBeehivePathMap (path, beehive_path, ftp_path) values
   ('6.2/en/powertools/SRPMS',
    'beehive/updates/powertools/6.2/SRPMS',
    'redhat/linux/updates/6.2/en/powertools/SRPMS');
insert into rhnBeehivePathMap (path, beehive_path, ftp_path) values
   ('7.0/en/os/noarch',
    'beehive/updates/dist/7.0/noarch',
    'redhat/linux/updates/7.0/en/os/noarch');
insert into rhnBeehivePathMap (path, beehive_path, ftp_path) values
   ('7.0/en/os/i386',
    'beehive/updates/dist/7.0/i386',
    'redhat/linux/updates/7.0/en/os/i386');
insert into rhnBeehivePathMap (path, beehive_path, ftp_path) values
   ('7.0/en/os/i586',
    'beehive/updates/dist/7.0/i586',
    'redhat/linux/updates/7.0/en/os/i586');
insert into rhnBeehivePathMap (path, beehive_path, ftp_path) values
   ('7.0/en/os/i686',
    'beehive/updates/dist/7.0/i686',
    'redhat/linux/updates/7.0/en/os/i686');
insert into rhnBeehivePathMap (path, beehive_path, ftp_path) values
   ('7.0/en/os/alpha',
    'beehive/updates/dist/7.0/alpha',
    'redhat/linux/updates/7.0/en/os/alpha');
insert into rhnBeehivePathMap (path, beehive_path, ftp_path) values
   ('7.0/en/os/alphaev6',
    'beehive/updates/dist/7.0/alphaev6',
    'redhat/linux/updates/7.0/en/os/alphaev6');
insert into rhnBeehivePathMap (path, beehive_path, ftp_path) values
   ('7.0/en/os/SRPMS',
    'beehive/updates/dist/7.0/SRPMS',
    'redhat/linux/updates/7.0/en/os/SRPMS');
insert into rhnBeehivePathMap (path, beehive_path, ftp_path) values
   ('7.0/en/powertools/noarch',
    'beehive/updates/powertools/7.0/noarch',
    'redhat/linux/updates/7.0/en/powertools/noarch');
insert into rhnBeehivePathMap (path, beehive_path, ftp_path) values
   ('7.0/en/powertools/i386',
    'beehive/updates/powertools/7.0/i386',
    'redhat/linux/updates/7.0/en/powertools/i386');
insert into rhnBeehivePathMap (path, beehive_path, ftp_path) values
   ('7.0/en/powertools/alpha',
    'beehive/updates/powertools/7.0/alpha',
    'redhat/linux/updates/7.0/en/powertools/alpha');
insert into rhnBeehivePathMap (path, beehive_path, ftp_path) values
   ('7.0/en/powertools/SRPMS',
    'beehive/updates/powertools/7.0/SRPMS',
    'redhat/linux/updates/7.0/en/powertools/SRPMS');
insert into rhnBeehivePathMap (path, beehive_path, ftp_path) values
   ('7.1/en/os/noarch',
    'beehive/updates/dist/7.1/noarch',
    'redhat/linux/updates/7.1/en/os/noarch');
insert into rhnBeehivePathMap (path, beehive_path, ftp_path) values
   ('7.1/en/os/i386',
    'beehive/updates/dist/7.1/i386',
    'redhat/linux/updates/7.1/en/os/i386');
insert into rhnBeehivePathMap (path, beehive_path, ftp_path) values
   ('7.1/en/os/i586',
    'beehive/updates/dist/7.1/i586',
    'redhat/linux/updates/7.1/en/os/i586');
insert into rhnBeehivePathMap (path, beehive_path, ftp_path) values
   ('7.1/en/os/i686',
    'beehive/updates/dist/7.1/i686',
    'redhat/linux/updates/7.1/en/os/i686');
insert into rhnBeehivePathMap (path, beehive_path, ftp_path) values
   ('7.1/en/os/athlon',
    'beehive/updates/dist/7.1/athlon',
    'redhat/linux/updates/7.1/en/os/athlon');
insert into rhnBeehivePathMap (path, beehive_path, ftp_path) values
   ('7.1/en/os/alpha',
    'beehive/updates/dist/7.1/alpha',
    'redhat/linux/updates/7.1/en/os/alpha');
insert into rhnBeehivePathMap (path, beehive_path, ftp_path) values
   ('7.1/en/os/alphaev6',
    'beehive/updates/dist/7.1/alphaev6',
    'redhat/linux/updates/7.1/en/os/alphaev6');
insert into rhnBeehivePathMap (path, beehive_path, ftp_path) values
   ('7.1/en/os/ia64',
    'beehive/updates/dist/7.1/ia64',
    'redhat/linux/updates/7.1/en/os/ia64');
insert into rhnBeehivePathMap (path, beehive_path, ftp_path) values
   ('7.1/en/os/s390x',
    'beehive/updates/dist/7.1/s390x',
    'redhat/linux/updates/7.1/en/os/s390x');
insert into rhnBeehivePathMap (path, beehive_path, ftp_path) values
   ('7.1/en/os/SRPMS',
    'beehive/updates/dist/7.1/SRPMS',
    'redhat/linux/updates/7.1/en/os/SRPMS');
insert into rhnBeehivePathMap (path, beehive_path, ftp_path) values
   ('7.1/en/powertools/noarch',
    'beehive/updates/powertools/7.1/noarch',
    'redhat/linux/updates/7.1/en/powertools/noarch');
insert into rhnBeehivePathMap (path, beehive_path, ftp_path) values
   ('7.1/en/powertools/i386',
    'beehive/updates/powertools/7.1/i386',
    'redhat/linux/updates/7.1/en/powertools/i386');
insert into rhnBeehivePathMap (path, beehive_path, ftp_path) values
   ('7.1/en/powertools/alpha',
    'beehive/updates/powertools/7.1/alpha',
    'redhat/linux/updates/7.1/en/powertools/alpha');
insert into rhnBeehivePathMap (path, beehive_path, ftp_path) values
   ('7.1/en/powertools/SRPMS',
    'beehive/updates/powertools/7.1/SRPMS',
    'redhat/linux/updates/7.1/en/powertools/SRPMS');
insert into rhnBeehivePathMap (path, beehive_path, ftp_path) values
   ('7.2/en/os/noarch',
    'beehive/updates/dist/7.2/noarch',
    'redhat/linux/updates/7.2/en/os/noarch');
insert into rhnBeehivePathMap (path, beehive_path, ftp_path) values
   ('7.2/en/os/i386',
    'beehive/updates/dist/7.2/i386',
    'redhat/linux/updates/7.2/en/os/i386');
insert into rhnBeehivePathMap (path, beehive_path, ftp_path) values
   ('7.2/en/os/i586',
    'beehive/updates/dist/7.2/i586',
    'redhat/linux/updates/7.2/en/os/i586');
insert into rhnBeehivePathMap (path, beehive_path, ftp_path) values
   ('7.2/en/os/i686',
    'beehive/updates/dist/7.2/i686',
    'redhat/linux/updates/7.2/en/os/i686');
insert into rhnBeehivePathMap (path, beehive_path, ftp_path) values
   ('7.2/en/os/athlon',
    'beehive/updates/dist/7.2/athlon',
    'redhat/linux/updates/7.2/en/os/athlon');
insert into rhnBeehivePathMap (path, beehive_path, ftp_path) values
   ('7.2/en/os/ia64',
    'beehive/updates/dist/7.2/ia64',
    'redhat/linux/updates/7.2/en/os/ia64');
insert into rhnBeehivePathMap (path, beehive_path, ftp_path) values
   ('7.2/en/os/s390',
    'beehive/updates/dist/7.2/s390',
    'redhat/linux/updates/7.2/en/os/s390');
insert into rhnBeehivePathMap (path, beehive_path, ftp_path) values
   ('7.2/en/os/SRPMS',
    'beehive/updates/dist/7.2/SRPMS',
    'redhat/linux/updates/7.2/en/os/SRPMS');
insert into rhnBeehivePathMap (path, beehive_path, ftp_path) values
   ('7.3/en/os/noarch',
    'beehive/updates/dist/7.3/noarch',
    'redhat/linux/updates/7.3/en/os/noarch');
insert into rhnBeehivePathMap (path, beehive_path, ftp_path) values
   ('7.3/en/os/i386',
    'beehive/updates/dist/7.3/i386',
    'redhat/linux/updates/7.3/en/os/i386');
insert into rhnBeehivePathMap (path, beehive_path, ftp_path) values
   ('7.3/en/os/i586',
    'beehive/updates/dist/7.3/i586',
    'redhat/linux/updates/7.3/en/os/i586');
insert into rhnBeehivePathMap (path, beehive_path, ftp_path) values
   ('7.3/en/os/i686',
    'beehive/updates/dist/7.3/i686',
    'redhat/linux/updates/7.3/en/os/i686');
insert into rhnBeehivePathMap (path, beehive_path, ftp_path) values
   ('7.3/en/os/athlon',
    'beehive/updates/dist/7.3/athlon',
    'redhat/linux/updates/7.3/en/os/athlon');
insert into rhnBeehivePathMap (path, beehive_path, ftp_path) values
   ('7.3/en/os/SRPMS',
    'beehive/updates/dist/7.3/SRPMS',
    'redhat/linux/updates/7.3/en/os/SRPMS');
insert into rhnBeehivePathMap (path, beehive_path, ftp_path) values
   ('7.1/en/rhdb/i386',
    'beehive/updates/rhdb/7.1/i386',
    'rhn/updates/7.1/en/rhdb/i386');
insert into rhnBeehivePathMap (path, beehive_path, ftp_path) values
   ('7.1/en/rhdb/noarch',
    'beehive/updates/rhdb/7.1/noarch',
    'rhn/updates/7.1/en/rhdb/noarch');
insert into rhnBeehivePathMap (path, beehive_path, ftp_path) values
   ('7.1/en/rhdb/SRPMS',
    'beehive/updates/rhdb/7.1/SRPMS',
    'rhn/updates/7.1/en/rhdb/SRPMS');
insert into rhnBeehivePathMap (path, beehive_path, ftp_path) values
   ('2.1AS/en/os/noarch',
    'beehive/updates/dist/2.1AS/noarch',
    'rhn/updates/2.1AS/en/os/noarch');
insert into rhnBeehivePathMap (path, beehive_path, ftp_path) values
   ('2.1AS/en/os/i386',
    'beehive/updates/dist/2.1AS/i386',
    'rhn/updates/2.1AS/en/os/i386');
insert into rhnBeehivePathMap (path, beehive_path, ftp_path) values
   ('2.1AS/en/os/i586',
    'beehive/updates/dist/2.1AS/i586',
    'rhn/updates/2.1AS/en/os/i586');
insert into rhnBeehivePathMap (path, beehive_path, ftp_path) values
   ('2.1AS/en/os/i686',
    'beehive/updates/dist/2.1AS/i686',
    'rhn/updates/2.1AS/en/os/i686');
insert into rhnBeehivePathMap (path, beehive_path, ftp_path) values
   ('2.1AS/en/os/athlon',
    'beehive/updates/dist/2.1AS/athlon',
    'rhn/updates/2.1AS/en/os/athlon');
insert into rhnBeehivePathMap (path, beehive_path, ftp_path) values
   ('2.1AS/en/os/SRPMS',
    'beehive/updates/dist/2.1AS/SRPMS',
    'rhn/updates/2.1AS/en/os/SRPMS');
insert into rhnBeehivePathMap (path, beehive_path, ftp_path) values
   ('2.1AS/en/os/ia64',
    'beehive/updates/dist/2.1AS/ia64',
    'rhn/updates/2.1AS/en/os/ia64');
insert into rhnBeehivePathMap (path, beehive_path, ftp_path) values
   ('2.1AW/en/os/ia64',
    'beehive/updates/dist/2.1AW/ia64',
    'rhn/updates/2.1AW/en/os/ia64');
insert into rhnBeehivePathMap (path, beehive_path, ftp_path) values
   ('2.1AW/en/os/noarch',
    'beehive/updates/dist/2.1AW/noarch',
    'rhn/updates/2.1AW/en/os/noarch');
insert into rhnBeehivePathMap (path, beehive_path, ftp_path) values
   ('2.1AW/en/os/SRPMS',
    'beehive/updates/dist/2.1AW/SRPMS',
    'rhn/updates/2.1AW/en/os/SRPMS');
insert into rhnBeehivePathMap (path, beehive_path, ftp_path) values
   ('2.1ES/en/os/noarch',
    'beehive/updates/dist/2.1ES/noarch',
    'rhn/updates/2.1ES/en/os/noarch');
insert into rhnBeehivePathMap (path, beehive_path, ftp_path) values
   ('2.1ES/en/os/athlon',
    'beehive/updates/dist/2.1ES/athlon',
    'rhn/updates/2.1ES/en/os/athlon');
insert into rhnBeehivePathMap (path, beehive_path, ftp_path) values
   ('2.1ES/en/os/i386',
    'beehive/updates/dist/2.1ES/i386',
    'rhn/updates/2.1ES/en/os/i386');
insert into rhnBeehivePathMap (path, beehive_path, ftp_path) values
   ('2.1ES/en/os/i686',
    'beehive/updates/dist/2.1ES/i686',
    'rhn/updates/2.1ES/en/os/i686');
insert into rhnBeehivePathMap (path, beehive_path, ftp_path) values
   ('2.1ES/en/os/SRPMS',
    'beehive/updates/dist/2.1ES/SRPMS',
    'rhn/updates/2.1ES/en/os/SRPMS');
insert into rhnBeehivePathMap (path, beehive_path, ftp_path) values
   ('2.1WS/en/os/noarch',
    'beehive/updates/dist/2.1WS/noarch',
    'rhn/updates/2.1WS/en/os/noarch');
insert into rhnBeehivePathMap (path, beehive_path, ftp_path) values
   ('2.1WS/en/os/athlon',
    'beehive/updates/dist/2.1WS/athlon',
    'rhn/updates/2.1WS/en/os/athlon');
insert into rhnBeehivePathMap (path, beehive_path, ftp_path) values
   ('2.1WS/en/os/i386',
    'beehive/updates/dist/2.1WS/i386',
    'rhn/updates/2.1WS/en/os/i386');
insert into rhnBeehivePathMap (path, beehive_path, ftp_path) values
   ('2.1WS/en/os/i686',
    'beehive/updates/dist/2.1WS/i686',
    'rhn/updates/2.1WS/en/os/i686');
insert into rhnBeehivePathMap (path, beehive_path, ftp_path) values
   ('2.1WS/en/os/SRPMS',
    'beehive/updates/dist/2.1WS/SRPMS',
    'rhn/updates/2.1WS/en/os/SRPMS');
insert into rhnBeehivePathMap (path, beehive_path, ftp_path) values
   ('enterprise/2.1AS/en/SH4.0/noarch',
   'beehive/updates/stronghold/2.1AS/noarch',
   'rhn/updates/stronghold/2.1AS/noarch');
insert into rhnBeehivePathMap (path, beehive_path, ftp_path) values
   ('enterprise/2.1AS/en/SH4.0/i386',
   'beehive/updates/stronghold/2.1AS/i386',
   'rhn/updates/stronghold/2.1AS/i386');
insert into rhnBeehivePathMap (path, beehive_path, ftp_path) values
   ('enterprise/2.1AS/en/SH4.0/SRPMS',
   'beehive/updates/stronghold/2.1AS/SRPMS',
   'rhn/updates/stronghold/2.1AS/SRPMS');
insert into rhnBeehivePathMap (path, beehive_path, ftp_path) values
   ('2.1AS/en/SH4.0/noarch',
   'beehive/updates/stronghold/2.1AS/noarch',
   'rhn/updates/stronghold/2.1AS/noarch');
insert into rhnBeehivePathMap (path, beehive_path, ftp_path) values
   ('2.1AS/en/SH4.0/i386',
   'beehive/updates/stronghold/2.1AS/i386',
   'rhn/updates/stronghold/2.1AS/i386');
insert into rhnBeehivePathMap (path, beehive_path, ftp_path) values
   ('2.1AS/en/SH4.0/SRPMS',
   'beehive/updates/stronghold/2.1AS/SRPMS',
   'rhn/updates/stronghold/2.1AS/SRPMS');
insert into rhnBeehivePathMap (path, beehive_path, ftp_path) values
   ('8.0/en/os/noarch',
    'beehive/updates/dist/8.0/noarch',
    'redhat/linux/updates/8.0/en/os/noarch');
insert into rhnBeehivePathMap (path, beehive_path, ftp_path) values
   ('8.0/en/os/i386',
    'beehive/updates/dist/8.0/i386',
    'redhat/linux/updates/8.0/en/os/i386');
insert into rhnBeehivePathMap (path, beehive_path, ftp_path) values
   ('8.0/en/os/i586',
    'beehive/updates/dist/8.0/i586',
    'redhat/linux/updates/8.0/en/os/i586');
insert into rhnBeehivePathMap (path, beehive_path, ftp_path) values
   ('8.0/en/os/i686',
    'beehive/updates/dist/8.0/i686',
    'redhat/linux/updates/8.0/en/os/i686');
insert into rhnBeehivePathMap (path, beehive_path, ftp_path) values
   ('8.0/en/os/athlon',
    'beehive/updates/dist/8.0/athlon',
    'redhat/linux/updates/8.0/en/os/athlon');
insert into rhnBeehivePathMap (path, beehive_path, ftp_path) values
   ('8.0/en/os/SRPMS',
    'beehive/updates/dist/8.0/SRPMS',
    'redhat/linux/updates/8.0/en/os/SRPMS');
insert into rhnBeehivePathMap (path, beehive_path, ftp_path) values
   ('9/en/os/noarch',
    'beehive/updates/dist/9/noarch',
    'redhat/linux/updates/9/en/os/noarch');
insert into rhnBeehivePathMap (path, beehive_path, ftp_path) values
   ('9/en/os/i386',
    'beehive/updates/dist/9/i386',
    'redhat/linux/updates/9/en/os/i386');
insert into rhnBeehivePathMap (path, beehive_path, ftp_path) values
   ('9/en/os/i586',
    'beehive/updates/dist/9/i586',
    'redhat/linux/updates/9/en/os/i586');
insert into rhnBeehivePathMap (path, beehive_path, ftp_path) values
   ('9/en/os/i686',
    'beehive/updates/dist/9/i686',
    'redhat/linux/updates/9/en/os/i686');
insert into rhnBeehivePathMap (path, beehive_path, ftp_path) values
   ('9/en/os/athlon',
    'beehive/updates/dist/9/athlon',
    'redhat/linux/updates/9/en/os/athlon');
insert into rhnBeehivePathMap (path, beehive_path, ftp_path) values
   ('9/en/os/SRPMS',
    'beehive/updates/dist/9/SRPMS',
    'redhat/linux/updates/9/en/os/SRPMS');
insert into rhnBeehivePathMap (path, beehive_path, ftp_path) values
   ('7.1/en/os/iSeries/noarch',
    'beehive/updates/dist/7.1-ppc-i/noarch',
    'redhat/linux/updates/7.1/en/os/iSeries/noarch');
insert into rhnBeehivePathMap (path, beehive_path, ftp_path) values
   ('7.1/en/os/iSeries/ppc',
    'beehive/updates/dist/7.1-ppc-i/ppc',
    'redhat/linux/updates/7.1/en/os/iSeries/ppc');
insert into rhnBeehivePathMap (path, beehive_path, ftp_path) values
   ('7.1/en/os/iSeries/ppc64',
    'beehive/updates/dist/7.1-ppc-i/ppc64',
    'redhat/linux/updates/7.1/en/os/iSeries/ppc64');
insert into rhnBeehivePathMap (path, beehive_path, ftp_path) values
   ('7.1/en/os/iSeries/SRPMS',
    'beehive/updates/dist/7.1-ppc-i/SRPMS',
    'redhat/linux/updates/7.1/en/os/iSeries/SRPMS');
insert into rhnBeehivePathMap (path, beehive_path, ftp_path) values
   ('7.1/en/os/pSeries/noarch',
    'beehive/updates/dist/7.1-ppc-p/noarch',
    'redhat/linux/updates/7.1/en/os/pSeries/noarch');
insert into rhnBeehivePathMap (path, beehive_path, ftp_path) values
   ('7.1/en/os/pSeries/ppc',
    'beehive/updates/dist/7.1-ppc-p/ppc',
    'redhat/linux/updates/7.1/en/os/pSeries/ppc');
insert into rhnBeehivePathMap (path, beehive_path, ftp_path) values
   ('7.1/en/os/pSeries/ppc64',
    'beehive/updates/dist/7.1-ppc-p/ppc64',
    'redhat/linux/updates/7.1/en/os/pSeries/ppc64');
insert into rhnBeehivePathMap (path, beehive_path, ftp_path) values
   ('7.1/en/os/pSeries/SRPMS',
    'beehive/updates/dist/7.1-ppc-p/SRPMS',
    'redhat/linux/updates/7.1/en/os/pSeries/SRPMS');
insert into rhnBeehivePathMap (path, beehive_path, ftp_path)
    values ('5.1/en/cms/noarch', 'beehive/updates/cms/5.1/noarch', 
        'rhn/updates/cms/5.1/noarch');
insert into rhnBeehivePathMap (path, beehive_path, ftp_path)
    values ('5.1/en/cms/i386', 'beehive/updates/cms/5.1/i386', 
        'rhn/updates/cms/5.1/i386');
insert into rhnBeehivePathMap (path, beehive_path, ftp_path)
    values ('5.1/en/cms/SRPMS', 'beehive/updates/cms/5.1/SRPMS', 
        'rhn/updates/cms/5.1/SRPMS');
insert into rhnBeehivePathMap (path, beehive_path, ftp_path)
    values ('5.2/en/cms/noarch', 'beehive/updates/cms/5.2/noarch', 
        'rhn/updates/cms/5.2/noarch');
insert into rhnBeehivePathMap (path, beehive_path, ftp_path)
    values ('5.2/en/cms/i386', 'beehive/updates/cms/5.2/i386', 
        'rhn/updates/cms/5.2/i386');
insert into rhnBeehivePathMap (path, beehive_path, ftp_path)
    values ('5.2/en/cms/SRPMS', 'beehive/updates/cms/5.2/SRPMS', 
        'rhn/updates/cms/5.2/SRPMS');
insert into rhnBeehivePathMap (path, beehive_path, ftp_path)
    values ('6.0/en/cms/noarch', 'beehive/updates/cms/6.0/noarch', 
        'rhn/updates/cms/6.0/noarch');
insert into rhnBeehivePathMap (path, beehive_path, ftp_path)
    values ('6.0/en/cms/i386', 'beehive/updates/cms/6.0/i386', 
        'rhn/updates/cms/6.0/i386');
insert into rhnBeehivePathMap (path, beehive_path, ftp_path)
    values ('6.0/en/cms/SRPMS', 'beehive/updates/cms/6.0/SRPMS', 
        'rhn/updates/cms/6.0/SRPMS');
insert into rhnBeehivePathMap (path, beehive_path, ftp_path)
    values ('6.0/en/waf/noarch', 'beehive/updates/waf/6.0/noarch', 
        'rhn/updates/waf/6.0/noarch');
insert into rhnBeehivePathMap (path, beehive_path, ftp_path)
    values ('6.0/en/waf/i386', 'beehive/updates/waf/6.0/i386', 
        'rhn/updates/waf/6.0/i386');
insert into rhnBeehivePathMap (path, beehive_path, ftp_path)
    values ('6.0/en/waf/SRPMS', 'beehive/updates/waf/6.0/SRPMS', 
        'rhn/updates/waf/6.0/SRPMS');
insert into rhnBeehivePathMap (path, beehive_path, ftp_path)
    values ('3AS/en/os/athlon', 'beehive/updates/dist/3AS/athlon',
        'rhn/updates/3AS/athlon');
insert into rhnBeehivePathMap (path, beehive_path, ftp_path)
    values ('3AS/en/os/i386', 'beehive/updates/dist/3AS/i386',
        'rhn/updates/3AS/i386');
insert into rhnBeehivePathMap (path, beehive_path, ftp_path)
    values ('3AS/en/os/i686', 'beehive/updates/dist/3AS/i686',
        'rhn/updates/3AS/i686');
insert into rhnBeehivePathMap (path, beehive_path, ftp_path)
    values ('3AS/en/os/ia64', 'beehive/updates/dist/3AS/ia64',
        'rhn/updates/3AS/ia64');
insert into rhnBeehivePathMap (path, beehive_path, ftp_path)
    values ('3AS/en/os/noarch', 'beehive/updates/dist/3AS/noarch',
        'rhn/updates/3AS/noarch');
insert into rhnBeehivePathMap (path, beehive_path, ftp_path)
    values ('3AS/en/os/ppc', 'beehive/updates/dist/3AS/ppc',
        'rhn/updates/3AS/ppc');
insert into rhnBeehivePathMap (path, beehive_path, ftp_path)
    values ('3AS/en/os/ppc64', 'beehive/updates/dist/3AS/ppc64',
        'rhn/updates/3AS/ppc64');
insert into rhnBeehivePathMap (path, beehive_path, ftp_path)
    values ('3AS/en/os/ppc64iseries', 'beehive/updates/dist/3AS/ppc64iseries',
        'rhn/updates/3AS/ppc64iseries');
insert into rhnBeehivePathMap (path, beehive_path, ftp_path)
    values ('3AS/en/os/ppc64pseries', 'beehive/updates/dist/3AS/ppc64pseries',
        'rhn/updates/3AS/ppc64pseries');
insert into rhnBeehivePathMap (path, beehive_path, ftp_path)
    values ('3AS/en/os/s390', 'beehive/updates/dist/3AS/s390',
        'rhn/updates/3AS/s390');
insert into rhnBeehivePathMap (path, beehive_path, ftp_path)
    values ('3AS/en/os/s390x', 'beehive/updates/dist/3AS/s390x',
        'rhn/updates/3AS/s390x');
insert into rhnBeehivePathMap (path, beehive_path, ftp_path)
    values ('3AS/en/os/SRPMS', 'beehive/updates/dist/3AS/SRPMS',
        'rhn/updates/3AS/SRPMS');
insert into rhnBeehivePathMap (path, beehive_path, ftp_path)
    values ('3AS/en/os/x86_64', 'beehive/updates/dist/3AS/x86_64',
        'rhn/updates/3AS/x86_64');
insert into rhnBeehivePathMap (path, beehive_path, ftp_path)
    values ('3ES/en/os/athlon', 'beehive/updates/dist/3ES/athlon',
        'rhn/updates/3ES/athlon');
insert into rhnBeehivePathMap (path, beehive_path, ftp_path)
    values ('3ES/en/os/i386', 'beehive/updates/dist/3ES/i386',
        'rhn/updates/3ES/i386');
insert into rhnBeehivePathMap (path, beehive_path, ftp_path)
    values ('3ES/en/os/i686', 'beehive/updates/dist/3ES/i686',
        'rhn/updates/3ES/i686');
insert into rhnBeehivePathMap (path, beehive_path, ftp_path)
    values ('3ES/en/os/ia64', 'beehive/updates/dist/3ES/ia64',
        'rhn/updates/3ES/ia64');
insert into rhnBeehivePathMap (path, beehive_path, ftp_path)
    values ('3ES/en/os/noarch', 'beehive/updates/dist/3ES/noarch',
        'rhn/updates/3ES/noarch');
insert into rhnBeehivePathMap (path, beehive_path, ftp_path)
    values ('3ES/en/os/ppc', 'beehive/updates/dist/3ES/ppc',
        'rhn/updates/3ES/ppc');
insert into rhnBeehivePathMap (path, beehive_path, ftp_path)
    values ('3ES/en/os/ppc64', 'beehive/updates/dist/3ES/ppc64',
        'rhn/updates/3ES/ppc64');
insert into rhnBeehivePathMap (path, beehive_path, ftp_path)
    values ('3ES/en/os/ppc64iseries', 'beehive/updates/dist/3ES/ppc64iseries',
        'rhn/updates/3ES/ppc64iseries');
insert into rhnBeehivePathMap (path, beehive_path, ftp_path)
    values ('3ES/en/os/ppc64pseries', 'beehive/updates/dist/3ES/ppc64pseries',
        'rhn/updates/3ES/ppc64pseries');
insert into rhnBeehivePathMap (path, beehive_path, ftp_path)
    values ('3ES/en/os/s390', 'beehive/updates/dist/3ES/s390',
        'rhn/updates/3ES/s390');
insert into rhnBeehivePathMap (path, beehive_path, ftp_path)
    values ('3ES/en/os/s390x', 'beehive/updates/dist/3ES/s390x',
        'rhn/updates/3ES/s390x');
insert into rhnBeehivePathMap (path, beehive_path, ftp_path)
    values ('3ES/en/os/SRPMS', 'beehive/updates/dist/3ES/SRPMS',
        'rhn/updates/3ES/SRPMS');
insert into rhnBeehivePathMap (path, beehive_path, ftp_path)
    values ('3ES/en/os/x86_64', 'beehive/updates/dist/3ES/x86_64',
        'rhn/updates/3ES/x86_64');
insert into rhnBeehivePathMap (path, beehive_path, ftp_path)
    values ('3WS/en/os/athlon', 'beehive/updates/dist/3WS/athlon',
        'rhn/updates/3WS/athlon');
insert into rhnBeehivePathMap (path, beehive_path, ftp_path)
    values ('3WS/en/os/i386', 'beehive/updates/dist/3WS/i386',
        'rhn/updates/3WS/i386');
insert into rhnBeehivePathMap (path, beehive_path, ftp_path)
    values ('3WS/en/os/i686', 'beehive/updates/dist/3WS/i686',
        'rhn/updates/3WS/i686');
insert into rhnBeehivePathMap (path, beehive_path, ftp_path)
    values ('3WS/en/os/ia64', 'beehive/updates/dist/3WS/ia64',
        'rhn/updates/3WS/ia64');
insert into rhnBeehivePathMap (path, beehive_path, ftp_path)
    values ('3WS/en/os/noarch', 'beehive/updates/dist/3WS/noarch',
        'rhn/updates/3WS/noarch');
insert into rhnBeehivePathMap (path, beehive_path, ftp_path)
    values ('3WS/en/os/ppc', 'beehive/updates/dist/3WS/ppc',
        'rhn/updates/3WS/ppc');
insert into rhnBeehivePathMap (path, beehive_path, ftp_path)
    values ('3WS/en/os/ppc64', 'beehive/updates/dist/3WS/ppc64',
        'rhn/updates/3WS/ppc64');
insert into rhnBeehivePathMap (path, beehive_path, ftp_path)
    values ('3WS/en/os/ppc64iseries', 'beehive/updates/dist/3WS/ppc64iseries',
        'rhn/updates/3WS/ppc64iseries');
insert into rhnBeehivePathMap (path, beehive_path, ftp_path)
    values ('3WS/en/os/ppc64pseries', 'beehive/updates/dist/3WS/ppc64pseries',
        'rhn/updates/3WS/ppc64pseries');
insert into rhnBeehivePathMap (path, beehive_path, ftp_path)
    values ('3WS/en/os/s390', 'beehive/updates/dist/3WS/s390',
        'rhn/updates/3WS/s390');
insert into rhnBeehivePathMap (path, beehive_path, ftp_path)
    values ('3WS/en/os/s390x', 'beehive/updates/dist/3WS/s390x',
        'rhn/updates/3WS/s390x');
insert into rhnBeehivePathMap (path, beehive_path, ftp_path)
    values ('3WS/en/os/SRPMS', 'beehive/updates/dist/3WS/SRPMS',
        'rhn/updates/3WS/SRPMS');
insert into rhnBeehivePathMap (path, beehive_path, ftp_path)
    values ('3WS/en/os/x86_64', 'beehive/updates/dist/3WS/x86_64',
        'rhn/updates/3WS/x86_64');
commit;

select '../rhn/procs/lookup_evr.sql' sql_file from dual;
-- SQL relevant contents from file ../rhn/procs/lookup_evr.sql
CREATE OR REPLACE FUNCTION
LOOKUP_EVR(e_in IN VARCHAR2, v_in IN VARCHAR2, r_in IN VARCHAR2)
RETURN NUMBER
DETERMINISTIC
IS
	PRAGMA AUTONOMOUS_TRANSACTION;
	evr_id		NUMBER;
BEGIN
	SELECT id INTO evr_id
          FROM rhnPackageEvr 
         WHERE ((epoch IS NULL and e_in IS NULL) OR (epoch = e_in)) 
           AND version = v_in AND release = r_in;
	RETURN evr_id;
EXCEPTION
        WHEN NO_DATA_FOUND THEN
            INSERT INTO rhnPackageEvr (id, epoch, version, release, evr) 
            VALUES (rhn_pkg_evr_seq.nextval, e_in, v_in, r_in, 
                EVR_T(e_in, v_in, r_in))
            RETURNING id INTO evr_id;
        COMMIT;
	RETURN evr_id;
END;
/
SHOW ERRORS

select '../rhn/procs/lookup_package_name.sql' sql_file from dual;
-- SQL relevant contents from file ../rhn/procs/lookup_package_name.sql
CREATE OR REPLACE FUNCTION
LOOKUP_PACKAGE_NAME(name_in IN VARCHAR2, ignore_null in number := 0)
RETURN NUMBER
DETERMINISTIC
IS
	PRAGMA AUTONOMOUS_TRANSACTION;
	name_id		NUMBER;
BEGIN
	if ignore_null = 1 and name_in is null then
		return null;
	end if;
	SELECT id
          INTO name_id
          FROM rhnPackageName 
         WHERE name = name_in;
	RETURN name_id;
EXCEPTION
        WHEN NO_DATA_FOUND THEN
            INSERT INTO rhnPackageName (id, name) 
                VALUES (rhn_pkg_name_seq.nextval, name_in)
                RETURNING id INTO name_id;
            COMMIT;
	RETURN name_id;
END;
/
SHOW ERRORS

select '../rhn/tables/rhnPackageNEVRA.sql' sql_file from dual;
-- SQL relevant contents from file ../rhn/tables/rhnPackageNEVRA.sql
create sequence rhn_pkgnevra_id_seq;
create table
rhnPackageNEVRA
(
	id			number
				constraint rhn_pkgnevra_id_nn not null
				constraint rhn_pkgnevra_id_pk primary key
					using index tablespace [[8m_tbs]],
	name_id			number
				constraint rhn_pkgnevra_nid_nn not null
				constraint rhn_pkgnevra_nid_fk
					references rhnPackageName(id),
	evr_id			number
				constraint rhn_pkgnevra_eid_nn not null
				constraint rhn_pkgnevra_eid_fk
					references rhnPackageEVR(id),
	package_arch_id		number
				constraint rhn_pkgnevra_paid_fk
					references rhnPackageArch(id)
)
	storage ( freelists 16 )
	initrans 32;
create index rhn_pkgnevra_nid_evrid_id_idx
	on rhnPackageNEVRA( name_id, evr_id, id )
	tablespace [[32m_tbs]]
	storage ( freelists 16 )
	initrans 32;

select '../rhn/procs/lookup_package_nevra.sql' sql_file from dual;
-- SQL relevant contents from file ../rhn/procs/lookup_package_nevra.sql
create or replace function
lookup_package_nevra(
	name_id_in in varchar2,
	evr_id_in in varchar2,
	package_arch_id_in in varchar2,
	ignore_null_name in number := 0
) return number
deterministic
is
	pragma autonomous_transaction;
	nevra_id number;
BEGIN
	if ignore_null_name = 1 and name_id_in is null then
		return null;
	end if;
	select	id
	into	nevra_id
	from	rhnPackageNEVRA
	where	1=1
		and name_id = name_id_in
		and evr_id = evr_id_in
		and (package_arch_id = package_arch_id_in or
			(package_arch_id is null
			 and package_arch_id_in is null));
	return nevra_id;
exception
	when no_data_found then
		insert into rhnPackageNEVRA
			(id, name_id, evr_id, package_arch_id)
			values
			(	rhn_pkgnevra_id_seq.nextval, 
				name_id_in, evr_id_in, package_arch_id_in
			) returning id into nevra_id;
		commit;
		return nevra_id;
end;
/
show errors

select '../rhn/procs/lookup_source_name.sql' sql_file from dual;
-- SQL relevant contents from file ../rhn/procs/lookup_source_name.sql
CREATE OR REPLACE FUNCTION
LOOKUP_SOURCE_NAME(name_in IN VARCHAR2)
RETURN NUMBER
DETERMINISTIC
IS
	PRAGMA AUTONOMOUS_TRANSACTION;
	source_id	NUMBER;
BEGIN
        select	id into source_id
        from	rhnSourceRPM 
        where	name = name_in;
        RETURN source_id;
EXCEPTION
        WHEN NO_DATA_FOUND THEN
            insert into rhnSourceRPM(id, name)
                    values (rhn_sourcerpm_id_seq.nextval, name_in)
                    returning id into source_id;
            COMMIT;
            RETURN source_id;
END;
/
SHOW ERRORS

select '../rhn/tables/rhnException_data.sql' sql_file from dual;
-- SQL relevant contents from file ../rhn/tables/rhnException_data.sql
insert into rhnException values (-20002, 'testing_error', 'An error used for testing and testing only');
insert into rhnException values (-20100, 'channel_no_parent_subscription', 'A server must be subscribed to the parent channel to subscribe to the child channel');
insert into rhnException values (-20101, 'channel_must_subscribe_to_parent', 'A server must be subscribed to all parents of all children');
insert into rhnException values (-20102, 'channel_server_one_base', 'A server can be subscribed to at most one base channel');
insert into rhnException values (-20200, 'usergroup_max_members', 'User group membership cannot exceed maximum membership');
insert into rhnException values (-20220, 'servergroup_max_members', 'Server group membership cannot exceed maximum membership');
insert into rhnException values (-20230, 'ugm_different_orgs', 'User and usergroup must be in same group to make a user a member');
insert into rhnException values (-20231, 'sgm_different_orgs', 'Server and servergroup must be in same group to make a server a member');
insert into rhnException values (-20232, 'no_org_admin_group', 'Organization has no org_admin usergroup');
insert into rhnException values (-20233, 'sg_delete_typed', 'Special server groups (non-null group_type) cannot be deleted');
insert into rhnException values (-20234, 'ug_delete_typed', 'Special user groups (non-null group_type) cannot be deleted');
insert into rhnException values (-20235, 'channel_family_no_subscriptions', 'Channel family subscription count cannot exceed maximum membership');
insert into rhnException values (-20236, 'channel_subscribe_no_family', 'Attempt to subscribe to a channel with no family');
insert into rhnException values (-20237, 'invalid_enterprise_flag','Enterprise flag must be Y or N');
insert into rhnException values (-20238, 'channel_unsubscribe_no_family','Attempt to unsubscribe from a channel with no family');
insert into rhnException values (-20239, 'arch_not_found','Architecture could not be found');
insert into rhnException values (-20240, 'channel_consent_no_license','No license agreement exists for that channel');
insert into rhnException values (-20241, 'channel_subscrib_no_consent','Channel requires consent to license for subscription');
insert into rhnException values (-20242, 'channel_arch_not_found','Channel architecture could not be found');
insert into rhnException values (-20243, 'package_arch_not_found','Package architecture could not be found');
insert into rhnException values (-20244, 'server_arch_not_found','Server architecture could not be found');
insert into rhnException values (-20245, 'cpu_arch_not_found','CPU architecture could not be found');
insert into rhnException values (-20246, 'channel_unsubscribe_child_exists','Unsubscribe failed because server is subscribed to child channels');
insert into rhnException values (-20247, 'null_email_address','A user must have either a pending or a validated email address');
insert into rhnException values (-20248, 'invalid_item_code','The specified item does not exist');
insert into rhnException values (-20249, 'invalid_server_group','The specified server group does not exist');
insert into rhnException values (-20250, 'invalid_channel_family','The specified channel family does not exist');
insert into rhnException values (-20251, 'invalid_state','The specified state does not exist');
insert into rhnException values (-20253, 'invalid_state_transition','The specified transition is not allowed');
insert into rhnException values (-20254, 'ep_error','Entitlement Proxy error');
insert into rhnException values (-20255, 'cannot_delete_user','The specified user may not be deleted.');
insert into rhnException values (-20256, 'no_channel_product','No products were found to entitle this channel');
insert into rhnException values (-20257, 'no_server_multiple_swmgr_entitlements','Server is already entitled');
insert into rhnException values (-20258, 'erratafile_type_not_found','No such errata file type exists');
insert into rhnException values (-20259, 'invalid_quantity','Number fields may not be null');
insert into rhnException values (-20260, 'invalid_operation','The operation specified is not supported');
insert into rhnException values (-20261, 'sgm_insert_diff_orgs','Server does not belong to same org as server_group');
insert into rhnException values (-20262, 'invalid_transaction_operation', 'Invalid transaction operation');
insert into rhnException values (-20263, 'no_subscribe_permissions','Insufficient permissions for subscription');
insert into rhnException values (-20264, 'invalid_user_group','The specified user group does not exist');
insert into rhnException values (-20265, 'invalid_snapshot_invalid_reason','The specified reason for snapshot invalidation does not exist');
insert into rhnException values (-20266, 'action_is_child','The specified action is in a chain, but is not the first action in the chain');
insert into rhnException values (-20267, 'not_enough_quota','Insufficient available quota for the specified action');
insert into rhnException values (-20268, 'server_not_in_group','The specified server is not a member of the specified group');
insert into rhnException values (-20269, 'servergroup_use_upgrade', 'The specified server group is full, upgrades are available');
insert into rhnException values (-20270, 'invalid_upgrade', 'The specified server cannot be upgraded from management to provisioning');
commit;

select '../rhn/tables/rhnChannelArch_data.sql' sql_file from dual;
-- SQL relevant contents from file ../rhn/tables/rhnChannelArch_data.sql
insert into rhnChannelArch (id, label, name) values
(rhn_channel_arch_id_seq.nextval, 'channel-ia32', 'IA-32');
insert into rhnChannelArch (id, label, name) values
(rhn_channel_arch_id_seq.nextval, 'channel-ia64', 'IA-64');
insert into rhnChannelArch (id, label, name) values
(rhn_channel_arch_id_seq.nextval, 'channel-sparc', 'Sparc');
insert into rhnChannelArch (id, label, name) values
(rhn_channel_arch_id_seq.nextval, 'channel-alpha', 'Alpha');
insert into rhnChannelArch (id, label, name) values
(rhn_channel_arch_id_seq.nextval, 'channel-s390', 's390');
insert into rhnChannelArch (id, label, name) values
(rhn_channel_arch_id_seq.nextval, 'channel-s390x', 's390x');
insert into rhnChannelArch (id, label, name) values
(rhn_channel_arch_id_seq.nextval, 'channel-iSeries', 'iSeries');
insert into rhnChannelArch (id, label, name) values
(rhn_channel_arch_id_seq.nextval, 'channel-pSeries', 'pSeries');
insert into rhnChannelArch (id, label, name) values
(rhn_channel_arch_id_seq.nextval, 'channel-x86_64', 'AMD64');
insert into rhnChannelArch (id, label, name) values
(rhn_channel_arch_id_seq.nextval, 'channel-ppc', 'PPC');
commit;

select '../rhn/procs/lookup_channel_arch.sql' sql_file from dual;
-- SQL relevant contents from file ../rhn/procs/lookup_channel_arch.sql
CREATE OR REPLACE FUNCTION
LOOKUP_CHANNEL_ARCH(label_in IN VARCHAR2)
RETURN NUMBER
DETERMINISTIC
IS
	PRAGMA AUTONOMOUS_TRANSACTION;
	channel_arch_id		NUMBER;
BEGIN
	SELECT id
          INTO channel_arch_id
          FROM rhnChannelArch
         WHERE label = label_in;
	RETURN channel_arch_id;
EXCEPTION
        WHEN NO_DATA_FOUND THEN
            rhn_exception.raise_exception('channel_arch_not_found');
END;
/
SHOW ERRORS

select '../rhn/tables/rhnServerArch_data.sql' sql_file from dual;
-- SQL relevant contents from file ../rhn/tables/rhnServerArch_data.sql
insert into rhnServerArch (id, label, name) values
(rhn_server_arch_id_seq.nextval, 'i386-redhat-linux', 'i386');
insert into rhnServerArch (id, label, name) values
(rhn_server_arch_id_seq.nextval, 'i486-redhat-linux', 'i486');
insert into rhnServerArch (id, label, name) values
(rhn_server_arch_id_seq.nextval, 'i586-redhat-linux', 'i586');
insert into rhnServerArch (id, label, name) values
(rhn_server_arch_id_seq.nextval, 'i686-redhat-linux', 'i686');
insert into rhnServerArch (id, label, name) values
(rhn_server_arch_id_seq.nextval, 'athlon-redhat-linux', 'athlon');
insert into rhnServerArch (id, label, name) values
(rhn_server_arch_id_seq.nextval, 'alpha-redhat-linux', 'alpha');
insert into rhnServerArch (id, label, name) values
(rhn_server_arch_id_seq.nextval, 'alphaev6-redhat-linux', 'alphaev6');
insert into rhnServerArch (id, label, name) values
(rhn_server_arch_id_seq.nextval, 'ia64-redhat-linux', 'ia64');
insert into rhnServerArch (id, label, name) values
(rhn_server_arch_id_seq.nextval, 'sparc-redhat-linux', 'sparc');
insert into rhnServerArch (id, label, name) values
(rhn_server_arch_id_seq.nextval, 'sparcv9-redhat-linux', 'sparcv9');
insert into rhnServerArch (id, label, name) values
(rhn_server_arch_id_seq.nextval, 'sparc64-redhat-linux', 'sparc64');
insert into rhnServerArch (id, label, name) values
(rhn_server_arch_id_seq.nextval, 's390-redhat-linux', 's390');
insert into rhnServerArch (id, label, name) values
(rhn_server_arch_id_seq.nextval, 's390x-redhat-linux', 's390x');
insert into rhnServerArch (id, label, name) values
(rhn_server_arch_id_seq.nextval, 'ppc-redhat-linux', 'ppc');
insert into rhnServerArch (id, label, name) values
(rhn_server_arch_id_seq.nextval, 'ppc64-redhat-linux', 'ppc64');
insert into rhnServerArch (id, label, name) values
(rhn_server_arch_id_seq.nextval, 'pSeries-redhat-linux', 'pSeries');
insert into rhnServerArch (id, label, name) values
(rhn_server_arch_id_seq.nextval, 'iSeries-redhat-linux', 'iSeries');
insert into rhnServerArch (id, label, name) values
(rhn_server_arch_id_seq.nextval, 'x86_64-redhat-linux', 'x86_64');
insert into rhnServerArch (id, label, name) values
(rhn_server_arch_id_seq.nextval, 'ppc64iseries-redhat-linux', 'ppc64iseries');
insert into rhnServerArch (id, label, name) values
(rhn_server_arch_id_seq.nextval, 'ppc64pseries-redhat-linux', 'ppc64pseries');
commit;

select '../rhn/procs/lookup_server_arch.sql' sql_file from dual;
-- SQL relevant contents from file ../rhn/procs/lookup_server_arch.sql
CREATE OR REPLACE FUNCTION
LOOKUP_SERVER_ARCH(label_in IN VARCHAR2)
RETURN NUMBER
DETERMINISTIC
IS
	PRAGMA AUTONOMOUS_TRANSACTION;
	server_arch_id		NUMBER;
BEGIN
	SELECT id
          INTO server_arch_id
          FROM rhnServerArch
         WHERE label = label_in;
	RETURN server_arch_id;
EXCEPTION
        WHEN NO_DATA_FOUND THEN
            rhn_exception.raise_exception('server_arch_not_found');
END;
/
SHOW ERRORS

select '../rhn/tables/rhnPackageArch_data.sql' sql_file from dual;
-- SQL relevant contents from file ../rhn/tables/rhnPackageArch_data.sql
insert into rhnPackageArch (id, label, name) values
(rhn_package_arch_id_seq.nextval, 'noarch', 'noarch');
insert into rhnPackageArch (id, label, name) values
(rhn_package_arch_id_seq.nextval, 'i386', 'i386');
insert into rhnPackageArch (id, label, name) values
(rhn_package_arch_id_seq.nextval, 'i486', 'i486');
insert into rhnPackageArch (id, label, name) values
(rhn_package_arch_id_seq.nextval, 'i586', 'i586');
insert into rhnPackageArch (id, label, name) values
(rhn_package_arch_id_seq.nextval, 'i686', 'i686');
insert into rhnPackageArch (id, label, name) values
(rhn_package_arch_id_seq.nextval, 'alpha', 'alpha');
insert into rhnPackageArch (id, label, name) values
(rhn_package_arch_id_seq.nextval, 'alphaev6', 'alphaev6');
insert into rhnPackageArch (id, label, name) values
(rhn_package_arch_id_seq.nextval, 'ia64', 'ia64');
insert into rhnPackageArch (id, label, name) values
(rhn_package_arch_id_seq.nextval, 'sparc', 'sparc');
insert into rhnPackageArch (id, label, name) values
(rhn_package_arch_id_seq.nextval, 'sparcv9', 'sparcv9');
insert into rhnPackageArch (id, label, name) values
(rhn_package_arch_id_seq.nextval, 'sparc64', 'sparc64');
insert into rhnPackageArch (id, label, name) values
(rhn_package_arch_id_seq.nextval, 'src', 'src');
insert into rhnPackageArch (id, label, name) values
(rhn_package_arch_id_seq.nextval, 's390', 's390');
insert into rhnPackageArch (id, label, name) values
(rhn_package_arch_id_seq.nextval, 'athlon', 'athlon');
insert into rhnPackageArch (id, label, name) values
(rhn_package_arch_id_seq.nextval, 's390x', 's390x');
insert into rhnPackageArch (id, label, name) values
(rhn_package_arch_id_seq.nextval, 'ppc', 'ppc');
insert into rhnPackageArch (id, label, name) values
(rhn_package_arch_id_seq.nextval, 'ppc64', 'ppc64');
insert into rhnPackageArch (id, label, name) values
(rhn_package_arch_id_seq.nextval, 'pSeries', 'pSeries');
insert into rhnPackageArch (id, label, name) values
(rhn_package_arch_id_seq.nextval, 'iSeries', 'iSeries');
insert into rhnPackageArch (id, label, name) values
(rhn_package_arch_id_seq.nextval, 'x86_64', 'x86_64');
insert into rhnPackageArch (id, label, name) values
(rhn_package_arch_id_seq.nextval, 'ppc64iseries', 'ppc64iseries');
insert into rhnPackageArch (id, label, name) values
(rhn_package_arch_id_seq.nextval, 'ppc64pseries', 'ppc64pseries');
commit;

select '../rhn/procs/lookup_package_arch.sql' sql_file from dual;
-- SQL relevant contents from file ../rhn/procs/lookup_package_arch.sql
CREATE OR REPLACE FUNCTION
LOOKUP_PACKAGE_ARCH(label_in IN VARCHAR2)
RETURN NUMBER
DETERMINISTIC
IS
	PRAGMA AUTONOMOUS_TRANSACTION;
	package_arch_id		NUMBER;
BEGIN
	SELECT id
          INTO package_arch_id
          FROM rhnPackageArch
         WHERE label = label_in;
	RETURN package_arch_id;
EXCEPTION
        WHEN NO_DATA_FOUND THEN
            rhn_exception.raise_exception('package_arch_not_found');
END;
/
SHOW ERRORS

select '../rhn/procs/lookup_package_capability.sql' sql_file from dual;
-- SQL relevant contents from file ../rhn/procs/lookup_package_capability.sql
CREATE OR REPLACE FUNCTION
LOOKUP_PACKAGE_CAPABILITY(name_in IN VARCHAR2, 
    version_in IN VARCHAR2 DEFAULT NULL)
RETURN NUMBER
DETERMINISTIC
IS
	PRAGMA AUTONOMOUS_TRANSACTION;
	name_id		NUMBER;
BEGIN
	IF version_in IS NULL THEN
		SELECT id
		  INTO name_id
		  FROM rhnPackageCapability
		 WHERE name = name_in
		   AND version IS NULL;
	ELSE
		SELECT id
		  INTO name_id
		  FROM rhnPackageCapability
		 WHERE name = name_in
		   AND version = version_in;
	END IF;
	RETURN name_id;
EXCEPTION
        WHEN NO_DATA_FOUND THEN
            INSERT INTO rhnPackageCapability (id, name, version) 
                VALUES (rhn_pkg_capability_id_seq.nextval, name_in, version_in)
                RETURNING id INTO name_id;
            COMMIT;
	RETURN name_id;
END;
/
SHOW ERRORS

select '../rhn/tables/rhnErrataFileType.sql' sql_file from dual;
-- SQL relevant contents from file ../rhn/tables/rhnErrataFileType.sql
create sequence rhn_erratafile_type_id_seq;
create table
rhnErrataFileType
(
	id		number
			constraint rhn_erratafile_type_id_nn not null,
	label		varchar2(128)
			constraint rhn_erratafile_type_label_nn not null
)
	storage ( freelists 16 )
	initrans 32;
create index rhn_erratafile_type_id_idx
	on rhnErrataFileType ( id )
	tablespace [[64k_tbs]]
	storage ( freelists 16 )
	initrans 32;
alter table rhnErrataFileType add constraint rhn_erratafile_type_id_pk
	primary key ( id );
create index rhn_erratafile_type_label_idx
	on rhnErrataFileType ( label )
	tablespace [[64k_tbs]]
	storage ( freelists 16 )
	initrans 32;
alter table rhnErrataFileType add constraint rhn_erratafile_type_label_uq
	unique ( label );

select '../rhn/tables/rhnErrataFileType_data.sql' sql_file from dual;
-- SQL relevant contents from file ../rhn/tables/rhnErrataFileType_data.sql
insert into rhnErrataFileType ( id, label )
	values ( rhn_erratafile_type_id_seq.nextval, 'RPM' );
insert into rhnErrataFileType ( id, label )
	values ( rhn_erratafile_type_id_seq.nextval, 'SRPM' );
insert into rhnErrataFileType ( id, label )
	values ( rhn_erratafile_type_id_seq.nextval, 'IMG' );

select '../rhn/procs/lookup_erratafile_type.sql' sql_file from dual;
-- SQL relevant contents from file ../rhn/procs/lookup_erratafile_type.sql
create or replace function
lookup_erratafile_type (
	label_in in varchar2
) return number deterministic is
	pragma autonomous_transaction;
	erratafile_type_id number;
begin
	select	id
	into	erratafile_type_id
	from	rhnErrataFileType
	where	label = label_in;
	return erratafile_type_id;
exception
	when no_data_found then
		rhn_exception.raise_exception('erratafile_type_not_found');
end;
/
show errors

select '../rhn/tables/rhnKickstartCommandName.sql' sql_file from dual;
-- SQL relevant contents from file ../rhn/tables/rhnKickstartCommandName.sql
create sequence rhn_kscommandname_id_seq;
create table
rhnKickstartCommandName
(
        id              number
			constraint rhn_kscommandname_id_nn not null
                        constraint rhn_kscommandname_id_pk primary key
				using index tablespace [[2m_tbs]],
        name            varchar2(128)
			constraint rhn_kscommand_name_nn not null
)
	storage ( freelists 16 )
	initrans 32;
create index rhn_kscommandname_name_id_idx
	on rhnKickstartCommandName( name, id )
	tablespace [[2m_tbs]]
	storage ( freelists 16 )
	initrans 32;
alter table rhnKickstartCommandName add constraint rhn_kscommandname_name_uq
	unique ( name );

select '../rhn/procs/lookup_ks_command_name.sql' sql_file from dual;
-- SQL relevant contents from file ../rhn/procs/lookup_ks_command_name.sql
create or replace function
lookup_ks_command_name(name_in IN VARCHAR2, ignore_null in number := 0)
return number
deterministic
is
	pragma autonomous_transaction;
	name_id		number;
begin
	if ignore_null = 1 and name_in is null then
		return null;
	end if;
	select	id
	into	name_id
	from	rhnKickstartCommandName
	where	name = name_in;
	return name_id;
exception
	when no_data_found then
		insert into rhnKickstartCommandName( id, name )
			values (rhn_kscommandname_id_seq.nextval, name_in)
			returning id into name_id;
		commit;
		return name_id;
end;
/
show errors

select '../rhn/tables/rhnSnapshotInvalidReason.sql' sql_file from dual;
-- SQL relevant contents from file ../rhn/tables/rhnSnapshotInvalidReason.sql
create sequence rhn_ssinvalid_id_seq;
create table
rhnSnapshotInvalidReason
(
	id			number
				constraint rhn_ssinvalid_id_nn not null
				constraint rhn_ssinvalid_id_pk primary key
					using index tablespace [[64k_tbs]],
	label			varchar2(32)
				constraint rhn_ssinvalid_label_nn not null,
	name			varchar2(128)
				constraint rhn_ssinvalid_name_nn not null,
	created			date default(sysdate)
				constraint rhn_ssinvalid_created_nn not null,
	modified		date default(sysdate)
				constraint rhn_ssinvalid_modified_nn not null
)
	storage ( freelists 16 )
	initrans 32;
create unique index rhn_ssinvalid_label_uq
	on rhnSnapshotInvalidReason(label)
	tablespace [[64k_tbs]]
	storage ( freelists 16 )
	initrans 32;
create or replace trigger
rhn_ssinvalid_mod_trig
before insert or update on rhnSnapshotInvalidReason
for each row
begin
	:new.modified := sysdate;
end;
/
show errors

select '../rhn/procs/lookup_snapshot_invalid_reason.sql' sql_file from dual;
-- SQL relevant contents from file ../rhn/procs/lookup_snapshot_invalid_reason.sql
CREATE OR REPLACE FUNCTION
lookup_snapshot_invalid_reason(label_in IN VARCHAR2)
RETURN NUMBER
DETERMINISTIC
IS
	PRAGMA AUTONOMOUS_TRANSACTION;
	snapshot_invalid_reason_id number;
BEGIN
	SELECT id
          INTO snapshot_invalid_reason_id
          FROM rhnSnapshotInvalidReason
         WHERE label = label_in;
	RETURN snapshot_invalid_reason_id;
EXCEPTION
        WHEN NO_DATA_FOUND THEN
            rhn_exception.raise_exception('invalid_snapshot_invalid_reason');
END;
/
SHOW ERRORS

select '../rhn/tables/rhnTagName.sql' sql_file from dual;
-- SQL relevant contents from file ../rhn/tables/rhnTagName.sql
create table
rhnTagName
(
        id              number
        	    	constraint rhn_tn_id_nn not null
    	    	    	constraint rhn_tn_id_pk primary key,
        name            varchar2(128)
    	    	    	constraint rhn_tn_name_nn not null,
       	created		date default(sysdate)
			constraint rhn_tn_created_nn not null,
	modified	date default(sysdate)
			constraint rhn_tn_modified_nn not null
);
create unique index rhn_tn_name_uq
    	on rhnTagName(name);
create sequence rhn_tagname_id_seq;
create or replace trigger
rhn_tn_mod_trig
before insert or update on rhnTagName
for each row
begin
        :new.modified := sysdate;
end;
/
show errors

select '../rhn/procs/lookup_tag_name.sql' sql_file from dual;
-- SQL relevant contents from file ../rhn/procs/lookup_tag_name.sql
CREATE OR REPLACE FUNCTION
LOOKUP_TAG_NAME(name_in IN VARCHAR2)
RETURN NUMBER
DETERMINISTIC
IS
	PRAGMA AUTONOMOUS_TRANSACTION;
	name_id     NUMBER;
BEGIN
        select id into name_id
	  from rhnTagName
	 where name = name_in;
        RETURN name_id;
EXCEPTION
        WHEN NO_DATA_FOUND THEN
            insert into rhnTagName(id, name)
                    values (rhn_tagname_id_seq.nextval, name_in)
                    returning id into name_id;
            COMMIT;
            RETURN name_id;
END;
/
SHOW ERRORS

select '../rhn/tables/rhnTag.sql' sql_file from dual;
-- SQL relevant contents from file ../rhn/tables/rhnTag.sql
create table
rhnTag
(
	id              number
			constraint rhn_tag_id_nn not null
			constraint rhn_tag_id_pk primary key,
	name_id         number
	    	    	constraint rhn_tag_nid_nn not null
			constraint rhn_tag_nid_fk
				references rhnTagName(id),
        org_id          number
                        constraint rhn_tag_oid_nn not null
                        constraint rhn_tag_oid_fk
                                references web_customer(id)
				on delete cascade,
       	created		date default(sysdate)
			constraint rhn_tag_created_nn not null,
	modified	date default(sysdate)
			constraint rhn_tag_modified_nn not null
);
create unique index rhn_tag_oid_nid_uq
    	on rhnTag(org_id, name_id);
create sequence rhn_tag_id_seq;
create or replace trigger
rhn_tag_mod_trig
before insert or update on rhnTag
for each row
begin
        :new.modified := sysdate;
end;
/
show errors

select '../rhn/procs/lookup_tag.sql' sql_file from dual;
-- SQL relevant contents from file ../rhn/procs/lookup_tag.sql
CREATE OR REPLACE FUNCTION
LOOKUP_TAG(org_id_in IN NUMBER, name_in IN VARCHAR2)
RETURN NUMBER
DETERMINISTIC
IS
	PRAGMA AUTONOMOUS_TRANSACTION;
	tag_id     NUMBER;
BEGIN
        select id into tag_id
	  from rhnTag
	 where org_id = org_id_in
	   and name_id = lookup_tag_name(name_in);
        RETURN tag_id;
EXCEPTION
        WHEN NO_DATA_FOUND THEN
            insert into rhnTag(id, org_id, name_id)
                    values (rhn_tag_id_seq.nextval, org_id_in, lookup_tag_name(name_in))
                    returning id into tag_id;
            COMMIT;
            RETURN tag_id;
END;
/
SHOW ERRORS

select '../rhn/tables/rhnBlacklistObsoletes.sql' sql_file from dual;
-- SQL relevant contents from file ../rhn/tables/rhnBlacklistObsoletes.sql
create table rhnBlacklistObsoletes
(
	name_id			number
				constraint rhn_bl_obs_nid_nn not null
				constraint rhn_bl_obs_nid_fk
					references rhnPackageName(id),
	evr_id			number
				constraint rhn_bl_obs_eid_nn not null
				constraint rhn_bl_obs_eid_fk
					references rhnPackageEVR(id),
	package_arch_id		number
				constraint rhn_bl_obs_paid_nn not null
				constraint rhn_bl_obs_paid_fk
					references rhnPackageArch(id),
	ignore_name_id		number
				constraint rhn_bl_obs_inid_nn not null
				constraint rhn_bl_obs_inid_fk
					references rhnPackageName(id),
	created			date default(sysdate)
				constraint rhn_bl_obs_created_nn not null,
	modified		date default(sysdate)
				constraint rhn_bl_obs_modified_nn not null
);
create index rhn_bl_obs_nepi_idx
	on rhnBlacklistObsoletes ( name_id, evr_id, package_arch_id, 
		ignore_name_id )
	storage ( freelists 16 )
	initrans 32;
alter table rhnBlacklistObsoletes add constraint rhn_bl_obs_nepi_uq
	unique ( name_id, evr_id, package_arch_id, ignore_name_id );
create or replace trigger
rhn_bl_obs_mod_trig
before insert or update on rhnBlacklistObsoletes
for each row
begin
	:new.modified := sysdate;
end;
/
show errors
create or replace trigger
rhn_bl_obs_chan_last_mod_trig
before insert or update or delete on rhnBlacklistObsoletes
for each row
begin
	update rhnChannel
	set last_modified = greatest(sysdate, last_modified + 1/86400)
        where id in (
            select cp.channel_id
            from rhnChannelPackage cp, rhnPackage p
            where cp.package_id = p.id
            and p.name_id = :old.name_id
            and p.evr_id = :old.evr_id
            and p.package_arch_id = :old.package_arch_id
        );
end;
/
show errors

select '../rhn/tables/rhnBlacklistObsoletes_data.sql' sql_file from dual;
-- SQL relevant contents from file ../rhn/tables/rhnBlacklistObsoletes_data.sql
insert into rhnBlacklistObsoletes
  (name_id, evr_id, package_arch_id, ignore_name_id)
values (
    LOOKUP_PACKAGE_NAME('gated'), LOOKUP_EVR(NULL, '3.6', '12'), 
    LOOKUP_PACKAGE_ARCH('i386'), LOOKUP_PACKAGE_NAME('zebra')
);
insert into rhnBlacklistObsoletes
  (name_id, evr_id, package_arch_id, ignore_name_id)
values (
    LOOKUP_PACKAGE_NAME('zebra'), LOOKUP_EVR(NULL, '0.91a', '6'), 
    LOOKUP_PACKAGE_ARCH('i386'), LOOKUP_PACKAGE_NAME('gated')
);
insert into rhnBlacklistObsoletes
  (name_id, evr_id, package_arch_id, ignore_name_id)
select
    LOOKUP_PACKAGE_NAME('gated'), LOOKUP_EVR(NULL, '3.6', '10'), 
    pa.id, LOOKUP_PACKAGE_NAME('zebra')
from rhnPackageArch pa
where pa.label in ('i386', 'alpha');
insert into rhnBlacklistObsoletes
  (name_id, evr_id, package_arch_id, ignore_name_id)
select
    LOOKUP_PACKAGE_NAME('zebra'), LOOKUP_EVR(NULL, '0.91a', '3'), 
    pa.id, LOOKUP_PACKAGE_NAME('gated')
from rhnPackageArch pa
where pa.label in ('i386', 'alpha');
commit;

select '../rhn/tables/rhnFile.sql' sql_file from dual;
-- SQL relevant contents from file ../rhn/tables/rhnFile.sql
create table
rhnFile
(
	id		number
			constraint rhn_file_id_nn not null
			constraint rhn_file_id_pk primary key
				using index tablespace [[64k_tbs]],
	org_id		number
			constraint rhn_file_oid_fk
				references web_customer(id)
				on delete cascade,
	file_size	number
			constraint rhn_file_fs_nn not null,
	md5sum		varchar2(64)
			constraint rhn_file_md5sum_nn not null,
	path		varchar2(1000)
			constraint rhn_file_path_nn not null,
	created		date default(sysdate)
			constraint rhn_file_created_nn not null,
	modified	date default(sysdate)
			constraint rhn_file_modified_nn not null
)
	storage ( freelists 16 )
	initrans 32;
create sequence rhn_file_id_seq;
create unique index rhn_file_path_uq
	on rhnFile(path)
	tablespace [[2m_tbs]]
	storage ( freelists 16 )
	initrans 32;

select '../rhn/tables/rhnDownloadType.sql' sql_file from dual;
-- SQL relevant contents from file ../rhn/tables/rhnDownloadType.sql
create table
rhnDownloadType
(
	id		number
			constraint rhn_download_type_id_nn not null
			constraint rhn_download_type_pk primary key,
	label		varchar2(48)
			constraint rhn_download_type_label_nn not null,
	name		varchar2(96)
			constraint rhn_download_type_name_nn not null
);
create unique index rhn_download_type_label_uq
	on rhnDownloadType(label);
create unique index rhn_download_type_name_uq
	on rhnDownloadType(name);

select '../rhn/tables/rhnDownloads.sql' sql_file from dual;
-- SQL relevant contents from file ../rhn/tables/rhnDownloads.sql
create table
rhnDownloads
(
	id		number
			constraint rhn_dl_id_nn not null
			constraint rhn_dl_id_pk primary key,
	channel_family_id  number
			constraint rhn_dl_cfid_nn not null
			constraint rhn_dl_cfid_fk
				references rhnChannelFamily(id),
	file_id 	number
			constraint rhn_dl_fid_nn not null
			constraint rhn_dl_fid_fk
			     	references rhnFile(id),
        name            varchar2(128)
	    	    	constraint rhn_dl_name_nn not null,			
        category        varchar2(128)
	    	    	constraint rhn_dl_cat_nn not null,
	ordering        number
			constraint rhn_dl_ord_nn not null,
        download_type  	number
			constraint rhn_dl_dltype_fk
				references rhnDownloadType(id),
	created		date default(sysdate)
			constraint rhn_dl_created_nn not null,
	modified	date default(sysdate)
			constraint rhn_dl_modified_nn not null
)
	storage ( freelists 16 )
	initrans 32;
create sequence rhn_download_id_seq;
create or replace trigger
rhn_download_mod_trig
before insert or update on rhnDownloads
for each row
begin
	:new.modified := sysdate;
end;
/
show errors

select '../rhn/tables/rhnChannelDownloads.sql' sql_file from dual;
-- SQL relevant contents from file ../rhn/tables/rhnChannelDownloads.sql
create table
rhnChannelDownloads
(
	channel_id	number
			constraint rhn_cd_cid_nn not null 
			constraint rhn_cd_cid_fk
				references rhnChannel(id) on delete cascade,
	downloads_id	number
			constraint rhn_cd_did_nn not null
			constraint rhn_cd_did_fk
				references rhnDownloads(id),
	created		date default (sysdate)
			constraint rhn_cd_created_nn not null,
	modified	date default (sysdate)
			constraint rhn_cd_modified_nn not null
);
create unique index rhn_cd_ce_uq
	on rhnChannelDownloads(channel_id, downloads_id);
create index rhn_cd_did_cid_idx
	on rhnChannelDownloads(downloads_id, channel_id);

select '../rhn/tables/rhnChannelErrata.sql' sql_file from dual;
-- SQL relevant contents from file ../rhn/tables/rhnChannelErrata.sql
create table
rhnChannelErrata
(
	channel_id	number
			constraint rhn_ce_cid_nn not null 
			constraint rhn_ce_cid_fk
				references rhnChannel(id)
				on delete cascade,
	errata_id	number
			constraint rhn_ce_eid_nn not null
			constraint rhn_ce_eid_fk
				references rhnErrata(id)
				on delete cascade,
	created		date default (sysdate)
			constraint rhn_ce_created_nn not null,
	modified	date default (sysdate)
			constraint rhn_ce_modified_nn not null
)
	storage ( freelists 16 )
	initrans 32;
create unique index rhn_ce_ce_uq
	on rhnChannelErrata(channel_id, errata_id)
	tablespace [[64k_tbs]]
	storage ( freelists 16 )
	initrans 32;
create index rhn_ce_eid_cid_idx
	on rhnChannelErrata(errata_id, channel_id)
	tablespace [[64k_tbs]]
	storage ( freelists 16 )
	initrans 32;

select '../rhn/tables/rhnChannelFamilyLicenseConsent.sql' sql_file from dual;
-- SQL relevant contents from file ../rhn/tables/rhnChannelFamilyLicenseConsent.sql
CREATE TABLE
rhnChannelFamilyLicenseConsent
(
        channel_family_id   number
			    constraint rhn_cfl_consent_cfid_nn not null
    	    	    	    constraint rhn_cfl_consent_cfid_fk
                            	references rhnChannelFamily(id) on delete cascade,
    	user_id             number
	    	       	    constraint rhn_cfl_consent_uid_nn not null
			    constraint rhn_cfl_consent_uid_fk
			    	references web_contact(id) on delete cascade,
	server_id           number
			    constraint rhn_cfl_consent_sid_nn not null
			    constraint rhn_cfl_consent_sid_fk
			    	references rhnServer(id) on delete cascade,
       	created		date default (sysdate)
			constraint rhn_cfl_consent_created_nn not null,
	modified	date default (sysdate)
			constraint rhn_cfl_consent_modified_nn not null
)
	storage ( freelists 16 )
	initrans 32;
create unique index rhn_cfl_consent_cf_s_uq
	on rhnChannelFamilyLicenseConsent(channel_family_id, server_id)
	tablespace [[64k_tbs]]
	storage ( freelists 16 )
	initrans 32;
create index rhn_cfl_consent_uid_idx
	on rhnChannelFamilyLicenseConsent ( user_id )
	tablespace [[64k_tbs]]
	storage ( freelists 16 )
	initrans 32
	nologging;
create or replace trigger
rhn_cfl_consent_mod_trig
before insert or update on rhnChannelFamilyLicenseConsent
for each row
begin
        :new.modified := sysdate;
end;
/
SHOW ERRORS;

select '../rhn/tables/rhnChannelFamilyLicense.sql' sql_file from dual;
-- SQL relevant contents from file ../rhn/tables/rhnChannelFamilyLicense.sql
CREATE TABLE
rhnChannelFamilyLicense
(
        channel_family_id   number
			    constraint rhn_cfl_cfid_nn not null
    	    	    	    constraint rhn_cfl_cfid_fk
                            	references rhnChannelFamily(id)
				on delete cascade,
    	license_path        varchar2(1000)
	    	       	    constraint rhn_cfl_license_nn not null,
	created		date default (sysdate)
			constraint rhn_cfl_created_nn not null,
	modified	date default (sysdate)
			constraint rhn_cfl_modified_nn not null
)
	storage ( freelists 16 )
	initrans 32;
create unique index rhn_cf_license_cfid_uq
	on rhnChannelFamilyLicense(channel_family_id)
	tablespace [[64k_tbs]]
	storage ( freelists 16 )
	initrans 32;
create or replace trigger
rhn_cf_license_mod_trig
before insert or update on rhnChannelFamilyLicense
for each row
begin
        :new.modified := sysdate;
end;
/
SHOW ERRORS;

select '../rhn/tables/rhnChannelFamilyMembers.sql' sql_file from dual;
-- SQL relevant contents from file ../rhn/tables/rhnChannelFamilyMembers.sql
create table
rhnChannelFamilyMembers
(
        channel_id      number
                        constraint rhn_cf_members_c_nn not null
                        constraint rhn_cf_members_c_fk
                                references rhnChannel(id) on delete cascade,
        channel_family_id number
                        constraint rhn_cf_family_nn not null
                        constraint rhn_cf_family_fk
                                references rhnChannelFamily(id),
        created         date default(sysdate)
                        constraint rhn_cf_member_cre_nn not null,
        modified        date default(sysdate)
                        constraint rhn_cf_member_mod_nn not null
)
	storage ( freelists 16 )
	initrans 32;
create unique index rhn_cf_member_uq
	on rhnChannelFamilyMembers(channel_id, channel_family_id)
	tablespace [[64k_tbs]]
	storage ( freelists 16 )
	initrans 32;
create unique index rhn_cf_c_uq
	on rhnChannelFamilyMembers(channel_id)
	tablespace [[64k_tbs]]
	storage ( freelists 16 )
	initrans 32;
create index rhn_cf_member_cf_c_idx
	on rhnChannelFamilyMembers(channel_family_id, channel_id)
	tablespace [[64k_tbs]]
	storage ( freelists 16 )
	initrans 32
	nologging;
create or replace trigger
rhn_cf_member_mod_trig
before insert or update on rhnChannelFamilyMembers
for each row
begin
	:new.modified := sysdate;
end;
/
show errors

select '../rhn/tables/rhnChannelNewestPackageAudit.sql' sql_file from dual;
-- SQL relevant contents from file ../rhn/tables/rhnChannelNewestPackageAudit.sql
create table
rhnChannelNewestPackageAudit
(
        refresh_time            date default sysdate
                                constraint rhn_cnp_at_rt_nn not null,
	channel_id		number
				constraint rhn_cnp_at_cid_nn not null
				constraint rhn_cnp_at_cid_fk
					references rhnChannel(id)
                                        on delete cascade,
        caller                  varchar2(256)
                                constraint rhn_cnp_at_caller_nn not null
)
	storage ( freelists 16 )
	initrans 32;
create index rhn_cnp_a_t_all_idx
	on rhnChannelNewestPackageAudit(channel_id, refresh_time, caller)
	tablespace [[8m_tbs]]
	storage ( freelists 16 )
	initrans 32;

select '../rhn/tables/rhnChannelNewestPackage.sql' sql_file from dual;
-- SQL relevant contents from file ../rhn/tables/rhnChannelNewestPackage.sql
create table
rhnChannelNewestPackage
(
	channel_id		number
				constraint rhn_cnp_cid_nn not null
				constraint rhn_cnp_cid_fk
					references rhnChannel(id)
					on delete cascade,
	name_id			number
				constraint rhn_cnp_nid_nn not null
				constraint rhn_cnp_nid_fk
					references rhnPackageName(id),
	evr_id			number
				constraint rhn_cnp_eid_nn not null
				constraint rhn_cnp_eid_fk
					references rhnPackageEVR(id),
	package_arch_id		number
				constraint rhn_cnp_paid_nn not null
				constraint rhn_cnp_paid_fk
					references rhnPackageArch(id),
	package_id		number
				constraint rhn_cnp_pid_nn not null
				constraint rhn_cnp_pid_fk
					references rhnPackage(id)
					on delete cascade
)
	storage ( freelists 16 )
	initrans 32;
create index rhn_cnp_cnep_idx
	on rhnChannelNewestPackage(channel_id, name_id, 
		package_arch_id, evr_id, package_id)
	tablespace [[8m_tbs]]
	storage ( freelists 16 )
	initrans 32;
alter table rhnChannelNewestPackage add constraint rhn_cnp_cid_nid_uq
	unique ( channel_id, name_id, package_arch_id );
create index rhn_cnp_necp_idx
	on rhnChannelNewestPackage(name_id, evr_id, channel_id, package_id)
	tablespace [[8m_tbs]]
	storage ( freelists 16 )
	initrans 32;
create index rhn_cnp_pid_idx
	on rhnChannelNewestPackage( package_id )
	tablespace [[2m_tbs]]
	storage ( freelists 16 )
	initrans 32;

select '../rhn/tables/rhnChannelPackageArchCompat.sql' sql_file from dual;
-- SQL relevant contents from file ../rhn/tables/rhnChannelPackageArchCompat.sql
create table
rhnChannelPackageArchCompat
(
        channel_arch_id	number
                        constraint rhn_cp_ac_caid_nn not null
                        constraint rhn_cp_ac_caid_fk 
				references rhnChannelArch(id),
	package_arch_id	number
			constraint rhn_cp_ac_paid_nn not null
			constraint rhn_cp_ac_paid_fk
				references rhnPackageArch(id),
	created		date default(sysdate)
			constraint rhn_cp_ac_created_nn not null,
	modified	date default(sysdate)
			constraint rhn_cp_ac_modified_nn not null
)
	storage ( freelists 16 )
	initrans 32;
create index rhn_cp_ac_caid_paid
	on rhnChannelPackageArchCompat(
		channel_arch_id, package_arch_id)
	tablespace [[64k_tbs]]
	storage ( freelists 16 )
	initrans 32;
alter table rhnChannelPackageArchCompat add constraint rhn_cp_ac_caid_paid_uq
	unique ( channel_arch_id, package_arch_id );
create index rhn_cp_ac_paid_caid
	on rhnChannelPackageArchCompat(
	 	package_arch_id, channel_arch_id)
	tablespace [[64k_tbs]]
	storage ( freelists 16 )
	initrans 32;
create or replace trigger
rhn_cp_ac_mod_trig
before insert or update on rhnChannelPackageArchCompat
for each row
begin
        :new.modified := sysdate;
end;
/
show errors

select '../rhn/tables/rhnChannelPackageArchCompat_data.sql' sql_file from dual;
-- SQL relevant contents from file ../rhn/tables/rhnChannelPackageArchCompat_data.sql
insert into rhnChannelPackageArchCompat (channel_arch_id, package_arch_id)
values (LOOKUP_CHANNEL_ARCH('channel-ia32'), LOOKUP_PACKAGE_ARCH('noarch'));
insert into rhnChannelPackageArchCompat (channel_arch_id, package_arch_id)
values (LOOKUP_CHANNEL_ARCH('channel-ia32'), LOOKUP_PACKAGE_ARCH('i386'));
insert into rhnChannelPackageArchCompat (channel_arch_id, package_arch_id)
values (LOOKUP_CHANNEL_ARCH('channel-ia32'), LOOKUP_PACKAGE_ARCH('i486'));
insert into rhnChannelPackageArchCompat (channel_arch_id, package_arch_id)
values (LOOKUP_CHANNEL_ARCH('channel-ia32'), LOOKUP_PACKAGE_ARCH('i586'));
insert into rhnChannelPackageArchCompat (channel_arch_id, package_arch_id)
values (LOOKUP_CHANNEL_ARCH('channel-ia32'), LOOKUP_PACKAGE_ARCH('i686'));
insert into rhnChannelPackageArchCompat (channel_arch_id, package_arch_id)
values (LOOKUP_CHANNEL_ARCH('channel-ia32'), LOOKUP_PACKAGE_ARCH('src'));
insert into rhnChannelPackageArchCompat (channel_arch_id, package_arch_id)
values (LOOKUP_CHANNEL_ARCH('channel-ia32'), LOOKUP_PACKAGE_ARCH('athlon'));
insert into rhnChannelPackageArchCompat (channel_arch_id, package_arch_id)
values (LOOKUP_CHANNEL_ARCH('channel-ia64'), LOOKUP_PACKAGE_ARCH('noarch'));
insert into rhnChannelPackageArchCompat (channel_arch_id, package_arch_id)
values (LOOKUP_CHANNEL_ARCH('channel-ia64'), LOOKUP_PACKAGE_ARCH('i386'));
insert into rhnChannelPackageArchCompat (channel_arch_id, package_arch_id)
values (LOOKUP_CHANNEL_ARCH('channel-ia64'), LOOKUP_PACKAGE_ARCH('i486'));
insert into rhnChannelPackageArchCompat (channel_arch_id, package_arch_id)
values (LOOKUP_CHANNEL_ARCH('channel-ia64'), LOOKUP_PACKAGE_ARCH('i586'));
insert into rhnChannelPackageArchCompat (channel_arch_id, package_arch_id)
values (LOOKUP_CHANNEL_ARCH('channel-ia64'), LOOKUP_PACKAGE_ARCH('i686'));
insert into rhnChannelPackageArchCompat (channel_arch_id, package_arch_id)
values (LOOKUP_CHANNEL_ARCH('channel-ia64'), LOOKUP_PACKAGE_ARCH('ia64'));
insert into rhnChannelPackageArchCompat (channel_arch_id, package_arch_id)
values (LOOKUP_CHANNEL_ARCH('channel-ia64'), LOOKUP_PACKAGE_ARCH('src'));
insert into rhnChannelPackageArchCompat (channel_arch_id, package_arch_id)
values (LOOKUP_CHANNEL_ARCH('channel-sparc'), LOOKUP_PACKAGE_ARCH('noarch'));
insert into rhnChannelPackageArchCompat (channel_arch_id, package_arch_id)
values (LOOKUP_CHANNEL_ARCH('channel-sparc'), LOOKUP_PACKAGE_ARCH('sparc'));
insert into rhnChannelPackageArchCompat (channel_arch_id, package_arch_id)
values (LOOKUP_CHANNEL_ARCH('channel-sparc'), LOOKUP_PACKAGE_ARCH('sparcv9'));
insert into rhnChannelPackageArchCompat (channel_arch_id, package_arch_id)
values (LOOKUP_CHANNEL_ARCH('channel-sparc'), LOOKUP_PACKAGE_ARCH('sparc64'));
insert into rhnChannelPackageArchCompat (channel_arch_id, package_arch_id)
values (LOOKUP_CHANNEL_ARCH('channel-sparc'), LOOKUP_PACKAGE_ARCH('src'));
insert into rhnChannelPackageArchCompat (channel_arch_id, package_arch_id)
values (LOOKUP_CHANNEL_ARCH('channel-alpha'), LOOKUP_PACKAGE_ARCH('noarch'));
insert into rhnChannelPackageArchCompat (channel_arch_id, package_arch_id)
values (LOOKUP_CHANNEL_ARCH('channel-alpha'), LOOKUP_PACKAGE_ARCH('alpha'));
insert into rhnChannelPackageArchCompat (channel_arch_id, package_arch_id)
values (LOOKUP_CHANNEL_ARCH('channel-alpha'), LOOKUP_PACKAGE_ARCH('alphaev6'));
insert into rhnChannelPackageArchCompat (channel_arch_id, package_arch_id)
values (LOOKUP_CHANNEL_ARCH('channel-alpha'), LOOKUP_PACKAGE_ARCH('src'));
insert into rhnChannelPackageArchCompat (channel_arch_id, package_arch_id)
values (LOOKUP_CHANNEL_ARCH('channel-s390'), LOOKUP_PACKAGE_ARCH('noarch'));
insert into rhnChannelPackageArchCompat (channel_arch_id, package_arch_id)
values (LOOKUP_CHANNEL_ARCH('channel-s390'), LOOKUP_PACKAGE_ARCH('s390'));
insert into rhnChannelPackageArchCompat (channel_arch_id, package_arch_id)
values (LOOKUP_CHANNEL_ARCH('channel-s390'), LOOKUP_PACKAGE_ARCH('src'));
insert into rhnChannelPackageArchCompat (channel_arch_id, package_arch_id)
values (LOOKUP_CHANNEL_ARCH('channel-s390x'), LOOKUP_PACKAGE_ARCH('noarch'));
insert into rhnChannelPackageArchCompat (channel_arch_id, package_arch_id)
values (LOOKUP_CHANNEL_ARCH('channel-s390x'), LOOKUP_PACKAGE_ARCH('s390'));
insert into rhnChannelPackageArchCompat (channel_arch_id, package_arch_id)
values (LOOKUP_CHANNEL_ARCH('channel-s390x'), LOOKUP_PACKAGE_ARCH('s390x'));
insert into rhnChannelPackageArchCompat (channel_arch_id, package_arch_id)
values (LOOKUP_CHANNEL_ARCH('channel-s390x'), LOOKUP_PACKAGE_ARCH('src'));
insert into rhnChannelPackageArchCompat (channel_arch_id, package_arch_id)
values (LOOKUP_CHANNEL_ARCH('channel-iSeries'), LOOKUP_PACKAGE_ARCH('noarch'));
insert into rhnChannelPackageArchCompat (channel_arch_id, package_arch_id)
values (LOOKUP_CHANNEL_ARCH('channel-iSeries'), LOOKUP_PACKAGE_ARCH('s390x'));
insert into rhnChannelPackageArchCompat (channel_arch_id, package_arch_id)
values (LOOKUP_CHANNEL_ARCH('channel-iSeries'), LOOKUP_PACKAGE_ARCH('ppc'));
insert into rhnChannelPackageArchCompat (channel_arch_id, package_arch_id)
values (LOOKUP_CHANNEL_ARCH('channel-iSeries'), LOOKUP_PACKAGE_ARCH('ppc64'));
insert into rhnChannelPackageArchCompat (channel_arch_id, package_arch_id)
values (LOOKUP_CHANNEL_ARCH('channel-iSeries'), LOOKUP_PACKAGE_ARCH('src'));
insert into rhnChannelPackageArchCompat (channel_arch_id, package_arch_id)
values (LOOKUP_CHANNEL_ARCH('channel-pSeries'), LOOKUP_PACKAGE_ARCH('noarch'));
insert into rhnChannelPackageArchCompat (channel_arch_id, package_arch_id)
values (LOOKUP_CHANNEL_ARCH('channel-pSeries'), LOOKUP_PACKAGE_ARCH('ppc'));
insert into rhnChannelPackageArchCompat (channel_arch_id, package_arch_id)
values (LOOKUP_CHANNEL_ARCH('channel-pSeries'), LOOKUP_PACKAGE_ARCH('ppc64'));
insert into rhnChannelPackageArchCompat (channel_arch_id, package_arch_id)
values (LOOKUP_CHANNEL_ARCH('channel-pSeries'), LOOKUP_PACKAGE_ARCH('src'));
insert into rhnChannelPackageArchCompat (channel_arch_id, package_arch_id)
values (LOOKUP_CHANNEL_ARCH('channel-x86_64'), LOOKUP_PACKAGE_ARCH('noarch'));
insert into rhnChannelPackageArchCompat (channel_arch_id, package_arch_id)
values (LOOKUP_CHANNEL_ARCH('channel-x86_64'), LOOKUP_PACKAGE_ARCH('i386'));
insert into rhnChannelPackageArchCompat (channel_arch_id, package_arch_id)
values (LOOKUP_CHANNEL_ARCH('channel-x86_64'), LOOKUP_PACKAGE_ARCH('i486'));
insert into rhnChannelPackageArchCompat (channel_arch_id, package_arch_id)
values (LOOKUP_CHANNEL_ARCH('channel-x86_64'), LOOKUP_PACKAGE_ARCH('i586'));
insert into rhnChannelPackageArchCompat (channel_arch_id, package_arch_id)
values (LOOKUP_CHANNEL_ARCH('channel-x86_64'), LOOKUP_PACKAGE_ARCH('i686'));
insert into rhnChannelPackageArchCompat (channel_arch_id, package_arch_id)
values (LOOKUP_CHANNEL_ARCH('channel-x86_64'), LOOKUP_PACKAGE_ARCH('athlon'));
insert into rhnChannelPackageArchCompat (channel_arch_id, package_arch_id)
values (LOOKUP_CHANNEL_ARCH('channel-x86_64'), LOOKUP_PACKAGE_ARCH('x86_64'));
insert into rhnChannelPackageArchCompat (channel_arch_id, package_arch_id)
values (LOOKUP_CHANNEL_ARCH('channel-x86_64'), LOOKUP_PACKAGE_ARCH('src'));
insert into rhnChannelPackageArchCompat (channel_arch_id, package_arch_id)
values (LOOKUP_CHANNEL_ARCH('channel-ppc'), LOOKUP_PACKAGE_ARCH('noarch'));
insert into rhnChannelPackageArchCompat (channel_arch_id, package_arch_id)
values (LOOKUP_CHANNEL_ARCH('channel-ppc'), LOOKUP_PACKAGE_ARCH('ppc'));
insert into rhnChannelPackageArchCompat (channel_arch_id, package_arch_id)
values (LOOKUP_CHANNEL_ARCH('channel-ppc'), LOOKUP_PACKAGE_ARCH('ppc64'));
insert into rhnChannelPackageArchCompat (channel_arch_id, package_arch_id)
values (LOOKUP_CHANNEL_ARCH('channel-ppc'), LOOKUP_PACKAGE_ARCH('ppc64iseries'));
insert into rhnChannelPackageArchCompat (channel_arch_id, package_arch_id)
values (LOOKUP_CHANNEL_ARCH('channel-ppc'), LOOKUP_PACKAGE_ARCH('ppc64pseries'));
insert into rhnChannelPackageArchCompat (channel_arch_id, package_arch_id)
values (LOOKUP_CHANNEL_ARCH('channel-ppc'), LOOKUP_PACKAGE_ARCH('src'));
commit;

select '../rhn/tables/rhnSnapshot.sql' sql_file from dual;
-- SQL relevant contents from file ../rhn/tables/rhnSnapshot.sql
create sequence rhn_snapshot_id_seq;
create table
rhnSnapshot
(
	id			number
				constraint rhn_snapshot_id_nn not null
				constraint rhn_snapshot_id_pk primary key
					using index tablespace [[8m_tbs]],
	org_id			number
				constraint rhn_snapshot_oid_nn not null
				constraint rhn_snapshot_oid_fk
					references web_customer(id),
	invalid			number
				constraint rhn_snapshot_invalid_fk
					references rhnSnapshotInvalidReason(id),
	reason			varchar2(4000)
				constraint rhn_snapshot_reason_nn not null,
	server_id		number
				constraint rhn_snapshot_sid_nn not null
				constraint rhn_snapshot_sid_fk
					references rhnServer(id)
					on delete cascade,
	created			date default(sysdate)
				constraint rhn_snapshot_created_nn not null,
	modified		date default(sysdate)
				constraint rhn_snapshot_modified_nn not null
)
	storage ( freelists 16 )
	initrans 32;
create index rhn_snapshot_sid_idx
	on rhnSnapshot( server_id )
	tablespace [[2m_tbs]]
	storage ( freelists 16 )
	initrans 32
	nologging;
create index rhn_snapshot_oid_idx
	on rhnSnapshot( org_id )
	tablespace [[2m_tbs]]
	storage ( freelists 16 )
	initrans 32
	nologging;

select '../rhn/tables/rhnSnapshotChannel.sql' sql_file from dual;
-- SQL relevant contents from file ../rhn/tables/rhnSnapshotChannel.sql
create table
rhnSnapshotChannel
(
	snapshot_id		number
				constraint rhn_snapchan_sid_nn not null
				constraint rhn_snapchan_sid_fk
					references rhnSnapshot(id)
					on delete cascade,
	channel_id		number
				constraint rhn_snapchan_cid_nn not null
				constraint rhn_snapchan_cid_fk
					references rhnChannel(id)
)
	storage ( freelists 16 )
	initrans 32;
create unique index rhn_snapchan_sid_cid_uq
	on rhnSnapshotChannel( snapshot_id, channel_id )
	tablespace [[8m_tbs]]
	storage ( freelists 16 )
	initrans 32;
create index rhn_snapshot_cid_idx
	on rhnSnapshotChannel( channel_id )
	tablespace [[4m_tbs]]
	storage ( freelists 16 )
	initrans 32
	nologging;
create or replace trigger
rhn_snapchan_mod_trig
before insert or update on rhnSnapshotChannel
for each row
begin
	update rhnSnapshot set modified = sysdate where id = :new.snapshot_id;
end;
/
show errors

select '../rhn/tables/rhnChannelPackage_triggers.sql' sql_file from dual;
-- SQL relevant contents from file ../rhn/tables/rhnChannelPackage_triggers.sql
create or replace trigger
rhn_channel_package_mod_trig
before insert or update on rhnChannelPackage
for each row
declare
	date_to_use	date;
	rc_modified	date;
	cursor snapshots is
		select	snapshot_id id
		from	rhnSnapshotChannel
		where	channel_id = :old.channel_id;
begin
	select	last_modified
	into	rc_modified
	from	rhnChannel
	where	id = :new.channel_id
	for update;
	select	sysdate
	into	date_to_use
	from	dual;
	if date_to_use <= rc_modified then
		date_to_use := rc_modified + 1/86400;
	end if;
	update rhnChannel
		set last_modified = date_to_use
		where id = :new.channel_id;
	:new.modified := date_to_use;
	if updating then
		for snapshot in snapshots loop
			update rhnSnapshot
				set invalid = lookup_snapshot_invalid_reason('channel_modified')
				where id = snapshot.id;
		end loop;
	end if;
end;
/
show errors
create or replace trigger
rhn_channel_package_del_trig
after delete on rhnChannelPackage
for each row
declare
	cursor snapshots is
		select	snapshot_id id
		from	rhnSnapshotChannel
		where	channel_id = :old.channel_id;
begin
	update rhnChannel
		set last_modified = sysdate
		where id = :old.channel_id;
	for snapshot in snapshots loop
		update rhnSnapshot
			set invalid = lookup_snapshot_invalid_reason('channel_modified')
			where id = snapshot.id;
	end loop;
end;
/
show errors

select '../rhn/tables/rhnChannelPermissionRole.sql' sql_file from dual;
-- SQL relevant contents from file ../rhn/tables/rhnChannelPermissionRole.sql
create sequence rhn_cperm_role_id_seq;
create table
rhnChannelPermissionRole
(
	id		number
			constraint rhn_cperm_role_id_nn not null,
	label		varchar2(32)
			constraint rhn_cperm_role_label_nn not null,
	description	varchar2(128)
			constraint rhn_cperm_role_desc_nn not null,
	created		date default(sysdate)
			constraint rhn_cperm_role_created_nn not null,
	modified	date default(sysdate)
			constraint rhn_cperm_role_modified_nn not null
)
	storage ( freelists 16 )
	initrans 32;
create index rhn_cperm_role_id_pk
	on rhnChannelPermissionRole ( id )
	tablespace [[64k_tbs]]
	storage ( freelists 16 )
	initrans 32;
alter table rhnChannelPermissionRole add constraint
	rhn_cperm_role_id_pk primary key ( id );
create index rhn_cperm_role_label_id_idx
	on rhnChannelPermissionRole ( label, id )
	tablespace [[64k_tbs]]
	storage ( freelists 16 )
	initrans 32;
alter table rhnChannelPermissionRole add constraint
	rhn_cperm_role_label_uq unique ( label );
create or replace trigger
rhn_cperm_role_mod_trig
before insert or update on rhnChannelPermissionRole
for each row
begin
	:new.modified := sysdate;
end;
/
show errors

select '../rhn/tables/rhnChannelPermissionRole_data.sql' sql_file from dual;
-- SQL relevant contents from file ../rhn/tables/rhnChannelPermissionRole_data.sql
insert into rhnChannelPermissionRole (id, label, description)
	values (rhn_cperm_role_id_seq.nextval,
		'subscribe',
		'Permission to subscribe to channel');
insert into rhnChannelPermissionRole (id, label, description)
	values (rhn_cperm_role_id_seq.nextval,
		'manage',
		'Permission to manage channel');

select '../rhn/tables/rhnChannelPermission.sql' sql_file from dual;
-- SQL relevant contents from file ../rhn/tables/rhnChannelPermission.sql
create table
rhnChannelPermission
(
	channel_id	number
			constraint rhn_cperm_cid_nn not null
			constraint rhn_cperm_cidffk
				references rhnChannel(id)
				on delete cascade,
	user_id		number
			constraint rhn_cperm_uid_nn not null
			constraint rhn_cperm_uid_fk
				references web_contact(id)
				on delete cascade,
	role_id		number
			constraint rhn_cperm_rid_nn not null
			constraint rhn_cperm_rid_fk
				references rhnChannelPermissionRole(id),
	created		date default(sysdate)
			constraint rhn_cperm_created_nn not null,
	modified	date default(sysdate)
			constraint rhn_cperm_modified_nn not null
)
	storage ( freelists 16 )
	initrans 32;
create unique index rhn_cperm_cid_uid_rid_idx
	on rhnChannelPermission(channel_id, user_id, role_id)
	tablespace [[2m_tbs]]
	storage ( freelists 16 )
	initrans 32;
create or replace trigger
rhn_cperm_mod_trig
before insert or update on rhnChannelPermission
for each row
begin
	:new.modified := sysdate;
end;
/
show errors

select '../rhn/tables/rhnRelationshipType.sql' sql_file from dual;
-- SQL relevant contents from file ../rhn/tables/rhnRelationshipType.sql
create sequence rhn_reltype_id_seq;
create table
rhnRelationshipType
(
	id			number
				constraint rhn_reltype_id_nn not null,
	label			varchar2(32)
				constraint rhn_reltype_label_nn not null,
	description		varchar2(256),
	created			date default(sysdate)
				constraint rhn_reltype_created_nn not null,
	modified		date default(sysdate)
				constraint rhn_reltype_modified_nn not null
)
	storage ( freelists 16 )
	initrans 32;
create index rhn_reltype_id_label_idx
	on rhnRelationshipType ( id, label )
	tablespace [[64k_tbs]]
	storage ( freelists 16 )
	initrans 32;
alter table rhnRelationshipType add constraint rhn_reltype_id_pk
	primary key ( id );
create index rhn_reltype_label_id_idx
	on rhnRelationshipType ( label, id )
	tablespace [[64k_tbs]]
	storage ( freelists 16 )
	initrans 32;
alter table rhnRelationshipType add constraint rhn_reltype_label_uq
	unique ( label );
create or replace trigger
rhn_reltype_mod_trig
before insert or update on rhnRelationshipType
for each row
begin
	:new.modified := sysdate;
end;
/
show errors

select '../rhn/tables/rhnChannelRelationship.sql' sql_file from dual;
-- SQL relevant contents from file ../rhn/tables/rhnChannelRelationship.sql
create table
rhnChannelRelationship
(
	from_channel_id		number
				constraint rhn_channelrel_fcid_nn not null
				constraint rhn_channelrel_fcid_fk
					references rhnChannel(id)
					on delete cascade,
	to_channel_id		number
				constraint rhn_channelrel_tcid_nn not null
				constraint rhn_channelrel_tcid_fk
					references rhnChannel(id)
					on delete cascade,
	rel_type_id		number
				constraint rhn_channelrel_rtid_nn not null
				constraint rhn_channelrel_rtid_fk
					references rhnRelationshipType(id),
	created			date default(sysdate)
				constraint rhn_channelrel_created_nn not null,
	modified		date default(sysdate)
				constraint rhn_channelrel_modified_nn not null
)
	storage ( freelists 16 )
	initrans 32;
create index rhn_channelrel_fcid_tcid_idx
	on rhnChannelRelationship ( from_channel_id, to_channel_id )
	tablespace [[2m_tbs]]
	storage ( freelists 16 )
	initrans 32;
alter table rhnChannelRelationship add constraint rhn_channelrel_fcid_tcid_uq
	unique ( from_channel_id, to_channel_id );
create index rhn_channelrel_tcid_fcid_idx
	on rhnChannelRelationship ( to_channel_id, from_channel_id )
	tablespace [[2m_tbs]]
	storage ( freelists 16 )
	initrans 32;
create or replace trigger
rhn_channelrel_mod_trig
before insert or update on rhnChannelRelationship
for each row
begin
	:new.modified := sysdate;
end;
/
show errors

select '../rhn/tables/rhnChannel_triggers.sql' sql_file from dual;
-- SQL relevant contents from file ../rhn/tables/rhnChannel_triggers.sql
create or replace trigger
rhn_channel_mod_trig
before insert or update on rhnChannel
for each row
begin
	:new.last_modified := sysdate;
	if updating then
		if (:old.id != :new.id) or
		  (:old.parent_channel != :new.parent_channel) or
		  (:old.org_id != :new.org_id) or
		  (:old.channel_arch_id != :new.channel_arch_id) or
		  (:old.label != :new.label) or
		  (:old.basedir != :new.basedir) or
		  (:old.name != :new.name) or
		  (:old.summary != :new.summary) or
		  (:old.description != :new.description) then
			:new.modified := sysdate;
		end if;
	end if;
end;
/
show errors
create or replace trigger
rhn_channel_del_trig
before delete on rhnChannel
for each row
declare
	cursor snapshots is
		select	snapshot_id id
		from	rhnSnapshotChannel
		where	channel_id = :old.id;
begin
	for snapshot in snapshots loop
		update rhnSnapshot
			set invalid = lookup_snapshot_invalid_reason('channel_removed')
			where id = snapshot.id;
		delete from rhnSnapshotChannel
			where snapshot_id = snapshot.id
				and channel_id = :old.id;
	end loop;
end;
/
show errors

select '../rhn/tables/rhnClientCapabilityName.sql' sql_file from dual;
-- SQL relevant contents from file ../rhn/tables/rhnClientCapabilityName.sql
create table
rhnClientCapabilityName
(
	id		number
			constraint rhn_clientcapnam_id_nn not null
			constraint rhn_clientcapnam_id_pk primary key 
				using index tablespace [[8m_tbs]],
	name		varchar2(32)
			constraint rhn_clientcapnam_name_nn not null
) 
	storage (freelists 16 )
	initrans 32;
create sequence rhn_client_capname_id_seq;

select '../rhn/tables/rhnClientCapability.sql' sql_file from dual;
-- SQL relevant contents from file ../rhn/tables/rhnClientCapability.sql
create table
rhnClientCapability
(
	server_id	number
			constraint rhn_clientcap_sid_nn not null
			constraint rhn_clientcap_sid_fk
				references rhnServer(id)
				on delete cascade,
	capability_name_id	number
			constraint rhn_clientcap_cap_nid_nn not null,
	version		varchar2(32)
			constraint rhn_clientcap_ver_nn not null,
	created		date default(sysdate)
			constraint rhn_clientcap_created_nn not null,
	modified	date default(sysdate)
			constraint rhn_clientcap_modified_nn not null
)
	storage ( freelists 16 )
	initrans 32;
create unique index rhn_clientcap_sid_cap_uq
	on rhnClientCapability(server_id, capability_name_id)
	tablespace [[32m_tbs]]
	storage ( freelists 16 )
	initrans 32;
create or replace trigger
rhn_clientcap_mod_trig
before insert or update on rhnClientCapability
for each row
begin
	:new.modified := sysdate;
end;
/
show errors

select '../rhn/tables/rhnSnapshotConfigChannel.sql' sql_file from dual;
-- SQL relevant contents from file ../rhn/tables/rhnSnapshotConfigChannel.sql
create table
rhnSnapshotConfigChannel
(
	snapshot_id		number
				constraint rhn_snapshotcc_sid_nn not null
				constraint rhn_snapshotcc_sid_fk
					references rhnSnapshot(id)
					on delete cascade,
	config_channel_id	number
				constraint rhn_snapshotcc_ccid_nn not null
				constraint rhn_snapshotcc_ccid_fk
					references rhnConfigChannel(id),
	created			date default(sysdate)
				constraint rhn_snapshotcc_creat_nn not null,
	modified		date default(sysdate)
				constraint rhn_snapshotcc_mod_nn not null
)
	storage ( freelists 16 )
	initrans 32;
create unique index rhn_snapshotcc_sid_ccid_uq
	on rhnSnapshotConfigChannel( snapshot_id, config_channel_id )
	tablespace [[4m_tbs]]
	storage ( freelists 16 )
	initrans 32;
create or replace trigger
rhn_snapshotcc_mod_trig
before insert or update on rhnSnapshotConfigChannel
for each row
begin
	:new.modified := sysdate;
end;
/
show errors

select '../rhn/tables/rhnConfigChannel_triggers.sql' sql_file from dual;
-- SQL relevant contents from file ../rhn/tables/rhnConfigChannel_triggers.sql
create or replace trigger
rhn_confchan_mod_trig
before insert or update on rhnConfigChannel
for each row
begin
	:new.modified := sysdate;
end;
/
show errors
create or replace trigger
rhn_confchan_del_trig
before delete on rhnConfigChannel
for each row
declare
	cursor snapshots is
		select	snapshot_id id
		from	rhnSnapshotConfigChannel
		where	config_channel_id = :old.id;
begin
	for snapshot in snapshots loop
		update rhnSnapshot
			set invalid = lookup_snapshot_invalid_reason('cc_removed')
			where id = snapshot.id;
		delete from rhnSnapshotConfigChannel
			where snapshot_id = snapshot.id
				and config_channel_id = :old.id;
	end loop;
end;
/
show errors

select '../rhn/tables/rhnConfigChannelType_data.sql' sql_file from dual;
-- SQL relevant contents from file ../rhn/tables/rhnConfigChannelType_data.sql
insert into rhnConfigChannelType(id, label, name, priority) values (
	rhn_confchantype_id_seq.nextval, 'normal',
	'A general purpose configuration channel', 1);
insert into rhnConfigChannelType(id, label, name, priority) values (
	rhn_confchantype_id_seq.nextval, 'local_override',
	'Files on disk win', 0);
insert into rhnConfigChannelType(id, label, name, priority) values (
	rhn_confchantype_id_seq.nextval, 'server_import',
	'Files imported from the server', 2);
commit;

select '../rhn/tables/rhnConfigFileFailure_data.sql' sql_file from dual;
-- SQL relevant contents from file ../rhn/tables/rhnConfigFileFailure_data.sql
insert into rhnConfigFileFailure (id, label, name) values
    (rhn_conffile_failure_id_seq.nextval, 'missing',
    'Missing file');
insert into rhnConfigFileFailure (id, label, name) values
    (rhn_conffile_failure_id_seq.nextval, 'too_big',
    'File too big');
insert into rhnConfigFileFailure (id, label, name) values
    (rhn_conffile_failure_id_seq.nextval, 'binary_file',
    'Binary file');
insert into rhnConfigFileFailure (id, label, name) values
    (rhn_conffile_failure_id_seq.nextval, 'insufficient_quota',
    'Insufficient free quota space');
commit;

select '../rhn/tables/rhnConfigFile_foreignkeys.sql' sql_file from dual;
-- SQL relevant contents from file ../rhn/tables/rhnConfigFile_foreignkeys.sql
alter table rhnConfigFile add constraint rhn_conffile_lcrid_fk
	foreign key ( latest_config_revision_id )
	references rhnConfigRevision(id)
	on delete set null;

select '../rhn/tables/rhnConfigFileState_data.sql' sql_file from dual;
-- SQL relevant contents from file ../rhn/tables/rhnConfigFileState_data.sql
insert into rhnConfigFileState(id, label, name) values
	(rhn_cfstate_id_seq.nextval, 'dead', 'Will not be deployed');
insert into rhnConfigFileState(id, label, name) values
	(rhn_cfstate_id_seq.nextval, 'alive', 'Will be deployed');
commit;

select '../rhn/tables/rhnSnapshotConfigRevision.sql' sql_file from dual;
-- SQL relevant contents from file ../rhn/tables/rhnSnapshotConfigRevision.sql
create table
rhnSnapshotConfigRevision
(
	snapshot_id		number
				constraint rhn_snapshotcr_sid_nn not null
				constraint rhn_snapshotcr_sid_fk
					references rhnSnapshot(id)
					on delete cascade,
	config_revision_id	number
				constraint rhn_snapshotcr_crid_nn not null
				constraint rhn_snapshotcr_crid_fk
					references rhnConfigRevision(id),
	created			date default(sysdate)
				constraint rhn_snapshotcr_creat_nn not null,
	modified		date default(sysdate)
				constraint rhn_snapshotcr_mod_nn not null
)
	storage ( freelists 16 )
	initrans 32;
create unique index rhn_snapshotcr_sid_crid_uq
	on rhnSnapshotConfigRevision( snapshot_id, config_revision_id )
	tablespace [[2m_tbs]]
	storage ( freelists 16 )
	initrans 32;
create or replace trigger
rhn_snapshotcr_mod_trig
before insert or update on rhnSnapshotConfigRevision
for each row
begin
	:new.modified := sysdate;
end;
/
show errors

select '../rhn/tables/rhnOrgQuota.sql' sql_file from dual;
-- SQL relevant contents from file ../rhn/tables/rhnOrgQuota.sql
create table
rhnOrgQuota
(
	org_id		number
			constraint rhn_orgquota_oid_nn not null
			constraint rhn_orgquota_oid_fk
				references web_customer(id),
	total		number default(0)
			constraint rhn_orgquota_total_nn not null,
	bonus		number default(0)
			constraint rhn_orgquota_bonus_nn not null,
	used		number default(0)
			constraint rhn_orgquota_used_nn not null,
	created		date default(sysdate)
			constraint rhn_orgquota_creat_nn not null,
	modified	date default(sysdate)
			constraint rhn_orgquota_mod_nn not null
)
	storage ( freelists 16 )
	initrans 32;
create unique index rhn_orgquota_oid_uq
	on rhnOrgQuota(org_id)
	tablespace [[2m_tbs]]
	storage ( freelists 16 )
	initrans 32;
create or replace trigger
rhn_orgquota_mod_trig
before insert or update on rhnOrgQuota
for each row
declare
	available_quota number;
begin
	:new.modified := sysdate;
	available_quota := :new.total + :new.bonus;
	if :new.used > available_quota then
		rhn_exception.raise_exception('not_enough_quota');
	end if;
end;
/
show errors

select '../rhn/tables/rhnConfigRevision_triggers.sql' sql_file from dual;
-- SQL relevant contents from file ../rhn/tables/rhnConfigRevision_triggers.sql
create or replace trigger
rhn_confrevision_mod_trig
before insert or update on rhnConfigRevision
for each row
begin
	:new.modified := sysdate;
end;
/
show errors
create or replace trigger
rhn_confrevision_acct_trig
after insert on rhnConfigRevision
for each row
declare
	org_id number;
	available number;
	added number;
begin
	select	cc.org_id id,
			oq.total + oq.bonus - oq.used available,
			content.file_size added
	into	org_id, available, added
	from	rhnConfigContent	content,
			rhnOrgQuota			oq,
			rhnConfigChannel	cc,
			rhnConfigFile		cf
	where	cf.id = :new.config_file_id
			and cf.config_channel_id = cc.id
			and cc.org_id = oq.org_id
			and :new.config_content_id = content.id;
	if added > available then
		rhn_exception.raise_exception('not_enough_quota');
	end if;
end;
/
show errors
create or replace trigger
rhn_confrevision_del_trig
before delete on rhnConfigRevision
for each row
declare
	cursor snapshots is
		select	snapshot_id id
		from	rhnSnapshotConfigRevision
		where	config_revision_id = :old.id;
begin
	for snapshot in snapshots loop
		update rhnSnapshot
			set invalid = lookup_snapshot_invalid_reason('cr_removed')
			where id = snapshot.id;
		delete from rhnSnapshotConfigRevision
			where snapshot_id = snapshot.id
				and config_revision_id = :old.id;
	end loop;
end;
/
show errors

select '../rhn/tables/rhnCpuArch.sql' sql_file from dual;
-- SQL relevant contents from file ../rhn/tables/rhnCpuArch.sql
create table
rhnCpuArch
(
	id		number
			constraint rhn_cpuarch_id_nn not null,
	label		varchar2(16)
			constraint rhn_cpuarch_label_nn not null,
	name		varchar2(64)
			constraint rhn_cpuarch_name_nn not null,
	created		date default(sysdate)
			constraint rhn_cpuarch_created_nn not null,
	modified	date default(sysdate)
			constraint rhn_cpuarch_modified_nn not null
)
	storage ( freelists 16 )
	initrans 32;
create sequence rhn_cpu_arch_id_seq start with 200;
create index rhn_cpuarch_id_l_n_idx
	on rhnCpuArch(id,label,name)
	tablespace [[2m_tbs]]
	storage ( freelists 16 )
	initrans 32;
alter table rhnCpuArch add constraint rhn_cpuarch_id_pk primary key (id);
create index rhn_cpuarch_l_id_n_idx
	on rhnCpuArch(label,id,name)
	tablespace [[2m_tbs]]
	storage ( freelists 16 )
	initrans 32;
alter table rhnCpuArch add constraint rhn_cpuarch_label_uq unique ( label );
create or replace trigger
rhn_cpuarch_mod_trig
before insert or update on rhnCpuArch
for each row
begin
        :new.modified := sysdate;
end;
/
show errors

select '../rhn/tables/rhnCpuArch_data.sql' sql_file from dual;
-- SQL relevant contents from file ../rhn/tables/rhnCpuArch_data.sql
insert into rhnCpuArch (id, label, name) values
(rhn_cpu_arch_id_seq.nextval, 'i386', 'i386');
insert into rhnCpuArch (id, label, name) values
(rhn_cpu_arch_id_seq.nextval, 'i486', 'i486');
insert into rhnCpuArch (id, label, name) values
(rhn_cpu_arch_id_seq.nextval, 'i586', 'i586');
insert into rhnCpuArch (id, label, name) values
(rhn_cpu_arch_id_seq.nextval, 'i686', 'i686');
insert into rhnCpuArch (id, label, name) values
(rhn_cpu_arch_id_seq.nextval, 'athlon', 'athlon');
insert into rhnCpuArch (id, label, name) values
(rhn_cpu_arch_id_seq.nextval, 'alpha', 'alpha');
insert into rhnCpuArch (id, label, name) values
(rhn_cpu_arch_id_seq.nextval, 'alphaev6', 'alphaev6');
insert into rhnCpuArch (id, label, name) values
(rhn_cpu_arch_id_seq.nextval, 'ia64', 'ia64');
insert into rhnCpuArch (id, label, name) values
(rhn_cpu_arch_id_seq.nextval, 'sparc', 'sparc');
insert into rhnCpuArch (id, label, name) values
(rhn_cpu_arch_id_seq.nextval, 'sparcv9', 'sparcv9');
insert into rhnCpuArch (id, label, name) values
(rhn_cpu_arch_id_seq.nextval, 'sparc64', 'sparc64');
insert into rhnCpuArch (id, label, name) values
(rhn_cpu_arch_id_seq.nextval, 's390', 's390');
insert into rhnCpuArch (id, label, name) values
(rhn_cpu_arch_id_seq.nextval, 's390x', 's390x');
insert into rhnCpuArch (id, label, name) values
(rhn_cpu_arch_id_seq.nextval, 'ppc', 'ppc');
insert into rhnCpuArch (id, label, name) values
(rhn_cpu_arch_id_seq.nextval, 'ppc64', 'ppc64');
insert into rhnCpuArch (id, label, name) values
(rhn_cpu_arch_id_seq.nextval, 'pSeries', 'pSeries');
insert into rhnCpuArch (id, label, name) values
(rhn_cpu_arch_id_seq.nextval, 'iSeries', 'iSeries');
insert into rhnCpuArch (id, label, name) values
(rhn_cpu_arch_id_seq.nextval, 'x86_64', 'x86_64');
commit;

select '../rhn/tables/rhnCpu.sql' sql_file from dual;
-- SQL relevant contents from file ../rhn/tables/rhnCpu.sql
create table
rhnCpu
(
	id		number
			constraint rhn_cpu_id_nn not null
			constraint rhn_cpu_id_pk primary key
			using index tablespace [[4m_tbs]],
	server_id	number
			constraint rhn_cpu_server_nn not null
			constraint rhn_cpu_server_fk
			references rhnServer(id) on delete cascade,
	cpu_arch_id	number
			constraint rhn_cpu_caid_nn not null
			constraint rhn_cpu_caid_fk
				references rhnCpuArch(id),
	bogomips	varchar(16),
	cache		varchar(16),
	family		varchar(32),
	MHz		varchar(16),
	stepping	varchar(16),
	flags		varchar(128),
	model		varchar(64),
	version		varchar(32),
	vendor		varchar(32),
	nrcpu		number default 1,
	acpiVersion	varchar(64),
	apic		varchar(32),
	apmVersion	varchar(32),
	chipset		varchar(64),
	created		date default (sysdate)
			constraint rhn_cpu_created_nn not null,
	modified	date default (sysdate)
			constraint rhn_cpu_modified_nn not null
)
	storage ( freelists 16 )
	initrans 32;
create sequence rhn_cpu_id_seq;
create index rhn_cpu_server_id_idx on
	rhnCpu(server_id)
	tablespace [[4m_tbs]]
	storage ( freelists 16 )
	initrans 32
	nologging;
create or replace trigger
rhn_cpu_mod_trig
before insert or update on rhnCpu
for each row
begin
        :new.modified := sysdate;
end;
/
show errors

select '../rhn/tables/rhnCryptoKeyType.sql' sql_file from dual;
-- SQL relevant contents from file ../rhn/tables/rhnCryptoKeyType.sql
create sequence rhn_cryptokeytype_id_seq;
create table
rhnCryptoKeyType
(
	id			number
				constraint rhn_cryptokeytype_id_nn not null
				constraint rhn_cryptokeytype_id_pk primary key
					using index tablespace [[64k_tbs]],
	label			varchar2(32)
				constraint rhn_cryptokeytype_label_nn not null,
	description		varchar2(256)
				constraint rhn_cryptokeytype_desc_nn not null,
	created			date default(sysdate)
				constraint rhn_cryptokeytype_creat_nn not null,
	modified		date default(sysdate)
				constraint rhn_cryptokeytype_mod_nn not null
)
	storage ( freelists 16 )
	initrans 32;
create index rhn_cryptokeytype_label_id_idx
	on rhnCryptoKeyType( label, id )
	tablespace [[64k_tbs]]
	storage ( freelists 16 )
	initrans 32;
alter table rhnCryptoKeyType add constraint rhn_cryptokeytype_label_uq
	unique ( label );
create or replace trigger
rhn_cryptokeytype_mod_trig
before insert or update on rhnCryptoKeyType
for each row
begin
	:new.modified := sysdate;
end;
/
show errors

select '../rhn/tables/rhnCryptoKey.sql' sql_file from dual;
-- SQL relevant contents from file ../rhn/tables/rhnCryptoKey.sql
create sequence rhn_cryptokey_id_seq;
create table
rhnCryptoKey
(
	id			number
				constraint rhn_cryptokey_id_nn not null
				constraint rhn_cryptokey_id_pk primary key
					using index tablespace [[2m_tbs]],
	org_id			number
				constraint rhn_cryptokey_oid_nn not null
				constraint rhn_cryptokey_oid_fk
					references web_customer(id)
					on delete cascade,
	description		varchar2(1024)
				constraint rhn_cryptokey_desc_nn not null,
	crypto_key_type_id	number
				constraint rhn_cryptokey_cktid_nn not null
				constraint rhn_cryptokey_cktid_fk
					references rhnCryptoKeyType(id),
	key			blob
)
	storage ( freelists 16 )
	initrans 32;
create index rhn_cryptokey_oid_idx
	on rhnCryptoKey( org_id )
	tablespace [[2m_tbs]]
	storage ( freelists 16 )
	initrans 32;

select '../rhn/tables/rhnCryptoKeyKickstart.sql' sql_file from dual;
-- SQL relevant contents from file ../rhn/tables/rhnCryptoKeyKickstart.sql
create table
rhnCryptoKeyKickstart
(
	crypto_key_id	number
			constraint rhn_ckey_ks_ckid_nn not null
			constraint rhn_ckey_ks_ckid_fk
				references rhnCryptoKey(id)
				on delete cascade,
        ksdata_id number
                        constraint rhn_ckey_ks_ksd_nn not null
                        constraint rhn_ckey_ks_ksd_fk
                                references rhnKSData(id)
				on delete cascade
)
	storage( freelists 16 )
	initrans 32;
create unique index rhn_ckey_ks_uq
	on rhnCryptoKeyKickstart(crypto_key_id, ksdata_id)
	tablespace [[4m_tbs]]
	storage( freelists 16 )
	initrans 32;
create index rhn_ckey_ks__ckuq
	on rhnCryptoKeyKickstart(ksdata_id, crypto_key_id)
	tablespace [[4m_tbs]]
	storage( freelists 16 )
	initrans 32;

select '../rhn/tables/rhnCryptoKeyType_data.sql' sql_file from dual;
-- SQL relevant contents from file ../rhn/tables/rhnCryptoKeyType_data.sql
insert into rhnCryptoKeyType(id, label, description) values
	(rhn_cryptokeytype_id_seq.nextval,'GPG','GPG');
insert into rhnCryptoKeyType(id, label, description) values
	(rhn_cryptokeytype_id_seq.nextval,'SSL','SSL');
commit;

select '../rhn/tables/rhnCustomDataKey.sql' sql_file from dual;
-- SQL relevant contents from file ../rhn/tables/rhnCustomDataKey.sql
create sequence rhn_cdatakey_id_seq;
create table
rhnCustomDataKey
(
	id		number
			constraint rhn_cdatakey_id_nn not null
			constraint rhn_cdatakey_pk primary key,
	org_id		number
			constraint rhn_cdatakey_oid_nn not null
			constraint rhn_cdatakey_oid_fk
			     references web_customer(id)
			     on delete cascade,
	label		varchar2(64)
			constraint rhn_cdatakey_label_nn not null,
	description	varchar2(4000)
			constraint rhn_cdatakey_desc_nn not null,
	created_by	number
			constraint rhn_cdatakey_cb_fk
			     references web_contact(id)
			     on delete set null,
	last_modified_by number
			constraint rhn_cdatakey_lmb_fk
				references web_contact(id)
				on delete set null,
	created		date default (sysdate)
			constraint rhn_cdatakey_created_nn not null,
	modified	date default (sysdate)
			constraint rhn_cdatakey_modified_nn not null
)
	storage ( freelists 16 )
	initrans 32;
create index rhn_cdatakey_oid_label_id_idx
	on rhnCustomDataKey(org_id, label, id)
	tablespace [[2m_tbs]]
	storage ( freelists 16 )
	initrans 32;
alter table rhnCustomDataKey add constraint rhn_cdatakey_label_uq
	unique ( label );
create or replace trigger
rhn_cdatakey_mod_trig
before insert or update on rhnCustomDataKey
for each row
begin
	:new.modified := sysdate;
end;
/
show errors

select '../rhn/tables/rhnCVE.sql' sql_file from dual;
-- SQL relevant contents from file ../rhn/tables/rhnCVE.sql
CREATE TABLE
rhnCVE
(
        id              number
			constraint rhn_cve_id_nn not null
                        constraint rhn_cve_id_pk primary key
			using index tablespace [[2m_tbs]],
        name            varchar2(13) -- like:  CXX-XXXX-XXXX
			constraint rhn_cve_name_nn not null
)
	storage ( freelists 16 )
	initrans 32;
create unique index rhn_cve_name_uq
	on rhnCVE(name)
	tablespace [[2m_tbs]]
	storage ( freelists 16 )
	initrans 32;
create sequence rhn_cve_id_seq;

select '../rhn/tables/rhnDaemonState.sql' sql_file from dual;
-- SQL relevant contents from file ../rhn/tables/rhnDaemonState.sql
create table
rhnDaemonState
(
	label		varchar2(64)
			constraint rhn_daemonstate_label_nn not null
			constraint rhn_daemonstate_label_pk primary key
			using index tablespace [[64k_tbs]],
	last_poll	date
			constraint rhn_daemonstate_lp_nn not null
)
	storage ( freelists 16 )
	initrans 32;

select '../rhn/tables/rhnDaemonState_data.sql' sql_file from dual;
-- SQL relevant contents from file ../rhn/tables/rhnDaemonState_data.sql
insert into rhnDaemonState values ('entitlement_run_me',sysdate-1000);
insert into rhnDaemonState values ('email_engine',sysdate-1000);
insert into rhnDaemonState values ('payloader_engine',sysdate-1000);
insert into rhnDaemonState values ('pushed_users',sysdate-1000);
commit;

select '../rhn/tables/rhnDailySummaryQueue.sql' sql_file from dual;
-- SQL relevant contents from file ../rhn/tables/rhnDailySummaryQueue.sql
create table
rhnDailySummaryQueue
(
	org_id		number
			constraint rhn_dsqueue_oid_nn not null
			constraint rhn_dsqueue_oid_fk
				references web_customer(id),
	created		date default(sysdate)
			constraint rhn_dsqueue_created_nn not null,
	modified	date default(sysdate)
			constraint rhn_dsqueue_modified_nn not null
)
	storage ( freelists 16 )
	initrans 32;
create index rhn_dsqueue_oid_idx
	on rhnDailySummaryQueue ( org_id )
	tablespace [[2m_tbs]]
	storage ( freelists 16 )
	initrans 32;
alter table rhnDailySummaryQueue add constraint rhn_dsqueue_oid_uq
	unique ( org_id );

select '../rhn/tables/rhnDevice.sql' sql_file from dual;
-- SQL relevant contents from file ../rhn/tables/rhnDevice.sql
create table
rhnDevice
(
	id		number
			constraint rhn_device_id_nn not null
			constraint rhn_device_id_pk primary key
				using index tablespace [[32m_tbs]],
	server_id	number
			constraint rhn_device_sid_nn not null
			constraint rhn_device_sid_fk
				references rhnServer(id) on delete cascade,
	class		varchar2(16),
	bus		varchar2(16),
	detached	number,
	device		varchar2(16),
	driver		varchar2(256),
	description	varchar2(256),
	pcitype		number default -1,
	prop1		varchar2(256),
	prop2		varchar2(256),
	prop3		varchar2(256),
	prop4		varchar2(256),
	created		date default (sysdate)
			constraint rhn_device_created_nn not null,
	modified	date default (sysdate)
			constraint rhn_device_modified_nn not null
)
	storage ( freelists 16 )
	initrans 32;
create sequence rhn_hw_dev_id_seq;
create index rhn_device_server_id_idx
	on rhnDevice(server_id)
	tablespace [[32m_tbs]]
	storage ( freelists 16 )
	initrans 32
	nologging;
create or replace trigger
rhn_device_mod_trig
before insert or update on rhnDevice
for each row
begin
        :new.modified := sysdate;
end;
/
show errors

select '../rhn/tables/rhnDistChannelMap.sql' sql_file from dual;
-- SQL relevant contents from file ../rhn/tables/rhnDistChannelMap.sql
create table
rhnDistChannelMap 
(
	os		varchar(64)
			constraint rhn_dcm_os_nn not null,
	release		varchar(64)
			constraint rhn_dcm_release_nn not null,
	channel_arch_id	number
			constraint rhn_dcm_caid_nn not null
			constraint rhn_dcm_caid_fk
				references rhnChannelArch(id),
	channel_id	number
			constraint rhn_dcm_cid_nn not null 
			constraint rhn_dcm_cid_fk
				references rhnChannel(id) on delete cascade
)
	storage ( freelists 16 )
	initrans 32;
create index rhn_dcm_os_release_caid_idx
	on rhnDistChannelMap(os, release, channel_arch_id)
	tablespace [[64k_tbs]]
	storage ( freelists 16 )
	initrans 32;
alter table rhnDistChannelMap add constraint rhn_dcm_os_release_caid_uq
	unique ( os, release, channel_arch_id );

select '../rhn/tables/rhnDownloadType_data.sql' sql_file from dual;
-- SQL relevant contents from file ../rhn/tables/rhnDownloadType_data.sql
insert into rhnDownloadType values (1, 'iso', 'ISO Images');
insert into rhnDownloadType values (2, 'channel-xml-dump', 'Channel Dump');
commit;

select '../rhn/tables/rhnEmailAddressState.sql' sql_file from dual;
-- SQL relevant contents from file ../rhn/tables/rhnEmailAddressState.sql
create table
rhnEmailAddressState
(
	id			number
				constraint rhn_eastate_id_nn not null,
	label			varchar2(32)
				constraint rhn_eastate_label_nn not null,
	created			date default(sysdate)
				constraint rhn_eastate_created_nn not null,
	modified		date default(sysdate)
				constraint rhn_eastate_modified_nn not null
)
	tablespace [[8m_data_tbs]]
	storage ( freelists 16 )
	initrans 32;
create sequence rhn_eastate_id_seq;
create index rhn_eastate_id_label_idx
	on rhnEmailAddressState ( id, label )
	tablespace [[64k_tbs]]
	storage ( freelists 16 )
	initrans 32;
alter table rhnEmailAddressState add
	constraint rhn_eastate_id_pk primary key ( id );
create index rhn_eastate_label_id_idx
	on rhnEmailAddressState ( label, id )
	tablespace [[64k_tbs]]
	storage ( freelists 16 )
	initrans 32;
alter table rhnEmailAddressState add
	constraint rhn_eastate_label_uq unique ( label );
create or replace trigger
rhn_eastate_mod_trig
before insert or update on rhnEmailAddressState
for each row
begin
        :new.modified := sysdate;
end;
/
show errors

select '../rhn/tables/rhnEmailAddress.sql' sql_file from dual;
-- SQL relevant contents from file ../rhn/tables/rhnEmailAddress.sql
create table
rhnEmailAddress
(
	id			number
				constraint rhn_eaddress_id_nn not null,
	address			varchar2(128)
				constraint rhn_eaddress_a_nn not null,
	user_id			number
				constraint rhn_eaddress_uid_nn not null
				constraint rhn_eaddress_uid_fk
					references web_contact(id)
					on delete cascade,
	state_id		constraint rhn_eaddress_sid_nn not null
				constraint rhn_eaddress_sid_fk
					references rhnEmailAddressState(id),
	next_action		date,
	created			date default(sysdate)
				constraint rhn_eaddress_created_nn not null,
	modified		date default(sysdate)
				constraint rhn_eaddress_modified_nn not null
)
	tablespace [[8m_data_tbs]]
	storage ( freelists 16 )
	initrans 32;
create sequence rhn_eaddress_id_seq;
create or replace trigger
rhn_eaddress_mod_trig
before insert or update on rhnEmailAddress
for each row
begin
	:new.modified := sysdate;
end;
/
show errors

select '../rhn/tables/rhnEmailAddress_indexes.sql' sql_file from dual;
-- SQL relevant contents from file ../rhn/tables/rhnEmailAddress_indexes.sql
create index rhn_eaddress_id_idx
	on rhnEmailAddress ( id )
	tablespace [[8m_tbs]]
	storage ( freelists 16 )
	initrans 32;
alter table rhnEmailAddress add
	constraint rhn_eaddress_id_pk primary key ( id );
create index rhn_eaddress_uid_sid_addr_idx
	on rhnEmailAddress ( user_id, state_id, address )
	tablespace [[8m_tbs]]
	storage ( freelists 16 )
	initrans 32;
alter table rhnEmailAddress add
	constraint rhn_eaddress_uid_sid_uq unique ( user_id, state_id );
create index rhn_eaddress_niusa_idx
	on rhnEmailAddress ( next_action, id, user_id, state_id, address )
	tablespace [[8m_tbs]]
	storage ( freelists 16 )
	initrans 32;

select '../rhn/tables/rhnEmailAddressLog.sql' sql_file from dual;
-- SQL relevant contents from file ../rhn/tables/rhnEmailAddressLog.sql
create table
rhnEmailAddressLog
(
	user_id			number
				constraint rhn_eaddresslog_uid_nn not null
				constraint rhn_eaddresslog_uid_fk
					references web_contact(id)
					on delete cascade,
	address			varchar2(128)
				constraint rhn_eaddresslog_a_nn not null,
	reason			varchar2(4000),
	created			date default(sysdate)
				constraint rhn_eaddresslog_created_nn not null
)
	tablespace [[8m_data_tbs]]
	storage ( freelists 16 )
	initrans 32;
create index rhn_eaddresslog_uid_idx
	on rhnEmailAddressLog(user_id)
	tablespace [[4m_tbs]]
	storage ( freelists 16 )
	initrans 32;
create index rhn_eaddresslog_a_idx
	on rhnEmailAddressLog(address)
	tablespace [[4m_tbs]]
	storage ( freelists 16 )
	initrans 32;
create index rhn_eaddresslog_created_idx
	on rhnEmailAddressLog(created)
	tablespace [[4m_tbs]]
	storage ( freelists 16 )
	initrans 32;

select '../rhn/tables/rhnEmailAddressState_data.sql' sql_file from dual;
-- SQL relevant contents from file ../rhn/tables/rhnEmailAddressState_data.sql
insert into rhnEmailAddressState ( id, label )
	values (rhn_eastate_id_seq.nextval, 'unverified');
insert into rhnEmailAddressState ( id, label )
	values (rhn_eastate_id_seq.nextval, 'pending');
insert into rhnEmailAddressState ( id, label )
	values (rhn_eastate_id_seq.nextval, 'pending_warned');
insert into rhnEmailAddressState ( id, label )
	values (rhn_eastate_id_seq.nextval, 'verified');
insert into rhnEmailAddressState ( id, label )
	values (rhn_eastate_id_seq.nextval, 'needs_verifying');
commit;

select '../rhn/tables/rhnEntitlementLog.sql' sql_file from dual;
-- SQL relevant contents from file ../rhn/tables/rhnEntitlementLog.sql
create table
rhnEntitlementLog
(
	run_time	date default(sysdate)
			constraint rhn_entitlement_log_rt_nn not null,
	bdate		date
			constraint rhn_entitlement_log_bdate_nn not null,
	edate		date
			constraint rhn_entitlement_log_edate_nn not null
)
	storage ( freelists 16 )
	initrans 32;

select '../rhn/tables/rhnErrataBuglist.sql' sql_file from dual;
-- SQL relevant contents from file ../rhn/tables/rhnErrataBuglist.sql
create table
rhnErrataBuglist
(
	errata_id	number
			constraint rhn_errata_buglist_errata_nn not null
			constraint rhn_errata_buglist_errata_fk
				references rhnErrata(id)
				on delete cascade,
	bug_id		number
			constraint rhn_errata_buglist_bug_nn not null,
	summary		varchar2(4000),
	created		date default (sysdate)
			constraint rhn_errata_buglist_created_nn not null,
	modified	date default (sysdate)
			constraint rhn_errata_buglist_modified_nn not null
)
	storage ( freelists 16 )
	initrans 32;
create unique index rhn_err_bug_list_uq
	on rhnErrataBuglist(errata_Id,bug_Id)
	tablespace [[64k_tbs]]
	storage ( freelists 16 )
	initrans 32;
create or replace trigger
rhn_errata_buglist_mod_trig
before insert or update on rhnErrataBuglist
for each row
begin
        :new.modified := sysdate;
end;
/
show errors

select '../rhn/tables/rhnErrataTmp.sql' sql_file from dual;
-- SQL relevant contents from file ../rhn/tables/rhnErrataTmp.sql
create table
rhnErrataTmp
(
        id              number
			constraint rhn_erratatmp_id_nn not null
                        constraint rhn_erratatmp_id_pk primary key
                        using index tablespace [[64k_tbs]],
        advisory        varchar2(32) -- advisory code
			constraint rhn_erratatmp_advisory_nn not null,
        advisory_type   varchar2(32) -- plain text type of advisory
			constraint rhn_erratatmp_adv_type_nn not null
			constraint rhn_erratatmp_adv_type_ck
			           check (advisory_type in ('Bug Fix Advisory',
				                            'Product Enhancement Advisory',
							    'Security Advisory')),
      	advisory_name	varchar2(32)  -- advisory name and version
			constraint rhn_erratatmp_advisory_name_nn not null,
	advisory_rel	number
			constraint rhn_erratatmp_advisory_rel_nn not null,
        product         varchar2(32),
        description     varchar2(4000), -- description
        synopsis        varchar2(4000), -- Short description
        topic           varchar2(4000), -- Problem description
        solution        varchar2(4000), -- how to resolve it
        issue_date      date default (sysdate)
			constraint rhn_erratatmp_issue_nn not null,
        update_date     date default (sysdate)
			constraint rhn_erratatmp_update_nn not null,
        refers_to	varchar2(4000),
        notes           varchar2(4000),
        org_id          number
                        constraint rhn_erratatmp_oid_fk
                                references web_customer(id)
				on delete cascade,
       locally_modified char(1)
			constraint rhn_erratatmp_lm_ck check
				(locally_modified in ('Y','N')),
        created         date default (sysdate)
			constraint rhn_erratatmp_created_nn not null,
        modified        date default (sysdate)
			constraint rhn_erratatmp_modified_nn not null
)
	storage ( freelists 16 )
	initrans 32;
create sequence rhn_erratatmp_id_seq;
create unique index rhn_erratatmp_advisory_uq
	on rhnerratatmp(advisory)
	tablespace [[64k_tbs]]
	storage ( freelists 16 )
	initrans 32;
create unique index rhn_erratatmp_advisory_name_uq
	on rhnerratatmp(advisory_name)
	tablespace [[64k_tbs]]
	storage ( freelists 16 )
	initrans 32;
create or replace trigger
rhn_erratatmp_mod_trig
before insert or update on rhnerratatmp
for each row
begin
        :new.modified := sysdate;
end;
/
show errors

select '../rhn/tables/rhnErrataBuglistTmp.sql' sql_file from dual;
-- SQL relevant contents from file ../rhn/tables/rhnErrataBuglistTmp.sql
create table
rhnErrataBuglistTmp
(
	errata_id	number
			constraint rhn_errata_buglisttmp_eid_nn not null
			constraint rhn_errata_buglisttmp_eid_fk
				references rhnErrataTmp(id)
				on delete cascade,
	bug_id		number
			constraint rhn_errata_buglisttmp_bid_nn not null,
	summary		varchar2(4000),
	created		date default (sysdate)
			constraint rhn_errata_buglisttmp_c_nn not null,
	modified	date default (sysdate)
			constraint rhn_errata_buglisttmp_m_nn not null
)
	storage ( freelists 16 )
	initrans 32;
create unique index rhn_err_buglisttmp_uq
	on rhnErrataBuglistTmp(errata_Id,bug_Id)
	tablespace [[64k_tbs]]
	storage ( freelists 16 )
	initrans 32;
create or replace trigger
rhn_errata_buglisttmp_mod_trig
before insert or update on rhnErrataBuglistTmp
for each row
begin
        :new.modified := sysdate;
end;
/
show errors

select '../rhn/tables/rhnErrataCVE.sql' sql_file from dual;
-- SQL relevant contents from file ../rhn/tables/rhnErrataCVE.sql
create table
rhnErrataCVE
(
	errata_id	number
			constraint rhn_err_cve_eid_nn not null
			constraint rhn_err_cve_eid_fk
				references rhnErrata(id)
				on delete cascade,
	cve_id	        number
			constraint rhn_err_cve_cid_nn not null
			constraint rhn_err_cve_cid_fk
				references rhnCVE(id),
	created		date default (sysdate)
			constraint rhn_err_cve_created_nn not null,
	modified	date default (sysdate)
			constraint rhn_err_cve_modified_nn not null
)
	storage ( freelists 16 )
	initrans 32;
create unique index rhn_err_cve_eid_cid_uq
	on rhnErrataCVE(errata_id, cve_id)
	tablespace [[64k_tbs]]
	storage ( freelists 16 )
	initrans 32;
create index rhn_err_cve_cid_eid_idx
	on rhnErrataCVE(cve_id, errata_id)
	tablespace [[64k_tbs]]
	storage ( freelists 16 )
	initrans 32
	nologging;

select '../rhn/tables/rhnErrataFile.sql' sql_file from dual;
-- SQL relevant contents from file ../rhn/tables/rhnErrataFile.sql
create sequence rhn_erratafile_id_seq;
create table
rhnErrataFile
(
	id		number
			constraint rhn_erratafile_id_nn not null,
	errata_id       number
			constraint rhn_erratafile_errata_nn not null
			constraint rhn_erratafile_errata_fk
				references rhnErrata(id)
				on delete cascade,
	type		number
			constraint rhn_erratafile_type_nn not null
			constraint rhn_erratafile_type_fk
				references rhnErrataFileType(id),
	md5sum		varchar2(64)
			constraint rhn_erratafile_md5_nn not null,
	filename	varchar2(128)
			constraint rhn_erratafile_name_nn not null,
	created		date default(sysdate)
			constraint rhn_erratafile_created_nn not null,
	modified	date default(sysdate)
			constraint rhn_erratafile_modified_nn not null
)
	storage ( freelists 16 )
	initrans 32;
create index rhn_erratafile_id_idx
	on rhnErrataFile ( id )
	tablespace [[64k_tbs]]
	storage ( freelists 16 )
	initrans 32;
alter table rhnErrataFile add constraint rhn_erratafile_id_pk
	primary key ( id );
create index rhn_erratafile_eid_file_idx
	on rhnErrataFile ( errata_id, filename )
	tablespace [[64k_tbs]]
	storage ( freelists 16 )
	initrans 32;
alter table rhnErrataFile add constraint rhn_erratafile_eid_file_uq
	unique ( errata_id, filename );
create or replace trigger
rhn_erratafile_mod_trig
before insert or update on rhnErrataFile
for each row
begin
        :new.modified := sysdate;
end;
/
show errors

select '../rhn/tables/rhnErrataFileChannel.sql' sql_file from dual;
-- SQL relevant contents from file ../rhn/tables/rhnErrataFileChannel.sql
create table
rhnErrataFileChannel
(
	channel_id	number
			constraint rhn_efilec_cid_nn not null 
			constraint rhn_efilec_cid_fk
				references rhnChannel(id)
				on delete cascade,
	errata_file_id	number
			constraint rhn_efilec_eid_nn not null
			constraint rhn_efilec_eid_fk
				references rhnErrataFile(id)
				on delete cascade,
	created		date default (sysdate)
			constraint rhn_efilec_created_nn not null,
	modified	date default (sysdate)
			constraint rhn_efilec_modified_nn not null
)
	storage ( freelists 16 )
	initrans 32;
create index rhn_efilec_efid_cid_idx
	on rhnErrataFileChannel(errata_file_id, channel_id)
	tablespace [[64k_tbs]]
	storage ( freelists 16 )
	initrans 32;
alter table rhnErrataFileChannel add constraint rhn_efilec_efid_cid_uq
	unique ( errata_file_id, channel_id );
create index rhn_efilec_cid_efid_idx
	on rhnErrataFileChannel(channel_id, errata_file_id)
	tablespace [[64k_tbs]]
	storage ( freelists 16 )
	initrans 32;
create or replace trigger
rhn_efilec_mod_trig
before insert or update on rhnErrataFileChannel
for each row
begin
	:new.modified := sysdate;
end;
/
show errors

select '../rhn/tables/rhnPackageSource.sql' sql_file from dual;
-- SQL relevant contents from file ../rhn/tables/rhnPackageSource.sql
create table
rhnPackageSource
(
        id              number
			constraint rhn_pkgsrc_id_nn not null
                        constraint rhn_pkgsrc_id_pk primary key
				using index tablespace [[64k_tbs]]
			storage(pctincrease 1),
        org_id          number
                        constraint rhn_pkgsrc_oid_fk
				references web_customer(id)
				on delete cascade,
	source_rpm_id	number
			constraint rhn_pkgsrc_srid_nn not null
			constraint rhn_pkgsrc_srid_fk
				references rhnSourceRPM(id),
        package_group   number
			constraint rhn_pkgsrc_group_nn not null
                        constraint rhn_pkgsrc_group_fk
				references rhnPackageGroup(id),
        rpm_version     varchar2(16)
			constraint rhn_pkgsrc_rpm_ver_nn not null,
        payload_size    number
			constraint rhn_pkgsrc_paysize_nn not null,
        build_host      varchar2(256)
			constraint rhn_pkgsrc_bh_nn not null,
        build_time      date
			constraint rhn_pkgsrc_bt_nn not null,
        sigmd5          varchar2(64)
			constraint rhn_package_sigmd5_nn not null,
        vendor          varchar2(64)
			constraint rhn_pkgsrc_vendor_nn not null,
	cookie		varchar2(128)
			constraint rhn_pkgsrc_cookie_nn not null,
        path            varchar2(1000),
        md5sum          varchar2(64)
	                constraint rhn_pkgsrc_md5sum_nn not null,
        package_size    number
	                constraint rhn_pkgsrc_ps_nn not null,
	last_modified	date default (sysdate)
			constraint rhn_pkgsrc_lm_nn not null,
        created         date default (sysdate)
			constraint rhn_pkgsrc_created_nn not null,
        modified        date default (sysdate)
			constraint rhn_pkgsrc_modified_nn not null
)
	storage( pctincrease 1 freelists 16 )
	initrans 32;
create sequence rhn_package_source_id_seq;
create unique index rhn_pkgsrc_srid_oid_uq
	on rhnPackageSource(source_rpm_id, org_id)
	tablespace [[64k_tbs]]
	storage( pctincrease 1 freelists 16 )
	initrans 32;
create or replace trigger
rhn_pkgsrc_mod_trig
before insert or update on rhnPackageSource
for each row
begin
        :new.modified := sysdate;
	:new.last_modified := sysdate;
end;
/
show errors

select '../rhn/tables/rhnErrataFilePackageSource.sql' sql_file from dual;
-- SQL relevant contents from file ../rhn/tables/rhnErrataFilePackageSource.sql
create table
rhnErrataFilePackageSource
(
	package_id	number
			constraint rhn_efileps_pid_nn not null 
			constraint rhn_efileps_pid_fk
				references rhnPackageSource(id)
				on delete cascade,
	errata_file_id	number
			constraint rhn_efileps_fileid_nn not null
			constraint rhn_efileps_fileid_fk
				references rhnErrataFile(id)
				on delete cascade,
	created		date default (sysdate)
			constraint rhn_efileps_created_nn not null,
	modified	date default (sysdate)
			constraint rhn_efileps_modified_nn not null
)
	storage ( freelists 16 )
	initrans 32;
create index rhn_efileps_efid_pid_idx
	on rhnErrataFilePackageSource ( errata_file_id, package_id )
	tablespace [[64k_tbs]]
	storage ( freelists 16 )
	initrans 32;
alter table rhnErrataFilePackageSource add constraint rhn_efileps_efid_uq
	unique ( errata_file_id );
create or replace trigger
rhn_efileps_mod_trig
before insert or update on rhnErrataFilePackageSource
for each row
begin
	:new.modified := sysdate;
end;
/
show errors

select '../rhn/tables/rhnErrataFilePackage.sql' sql_file from dual;
-- SQL relevant contents from file ../rhn/tables/rhnErrataFilePackage.sql
create table
rhnErrataFilePackage
(
	package_id	number
			constraint rhn_efilep_pid_nn not null 
			constraint rhn_efilep_pid_fk
				references rhnPackage(id)
				on delete cascade,
	errata_file_id	number
			constraint rhn_efilep_fileid_nn not null
			constraint rhn_efilep_fileid_fk
				references rhnErrataFile(id)
				on delete cascade,
	created		date default (sysdate)
			constraint rhn_efilep_created_nn not null,
	modified	date default (sysdate)
			constraint rhn_efilep_modified_nn not null
)
	storage ( freelists 16 )
	initrans 32;
create index rhn_efilep_efid_pid_idx
	on rhnErrataFilePackage( errata_file_id, package_id )
	tablespace [[2m_tbs]]
	storage ( freelists 16 )
	initrans 32;
alter table rhnErrataFilePackage add constraint rhn_efilep_efid_uq
	unique ( errata_file_id );
create index rhn_efilep_pid_idx
	on rhnErrataFilePackage ( package_id )
	tablespace [[2m_tbs]]
	storage ( freelists 16 )
	initrans 32;
create or replace trigger
rhn_efilep_mod_trig
before insert or update on rhnErrataFilePackage
for each row
begin
	:new.modified := sysdate;
end;
/
show errors

select '../rhn/tables/rhnErrataFileTmp.sql' sql_file from dual;
-- SQL relevant contents from file ../rhn/tables/rhnErrataFileTmp.sql
create table
rhnErrataFileTmp
(
	id		number
			constraint rhn_erratafiletmp_id_nn not null,
	errata_id       number
			constraint rhn_erratafiletmp_errata_nn not null
			constraint rhn_erratafiletmp_errata_fk
				references rhnErrataTmp(id)
				on delete cascade,
	type		number
			constraint rhn_erratafiletmp_type_nn not null
			constraint rhn_erratafiletmp_type_fk
				references rhnErrataFileType(id),
	md5sum		varchar2(64)
			constraint rhn_erratafiletmp_md5_nn not null,
	filename	varchar2(128)
			constraint rhn_erratafiletmp_name_nn not null,
	created		date default(sysdate)
			constraint rhn_erratafiletmp_created_nn not null,
	modified	date default(sysdate)
			constraint rhn_erratafiletmp_modified_nn not null
)
	storage ( freelists 16 )
	initrans 32;
create index rhn_erratafiletmp_id_idx
	on rhnErrataFileTmp ( id )
	tablespace [[64k_tbs]]
	storage ( freelists 16 )
	initrans 32;
alter table rhnErrataFileTmp add constraint rhn_erratafiletmp_id_pk
	primary key ( id );
create index rhn_erratafiletmp_eid_file_idx
	on rhnErrataFileTmp ( errata_id, filename )
	tablespace [[64k_tbs]]
	storage ( freelists 16 )
	initrans 32;
alter table rhnErrataFileTmp add constraint rhn_erratafiletmp_eid_file_uq
	unique ( errata_id, filename );
create or replace trigger
rhn_erratafiletmp_mod_trig
before insert or update on rhnErrataFileTmp
for each row
begin
        :new.modified := sysdate;
end;
/
show errors

select '../rhn/tables/rhnErrataKeyword.sql' sql_file from dual;
-- SQL relevant contents from file ../rhn/tables/rhnErrataKeyword.sql
create table
rhnErrataKeyword
(
	errata_id       number
			constraint rhn_err_keyword_eid_nn not null
			constraint rhn_err_keyword_eid_fk
				references rhnErrata(id)
				on delete cascade,
	keyword		varchar2(64),
	created		date default(sysdate)
			constraint rhn_err_keyword_created_nn not null,
	modified	date default(sysdate)
			constraint rhn_err_keyword_modified_nn not null
)
	storage ( freelists 16 )
	initrans 32;
create unique index rhn_err_keyword_eid_uq
	on rhnErrataKeyword(keyword,errata_id)
	tablespace [[64k_tbs]]
	storage ( freelists 16 )
	initrans 32;
create index rhn_errkw_eid_idx
	on rhnErrataKeyword(errata_id)
	tablespace [[64k_tbs]]
	storage ( freelists 16 )
	initrans 32;
create or replace trigger
rhn_errata_keyword_mod_trig
before insert or update on rhnErrataKeyword
for each row
begin
        :new.modified := sysdate;
end;
/
show errors

select '../rhn/tables/rhnErrataKeywordTmp.sql' sql_file from dual;
-- SQL relevant contents from file ../rhn/tables/rhnErrataKeywordTmp.sql
create table
rhnErrataKeywordTmp
(
	errata_id       number
			constraint rhn_err_keywordtmp_eid_nn not null
			constraint rhn_err_keywordtmp_eid_fk
				references rhnErrataTmp(id)
				on delete cascade,
	keyword		varchar2(64),
	created		date default(sysdate)
			constraint rhn_err_keywordtmp_created_nn not null,
	modified	date default(sysdate)
			constraint rhn_err_keywordtmp_modified_nn not null
)
	storage ( freelists 16 )
	initrans 32;
create unique index rhn_err_keywordtmp_eid_uq
	on rhnErrataKeywordTmp(keyword,errata_id)
	tablespace [[64k_tbs]]
	storage ( freelists 16 )
	initrans 32;
create index rhn_errkwtmp_eid_idx
	on rhnErrataKeywordTmp(errata_id)
	tablespace [[64k_tbs]]
	storage ( freelists 16 )
	initrans 32;
create or replace trigger
rhn_errata_keywordtmp_mod_trig
before insert or update on rhnErrataKeywordTmp
for each row
begin
        :new.modified := sysdate;
end;
/
show errors

select '../rhn/tables/rhnErrataNotificationQueue.sql' sql_file from dual;
-- SQL relevant contents from file ../rhn/tables/rhnErrataNotificationQueue.sql
create table
rhnErrataNotificationQueue
(
	errata_id		number
				constraint rhn_enqueue_eid_nn not null
				constraint rhn_enqueue_eid_fk
					references rhnErrata(id)
					on delete cascade,
        org_id                  number
                            	constraint rhn_enqueue_oid_nn not null
                            	constraint rhn_enqueue_oid_fk
                                	references web_customer(id)
					on delete cascade,
	next_action		date,
	created			date default(sysdate)
				constraint rhn_enqueue_created_nn not null,
	modified		date default(sysdate)
				constraint rhn_enqueue_modified_nn not null
)
	storage ( freelists 16 )
	initrans 32;
create index rhn_enqueue_eid_idx
	on rhnErrataNotificationQueue ( errata_id, org_id )
	tablespace [[4m_tbs]]
	storage ( freelists 16 )
	initrans 32;
alter table rhnErrataNotificationQueue add constraint rhn_enqueue_eoid_uq
	unique ( errata_id, org_id );
create index rhn_enqueue_na_eid_idx
	on rhnErrataNotificationQueue ( next_action, errata_id )
	tablespace [[8m_tbs]]
	storage ( freelists 16 )
	initrans 32;
create or replace trigger
rhn_enqueue_mod_trig
before insert or update on rhnErrataNotificationQueue
for each row
begin
	:new.modified := sysdate;
end;
/
show errors

select '../rhn/tables/rhnErrataPackage.sql' sql_file from dual;
-- SQL relevant contents from file ../rhn/tables/rhnErrataPackage.sql
create table
rhnErrataPackage
(
	errata_id	number
			constraint rhn_err_pkg_eid_nn not null
			constraint rhn_err_pkg_eid_fk
				references rhnErrata(id)
				on delete cascade,
	package_id	number
			constraint rhn_err_pkg_pid_nn not null
			constraint rhn_err_pkg_pid_fk
				references rhnPackage(id)
				on delete cascade,
	created		date default (sysdate)
			constraint rhn_err_pkg_created_nn not null,
	modified	date default (sysdate)
			constraint rhn_err_pkg_modified_nn not null
)
	storage ( freelists 16 )
	initrans 32;
create unique index rhn_err_pkg_eid_pid_uq
	on rhnErrataPackage(errata_id, package_id)
	tablespace [[64k_tbs]]
	storage ( freelists 16 )
	initrans 32;
create index rhn_err_pkg_pid_eid_idx
	on rhnErrataPackage(package_id, errata_id)
	tablespace [[64k_tbs]]
	storage ( freelists 16 )
	initrans 32
	nologging; 

select '../rhn/tables/rhnErrataPackageTmp.sql' sql_file from dual;
-- SQL relevant contents from file ../rhn/tables/rhnErrataPackageTmp.sql
create table
rhnErrataPackageTmp
(
	errata_id	number
			constraint rhn_err_pkgtmp_eid_nn not null
			constraint rhn_err_pkgtmp_eid_fk
				references rhnErrataTmp(id)
				on delete cascade,
	package_id	number
			constraint rhn_err_pkgtmp_pid_nn not null
			constraint rhn_err_pkgtmp_pid_fk
				references rhnPackage(id),
	created		date default (sysdate)
			constraint rhn_err_pkgtmp_created_nn not null,
	modified	date default (sysdate)
			constraint rhn_err_pkgtmp_modified_nn not null
)
	storage ( freelists 16 )
	initrans 32;
create unique index rhn_err_pkgtmp_eid_pid_uq
	on rhnErrataPackageTmp(errata_id, package_id)
	tablespace [[64k_tbs]]
	storage ( freelists 16 )
	initrans 32;
create index rhn_err_pkgtmp_pid_eid_idx
	on rhnErrataPackageTmp(package_id, errata_id)
	tablespace [[64k_tbs]]
	storage ( freelists 16 )
	initrans 32
	nologging;
create or replace trigger
rhn_errata_packagetmp_mod_trig
before insert or update on rhnErrataPackageTmp
for each row
begin
        :new.modified := sysdate;
end;
/
show errors

select '../rhn/tables/rhnErrataPackage_triggers.sql' sql_file from dual;
-- SQL relevant contents from file ../rhn/tables/rhnErrataPackage_triggers.sql
create or replace trigger
rhn_errata_package_mod_trig
before insert or update on rhnErrataPackage
for each row
begin
        :new.modified := sysdate;
end;
/
show errors

select '../rhn/tables/rhnErrataQueue.sql' sql_file from dual;
-- SQL relevant contents from file ../rhn/tables/rhnErrataQueue.sql
create table
rhnErrataQueue
(
	errata_id		number
				constraint rhn_equeue_eid_nn not null
				constraint rhn_equeue_eid_fk
					references rhnErrata(id)
					on delete cascade,
	next_action		date,
	created			date default(sysdate)
				constraint rhn_equeue_created_nn not null,
	modified		date default(sysdate)
				constraint rhn_equeue_modified_nn not null
)
	storage ( freelists 16 )
	initrans 32;
create index rhn_equeue_eid_idx
	on rhnErrataQueue ( errata_id )
	tablespace [[4m_tbs]]
	storage ( freelists 16 )
	initrans 32;
alter table rhnErrataQueue add constraint rhn_equeue_eoid_uq
	unique ( errata_id );
create index rhn_equeue_na_eid_idx
	on rhnErrataQueue ( next_action, errata_id )
	tablespace [[8m_tbs]]
	storage ( freelists 16 )
	initrans 32;

select '../rhn/tables/rhnErrataRelationship.sql' sql_file from dual;
-- SQL relevant contents from file ../rhn/tables/rhnErrataRelationship.sql
create table
rhnErrataRelationship
(
	from_errata_id		number
				constraint rhn_erratarel_feid_nn not null
				constraint rhn_erratarel_feid_fk
					references rhnErrata(id)
					on delete cascade,
	to_errata_id		number
				constraint rhn_erratarel_teid_nn not null
				constraint rhn_erratarel_teid_fk
					references rhnErrata(id)
					on delete cascade,
	rel_type_id		number
				constraint rhn_erratarel_rtid_nn not null
				constraint rhn_erratarel_rtid_fk
					references rhnRelationshipType(id),
	created			date default(sysdate)
				constraint rhn_erratarel_created_nn not null,
	modified		date default(sysdate)
				constraint rhn_erratarel_modified_nn not null
)
	storage ( freelists 16 )
	initrans 32;
create index rhn_erratarel_feid_teid_idx
	on rhnErrataRelationship ( from_errata_id, to_errata_id )
	tablespace [[2m_tbs]]
	storage ( freelists 16 )
	initrans 32;
alter table rhnErrataRelationship add constraint rhn_erratarel_feid_teid_uq
	unique ( from_errata_id, to_errata_id );
create index rhn_erratarel_teid_feid_idx
	on rhnErrataRelationship ( to_errata_id, from_errata_id )
	tablespace [[2m_tbs]]
	storage ( freelists 16 )
	initrans 32;
create or replace trigger
rhn_erratarel_mod_trig
before insert or update on rhnErrataRelationship
for each row
begin
	:new.modified := sysdate;
end;
/
show errors

select '../rhn/tables/rhnErrataRelationshipTmp.sql' sql_file from dual;
-- SQL relevant contents from file ../rhn/tables/rhnErrataRelationshipTmp.sql
create table
rhnErrataRelationshipTmp
(
	from_errata_id		number
				constraint rhn_ereltmp_feid_nn not null
				constraint rhn_ereltmp_feid_fk
					references rhnErrata(id)
					on delete cascade,
	to_errata_id		number
				constraint rhn_ereltmp_teid_nn not null
				constraint rhn_ereltmp_teid_fk
					references rhnErrataTmp(id)
					on delete cascade,
	rel_type_id		number
				constraint rhn_ereltmp_rtid_nn not null
				constraint rhn_ereltmp_rtid_fk
					references rhnRelationshipType(id),
	created			date default(sysdate)
				constraint rhn_ereltmp_created_nn not null,
	modified		date default(sysdate)
				constraint rhn_ereltmp_modified_nn not null
)
	storage ( freelists 16 )
	initrans 32;
create index rhn_ereltmp_feid_teid_idx
	on rhnErrataRelationshipTmp ( from_errata_id, to_errata_id )
	tablespace [[2m_tbs]]
	storage ( freelists 16 )
	initrans 32;
alter table rhnErrataRelationshipTmp add constraint rhn_ereltmp_feid_teid_uq
	unique ( from_errata_id, to_errata_id );
create index rhn_ereltmp_teid_feid_idx
	on rhnErrataRelationshipTmp ( to_errata_id, from_errata_id )
	tablespace [[2m_tbs]]
	storage ( freelists 16 )
	initrans 32;
create or replace trigger
rhn_ereltmp_mod_trig
before insert or update on rhnErrataRelationshipTmp
for each row
begin
	:new.modified := sysdate;
end;
/
show errors

select '../rhn/tables/rhnFAQClass.sql' sql_file from dual;
-- SQL relevant contents from file ../rhn/tables/rhnFAQClass.sql
create table
rhnFAQClass
(
	id	    number
		    constraint rhn_faq_class_id_nn not null
		    constraint rhn_faq_class_id_pk primary key
			using index tablespace [[64k_tbs]]
			storage(pctincrease 1),
	name	    varchar2(128),
	label       varchar2(32)
	    	    constraint rhn_faq_class_label_nn not null,
	ordering  number
	            constraint rhn_faq_class_or_nn not null
)
	storage ( freelists 16 )
	initrans 32;
CREATE SEQUENCE RHN_FAQ_CLASS_ID_SEQ START WITH 101;
create unique index rhn_faqclass_label_uq
	on rhnFAQClass(label)
	tablespace [[64k_tbs]]
	storage ( freelists 16 )
	initrans 32;
create unique index rhn_faqclass_or_uq
	on rhnFAQClass(ordering)
	tablespace [[64k_tbs]]
	storage ( freelists 16 )
	initrans 32;

select '../rhn/tables/rhnFAQClass_data.sql' sql_file from dual;
-- SQL relevant contents from file ../rhn/tables/rhnFAQClass_data.sql
INSERT INTO RHNFAQCLASS ( ID, NAME, LABEL, ORDERING ) VALUES ( 
1, 'General', 'general', 100); 
INSERT INTO RHNFAQCLASS ( ID, NAME, LABEL, ORDERING ) VALUES ( 
2, 'Account Management', 'account_management', 120); 
INSERT INTO RHNFAQCLASS ( ID, NAME, LABEL, ORDERING ) VALUES ( 
3, 'Getting Started', 'getting_started', 140); 
INSERT INTO RHNFAQCLASS ( ID, NAME, LABEL, ORDERING ) VALUES ( 
4, 'Service Levels', 'service_levels', 160); 
INSERT INTO RHNFAQCLASS ( ID, NAME, LABEL, ORDERING ) VALUES ( 
5, 'Using RHN', 'using_rhn', 180); 
INSERT INTO RHNFAQCLASS ( ID, NAME, LABEL, ORDERING ) VALUES ( 
6, 'Technical Questions', 'technical_questions', 200); 
INSERT INTO RHNFAQCLASS ( ID, NAME, LABEL, ORDERING ) VALUES ( 
7, 'Management Service', 'enterprise_service', 220); 
INSERT INTO RHNFAQCLASS ( ID, NAME, LABEL, ORDERING ) VALUES ( 
8, 'Privacy/Legal', 'legal', 240); 
INSERT INTO RHNFAQCLASS ( ID, NAME, LABEL, ORDERING ) VALUES ( 
9, 'Policies', 'policy', 260); 
INSERT INTO RHNFAQCLASS ( ID, NAME, LABEL, ORDERING ) VALUES ( 
11, 'Definitions', 'definitions', 270); 
COMMIT;
COMMIT;

select '../rhn/tables/rhnFAQ.sql' sql_file from dual;
-- SQL relevant contents from file ../rhn/tables/rhnFAQ.sql
create table
rhnFAQ
(
	id		number
			constraint rhn_faq_id_nn not null
			constraint rhn_faq_id_pk primary key
				using index tablespace [[64k_tbs]] 
                                storage(pctincrease 1),
	class_id	number
			constraint rhn_faq_class_fk
				references rhnFAQClass(id),
	subject		varchar2(200),
	details		varchar2(4000),
	private		number default(0)
			constraint rhn_faq_private_nn not null,
	usage_count     number default(0)
	    	    	constraint rhn_faq_usage_nn not null,
        created         date default(sysdate)
                        constraint rhn_faq_created_nn not null,
        modified        date default(sysdate)
                        constraint rhn_faq_modified_nn not null
)
	storage ( freelists 16 )
	initrans 32;
create sequence rhn_faq_id_seq;
create or replace trigger
rhn_faq_mod_trig
before insert or update on rhnFAQ
for each row
begin
        :new.modified := sysdate;
end;
/
show errors

select '../rhn/tables/rhnFAQ_satdata.sql' sql_file from dual;
-- SQL relevant contents from file ../rhn/tables/rhnFAQ_satdata.sql
SET SQLBLANKLINES ON
SET SCAN OFF
INSERT INTO RHNFAQ ( ID, SUBJECT, DETAILS, PRIVATE, CREATED, MODIFIED, USAGE_COUNT,
CLASS_ID ) VALUES ( 
64, 'pvt: This message is being forwarded to customerservice@redhat.com', 'This message has been forwarded to customerservice@redhat.com.  That group handles all billing and purchasing related questions.'
, 1,  TO_Date( '10/02/2002 12:00:00 AM', 'MM/DD/YYYY HH:MI:SS AM'),  TO_Date( '05/12/2003 10:18:24 PM', 'MM/DD/YYYY HH:MI:SS AM')
, 22, 1); 
INSERT INTO RHNFAQ ( ID, SUBJECT, DETAILS, PRIVATE, CREATED, MODIFIED, USAGE_COUNT,
CLASS_ID ) VALUES ( 
65, 'I''m having trouble registering my Red Hat Enterprise Linux product.  Why?', 'Enterprise entitlements are required for use with Red Hat Enterprise Linux.
A customer who registers an Enterprise Linux system with RHN without having any Enterprise Linux entitlements will receive an error message similar to:
"No public channels available for ("2.1AS'', ''i686'')"
In order to register your system, you first need to activate your RHN Enterprise Linux entitlements at:
http://www.redhat.com/support
Use the product ID that came with your Red Hat Enterprise Linux product.
'
, 0,  TO_Date( '10/02/2002 12:00:00 AM', 'MM/DD/YYYY HH:MI:SS AM'),  TO_Date( '03/31/2003 09:26:12 AM', 'MM/DD/YYYY HH:MI:SS AM')
, 13, 7); 
INSERT INTO RHNFAQ ( ID, SUBJECT, DETAILS, PRIVATE, CREATED, MODIFIED, USAGE_COUNT,
CLASS_ID ) VALUES ( 
66, 'pvt: I bought service with RHN, but it won''t let me use Priority FTP access.  Why not?vp'
, 'Instant ISO access is not the same as Priority FTP access; they are separate entities.  Customers who purchase Red Hat Network service have Instant ISO access only.  Priority FTP access is available only to legacy users, and is in the process of being phased out.
'
, 1,  TO_Date( '10/02/2002 12:00:00 AM', 'MM/DD/YYYY HH:MI:SS AM'),  TO_Date( '04/24/2003 09:34:56 PM', 'MM/DD/YYYY HH:MI:SS AM')
, 6, 1); 
INSERT INTO RHNFAQ ( ID, SUBJECT, DETAILS, PRIVATE, CREATED, MODIFIED, USAGE_COUNT,
CLASS_ID ) VALUES ( 
67, 'How do I register a system for RHN service on Red Hat Linux?', 'To register a system for RHN service on Red Hat Linux please run "rhn_register". Refer to the RHN User Guide (also available through the Help link at the RHN website) for additional instructions.
Note: for Red Hat Linux 8.0 and later, please run "up2date --register" instead of "rhn_register".
'
, 0,  TO_Date( '10/02/2002 12:00:00 AM', 'MM/DD/YYYY HH:MI:SS AM'),  TO_Date( '04/16/2003 09:09:30 PM', 'MM/DD/YYYY HH:MI:SS AM')
, 19, 3); 
INSERT INTO RHNFAQ ( ID, SUBJECT, DETAILS, PRIVATE, CREATED, MODIFIED, USAGE_COUNT,
CLASS_ID ) VALUES ( 
25, 'The RHN website and up2date do not agree on what errata is needed for my system.'
, 'You can refresh the profile package list by running "up2date -p" on the machine itself.  Alternatively, you can schedule this from the website by clicking on the system in the System List, choosing the Packages tab, and then clicking on the "Update Package List" button at the bottom of the page.
'
, 0,  TO_Date( '06/14/2002 12:00:00 AM', 'MM/DD/YYYY HH:MI:SS AM'),  TO_Date( '04/14/2003 09:24:01 PM', 'MM/DD/YYYY HH:MI:SS AM')
, 10, 6); 
INSERT INTO RHNFAQ ( ID, SUBJECT, DETAILS, PRIVATE, CREATED, MODIFIED, USAGE_COUNT,
CLASS_ID ) VALUES ( 
26, 'I had to re-install my system. How do I re-register and get my entitlement back?'
, 'You''ll need to re-register the client system if you haven''t already, and then move an entitlement to the new profile.
* Log into our website at:  https://rhn.redhat.com.
* Click on "Systems" in the top navigation bar, then the name of the old system in the System List.
* Click "delete system" on the top-right corner of the page.
* As root at the command line, delete the file /etc/sysconfig/rhn/systemid from your system.
* Run "rhn_register" (Red Hat Linux 7.x) or "up2date --register" (Red Hat Linux 8.0 and newer) on your system.
* Once the system is registered, log in at https://rhn.redhat.com.
* Click "Systems" in the top navigation bar, then "System Entitlements" on the left.
* Select the appropriate entitlement level for the new system and click "Update Entitlements."'
, 0,  TO_Date( '06/14/2002 12:00:00 AM', 'MM/DD/YYYY HH:MI:SS AM'),  TO_Date( '05/18/2003 09:42:55 PM', 'MM/DD/YYYY HH:MI:SS AM')
, 411, 5); 
INSERT INTO RHNFAQ ( ID, SUBJECT, DETAILS, PRIVATE, CREATED, MODIFIED, USAGE_COUNT,
CLASS_ID ) VALUES ( 
27, 'How can I request a new feature or improvement for the Red Hat Network?', 'For technical requests, you can make a "Request for Enhancement" (RFE) at http://bugzilla.redhat.com/bugzilla.  The product is "Red Hat Network" and the various components are prefaced by "RHN/".  Please put "[RFE]" at the beginning of the summary line of your request.
If you would like to provide non-technical feedback to Red Hat Network, please go to https://rhn.redhat.com/help/contact.pxt and follow the directions for "feedback".
'
, 0,  TO_Date( '06/14/2002 12:00:00 AM', 'MM/DD/YYYY HH:MI:SS AM'),  TO_Date( '05/18/2003 09:56:14 PM', 'MM/DD/YYYY HH:MI:SS AM')
, 74, 9); 
INSERT INTO RHNFAQ ( ID, SUBJECT, DETAILS, PRIVATE, CREATED, MODIFIED, USAGE_COUNT,
CLASS_ID ) VALUES ( 
28, 'Where do I report a bug in the RHN website or update agent?', 'Bugs can be reported at http://bugzilla.redhat.com/bugzilla -- the product is "Red Hat Network", and the various components are prefixed with "RHN/".
Please be sure to read the FAQ and review all of the open bugs before submitting your bug.
'
, 0,  TO_Date( '06/14/2002 12:00:00 AM', 'MM/DD/YYYY HH:MI:SS AM'),  TO_Date( '05/15/2003 10:47:49 PM', 'MM/DD/YYYY HH:MI:SS AM')
, 45, 9); 
INSERT INTO RHNFAQ ( ID, SUBJECT, DETAILS, PRIVATE, CREATED, MODIFIED, USAGE_COUNT,
CLASS_ID ) VALUES ( 
30, 'What is the difference between i386, i586, and i686 packages?', 'i386 is a generic designation for all processors backwardly compatible with the Intel 80386; i586 is for all processors backwardly compatible with the Intel Pentium; and i686 is for Intel processors backwardly compatible with the Pentium Pro chip (Pentium II, III, IV, etc).  Only the kernel has i586 and i686 versions, and glibc has an i686 version.  up2date should automatically determine which versions of the kernel and glibc packages are appropriate for your systems.
'
, 0,  TO_Date( '06/14/2002 12:00:00 AM', 'MM/DD/YYYY HH:MI:SS AM'),  TO_Date( '04/15/2003 10:33:49 PM', 'MM/DD/YYYY HH:MI:SS AM')
, 8, 11); 
INSERT INTO RHNFAQ ( ID, SUBJECT, DETAILS, PRIVATE, CREATED, MODIFIED, USAGE_COUNT,
CLASS_ID ) VALUES ( 
1, 'What is Red Hat Network?', 'Red Hat Network is a systems support and management environment for Red Hat Linux systems and networks. For more information, please see the Red Hat Network product information page:
http://www.redhat.com/software/rhn/offerings/
For individual systems and small networks, see http://www.redhat.com/software/rhn
For enterprise deployments, see http://www.redhat.com/software/rhen
'
, 0,  TO_Date( '03/07/2002 12:00:00 AM', 'MM/DD/YYYY HH:MI:SS AM'),  TO_Date( '05/14/2003 05:00:08 AM', 'MM/DD/YYYY HH:MI:SS AM')
, 26, 1); 
INSERT INTO RHNFAQ ( ID, SUBJECT, DETAILS, PRIVATE, CREATED, MODIFIED, USAGE_COUNT,
CLASS_ID ) VALUES ( 
3, 'Does Red Hat Network only work on Linux? Which versions?', 'Yes. Red Hat Network currently only supports versions of Red Hat Linux and Red Hat Enterprise Linux that are still active (have not yet reached End of Life status). For a list of currently maintained Red Hat versions, please go to http://www.redhat.com/apps/support/errata/
Please note that Red Hat''s Enterprise Network Monitoring Module does support different platforms. For more information, please go to http://www.redhat.com/software/rhen/system_mgmt/
'
, 0,  TO_Date( '03/07/2002 12:00:00 AM', 'MM/DD/YYYY HH:MI:SS AM'),  TO_Date( '03/31/2003 09:26:12 AM', 'MM/DD/YYYY HH:MI:SS AM')
, 4, 1); 
INSERT INTO RHNFAQ ( ID, SUBJECT, DETAILS, PRIVATE, CREATED, MODIFIED, USAGE_COUNT,
CLASS_ID ) VALUES ( 
5, 'I can''t find the Red Hat Network Registration Client.  What is it and where do I find it?'
, 'The Red Hat Network Registration Client steps you through the process of creating a user account if you do not already have one and registering your system by creating a System Profile. It can be started by using one of the following methods:
* On the GNOME desktop, go to the Main Menu Button (on the Panel) => Programs => System => Red Hat Network.
* On the KDE desktop, go to the Main Menu Button (on the Panel) => System => Red Hat Network
* At a shell prompt, type the command "rhn_register".
In Red Hat Linux 8.0 and newer, rhn_register exists as a mode of the up2date client, so:
* On the GNOME and KDE desktops, go to the Main Menu Button (on the Panel) => System Tools => Red Hat Network. (If the system is unregistered, it will automatically launch in registration mode.)
* At a shell prompt (for example, an xterm or gnome-terminal), type the command "up2date --register".
'
, 0,  TO_Date( '03/07/2002 12:00:00 AM', 'MM/DD/YYYY HH:MI:SS AM'),  TO_Date( '05/19/2003 01:31:52 AM', 'MM/DD/YYYY HH:MI:SS AM')
, 126, 5); 
INSERT INTO RHNFAQ ( ID, SUBJECT, DETAILS, PRIVATE, CREATED, MODIFIED, USAGE_COUNT,
CLASS_ID ) VALUES ( 
7, 'I forgot my username and password. How do I access my account?', 'From the front page, click on the "Lost Password?" link, enter your username and email address, and then click the "Send Password" button.
If you have neither your username nor your password, enter your email address in the second field provided, and then click the "Send Account List" button.
If the email address matches the email address on file for your account, your information will be sent to you. If this does not work for you, please call our customer service desk at 1-866-2-RedHat.
'
, 0,  TO_Date( '03/07/2002 12:00:00 AM', 'MM/DD/YYYY HH:MI:SS AM'),  TO_Date( '04/16/2003 09:14:22 PM', 'MM/DD/YYYY HH:MI:SS AM')
, 16, 2); 
INSERT INTO RHNFAQ ( ID, SUBJECT, DETAILS, PRIVATE, CREATED, MODIFIED, USAGE_COUNT,
CLASS_ID ) VALUES ( 
8, 'What are the service levels for Red Hat Network?', 'Red Hat Network currently offers three levels of service: RHN Demo Service, RHN Update Service and RHN Management Service.  For more details, go to http://www.redhat.com/software/rhn/offerings
'
, 0,  TO_Date( '03/07/2002 12:00:00 AM', 'MM/DD/YYYY HH:MI:SS AM'),  TO_Date( '05/08/2003 03:43:45 AM', 'MM/DD/YYYY HH:MI:SS AM')
, 50, 4); 
INSERT INTO RHNFAQ ( ID, SUBJECT, DETAILS, PRIVATE, CREATED, MODIFIED, USAGE_COUNT,
CLASS_ID ) VALUES ( 
69, 'pvt: You are sending packets to my machine! (Firewall log attached)', 'As you can see, the packets you are seeing are response packets coming from our host and port 443 to your machine.
These packets have the SYN/ACK flags set up. These types of packets are sent only in response to a connection request from your computer.
TCP uses a three-way handshake protocol to establish a connection:
* the client sends a SYN packet to the server requesting a connection
* the server acknowledges the request and sends back a SYN/ACK packet
* the client responds back with an ACK packet and the connection is established
Your firewall rules are not allowing the server responses to pass through.  The rhnsd daemon is initiating these requests. You have 2 choices:
* fix the firewall rules so you allow the reply packets to pass through and therefore allow your host to connect outside; or
* disable the rhnsd daemon: service rhnsd stop
'
, 1,  TO_Date( '10/02/2002 12:00:00 AM', 'MM/DD/YYYY HH:MI:SS AM'),  TO_Date( '03/31/2003 09:26:11 AM', 'MM/DD/YYYY HH:MI:SS AM')
, 3, 1); 
INSERT INTO RHNFAQ ( ID, SUBJECT, DETAILS, PRIVATE, CREATED, MODIFIED, USAGE_COUNT,
CLASS_ID ) VALUES ( 
125, 'pvt: no RHL support at rhn-help', 'This address is intended for support questions related only to Red Hat
Network. General Red Hat Linux support is not available from this address.
If you have not already done so, you can activate your product and receive advanced support at:
https://www.redhat.com/apps/support/
Even if you are not registered with Red Hat Support, you are welcome to browse
our documentation and online resources available at:
https://www.redhat.com/docs/
You may also get access to Tips, FAQs, and online HOWTOs to guide you through
Linux-related tasks if you start looking from our Support Resources Home Page
available at:
https://www.redhat.com/apps/support/resources/
The Red Hat mailing lists are also good venues for finding answers to your
questions. For more information on the Red Hat mailing lists, please see:
http://www.redhat.com/mailing-lists/
If you would like to report a bug or a problem with a component of the Red Hat Linux distribution, we encourage you to visit our bug tracking system and file a bug report at:
http://bugzilla.redhat.com/bugzilla
'
, 1,  TO_Date( '12/11/2002 12:00:00 AM', 'MM/DD/YYYY HH:MI:SS AM'),  TO_Date( '03/31/2003 09:26:12 AM', 'MM/DD/YYYY HH:MI:SS AM')
, 288, 1); 
INSERT INTO RHNFAQ ( ID, SUBJECT, DETAILS, PRIVATE, CREATED, MODIFIED, USAGE_COUNT,
CLASS_ID ) VALUES ( 
126, 'How do I change my RHN password?', 'To change your password:
* Log in to the Red Hat Network website with your existing username and password.
* If you are not at Your RHN page, click its link in the top navigation bar.
* Click "Your Account" in the left navigation bar.
* Type your new password in both the Password and Password Confirmation fields.
* Click the "Update" button.
'
, 0,  TO_Date( '12/12/2002 12:00:00 AM', 'MM/DD/YYYY HH:MI:SS AM'),  TO_Date( '03/31/2003 09:26:12 AM', 'MM/DD/YYYY HH:MI:SS AM')
, 9, 2); 
INSERT INTO RHNFAQ ( ID, SUBJECT, DETAILS, PRIVATE, CREATED, MODIFIED, USAGE_COUNT,
CLASS_ID ) VALUES ( 
13, 'What is "rhnsd" and why is it running on my system?', '"rhnsd" is the Red Hat Network Daemon. Every other hour, it sends a request to Red Hat Network asking for any notifications or updates and works in coordination with Red Hat Network to schedule automated tasks. It sends information to Red Hat Network only requested by you. If you add a new system using the Red Hat Network web interface, the next time the Red Hat Network Daemon probes Red Hat Network it receives a request to return the information you requested as part of your System Profile, such as what package versions are installed on your system.
'
, 0,  TO_Date( '03/07/2002 12:00:00 AM', 'MM/DD/YYYY HH:MI:SS AM'),  TO_Date( '04/08/2003 10:52:29 PM', 'MM/DD/YYYY HH:MI:SS AM')
, 9, 6); 
INSERT INTO RHNFAQ ( ID, SUBJECT, DETAILS, PRIVATE, CREATED, MODIFIED, USAGE_COUNT,
CLASS_ID ) VALUES ( 
15, 'My systems are not checking in.  What does that mean?', 'When the RHN client connects to RHN to see if there are any updates available, or if any actions have been scheduled, this is considered a checkin.
If you are seeing a message indicating that checkins are not happening, it means that the RHN client on your system is not successfully reaching Red Hat Network for some reason. Things to check:
* Make certain that your client is configured correctly.
* Make sure that your system can communicate with RHN via SSL (port 443).  You may test this by running the following command from a shell prompt: telnet xmlrpc.rhn.redhat.com 443
* Make sure that the rhnsd daemon is activated and running.  You may ensure this by running the following commands:
chkconfig --level 345 rhnsd on
service rhnsd start
If these settings are correct and your system still is not checking in, the ''Repairing a corrupt rpm database'' faq at http://rhn.redhat.com/help/faq/technical_questions.pxt#227 , or get in touch with our technical support team.
'
, 0,  TO_Date( '03/07/2002 12:00:00 AM', 'MM/DD/YYYY HH:MI:SS AM'),  TO_Date( '05/14/2003 05:04:29 AM', 'MM/DD/YYYY HH:MI:SS AM')
, 151, 5); 
INSERT INTO RHNFAQ ( ID, SUBJECT, DETAILS, PRIVATE, CREATED, MODIFIED, USAGE_COUNT,
CLASS_ID ) VALUES ( 
17, 'Can I use Red Hat Network to upgrade my Red Hat Linux kernel?', 'Yes. You must use Red Hat Update Agent version 2.5.4 or higher. If you choose the kernel packages and allow Red Hat Network to install them to your system, it will modify your LILO or GRUB configuration file so that your system boots the new kernel the next time it is rebooted.
'
, 0,  TO_Date( '03/07/2002 12:00:00 AM', 'MM/DD/YYYY HH:MI:SS AM'),  TO_Date( '03/31/2003 09:26:12 AM', 'MM/DD/YYYY HH:MI:SS AM')
, 11, 5); 
INSERT INTO RHNFAQ ( ID, SUBJECT, DETAILS, PRIVATE, CREATED, MODIFIED, USAGE_COUNT,
CLASS_ID ) VALUES ( 
41, 'pvt: Updates to newer versions recommended by third-party security advisories.'
, 'We have released fixes for all known vulnerabilities you are mentioning.  Red Hat does not usually update to a new code base for the core applications and libraries if we have other options available. In the cases you have mentioned we choose to backport the security fixes to the code base we initially shipped to our customers. We do this in order to minimize the impact on the stability and the QA resources that both we and the customers invest in qualifying a particular release for a particular task.
The latest versions of those packages provided by Red Hat are not vulnerable to the issues you mention.
'
, 1,  TO_Date( '10/01/2002 12:00:00 AM', 'MM/DD/YYYY HH:MI:SS AM'),  TO_Date( '04/13/2003 11:31:22 PM', 'MM/DD/YYYY HH:MI:SS AM')
, 10, 1); 
INSERT INTO RHNFAQ ( ID, SUBJECT, DETAILS, PRIVATE, CREATED, MODIFIED, USAGE_COUNT,
CLASS_ID ) VALUES ( 
62, 'Is Red Hat Technical Support available in other languages besides English?', 'At this time, Red Hat Network technical support is English only.
'
, 0,  TO_Date( '10/02/2002 12:00:00 AM', 'MM/DD/YYYY HH:MI:SS AM'),  TO_Date( '04/27/2003 10:32:41 PM', 'MM/DD/YYYY HH:MI:SS AM')
, 26, 4); 
INSERT INTO RHNFAQ ( ID, SUBJECT, DETAILS, PRIVATE, CREATED, MODIFIED, USAGE_COUNT,
CLASS_ID ) VALUES ( 
63, 'How do I download RPMs for a system without using up2date?', 'It is possible for Red Hat Network users to download updated packages directly from the RHN website without using up2date.
To download them:
* Log in to the RHN web site.
* Click "Software" in the top navigation bar.
* Click the appropriate channel name.
* On the Channel Details page, click the "Packages" tab.
* Select the RPMs you want and click the "Download" button. You will be presented with a confirmation screen.
* Click "Download Selected Packages Now!"
* You will then be asked for the location to save the tar archive containing all the packages you selected.
* To extract the packages once the download is complete, run: tar -xvf rhn-packages.tar
'
, 0,  TO_Date( '10/02/2002 12:00:00 AM', 'MM/DD/YYYY HH:MI:SS AM'),  TO_Date( '03/31/2003 09:26:12 AM', 'MM/DD/YYYY HH:MI:SS AM')
, 9, 5); 
INSERT INTO RHNFAQ ( ID, SUBJECT, DETAILS, PRIVATE, CREATED, MODIFIED, USAGE_COUNT,
CLASS_ID ) VALUES ( 
31, 'The update agent wants to install an older version of a package.  Why?', 'This is probably because of the epoch number of the package.  RPM checks three things when it tries to determine whether a package is newer: epoch, version, and release, in that order.  A higher epoch number trumps both version and release.  To see the epoch number on an installed package, use the command:
rpm -q --queryformat "%{NAME}-%{VERSION}-%{RELEASE}:%{EPOCH}\n" packagename
The epoch is the number after the colon.  On the RHN website, you can also see the epoch for the package on the Installed Packages list for the system, (again, the number after the colon).
Epoch numbers are used to preserve RPM''s concept of "newer" when package versions are changed inconveniently. The classic example of the need for an epoch is perl, which changed from version 5.00503 to 5.6, thereby breaking rpm''s segmented version comparison (i.e the integer 6 < 503, rather than 5.6 > 5.00503).
To keep the update agent from trying to update your package, add it to the package skip list (pkgSkipList) in your up2date configuration:
up2date --configure --nox
However, the package will still show up on your list of applicable errata.
'
, 0,  TO_Date( '06/14/2002 12:00:00 AM', 'MM/DD/YYYY HH:MI:SS AM'),  TO_Date( '04/06/2003 10:26:15 PM', 'MM/DD/YYYY HH:MI:SS AM')
, 7, 6); 
INSERT INTO RHNFAQ ( ID, SUBJECT, DETAILS, PRIVATE, CREATED, MODIFIED, USAGE_COUNT,
CLASS_ID ) VALUES ( 
32, 'pvt: Red Hat Linux support', 'This address is intended for support questions related only to Red Hat Network. General Red Hat Linux support is not available from this address.  If you are registered with Red Hat Support, you may address your questions at:
http://www.redhat.com/support
If you have not already done so, you can activate your product and receive advanced support at:
https://www.redhat.com/apps/support/
Even if you are not registered with Red Hat Support, you are welcome to browse
our documentation and online resources available at:
https://www.redhat.com/docs/
You may also get access to Tips, FAQs, and online HOWTOs to guide you through
Linux-related tasks if you start looking from our Support Resources Home Page
available at:
https://www.redhat.com/apps/support/resources/
The Red Hat mailing lists are also good venues for finding answers to your
questions. For more information on the Red Hat mailing lists, please see:
http://www.redhat.com/mailing-lists/
If you would like to report a bug or a problem with a component of the Red Hat Linux distribution, we encourage you to visit our bug tracking system and file a bug report at:
http://bugzilla.redhat.com/bugzilla
'
, 1,  TO_Date( '06/22/2002 12:00:00 AM', 'MM/DD/YYYY HH:MI:SS AM'),  TO_Date( '05/19/2003 01:13:04 AM', 'MM/DD/YYYY HH:MI:SS AM')
, 768, 1); 
INSERT INTO RHNFAQ ( ID, SUBJECT, DETAILS, PRIVATE, CREATED, MODIFIED, USAGE_COUNT,
CLASS_ID ) VALUES ( 
33, 'How do I delete System Profiles?', 'In order to delete System Profiles from Red Hat Network, you need to log in to the RHN website at https://rhn.redhat.com.  Once logged in, click on the "Systems" link in the top navigation bar, which will take you to a list of the profiles you have registered with RHN. (If you instead see System Groups, click "View Systems" near the top of the page.)
Click on the name of the profile you wish to delete from the service. This will bring up its System Details page. Click the "delete system" button at the top-right corner of the page. Then confirm that you wish to delete the profile.
The profile will be removed after confirmation.
'
, 0,  TO_Date( '06/24/2002 12:00:00 AM', 'MM/DD/YYYY HH:MI:SS AM'),  TO_Date( '05/12/2003 10:57:15 PM', 'MM/DD/YYYY HH:MI:SS AM')
, 89, 7); 
INSERT INTO RHNFAQ ( ID, SUBJECT, DETAILS, PRIVATE, CREATED, MODIFIED, USAGE_COUNT,
CLASS_ID ) VALUES ( 
36, 'pvt: Educational Channel', 'The educational channel and Red Hat educational initiative is currently undergoing some changes (all for the positive). Please stay tuned and periodically check the following websites for more information:
www.redhat.com
www.redhat.com/index2.html
www.redhat.com/software/rhn
'
, 1,  TO_Date( '08/20/2002 12:00:00 AM', 'MM/DD/YYYY HH:MI:SS AM'),  TO_Date( '03/31/2003 09:26:13 AM', 'MM/DD/YYYY HH:MI:SS AM')
, 14, 1); 
INSERT INTO RHNFAQ ( ID, SUBJECT, DETAILS, PRIVATE, CREATED, MODIFIED, USAGE_COUNT,
CLASS_ID ) VALUES ( 
35, 'An errata install fails with dependency errors, but dependencies are satisfied.  Why?'
, 'Sometimes the application of an errata from the RHN web site will fail because the errata applies to packages that are set to be skipped in the local skip list for a system''s up2date client.  The error message in the history log will incorrectly cite a dependency problem.
To fix this problem, run:
up2date --configure
...as root from the client system, and remove the relevant packages from the skip list.  Rescheduling the errata should then work as expected.
'
, 0,  TO_Date( '08/20/2002 12:00:00 AM', 'MM/DD/YYYY HH:MI:SS AM'),  TO_Date( '05/13/2003 10:24:11 PM', 'MM/DD/YYYY HH:MI:SS AM')
, 23, 6); 
INSERT INTO RHNFAQ ( ID, SUBJECT, DETAILS, PRIVATE, CREATED, MODIFIED, USAGE_COUNT,
CLASS_ID ) VALUES ( 
249, 'Where can I see a copy of the SLA (Service Level Agreement) for RHN Technical Support?'
, 'This can be viewed online at the following site:
http://www.redhat.com/services/techsupport/production/RHN_basic.html'
, 0,  TO_Date( '03/31/2003 11:55:25 AM', 'MM/DD/YYYY HH:MI:SS AM'),  TO_Date( '04/09/2003 11:00:32 PM', 'MM/DD/YYYY HH:MI:SS AM')
, 6, 4); 
INSERT INTO RHNFAQ ( ID, SUBJECT, DETAILS, PRIVATE, CREATED, MODIFIED, USAGE_COUNT,
CLASS_ID ) VALUES ( 
288, 'My system''s IP address and hostname have changed, but RHN doesn''t reflect this. What should I do?'
, 'RHN stores a profile for each registered system. In addition to properties set by the user during registration, this profile may contain various kinds of information about the system''s hardware, including processor type, networking addresses, and storage devices. This information can be found in the RHN website:
1. Once logged in, click on Systems in the top navigation bar.
2. Click on the name of a system in one of the lists. (This may require leaving a System Groups view.)
3. In the System Details page, click the Hardware subtab. All of the hardware information RHN has collected about your system will appear on the resulting page.
4. To update this information, click the Schedule Hardware Refresh button. The hardware profile will be updated at the system''s next connection to RHN.'
, 0,  TO_Date( '04/22/2003 04:00:05 PM', 'MM/DD/YYYY HH:MI:SS AM'),  TO_Date( '04/23/2003 09:45:57 AM', 'MM/DD/YYYY HH:MI:SS AM')
, 0, 6); 
INSERT INTO RHNFAQ ( ID, SUBJECT, DETAILS, PRIVATE, CREATED, MODIFIED, USAGE_COUNT,
CLASS_ID ) VALUES ( 
290, 'Why does up2date tell me "Your system is fully updated" when the RHN website lists updates for my system?'
, 'This error is likely caused by one of two problems: Either the system''s package profile on RHN is out of date or up2date''s package exceptions list is preventing the updates from occurring.
Since updating the package profile is simplest, try this first. Log into the RHN website, click "Systems" in the top navigation bar, and then click the name of the system. In the System Details page, click the "Packages" tab and then click the "Update Package List" button. The profile will be updated when the system next connects to RHN. This should either remove the updates listed for your system or allow you to conduct the updates if they remain.
If this still does not resolve the error, check your package exceptions list, which enables you to identify packages to be exempt from updates. To ensure your settings are not preventing the updates, launch the Update Agent Configuration Tool by running the command:
up2date-config
In the tool, click the "Package Exceptions" tab and look for the packages listed as requiring updating.
To check the package skip list in the up2date configuration file, open the file /etc/sysconfig/rhn/up2date and look for the package entries under the pkgSkipList setting. To override the package exceptions and force an update of the entire system, run the command:
up2date -uf
If the packages aren''t updated, the RHN website will continue to list them as outdated, regardless of their inclusion in the system''s package exceptions list.'
, 0,  TO_Date( '04/22/2003 06:32:03 PM', 'MM/DD/YYYY HH:MI:SS AM'),  TO_Date( '04/25/2003 08:04:45 PM', 'MM/DD/YYYY HH:MI:SS AM')
, 0, 6); 
INSERT INTO RHNFAQ ( ID, SUBJECT, DETAILS, PRIVATE, CREATED, MODIFIED, USAGE_COUNT,
CLASS_ID ) VALUES ( 
291, 'Why does Apache fail to restart after I update my RHN Management Satellite Server?', 'Apache RPMs do not restart the httpd service upon installation. Therefore, after conducting a full update of an RHN Management Satellite Server (such as with the command up2date -uf), Apache fails. The error will look something like:
[Mon Feb 10 11:50:12 2003] [notice] SIGHUP received.  Attempting to restart
Syntax error on line 214 of /etc/httpd/conf/httpd.conf: Cannot load /etc/httpd/modules/mod_log_config.so into server: /etc/httpd/modules/mod_log_config.so: undefined symbol: ap_escape_logitem
To resolve this, restart the httpd service.'
, 0,  TO_Date( '04/22/2003 08:27:51 PM', 'MM/DD/YYYY HH:MI:SS AM'),  TO_Date( '04/23/2003 09:48:30 AM', 'MM/DD/YYYY HH:MI:SS AM')
, 0, 7); 
INSERT INTO RHNFAQ ( ID, SUBJECT, DETAILS, PRIVATE, CREATED, MODIFIED, USAGE_COUNT,
CLASS_ID ) VALUES ( 
308, 'How do I resolve dropped connections during ISO downloads?', 'Red Hat recommends using the Curl open source tool for downloading ISO images. This tool enables you to resume downloads that have been interrupted. If you use RHN and don''t currently have Curl, you may install it by running the command "up2date curl" from a shell prompt.
Once Curl is installed, at a shell prompt, cut and paste the URL for the ISO into the Curl command as follows:
[user@localhost home]$ curl -C - -O ''very_long_url''
The URL, which can be derived from the Easy ISOs page of the RHN website, is very long because it contains session authentication information. Be sure to include the single quotation marks around it. The ''-C -'' option allows you to continue the download if it is interrupted, such as by a lost connection. The ''-O'' (the letter ''O'', not a zero) option will save the file with the same name as on the RHN Servers.'
, 0,  TO_Date( '04/30/2003 07:02:36 PM', 'MM/DD/YYYY HH:MI:SS AM'),  TO_Date( '05/02/2003 11:41:21 AM', 'MM/DD/YYYY HH:MI:SS AM')
, 0, 5); 
INSERT INTO RHNFAQ ( ID, SUBJECT, DETAILS, PRIVATE, CREATED, MODIFIED, USAGE_COUNT,
CLASS_ID ) VALUES ( 
310, 'Why does the registration process prompt me for an organization ID if I don''t need one to register?'
, 'The organization ID is legacy from the days in which RHN allowed users to request addition to an existing organization, which then required an Organization Administrator to approve the new user.
Now, the RHN website allows Organization Administrators to create user accounts directly. Unfortunately, older versions of the registration tools (both rhn_register and up2date) still contain organization ID and password fields. You may disregard them.'
, 0,  TO_Date( '05/02/2003 08:51:09 PM', 'MM/DD/YYYY HH:MI:SS AM'),  TO_Date( '05/03/2003 09:07:56 AM', 'MM/DD/YYYY HH:MI:SS AM')
, 0, 3); 
INSERT INTO RHNFAQ ( ID, SUBJECT, DETAILS, PRIVATE, CREATED, MODIFIED, USAGE_COUNT,
CLASS_ID ) VALUES ( 
221, 'How do I get more legal information?', 'Please go to http://www.redhat.com/software/rhn/legal'
, 0,  TO_Date( '03/27/2003 06:47:21 PM', 'MM/DD/YYYY HH:MI:SS AM'),  TO_Date( '03/31/2003 09:26:11 AM', 'MM/DD/YYYY HH:MI:SS AM')
, 0, 8); 
INSERT INTO RHNFAQ ( ID, SUBJECT, DETAILS, PRIVATE, CREATED, MODIFIED, USAGE_COUNT,
CLASS_ID ) VALUES ( 
224, 'What is an ISO?', 'An ISO is an image file of the contents of a CD.
For example, by downloading the Red Hat Linux ISOs to your system, you can then burn a CD that will be identical to the Red Hat Linux CDs that are available in retail stores.'
, 0,  TO_Date( '03/28/2003 11:22:00 AM', 'MM/DD/YYYY HH:MI:SS AM'),  TO_Date( '04/16/2003 09:07:32 PM', 'MM/DD/YYYY HH:MI:SS AM')
, 0, 11); 
INSERT INTO RHNFAQ ( ID, SUBJECT, DETAILS, PRIVATE, CREATED, MODIFIED, USAGE_COUNT,
CLASS_ID ) VALUES ( 
225, 'What is Errata?', 'An Errata is a message about new updates for your system, usually accompanied by updated packages.
Red Hat Network is a tool to update your system with these errata packages.'
, 0,  TO_Date( '03/28/2003 11:25:25 AM', 'MM/DD/YYYY HH:MI:SS AM'),  TO_Date( '04/16/2003 09:08:17 PM', 'MM/DD/YYYY HH:MI:SS AM')
, 0, 11); 
INSERT INTO RHNFAQ ( ID, SUBJECT, DETAILS, PRIVATE, CREATED, MODIFIED, USAGE_COUNT,
CLASS_ID ) VALUES ( 
227, 'How do I repair a corrupt RPM database?', 'Occasionally, the RPM database on a Red Hat Linux machine will become corrupt.  This usually happens when an RPM transaction is interrupted at a critical time.  Symptoms of this problem include one of the following programs not responding or freezing:
* up2date
* The RHN alert notification tool (applet in the Gnome or KDE panel)
* rhn_check
* rpm
This problem can also cause a system to stop checking in with RHN.
To fix this problem, run the following commands as root:
* kill all RPM processes (rhn_check, up2date, rpm, rhn-applet):
     $ ps -axwww | grep rhn_check
In the list of processes, the first number on each line is the PID.  For all PIDs listed except for the one associated with grep:
     $ kill -9 <PID>
Repeat the above steps for each of the programs listed.
* remove any RPM lock files (/var/lib/rpm/__db*):
     $ rm -rf /var/lib/rpm/__db*
* rebuild the rpm database:
     $ rpm --rebuilddb
If the above steps do not work, please contact technical support for more assistance.'
, 0,  TO_Date( '03/28/2003 11:34:34 AM', 'MM/DD/YYYY HH:MI:SS AM'),  TO_Date( '05/07/2003 11:31:57 PM', 'MM/DD/YYYY HH:MI:SS AM')
, 2, 6); 
INSERT INTO RHNFAQ ( ID, SUBJECT, DETAILS, PRIVATE, CREATED, MODIFIED, USAGE_COUNT,
CLASS_ID ) VALUES ( 
231, 'How do I move my Red Hat Network entitlement to another machine?', 'All of the systems that you want to entitle, or un-entitle, must be registered with Red Hat Network. Please see the FAQ question relating to registering new systems.
First Step - unentitle old system
1) Sign in with Red Hat Network
2) Click on "Systems"
3) Click on "Systems Entitlements"
4) Change entitlement of old system to "none"
5) Click "Update Entitlements"
Next Step - entitle new system
From same screen, change the entitlement on the new system to the entitlement you would like to have. Click "Update Entitlements".'
, 0,  TO_Date( '03/28/2003 12:07:10 PM', 'MM/DD/YYYY HH:MI:SS AM'),  TO_Date( '05/14/2003 09:33:40 PM', 'MM/DD/YYYY HH:MI:SS AM')
, 2, 5); 
INSERT INTO RHNFAQ ( ID, SUBJECT, DETAILS, PRIVATE, CREATED, MODIFIED, USAGE_COUNT,
CLASS_ID ) VALUES ( 
230, 'I just upgraded my system. How do I re-register it with Red Hat Network?', 'If you are running a version of Red Hat Linux 7.3 (or prior release), do the following:
1) Log in as root
2) Type "rhn_register"
If you are running a version of Red Hat Linux 8.0 (or later release), do the following:
1) Log in as root
2) Type "up2date --register"'
, 0,  TO_Date( '03/28/2003 12:01:49 PM', 'MM/DD/YYYY HH:MI:SS AM'),  TO_Date( '04/24/2003 10:47:23 PM', 'MM/DD/YYYY HH:MI:SS AM')
, 2, 5); 
INSERT INTO RHNFAQ ( ID, SUBJECT, DETAILS, PRIVATE, CREATED, MODIFIED, USAGE_COUNT,
CLASS_ID ) VALUES ( 
232, 'How do I get copies of the latest release notes for Red Hat Network?', 'Click on the Help button in the upper right hand corner. Then click on Release Notes listed on the navigation bar on the left.'
, 0,  TO_Date( '03/28/2003 12:16:19 PM', 'MM/DD/YYYY HH:MI:SS AM'),  TO_Date( '03/31/2003 09:26:11 AM', 'MM/DD/YYYY HH:MI:SS AM')
, 0, 5); 
INSERT INTO RHNFAQ ( ID, SUBJECT, DETAILS, PRIVATE, CREATED, MODIFIED, USAGE_COUNT,
CLASS_ID ) VALUES ( 
70, 'pvt: Updating kernel and config files', 'Because of the wide range of changes and setups involved in the scenarios you describe we have chosen the conservative path in the default configuration.
We recommend that you upgrade the kernel on the boxes while you can observe the process (ie, running "up2date --force kernel" from the command line). The same goes for the packages which have config files DBmodified - please check the results of the upgrade process to make sure you will not have an interruption of service due to changed config files.
Once you have been through this process a few times and get a better feel for how RHN handles your particular setup, you can decide to let RHN perform these updates for you automatically.
'
, 1,  TO_Date( '10/02/2002 12:00:00 AM', 'MM/DD/YYYY HH:MI:SS AM'),  TO_Date( '04/14/2003 10:30:31 PM', 'MM/DD/YYYY HH:MI:SS AM')
, 26, 1); 
INSERT INTO RHNFAQ ( ID, SUBJECT, DETAILS, PRIVATE, CREATED, MODIFIED, USAGE_COUNT,
CLASS_ID ) VALUES ( 
73, 'pvt: I can''t get into ftp.redhat.com. Why?', '
Due to the popularity of Red Hat Linux 8.0, our ftp servers are currently heavily loaded, and are at their capacity. We apologize for any inconvenience this may cause.
If you are not able to log into the ftp.redhat.com ftp site, it is probably because the servers are serving the maximum number of users currently. You can try later, or better yet, try one of the many Red Hat mirror sites. They are listed at:
https://www.redhat.com/download/mirror.html
  '
, 1,  TO_Date( '10/02/2002 12:00:00 AM', 'MM/DD/YYYY HH:MI:SS AM'),  TO_Date( '04/24/2003 09:35:36 PM', 'MM/DD/YYYY HH:MI:SS AM')
, 3, 1); 
INSERT INTO RHNFAQ ( ID, SUBJECT, DETAILS, PRIVATE, CREATED, MODIFIED, USAGE_COUNT,
CLASS_ID ) VALUES ( 
82, 'Red Hat''s "GPG Key" - what is it and how do I install it?', 'The first time you run the graphical version of the Red Hat Update Agent, it prompts you to install the Red Hat GPG key. This key is required to authenticate the packages downloaded from Red Hat Network. If you run the command line version the first time you start Red Hat Update Agent, you need to install the Red Hat GPG key manually; follow the instructions that up2date displays.'
, 0,  TO_Date( '10/17/2002 12:00:00 AM', 'MM/DD/YYYY HH:MI:SS AM'),  TO_Date( '05/06/2003 11:15:40 PM', 'MM/DD/YYYY HH:MI:SS AM')
, 10, 6); 
INSERT INTO RHNFAQ ( ID, SUBJECT, DETAILS, PRIVATE, CREATED, MODIFIED, USAGE_COUNT,
CLASS_ID ) VALUES ( 
124, 'pvt: no RHL support at rhn-feedback', 'This address is intended for feedback related only to Red Hat
Network. General Red Hat Linux support is not available from this address.
If you are registered with Red Hat Support, you may address your questions
at:
http://www.redhat.com/support
Even if you are not registered with Red Hat Support, you are welcome to browse
our documentation and online resources available at:
https://www.redhat.com/docs/
You may also get access to Tips, FAQs, and online HOWTOs to guide you through
Linux-related tasks if you start looking from our Support Resources Home Page
available at:
https://www.redhat.com/apps/support/resources/
The Red Hat mailing lists are also good venues for finding answers to your
questions. For more information on the Red Hat mailing lists, please see:
http://www.redhat.com/mailing-lists/
If you would like to report a bug or a problem with a component of the Red Hat Linux distribution, we encourage you to visit our bug tracking system and file a bug report at:
http://bugzilla.redhat.com/bugzilla'
, 1,  TO_Date( '12/11/2002 12:00:00 AM', 'MM/DD/YYYY HH:MI:SS AM'),  TO_Date( '03/31/2003 09:26:11 AM', 'MM/DD/YYYY HH:MI:SS AM')
, 10, 1); 
INSERT INTO RHNFAQ ( ID, SUBJECT, DETAILS, PRIVATE, CREATED, MODIFIED, USAGE_COUNT,
CLASS_ID ) VALUES ( 
191, 'pvt: I want to unsubscribe from the maillist !', 'To stop receiving mails from RHN , please see below:
Use your RHN account to login, then go to "Your RHN"==>"Your preferences" .
The Your Preferences page allows you to configure Red Hat Network options, including:
      Errata Email Notification — Determine whether you want to receive email every time an Errata Alert is applicable to one or more systems in your RHN account.
      RHN List Page Size — Maximum number of items that will appear in a list on a single page. If more items are in the list, clicking the Next button will display the next group of items. This preference applies to system lists, Errata lists, package lists, and so on.
      Time Zone — Set your time zone so that scheduled actions are scheduled according to the time in your time zone.
      Red Hat Contact Options — Identify what ways (email, phone, fax, or mail) Red Hat may contact you.
After making changes to any of these options, click the Save Preferences button on the bottom right-hand corner.
'
, 1,  TO_Date( '02/19/2003 08:20:46 PM', 'MM/DD/YYYY HH:MI:SS AM'),  TO_Date( '04/27/2003 11:53:51 PM', 'MM/DD/YYYY HH:MI:SS AM')
, 89, 1); 
INSERT INTO RHNFAQ ( ID, SUBJECT, DETAILS, PRIVATE, CREATED, MODIFIED, USAGE_COUNT,
CLASS_ID ) VALUES ( 
209, 'I can''t log in with my username or password.  What should I do?', 'First, please check to see if you are using the correct username and password (see answers to questions in this section). If you are using the correct username and password, please call customer service at 1-866-2-RedHat or contact them at customerservice@redhat.com'
, 0,  TO_Date( '03/27/2003 03:57:30 PM', 'MM/DD/YYYY HH:MI:SS AM'),  TO_Date( '03/31/2003 09:26:10 AM', 'MM/DD/YYYY HH:MI:SS AM')
, 0, 2); 
INSERT INTO RHNFAQ ( ID, SUBJECT, DETAILS, PRIVATE, CREATED, MODIFIED, USAGE_COUNT,
CLASS_ID ) VALUES ( 
228, 'pvt: How can I subscribe for Red Hat 9 now?', 'Red Hat Linux 9 ISOs will be available to paid subscribers starting March 31, 2003--a week before they will be available on redhat.com, in stores, or on Red Hat FTP. A paid subscription also gets you access to RHN technical support, errata updates, priority access during peak times, and immediate email notification. It''s the quickest way to get Red Hat Linux 9.
Note: Red Hat Network does not include printed documentation or Red Hat Linux Installation Support. If that''s what you''re looking for,  you can purchase Red Hat Linux 9 at redhat.com or at retail stores, available April 7, 2003. Red Hat Linux 9 or Red Hat Linux 9 Professional includes source code and documentation CDs, printed documentation manuals, installation support, and 1- or 2- month Update Subscription to Red Hat Network.
For more informations please visit this page:
http://www.redhat.com/mktg/rh9iso/
'
, 1,  TO_Date( '03/25/2003 03:09:59 AM', 'MM/DD/YYYY HH:MI:SS AM'),  TO_Date( '04/06/2003 09:07:11 PM', 'MM/DD/YYYY HH:MI:SS AM')
, 9, 1); 
INSERT INTO RHNFAQ ( ID, SUBJECT, DETAILS, PRIVATE, CREATED, MODIFIED, USAGE_COUNT,
CLASS_ID ) VALUES ( 
208, 'I am new to Red Hat Network. How do I create an account?', 'Go to http://rhn.redhat.com and click on the link that says "Create Account". From here, please follow the directions.'
, 0,  TO_Date( '03/27/2003 03:55:40 PM', 'MM/DD/YYYY HH:MI:SS AM'),  TO_Date( '03/31/2003 09:26:11 AM', 'MM/DD/YYYY HH:MI:SS AM')
, 0, 3); 
INSERT INTO RHNFAQ ( ID, SUBJECT, DETAILS, PRIVATE, CREATED, MODIFIED, USAGE_COUNT,
CLASS_ID ) VALUES ( 
210, 'How do I login to Red Hat Network?', 'Go to http://rhn.redhat.com
From this page, enter in your username and password in the box. If you do not have your username and password, please see the FAQ relating to this.'
, 0,  TO_Date( '03/27/2003 03:59:43 PM', 'MM/DD/YYYY HH:MI:SS AM'),  TO_Date( '03/31/2003 09:26:11 AM', 'MM/DD/YYYY HH:MI:SS AM')
, 0, 3); 
INSERT INTO RHNFAQ ( ID, SUBJECT, DETAILS, PRIVATE, CREATED, MODIFIED, USAGE_COUNT,
CLASS_ID ) VALUES ( 
212, 'How do I contact Red Hat Network?', 'To contact Red Hat Network, please go to: http://www.redhat.com/software/rhn/contact'
, 0,  TO_Date( '03/27/2003 04:02:07 PM', 'MM/DD/YYYY HH:MI:SS AM'),  TO_Date( '03/31/2003 09:26:11 AM', 'MM/DD/YYYY HH:MI:SS AM')
, 0, 1); 
INSERT INTO RHNFAQ ( ID, SUBJECT, DETAILS, PRIVATE, CREATED, MODIFIED, USAGE_COUNT,
CLASS_ID ) VALUES ( 
215, 'How do I know when I need to update my system?', 'Once your system is registered on Red Hat Network, a small icon will appear on your tool bar (Red Hat Linux 7.3 and higher). The icon will display either an exclamation point with red background (meaning that there is an update waiting to be downloaded) or a check mark with blue background (meaning that there are no updates waiting). If your icon portrays a question mark, it means that Red Hat Network is not able to see your system.
By double clicking on the icon, this will activate Red Hat Network update tool.'
, 0,  TO_Date( '03/27/2003 04:27:48 PM', 'MM/DD/YYYY HH:MI:SS AM'),  TO_Date( '03/31/2003 09:26:11 AM', 'MM/DD/YYYY HH:MI:SS AM')
, 0, 1); 
INSERT INTO RHNFAQ ( ID, SUBJECT, DETAILS, PRIVATE, CREATED, MODIFIED, USAGE_COUNT,
CLASS_ID ) VALUES ( 
217, 'Can I use Red Hat Network to upgrade to a newer version of Red Hat Linux?', 'No. While Red Hat Network always supports the latest version of Red Hat Linux, Red Hat Network cannot be used today to upgrade your system from one version of Red Hat Linux to the next. You will need to do a CD based install. However, if you are a paid subscriber to Red Hat Network (Update or Management), you have access to the new Red Hat Linux ISOs the moment they are made available. For more information, see http://www.redhat.com/software/rhn/offerings
'
, 0,  TO_Date( '03/27/2003 04:39:01 PM', 'MM/DD/YYYY HH:MI:SS AM'),  TO_Date( '03/31/2003 09:26:11 AM', 'MM/DD/YYYY HH:MI:SS AM')
, 0, 5); 
INSERT INTO RHNFAQ ( ID, SUBJECT, DETAILS, PRIVATE, CREATED, MODIFIED, USAGE_COUNT,
CLASS_ID ) VALUES ( 
219, 'What are the terms and conditions of Red Hat Network?', 'To see a copy of the Red Hat Network Terms and Conditions, please go to http://www.redhat.com/licenses/rhn.html'
, 0,  TO_Date( '03/27/2003 06:03:20 PM', 'MM/DD/YYYY HH:MI:SS AM'),  TO_Date( '03/31/2003 09:26:11 AM', 'MM/DD/YYYY HH:MI:SS AM')
, 0, 8); 
INSERT INTO RHNFAQ ( ID, SUBJECT, DETAILS, PRIVATE, CREATED, MODIFIED, USAGE_COUNT,
CLASS_ID ) VALUES ( 
23, 'How do I remove a pending action?', 'A pending action will be removed when there are no longer any systems scheduled for it.  For Demo or Update entitlements this will always be done on a per system basis:
* Log into the RHN website.
* Click "Schedule" on the top navigation bar, then "Pending Actions" in the left navigation bar.
* Click on the numeral in the "In Progress" column of the row for the action you want to remove.
* Click on the desired system name.
* Click on the "Events" tab in the System Details navigation.
* Click on the "Pending" subtab.
* Select the event you wish to cancel, and click "Cancel Events"
* Click the "Cancel Selected Events" on the confirmation page.
For systems with Management entitlements, simply remove the systems from the action:
* Click "Schedule" on the top navigation bar, then "Pending Actions" in the left navigation bar.
* Click on the numeral in the "In Progress" column of the row for the action you want to remove.
* Select the systems for removal from the action and then click on the "Unschedule Action" button.
'
, 0,  TO_Date( '06/14/2002 12:00:00 AM', 'MM/DD/YYYY HH:MI:SS AM'),  TO_Date( '05/18/2003 09:53:59 PM', 'MM/DD/YYYY HH:MI:SS AM')
, 14, 7); 
INSERT INTO RHNFAQ ( ID, SUBJECT, DETAILS, PRIVATE, CREATED, MODIFIED, USAGE_COUNT,
CLASS_ID ) VALUES ( 
24, 'Why do scheduled kernel errata fail to install?', 'By default, the kernel packages are marked to be skipped by the update agent.  You can change this configuration by running:
up2date --configure --nox
...and changing or clearing the "pkgSkipList" parameter.  You should then be able to schedule your kernel update.
'
, 0,  TO_Date( '06/14/2002 12:00:00 AM', 'MM/DD/YYYY HH:MI:SS AM'),  TO_Date( '04/30/2003 04:21:47 AM', 'MM/DD/YYYY HH:MI:SS AM')
, 11, 6); 
INSERT INTO RHNFAQ ( ID, SUBJECT, DETAILS, PRIVATE, CREATED, MODIFIED, USAGE_COUNT,
CLASS_ID ) VALUES ( 
131, 'pvt: openssl packages', 'The latest releases of the OpenSSL packages from Red Hat include fixes for all known security vulnerabilities, including the various types of worms that float around.
Please remember that just upgrading the packages is not sufficient. You will have to restart at least your Apache server in order for the new libraries to be loaded by the running Apache process.
More details about the applicable OpenSSL errata can be found at:
https://rhn.redhat.com/errata/RHSA-2002-160.html
and
https://rhn.redhat.com/network/errata/errata_details.pxt?eid=1143
'
, 1,  TO_Date( '12/19/2002 07:33:20 PM', 'MM/DD/YYYY HH:MI:SS AM'),  TO_Date( '03/31/2003 09:26:10 AM', 'MM/DD/YYYY HH:MI:SS AM')
, 4, 1); 
INSERT INTO RHNFAQ ( ID, SUBJECT, DETAILS, PRIVATE, CREATED, MODIFIED, USAGE_COUNT,
CLASS_ID ) VALUES ( 
148, 'pvt: delayed response', 'Due to significant interest & volume in Red Hat Network services, we have been unable to respond to your question in a timely manner.  We apologize for the delay and any inconvenience this delay may have caused you.  In response to your question, below is a response to your question.  If this solution does not resolve your issue, please resubmit with additional information.
'
, 1,  TO_Date( '02/05/2003 12:41:33 PM', 'MM/DD/YYYY HH:MI:SS AM'),  TO_Date( '04/03/2003 11:24:13 PM', 'MM/DD/YYYY HH:MI:SS AM')
, 39, 1); 
INSERT INTO RHNFAQ ( ID, SUBJECT, DETAILS, PRIVATE, CREATED, MODIFIED, USAGE_COUNT,
CLASS_ID ) VALUES ( 
168, 'pvt: New To Linux', 'This address is intended for support questions from paid subscribers and is related only to Red Hat Network. General Red Hat Linux support is not available from this address.  If you are registered with Red Hat Support, you may address your questions at:
http://www.redhat.com/support
If you have not already done so, you can activate your product and receive advanced support at:
https://www.redhat.com/apps/support/
Even if you are not registered with Red Hat Support, you are welcome to browse
our documentation and online resources available at:
https://www.redhat.com/docs/
You may also get access to Tips, FAQs, and online HOWTOs to guide you through
Linux-related tasks if you start looking from our Support Resources Home Page
available at:
https://www.redhat.com/apps/support/resources/
The Red Hat mailing lists are also good venues for finding answers to your
questions. For more information on the Red Hat mailing lists, please see:
http://www.redhat.com/mailing-lists/
If you would like to report a bug or a problem with a component of the Red Hat Linux distribution, we encourage you to visit our bug tracking system and file a bug report at:
http://bugzilla.redhat.com/bugzilla
'
, 1,  TO_Date( '02/13/2003 04:23:15 AM', 'MM/DD/YYYY HH:MI:SS AM'),  TO_Date( '03/31/2003 09:26:10 AM', 'MM/DD/YYYY HH:MI:SS AM')
, 6, 1); 
INSERT INTO RHNFAQ ( ID, SUBJECT, DETAILS, PRIVATE, CREATED, MODIFIED, USAGE_COUNT,
CLASS_ID ) VALUES ( 
169, 'How do I change my email address?', 'To change your email:
* Log in to the Red Hat Network website with your existing username and password.
* If you are not at Your RHN page, click its link in the top navigation bar.
* Click "Your Account" in the left navigation bar.
* Click "Change Email"
* Type your new email in field.
* Click the "Send Verification" or "Update" button.'
, 0,  TO_Date( '02/13/2003 10:03:56 PM', 'MM/DD/YYYY HH:MI:SS AM'),  TO_Date( '04/13/2003 09:15:55 PM', 'MM/DD/YYYY HH:MI:SS AM')
, 16, 2); 
INSERT INTO RHNFAQ ( ID, SUBJECT, DETAILS, PRIVATE, CREATED, MODIFIED, USAGE_COUNT,
CLASS_ID ) VALUES ( 
170, 'pvt: How to entitle system in my RHN', '* Once the system is registered, log in at https://rhn.redhat.com.
* Click "Systems" in the top navigation bar, then "System Entitlements" on the left.
* Select the appropriate entitlement level for the new system and click "Update Entitlements."'
, 1,  TO_Date( '02/13/2003 10:36:28 PM', 'MM/DD/YYYY HH:MI:SS AM'),  TO_Date( '05/15/2003 09:36:58 PM', 'MM/DD/YYYY HH:MI:SS AM')
, 54, 1); 
INSERT INTO RHNFAQ ( ID, SUBJECT, DETAILS, PRIVATE, CREATED, MODIFIED, USAGE_COUNT,
CLASS_ID ) VALUES ( 
188, 'pvt: system on a closed net , but still want to update', 'RHN Management Satellite Server provides for local management of system profiles, thus allowing for completely disconnected operation from external networks.
More information, please follow this link:
https://rhn.redhat.com/info/purchase_info.pxt
'
, 1,  TO_Date( '02/18/2003 09:35:22 PM', 'MM/DD/YYYY HH:MI:SS AM'),  TO_Date( '04/07/2003 11:03:00 PM', 'MM/DD/YYYY HH:MI:SS AM')
, 8, 1); 
INSERT INTO RHNFAQ ( ID, SUBJECT, DETAILS, PRIVATE, CREATED, MODIFIED, USAGE_COUNT,
CLASS_ID ) VALUES ( 
189, 'What are the differences between Update, Management, and Demo Accounts?', 'Update service level subscriptions to Red Hat Network allow individuals to register one or more systems, manage these systems independently, receive priority access to Red Hat Network, and download Easy ISOs (full versions of Red Hat Linux). Update subscriptions are $60 per system and renew annually. Customers may receive also limited time (less than one year) Update subscriptions with the Red Hat Linux distribution products.
Management service level subscriptions to Red Hat Network allow organizations to manage multiple systems, individually or in groups of systems. Management subscriptions efficiently combine the power and flexibility of fine-grained control with the scalability to support thousands of systems.
Demo refers to our complimentary service level. Any user may receive one Demo account with Red Hat Network to receive notifications and system updates. Demo users are asked to take a short survey every 60 days in order to provide Red Hat with valued customer input and to validate that the account is still active. Please note that there can be only one demo account per email address.
Note: A Demo account does not provide guaranteed access to errata or bandwidth allocation during peak times, as these resources are reserved for paying subscribers. For this reason, Red Hat strongly recommends purchasing at least an Update service level if you are using your Linux system for home or business production use.
For more information, please follow this link:
http://www.redhat.com/software/rhn/offerings'
, 0,  TO_Date( '02/18/2003 10:53:18 PM', 'MM/DD/YYYY HH:MI:SS AM'),  TO_Date( '04/21/2003 12:08:01 PM', 'MM/DD/YYYY HH:MI:SS AM')
, 48, 4); 
INSERT INTO RHNFAQ ( ID, SUBJECT, DETAILS, PRIVATE, CREATED, MODIFIED, USAGE_COUNT,
CLASS_ID ) VALUES ( 
190, 'pvt:How can i delete my account in RHN?', 'Sorry,you can not delete your account in RHN now. But your account will be disabled if you do not accept the survey per 60 days.'
, 1,  TO_Date( '02/19/2003 04:22:18 AM', 'MM/DD/YYYY HH:MI:SS AM'),  TO_Date( '03/31/2003 09:26:10 AM', 'MM/DD/YYYY HH:MI:SS AM')
, 25, 1); 
COMMIT;

select '../rhn/tables/rhnFileDownload.sql' sql_file from dual;
-- SQL relevant contents from file ../rhn/tables/rhnFileDownload.sql
create table
rhnFileDownload
(
	file_id			number
				constraint rhn_filedl_fid_nn not null
				constraint rhn_filedl_fid_fk
					references rhnFile(id),
	location		varchar2(2000)
				constraint rhn_filedl_location_nn not null,
	token			varchar2(48),
	requestor_ip		varchar2(15)
				constraint rhn_filedl_rip_nn not null,
	start_time		date default(sysdate)
				constraint rhn_filedl_start_nn not null,
	user_id			number
				constraint rhn_filedl_uid_fk
					references web_contact(id)
					on delete set null
)
	storage ( freelists 16 )
	initrans 32;
create index rhn_filedl_uid_fid_idx
	on rhnFileDownload ( user_id, file_id )
	tablespace [[4m_tbs]]
	storage ( freelists 16 )
	initrans 32;
create index rhn_filedl_token_idx
	on rhnFileDownload ( token )
	tablespace [[8m_tbs]]
	storage ( freelists 16 )
	initrans 32;
create index rhn_filedl_start_idx
        on rhnFileDownload ( start_time )
        tablespace [[8m_tbs]]
        storage ( freelists 16 )
        initrans 32;

select '../rhn/tables/rhnFileLocation.sql' sql_file from dual;
-- SQL relevant contents from file ../rhn/tables/rhnFileLocation.sql
create table
rhnFileLocation
(
	file_id 	number
			constraint rhn_fileloc_fid_nn not null
			constraint rhn_fileloc_fid_fk
			     	references rhnFile(id),
        location        varchar2(128)
	    	    	constraint rhn_fileloc_loc_nn not null
)
	storage ( freelists 16 )
	initrans 32;
create unique index rhn_fileloc_file_loc_uq
	on rhnFileLocation(file_id, location)
	tablespace [[2m_tbs]]
	storage ( freelists 16 )
	initrans 32;

select '../rhn/tables/rhnGrailComponentChoices.sql' sql_file from dual;
-- SQL relevant contents from file ../rhn/tables/rhnGrailComponentChoices.sql
create table
rhnGrailComponentChoices
(
        user_id         number
                        constraint rhn_grail_comp_ch_nn not null
                        constraint rhn_grail_comp_ch_user_fk
                                   references web_contact(id)
				   on delete cascade,
        ordering        number
                        constraint rhn_grail_comp_ch_order_nn not null,
        component_pkg   varchar2(64)
                        constraint rhn_grail_comp_ch_pkg_nn not null,
        component_mode  varchar2(64)
                        constraint rhn_grail_comp_ch_mode_nn not null
)
	storage ( freelists 16 )
	initrans 32;
create unique index rhn_grail_comp_ch_user_ord_uq
	on rhnGrailComponentChoices(user_id,ordering)
	tablespace [[64k_tbs]]
	storage ( freelists 16 )
	initrans 32;
create index rhn_grail_cmp_ch_user
	on rhnGrailComponentChoices(user_id)
	tablespace [[64k_tbs]]
	storage ( freelists 16 )
	initrans 32
	nologging;

select '../rhn/tables/rhnUserGroupType.sql' sql_file from dual;
-- SQL relevant contents from file ../rhn/tables/rhnUserGroupType.sql
create table
rhnUserGroupType
(
	id		number
			constraint rhn_userGroupType_id_nn not null
			constraint rhn_userGroupType_id_pk primary key
				using index tablespace [[64k_tbs]],
	label		varchar2(64)
			constraint rhn_userGroupType_label_nn not null,
	name		varchar2(64)
			constraint rhn_userGroupType_name_nn not null,
	created		date default(sysdate)
			constraint rhn_userGroupType_created_nn not null,
	modified	date default(sysdate)
			constraint rhn_userGroupType_modified_nn not null
)
	storage ( freelists 16 )
	initrans 32;
create sequence rhn_usergroup_type_seq;
create index rhn_usergrouptype_label_id_idx
	on rhnUserGroupType ( label, id )
	tablespace [[64k_tbs]]
	storage ( freelists 16 )
	initrans 32;
alter table rhnUserGroupType add
	constraint rhn_usergrouptype_label_uq unique ( label );
insert into rhnUserGroupType (id, label, name) values (
	rhn_usergroup_type_seq.nextval,
	'org_admin',
	'Organization Administrator'
);

select '../rhn/tables/rhnGrailComponents.sql' sql_file from dual;
-- SQL relevant contents from file ../rhn/tables/rhnGrailComponents.sql
create table
rhnGrailComponents
(
        id              number
                        constraint rhn_grail_comp_pk primary key
                                using index tablespace [[64k_tbs]],
        component_pkg   varchar2(64)
                        constraint rhn_grail_comp_pkg_nn not null,
        component_mode  varchar2(64)
                        constraint rhn_grail_comp_mode_nn not null,
        config_mode     varchar2(64),
        component_label varchar2(128),
        role_required   number
                        constraint rhn_grail_comp_role_type_fk
                                references rhnUserGroupType(id)
)
	storage ( freelists 16 )
	initrans 32;
create sequence rhn_grail_components_seq;
create unique index rhn_grail_comp_pkg_mode_uq
	on rhnGrailComponents(component_pkg, component_mode)
	tablespace [[64k_tbs]]
	storage ( freelists 16 )
	initrans 32;
create unique index rhn_grail_comp_label_uq
	on rhnGrailComponents(component_label)
	tablespace [[64k_tbs]]
	storage ( freelists 16 )
	initrans 32;

select '../rhn/tables/rhnKickstartCommand.sql' sql_file from dual;
-- SQL relevant contents from file ../rhn/tables/rhnKickstartCommand.sql
create table
rhnKickstartCommand
(
	kickstart_id		number
				constraint rhn_kscommand_ksid_nn not null
				constraint rhn_kscommand_ksid_fk
					references rhnKSData(id)
					on delete cascade,
	ks_command_name_id	number
				constraint rhn_kscommand_kcnid_nn not null
				constraint rhn_kscommand_kcnid_fk
					references rhnKickstartCommandName(id),
    	arguments               varchar2(256),
	created			date default(sysdate)
				constraint rhn_kscommand_created_nn not null,
	modified		date default(sysdate)
				constraint rhn_kscommand_modified_nn not null
)
	storage ( freelists 16 )
	initrans 32;
create index rhn_kscommand_ksid_idx
	on rhnKickstartCommand( kickstart_id )
	tablespace [[4m_tbs]]
	storage ( freelists 16 )
	initrans 32;
create or replace trigger
rhn_kscommand_mod_trig
before insert or update on rhnKickstartCommand
for each row
begin
	:new.modified := sysdate;
end;
/
show errors

select '../rhn/tables/rhnKickstartDefaults.sql' sql_file from dual;
-- SQL relevant contents from file ../rhn/tables/rhnKickstartDefaults.sql
create table
rhnKickstartDefaults
(
        kickstart_id            number
                                constraint rhn_ksd_ksid_nn not null
                                constraint rhn_ksd_ksid_uq unique
                                constraint rhn_ksd_ksid_fk
                                        references rhnKSData(id)
                                        on delete cascade,
        kstree_id               number
                                constraint rhn_ksd_kstid_nn not null
                                constraint rhn_ksd_kstid_fk
                                        references rhnKickstartableTree(id)
                                        on delete cascade,
        regtoken_id             number
                                constraint rhn_ksd_rtid_fk
                                        references rhnRegToken(id)
                                        on delete set null,
        server_profile_id       number
                                constraint rhn_ksd_spid_fk
                                        references rhnServerProfile(id)
                                        on delete set null,
        cfg_management_flag     char(1) default ('Y')
                                constraint rhn_ksd_cmf_nn not null
                                constraint rhn_ksd_cmf_ck
                                        check (cfg_management_flag in ('Y','N')),
        created                 date default(sysdate)
                                constraint rhn_ksd_created_nn not null,
        modified                date default(sysdate)
                                constraint rhn_ksd_modified_nn not null
)
        storage ( freelists 16 )
        initrans 32;
create index rhn_ksd_kstid_idx
        on rhnKickstartDefaults( kstree_id )
        tablespace [[8m_tbs]]
        storage ( freelists 16 )
        initrans 32;
create or replace trigger
rhn_ksd_mod_trig
before insert or update on rhnKickstartDefaults
for each row
begin
        :new.modified := sysdate;
end;
/
show errors

select '../rhn/tables/rhnKickstartIPRange.sql' sql_file from dual;
-- SQL relevant contents from file ../rhn/tables/rhnKickstartIPRange.sql
create table
rhnKickstartIPRange
(
        kickstart_id            number
                                constraint rhn_ksip_ksid_nn not null
                                constraint rhn_ksip_ksid_fk
                                        references rhnKSData(id)
                                        on delete cascade,
        org_id                  number
                                constraint rhn_ksip_oid_nn not null
                                constraint rhn_ksip_oid_fk
                                        references  web_customer(id)
                                        on delete cascade,
        min                     number
                                constraint rhn_ksip_min_nn not null,
        max                     number
                                constraint rhn_ksip_max_nn not null,
        created                 date default(sysdate)
                                constraint rhn_ksip_created_nn not null,
        modified                date default(sysdate)
                                constraint rhn_ksip_modified_nn not null
)
        storage ( freelists 16 )
        initrans 32;
create index rhn_ksip_kickstart_id_idx
        on rhnKickstartIPRange( kickstart_id )
        tablespace [[4m_tbs]]
        storage ( freelists 16 )
        initrans 32;
create index rhn_ksip_org_id_idx
        on rhnKickstartIPRange( org_id )
        tablespace [[4m_tbs]]
        storage ( freelists 16 )
        initrans 32;
alter table rhnKickstartIPRange add constraint rhn_ksip_oid_min_max_uq
       	unique ( org_id, min, max );
create or replace trigger
rhn_ksip_mod_trig
before insert or update on rhnKickstartIPRange
for each row
begin
        :new.modified := sysdate;
end;
/
show errors

select '../rhn/tables/rhnKickstartPackage.sql' sql_file from dual;
-- SQL relevant contents from file ../rhn/tables/rhnKickstartPackage.sql
create table
rhnKickstartPackage
(
	kickstart_id		number
				constraint rhn_kspackage_ksid_nn not null
				constraint rhn_kspackage_ksid_fk
					references rhnKSData(id)
					on delete cascade,
	package_name_id		number
				constraint rhn_kspackage_pnid_nn not null
				constraint rhn_kspackage_pnid_fk
					references rhnPackageName(id),
	created			date default(sysdate)
				constraint rhn_kspackage_created_nn not null,
	modified		date default(sysdate)
				constraint rhn_kspackage_modified_nn not null
)
	storage ( freelists 16 )
	initrans 32;
create index rhn_kspackage_id_idx
	on rhnKickstartPackage( kickstart_id )
	tablespace [[4m_tbs]]
	storage ( freelists 16 )
	initrans 32;
create or replace trigger
rhn_kspackage_mod_trig
before insert or update on rhnKickstartPackage
for each row
begin
	:new.modified := sysdate;
end;
/
show errors

select '../rhn/tables/rhnKickstartSessionHistory.sql' sql_file from dual;
-- SQL relevant contents from file ../rhn/tables/rhnKickstartSessionHistory.sql
create sequence rhn_ks_sessionhist_id_seq;
create table
rhnKickstartSessionHistory
(
	id			number
				constraint rhn_ks_sessionhist_id_nn not null
				constraint rhn_ks_sessionhist_id_pk primary key
					using index tablespace [[8m_tbs]],
	kickstart_session_id	number
				constraint rhn_ks_sessionhist_ksid_nn not null
				constraint rhn_ks_sessionhist_ksid_fk
					references rhnKickstartSession(id)
					on delete cascade,
        action_id               number
				constraint rhn_ks_sessionhist_aid_fk
					references rhnAction(id)
					on delete set null,
	state_id		number
				constraint rhn_ks_sessionhist_stat_nn not null
				constraint rhn_ks_sessionhist_stat_fk
					references rhnKickstartSessionState(id),
	time			date default(sysdate)
				constraint rhn_ks_sessionhist_time_nn not null,
	message			varchar2(4000),
	created			date default(sysdate)
				constraint rhn_ks_sessionhist_creat_nn not null,
	modified		date default(sysdate)
				constraint rhn_ks_sessionhist_mod_nn not null
)
	storage ( freelists 16 )
	initrans 32;
create index rhn_ks_sessionhist_ksid_idx
	on rhnKickstartSessionHistory( kickstart_session_id )
	tablespace [[8m_tbs]]
	storage ( freelists 16 )
	initrans 32;
create or replace trigger
rhn_ks_sessionhist_mod_trig
before insert or update on rhnKickstartSessionHistory
for each row
begin
	:new.modified := sysdate;
end;
/
show errors

select '../rhn/tables/rhnKickstartSessionState_data.sql' sql_file from dual;
-- SQL relevant contents from file ../rhn/tables/rhnKickstartSessionState_data.sql
insert
  into rhnKickstartSessionState
       (id, name, label, description)
values (rhn_ks_session_state_id_seq.nextval, 'Created', 'created',
        'Kickstart session created, but has not yet been used.'
       );
insert
  into rhnKickstartSessionState
       (id, name, label, description)
values (rhn_ks_session_state_id_seq.nextval, 'Deployed', 'deployed',
        'Files required for kickstart action have been installed.'
       );
insert
  into rhnKickstartSessionState
       (id, name, label, description)
values (rhn_ks_session_state_id_seq.nextval, 'Injected', 'injected',
        'The system configuration has been modified to begin kickstart upon next boot.'
       );
insert
  into rhnKickstartSessionState
       (id, name, label, description)
values (rhn_ks_session_state_id_seq.nextval, 'Restarted', 'restarted',
        'The system has been restarted in order to begin the kickstart process.'
       );
insert
  into rhnKickstartSessionState
       (id, name, label, description)
values (rhn_ks_session_state_id_seq.nextval, 'Configuration accessed', 'configuration_accessed',
        'The system has downloaded the kickstart configuraton file from RHN.'
       );
insert
  into rhnKickstartSessionState
       (id, name, label, description)
values (rhn_ks_session_state_id_seq.nextval, 'Started', 'started',
        'The initial files required for anaconda have been downloaded.'
       );
insert
  into rhnKickstartSessionState
       (id, name, label, description)
values (rhn_ks_session_state_id_seq.nextval, 'In Progress', 'in_progress',
        'The system is downloading the RPMs required to install.'
       );
insert
  into rhnKickstartSessionState
       (id, name, label, description)
values (rhn_ks_session_state_id_seq.nextval, 'Registration Complete', 'registered',
        'The system has successfully registered with RHN after kickstarting.'
       );
insert
  into rhnKickstartSessionState
       (id, name, label, description)
values (rhn_ks_session_state_id_seq.nextval, 'Package Synch', 'package_synch',
        'Package synchronization in progress.'
       );
insert
  into rhnKickstartSessionState
       (id, name, label, description)
values (rhn_ks_session_state_id_seq.nextval, 'Package Synch Scheduled', 
        'package_synch_scheduled', 'Package synchronization scheduled.'
       );
insert
  into rhnKickstartSessionState
       (id, name, label, description)
values (rhn_ks_session_state_id_seq.nextval, 'Complete', 'complete',
        'Kickstart complete.'
       );
insert
  into rhnKickstartSessionState
       (id, name, label, description)
values (rhn_ks_session_state_id_seq.nextval, 'Failed', 'failed',
        'Kickstart failed.'
       );

select '../rhn/tables/rhnKickstartSession_triggers.sql' sql_file from dual;
-- SQL relevant contents from file ../rhn/tables/rhnKickstartSession_triggers.sql
create or replace trigger
rhn_ks_session_mod_trig
before insert or update on rhnKickstartSession
for each row
begin
	:new.modified := sysdate;
end;
/
show errors
create or replace trigger
rhn_ks_session_history_trigger
after insert or update on rhnKickstartSession
for each row
begin
	if inserting or (updating and :new.state_id != :old.state_id) then
		insert into rhnKickstartSessionHistory (
				id, kickstart_session_id, action_id, state_id
			) values (
				rhn_ks_sessionhist_id_seq.nextval,
				:new.id,
				:new.action_id,
				:new.state_id
			);
	end if;
end;
/
show errors

select '../rhn/tables/rhnKSInstallType_data.sql' sql_file from dual;
-- SQL relevant contents from file ../rhn/tables/rhnKSInstallType_data.sql
insert into rhnKSInstallType (id, label, name)
        values (rhn_ksinstalltype_id_seq.nextval,
                'rhel_3','Red Hat Enterprise Linux 3'
        );
insert into rhnKSInstallType (id, label, name)
        values (rhn_ksinstalltype_id_seq.nextval,
                'rhel_2.1','Red Hat Enterprise Linux 2.1'
        );
commit;

select '../rhn/tables/rhnKSTreeFile.sql' sql_file from dual;
-- SQL relevant contents from file ../rhn/tables/rhnKSTreeFile.sql
create table
rhnKSTreeFile
(
	kstree_id		number
				constraint rhn_kstreefile_kid_nn not null
				constraint rhn_kstreefile_kid_fk
					references rhnKickstartableTree(id)
					on delete cascade,
	relative_filename	varchar2(256)
				constraint rhn_kstreefile_rfn_nn not null,
	md5sum			varchar2(64)
				constraint rhn_kstreefile_md5sum_nn not null,
	file_size		number
				constraint rhn_kstreefile_file_size_nn not null,
	last_modified		date default(sysdate)
				constraint rhn_kstreefile_lastmod_nn not null,
	created			date default(sysdate)
				constraint rhn_kstreefile_created_nn not null,
	modified		date default(sysdate)
				constraint rhn_kstreefile_modified_nn not null
)
	storage ( freelists 16 )
	initrans 32;
create unique index rhn_kstreefile_kid_rfn_uq
	on rhnKSTreeFile ( kstree_id, relative_filename )
	tablespace [[8m_tbs]]
	storage ( freelists 16 )
	initrans 32;
create or replace trigger
rhn_kstreefile_mod_trig
before insert or update on rhnKSTreeFile
for each row
begin
	:new.modified := sysdate;
end;
/
show errors

select '../rhn/tables/rhnKSTreeType_data.sql' sql_file from dual;
-- SQL relevant contents from file ../rhn/tables/rhnKSTreeType_data.sql
insert into rhnKSTreeType (id, label, name)
        values (rhn_kstree_type_seq.nextval,
                'rhn-managed','RHN managed kickstart tree'
        );
insert into rhnKSTreeType (id, label, name)
        values (rhn_kstree_type_seq.nextval,
                'externally-managed','Externally managed kickstart tree'
        );
commit;

select '../rhn/tables/rhnMessagePriority.sql' sql_file from dual;
-- SQL relevant contents from file ../rhn/tables/rhnMessagePriority.sql
create table
rhnMessagePriority
(
	id		number
			constraint rhn_m_priority_id_nn not null
			constraint rhn_m_priority_id_pk primary key
				using index tablespace [[64k_tbs]],
	label		varchar2(48)
			constraint rhn_m_priority_label_nn not null
)
	storage ( freelists 16 )
	initrans 32;
create sequence rhn_m_priority_id_seq;
create unique index rhn_m_priority_label_uq
	on rhnMessagePriority(label)
	tablespace [[64k_tbs]]
	storage ( freelists 16 )
	initrans 32;
create index rhn_m_priority_label_id_idx
	on rhnMessagePriority(label,id)
	tablespace [[64k_tbs]]
	storage ( freelists 16 )
	initrans 32;

select '../rhn/tables/rhnMessagePriority_data.sql' sql_file from dual;
-- SQL relevant contents from file ../rhn/tables/rhnMessagePriority_data.sql
insert into rhnMessagePriority values (
	rhn_m_priority_id_seq.nextval, 'warning'
);
insert into rhnMessagePriority values (
	rhn_m_priority_id_seq.nextval, 'error'
);

select '../rhn/tables/rhnMessageType.sql' sql_file from dual;
-- SQL relevant contents from file ../rhn/tables/rhnMessageType.sql
create table
rhnMessageType
(
	id		number
			constraint rhn_m_type_id_nn not null
			constraint rhn_m_type_id_pk primary key
				using index tablespace [[64k_tbs]],
	label		varchar2(48)
			constraint rhn_m_type_label_nn not null,
	name		varchar2(96)
			constraint rhn_m_type_name_nn not null
)
	storage ( freelists 16 )
	initrans 32;
create sequence rhn_mt_id_seq;
create unique index rhn_m_type_label_uq
	on rhnMessageType(label)
	tablespace [[64k_tbs]]
	storage ( freelists 16 )
	initrans 32;
create unique index rhn_m_type_name_uq
	on rhnMessageType(name)
	tablespace [[64k_tbs]]
	storage ( freelists 16 )
	initrans 32;
create index rhn_m_type_label_id_idx
	on rhnMessageType(label,id)
	tablespace [[64k_tbs]]
	storage ( freelists 16 )
	initrans 32;

select '../rhn/tables/rhnMessage.sql' sql_file from dual;
-- SQL relevant contents from file ../rhn/tables/rhnMessage.sql
create table
rhnMessage
(
	id		number
			constraint rhn_m_id_nn not null
			constraint rhn_m_id_pk primary key
				using index tablespace [[64k_tbs]],
	message_type	number
			constraint rhn_m_mt_nn not null
			constraint rhn_m_mt_fk
				references rhnMessageType(id),
	priority	number default 0
			constraint rhn_m_priority_nn not null
			constraint rhn_m_priority_fk
				references rhnMessagePriority(id),
	created		date default (sysdate)
			constraint rhn_m_created_nn not null,
	modified	date default (sysdate)
			constraint rhn_m_modified_nn not null
)
	storage ( freelists 16 )
	initrans 32;
create sequence rhn_m_id_seq;
create or replace trigger
rhn_m_mod_trig
before insert or update on rhnMessage
for each row
begin
	:new.modified := sysdate;
end;
/
show errors

select '../rhn/tables/rhnMessageType_data.sql' sql_file from dual;
-- SQL relevant contents from file ../rhn/tables/rhnMessageType_data.sql
insert into rhnMessageType (id, label, name) values (
    rhn_mt_id_seq.nextval, 'server', 'System Message'
);

select '../rhn/tables/rhnMonitorGranularity.sql' sql_file from dual;
-- SQL relevant contents from file ../rhn/tables/rhnMonitorGranularity.sql
create table
rhnMonitorGranularity
(
	id		number
			constraint rhn_monitorgran_id_nn not null
			constraint rhn_monitorgran_id_pk primary key
				using index tablespace [[4m_tbs]],
	label		varchar2(16)
			constraint rhn_monitorgran_label_nn not null
)
	storage ( freelists 16 )
	initrans 32;
create sequence rhn_monitorgranularity_id_seq;
create unique index rhn_monitorgran_label_uq
	on rhnMonitorGranularity(label)
	tablespace [[64k_tbs]]
	storage ( freelists 16 )
	initrans 32;
create index rhn_monitorgran_label_id_idx
	on rhnMonitorGranularity(label,id)
	tablespace [[64k_tbs]]
	storage ( freelists 16 )
	initrans 32;

select '../rhn/tables/rhnMonitorGranularity_data.sql' sql_file from dual;
-- SQL relevant contents from file ../rhn/tables/rhnMonitorGranularity_data.sql
insert into rhnMonitorGranularity values (
	rhn_monitorgranularity_id_seq.nextval, 'daily'
);
commit;

select '../rhn/tables/rhnMonitor.sql' sql_file from dual;
-- SQL relevant contents from file ../rhn/tables/rhnMonitor.sql
create table
rhnMonitor
(
    batch_id    number
    	    	constraint rhn_monitor_bid_nn not null,
    server_id	number
    	    	constraint rhn_monitor_sid_nn not null
		constraint rhn_monitor_sid_fk
			references rhnServer(id)
			on delete cascade,
    probe_id	number
    	    	constraint rhn_monitor_probe_nn not null,
    component	varchar2(128),
    field	varchar2(128),
    timestamp	date
    	    	constraint rhn_monitor_ts_nn not null,
    granularity	number
    		constraint rhn_monitor_granularity_nn not null
		constraint rhn_monitor_granularity_fk
			references rhnMonitorGranularity(id),
    value       varchar2(4000)
)
	storage ( freelists 16 )
	initrans 32;
create sequence rhn_monitor_bid_seq;
create index rhn_monitor_bid_idx
    	on rhnMonitor(batch_id)
	tablespace [[8m_tbs]]
	storage ( freelists 16 )
	initrans 32;
create unique index rhn_monitor_idx
    	on rhnMonitor(server_id, probe_id, granularity, timestamp, component, field)
	tablespace [[8m_tbs]]
	storage ( freelists 16 )
	initrans 32;

select '../rhn/tables/rhnOrgAvailableStates.sql' sql_file from dual;
-- SQL relevant contents from file ../rhn/tables/rhnOrgAvailableStates.sql
create table
rhnOrgAvailableStates
(
	id			number
				constraint rhn_oastates_id_nn not null,
	label			varchar2(32)
				constraint rhn_oastates_label_nn not null,
	created			date default(sysdate)
				constraint rhn_oastates_created_nn not null,
	modified		date default(sysdate)
				constraint rhn_oastates_modified_nn not null
)
	storage ( freelists 16 )
	initrans 32;
create sequence rhn_oastates_id_seq;
create index rhn_oastates_id_label_idx
	on rhnOrgAvailableStates(id, label)
	tablespace [[2m_tbs]]
	storage ( freelists 16 )
	initrans 32;
alter table rhnOrgAvailableStates add
	constraint rhn_oastatis_id_pk primary key ( id );
create index rhn_oastates_label_id_idx
	on rhnOrgAvailableStates(label, id)
	tablespace [[2m_tbs]]
	storage ( freelists 16 )
	initrans 32;
alter table rhnOrgAvailableStates add
	constraint rhn_oastates_label_uq unique ( label );
create or replace trigger
rhn_oastates_mod_trig
before insert or update on rhnOrgAvailableStates
for each row
begin
	:new.modified := sysdate;
end;
/
show errors

select '../rhn/tables/rhnOrgAvailableStates_data.sql' sql_file from dual;
-- SQL relevant contents from file ../rhn/tables/rhnOrgAvailableStates_data.sql
insert into rhnOrgAvailableStates (ID, LABEL)
     values (rhn_oastates_id_seq.nextval, 'legacy_unclassified');
insert into rhnOrgAvailableStates (ID, LABEL)
     values (rhn_oastates_id_seq.nextval, 'legacy_web');
insert into rhnOrgAvailableStates (ID, LABEL)
     values (rhn_oastates_id_seq.nextval, 'legacy_rhn');
insert into rhnOrgAvailableStates (ID, LABEL)
     values (rhn_oastates_id_seq.nextval, 'paid');
insert into rhnOrgAvailableStates (ID, LABEL)
     values (rhn_oastates_id_seq.nextval, 'grace');
insert into rhnOrgAvailableStates (ID, LABEL)
     values (rhn_oastates_id_seq.nextval, 'freeloader');
insert into rhnOrgAvailableStates (ID, LABEL)
     values (rhn_oastates_id_seq.nextval, 'freeloader_warned');
insert into rhnOrgAvailableStates (ID, LABEL)
     values (rhn_oastates_id_seq.nextval, 'freeloader_survey_sent');
insert into rhnOrgAvailableStates (ID, LABEL)
     values (rhn_oastates_id_seq.nextval, 'disabled_freeloader');
insert into rhnOrgAvailableStates (ID, LABEL)
     values (rhn_oastates_id_seq.nextval, 'disabled_email');
insert into rhnOrgAvailableStates (ID, LABEL)
     values (rhn_oastates_id_seq.nextval, 'falling_from_grace');
commit;

select '../rhn/tables/rhnOrgChannelSettingsType.sql' sql_file from dual;
-- SQL relevant contents from file ../rhn/tables/rhnOrgChannelSettingsType.sql
create sequence rhn_ocstngs_type_id_seq;
create table
rhnOrgChannelSettingsType
(
	id		number
			constraint rhn_ocstngs_type_id_nn not null
			constraint rhn_ocstngs_type_id_pk primary key,
	label		varchar2(32)
			constraint rhn_ocstngs_type_label_nn not null,
	created		date default(sysdate)
			constraint rhn_ocstngs_type_created_nn not null,
	modified	date default(sysdate)
			constraint rhn_ocstngs_type_modified_nn not null
)
	storage ( freelists 16 )
	initrans 32;
create index rhn_ocstngs_type_l_id_idx
	on rhnOrgChannelSettingsType( label, id )
	tablespace [[64k_tbs]]
	storage ( freelists 16 )
	initrans 32;
create or replace trigger
rhn_orgcsettings_type_mod_trig
before insert or update on rhnOrgChannelSettingsType
for each row
begin
	:new.modified := sysdate;
end;
/
show errors

select '../rhn/tables/rhnOrgChannelSettings.sql' sql_file from dual;
-- SQL relevant contents from file ../rhn/tables/rhnOrgChannelSettings.sql
create table
rhnOrgChannelSettings
(
	org_id		number
			constraint rhn_orgcsettings_oid_nn not null
			constraint rhn_orgcsettings_oid_fk
				references web_customer(id)
				on delete cascade,
	channel_id	number
			constraint rhn_orgcsettings_cid_nn not null
			constraint rhn_orgcsettings_cid_fk
				references rhnChannel(id)
				on delete cascade,
	setting_id	number
			constraint rhn_orgcsettings_sid_nn not null
			constraint rhn_orgcsettings_sid_fk
				references rhnOrgChannelSettingsType(id),
	created		date default(sysdate)
			constraint rhn_orgcsettings_created_nn not null,
	modified	date default(sysdate)
			constraint rhn_orgcsettings_modified_nn not null
)
	storage ( freelists 16 )
	initrans 32;
create unique index rhn_orgcsettings_oid_cid_uq
	on rhnOrgChannelSettings(org_id, channel_id, setting_id)
	tablespace [[8m_tbs]]
	storage ( freelists 16 )
	initrans 32;
create or replace trigger
rhn_orgcsettings_mod_trig
before insert or update on rhnOrgChannelSettings
for each row
begin
	:new.modified := sysdate;	
end;
/
show errors

select '../rhn/tables/rhnOrgChannelSettingsType_data.sql' sql_file from dual;
-- SQL relevant contents from file ../rhn/tables/rhnOrgChannelSettingsType_data.sql
insert into rhnOrgChannelSettingsType ( id, label )
	values ( rhn_ocstngs_type_id_seq.nextval, 'not_globally_subscribable' );
commit;

select '../rhn/tables/rhnOrgEntitlementType.sql' sql_file from dual;
-- SQL relevant contents from file ../rhn/tables/rhnOrgEntitlementType.sql
create table
rhnOrgEntitlementType
(
        id              number
			constraint rhn_org_ent_type_id_nn not null
                        constraint rhn_org_ent_type_id_pk primary key
                                using index tablespace [[64k_tbs]],
        label           varchar2(32)
                        constraint rhn_org_ent_type_label_nn not null,
        name            varchar2(64)
                        constraint rhn_org_ent_type_name_nn not null,
        created         date default(sysdate)
                        constraint rhn_org_ent_type_created_nn not null,
        modified        date default(sysdate)
                        constraint rhn_org_ent_type_mod_nn not null
)
	storage ( freelists 16 )
	initrans 32;
create sequence rhn_org_entitlement_type_seq;
create unique index rhn_org_entitle_type_label_uq 
	on rhnOrgEntitlementType(label)
	tablespace [[64k_tbs]]
	storage ( freelists 16 )
	initrans 32;
create or replace trigger
rhn_org_ent_type_mod_trig
before insert or update on rhnOrgEntitlementType
for each row
begin
        :new.modified := sysdate;
end;
/
show errors

select '../rhn/tables/rhnOrgEntitlements.sql' sql_file from dual;
-- SQL relevant contents from file ../rhn/tables/rhnOrgEntitlements.sql
create table
rhnOrgEntitlements
(
        org_id          number
                        constraint rhn_org_ent_nn not null
                        constraint rhn_org_ent_fk
                                references web_customer(id)
				on delete cascade,
        entitlement_id  number
                        constraint rhn_org_ent_eid_nn not null
                        constraint rhn_org_ent_eid_fk
                                references rhnOrgEntitlementType(id),
        created         date default(sysdate)
                        constraint rhn_org_ent_cre_nn not null,
        modified        date default(sysdate)
                        constraint rhn_org_ent_mod_nn not null
)
	storage ( freelists 16 )
	initrans 32;
create unique index rhn_org_ent_org_eid_uq
	on rhnOrgEntitlements(org_id, entitlement_id)
	tablespace [[2m_tbs]]
	storage ( freelists 16 )
	initrans 32;
create or replace trigger
rhn_org_ent_mod_trig
before insert or update on rhnOrgEntitlements
for each row
begin
        :new.modified := sysdate;
end;
/
show errors

select '../rhn/tables/rhnOrgEntitlementType_data.sql' sql_file from dual;
-- SQL relevant contents from file ../rhn/tables/rhnOrgEntitlementType_data.sql
insert into rhnOrgEntitlementType (id, label, name)
        values (rhn_org_entitlement_type_seq.nextval,
                'sw_mgr_enterprise','Software Manager Enterprise'
        );
insert into rhnOrgEntitlementType (id, label, name)
        values (rhn_org_entitlement_type_seq.nextval,
                'rhn_monitor','Red Hat Network Monitoring'
        );
insert into rhnOrgEntitlementType (id, label, name)
        values (rhn_org_entitlement_type_seq.nextval,
                'rhn_provisioning','Red Hat Network Provisioning'
        );
commit;

select '../rhn/tables/rhnOrgErrataCacheQueue.sql' sql_file from dual;
-- SQL relevant contents from file ../rhn/tables/rhnOrgErrataCacheQueue.sql
create table rhnOrgErrataCacheQueue
(
        org_id          number
                        constraint rhn_oecq_oid_nn not null
                        constraint rhn_oecq_oid_fk
                                references web_customer(id)
				on delete cascade,
        server_count    number constraint rhn_oecq_sc_nn not null,
        processed       number default(0)
                        constraint rhn_oecq_oid_processed_nn not null
)
	storage ( freelists 16 )
	initrans 32;
create unique index rhn_oecq_oid_uq
        on rhnOrgErrataCacheQueue(org_id)
        tablespace [[4m_tbs]]
	storage ( freelists 16 )
	initrans 32;
alter table rhnOrgErrataCacheQueue nologging;
alter index rhn_oecq_oid_uq nologging;

select '../rhn/tables/rhnOrgErrataCacheQueue_data.sql' sql_file from dual;
-- SQL relevant contents from file ../rhn/tables/rhnOrgErrataCacheQueue_data.sql
insert into rhnOrgErrataCacheQueue (org_id, processed)
	select distinct org_id, 0 from rhnserver;
commit;

select '../rhn/tables/rhnOrgInfo.sql' sql_file from dual;
-- SQL relevant contents from file ../rhn/tables/rhnOrgInfo.sql
create table
rhnOrgInfo
(
	org_id			number
				constraint rhn_orginfo_oid_nn not null
				constraint rhn_orginfo_oid_fk
					references web_customer(id),
	default_group_type	number default(2)
				constraint rhn_orginfo_dgt_nn not null
				constraint rhn_orginfo_dgt_fk
					references rhnServerGroupType(id),
	created			date default(sysdate)
				constraint rhn_orginfo_created_nn not null,
	modified		date default(sysdate)
				constraint rhn_orginfo_modified_nn not null
)
	storage ( freelists 16 )
	initrans 32;
create unique index rhn_orginfo_oid_uq
	on rhnOrgInfo(org_id)
	tablespace [[2m_tbs]]
	storage ( freelists 16 )
	initrans 32;
create or replace trigger
rhn_orginfo_mod_trig
before insert or update on rhnOrgInfo
for each row
begin
	:new.modified := sysdate;
end;
/
show errors

select '../rhn/tables/rhnOrgStateLog.sql' sql_file from dual;
-- SQL relevant contents from file ../rhn/tables/rhnOrgStateLog.sql
create table
rhnOrgStateLog
(
	org_id			number
				constraint rhn_ostatelog_oid_nn not null
				constraint rhn_ostatelog_oid_fk
					references web_customer(id)
					on delete cascade,
	old_state_id		number
				constraint rhn_ostatelog_osid_nn not null
				constraint rhn_ostatelog_osid_fk
					references rhnOrgAvailableStates(id),
	new_state_id		number
				constraint rhn_ostatelog_nsid_nn not null
				constraint rhn_ostatelog_nsid_fk
					references rhnOrgAvailableStates(id),
	reason			varchar2(4000),
	created			date default(sysdate)
				constraint rhn_ostatelog_created_nn not null
)
	tablespace [[8m_data_tbs]]
	storage ( freelists 16 )
	initrans 32;
create index rhn_ostatelog_oid_idx
	on rhnOrgStateLog(org_id)
	tablespace [[4m_tbs]]
	storage ( freelists 16 )
	initrans 32;
create index rhn_ostatelog_created_idx
	on rhnOrgStateLog(created)
	tablespace [[4m_tbs]]
	storage ( freelists 16 )
	initrans 32;

select '../rhn/tables/rhnOrgState.sql' sql_file from dual;
-- SQL relevant contents from file ../rhn/tables/rhnOrgState.sql
create table
rhnOrgState
(
	org_id			number
				constraint rhn_ostate_oid_nn not null
				constraint rhn_ostate_oid_fk
					references web_customer(id)
					on delete cascade,
	state_id		number
				constraint rhn_ostate_sid_nn not null
				constraint rhn_ostate_sid_fk
					references rhnOrgAvailableStates(id),
	next_action		date,
	created			date default(sysdate)
				constraint rhn_ostate_created_nn not null,
	modified		date default(sysdate)
				constraint rhn_ostate_modified_nn not null
)
	tablespace [[8m_data_tbs]]
	storage ( freelists 16 )
	initrans 32;
create index rhn_ostate_oid_sid_idx
	on rhnOrgState(org_id, state_id)
	tablespace [[8m_tbs]]
	storage ( freelists 16 )
	initrans 32;
alter table rhnOrgState add
	constraint rhn_ostate_oid_uq unique ( org_id );
create index rhn_ostate_na_oid_sid
	on rhnOrgState( next_action, org_id, state_id )
	tablespace [[8m_tbs]]
	storage ( freelists 16 )
	initrans 32;
create index rhn_ostate_sid_oid_idx
	on rhnOrgState( state_id, org_id )
	tablespace [[8m_tbs]]
	storage ( freelists 16 )
	initrans 32;

select '../rhn/tables/rhnOrgStateTransitions.sql' sql_file from dual;
-- SQL relevant contents from file ../rhn/tables/rhnOrgStateTransitions.sql
create table
rhnOrgStateTransitions
(
	from_state		number
				constraint rhn_ostransitions_from_nn not null
				constraint rhn_ostransitions_from_fk
					references rhnOrgAvailableStates(id),
	to_state		number
				constraint rhn_ostransitions_to_nn not null
				constraint rhn_ostransitions_to_fk
					references rhnOrgAvailableStates(id)
)
	storage ( freelists 16 )
	initrans 32;
create index rhn_ostransitions_fs_ts_idx
	on rhnOrgStateTransitions ( from_state, to_state )
	tablespace [[64k_tbs]]
	storage ( freelists 16 )
	initrans 32;
alter table rhnOrgStateTransitions add
	constraint rhn_ostransitions_fs_ts_uq unique ( from_state, to_state );

select '../rhn/tables/rhnOrgStateTransitions_data.sql' sql_file from dual;
-- SQL relevant contents from file ../rhn/tables/rhnOrgStateTransitions_data.sql
CREATE OR REPLACE PROCEDURE
add_org_state_transition(from_state_in IN varchar2, to_state_in IN varchar2)
IS
    from_state_id NUMBER;
    to_state_id NUMBER;
BEGIN
    SELECT id INTO from_state_id 
    FROM rhnOrgAvailableStates where label = from_state_in;
    SELECT id INTO to_state_id 
    FROM rhnOrgAvailableStates where label = to_state_in;
    INSERT INTO
    	rhnOrgStateTransitions (from_state, to_state)
    VALUES
        (from_state_id, to_state_id);
END;
/
SHOW ERRORS;
declare
  cursor state_cursor is
    select label from rhnOrgAvailableStates where label <> 'paid';
begin
  for state_req in state_cursor
  loop
    add_org_state_transition(state_req.label, 'paid');
  end loop;
  add_org_state_transition('legacy_unclassified', 'legacy_rhn');
  add_org_state_transition('legacy_unclassified', 'legacy_web');
  add_org_state_transition('legacy_unclassified', 'falling_from_grace');
  add_org_state_transition('legacy_rhn', 'freeloader');
  add_org_state_transition('legacy_rhn', 'disabled_email');
  add_org_state_transition('legacy_web', 'grace');
  add_org_state_transition('legacy_web', 'legacy_unclassified');
  add_org_state_transition('grace', 'freeloader');  
  add_org_state_transition('grace', 'disabled_email');
  add_org_state_transition('freeloader', 'freeloader_survey_sent');
  add_org_state_transition('freeloader_survey_sent', 'freeloader_warned');
  add_org_state_transition('freeloader_survey_sent', 'freeloader');
  add_org_state_transition('freeloader_warned', 'disabled_freeloader');
  add_org_state_transition('freeloader_warned', 'freeloader');
  add_org_state_transition('disabled_freeloader', 'freeloader');
  add_org_state_transition('disabled_email', 'freeloader');
  add_org_state_transition('paid', 'falling_from_grace');
  add_org_state_transition('falling_from_grace', 'freeloader');
  add_org_state_transition('falling_from_grace', 'disabled_email');
end;
/
commit;
drop procedure add_org_state_transition;

select '../rhn/views/rhnPaidOrgs.sql' sql_file from dual;
-- SQL relevant contents from file ../rhn/views/rhnPaidOrgs.sql
create or replace view
rhnPaidOrgs
as
select	org_id
from	rhnServerGroup
where	group_type = 3
	and NVL(max_members,1) > 0
union all
select	org_id
from	rhnServerGroup
where	group_type = 2
	and NVL(max_members,2) > 1
union all
select	sg.org_id
from	rhnServerGroupType sgt,
	rhnServerGroup sg
where	sgt.label = 'provisioning_entitled'
	and sgt.id = sg.group_type
	and NVL(sg.max_members,2) > 1;

select '../rhn/packages/rhn_bel.pkb' sql_file from dual;
-- SQL relevant contents from file ../rhn/packages/rhn_bel.pkb
create or replace
package body rhn_bel
is
	function find_state_of_org (
		org_id_in in number
	) return varchar2 is
		state_label rhnOrgAvailableStates.label%TYPE;
	begin
		select oas.label into state_label
		from    rhnOrgAvailableStates oas,
			rhnOrgState os
		where   os.org_id = org_id_in
			and os.state_id = oas.id;
		return state_label;
	end find_state_of_org;
	function is_state_legacy_unclassified (
		org_id_in in number
	) return number is
		cursor states is
			select	1
			from	rhnOrgAvailableStates oas,
					rhnOrgState os
			where	os.org_id = org_id_in
				and os.state_id = oas.id
					and oas.label = 'legacy_unclassified';
	begin
		for x in states loop return 1; end loop;
		return 0;
	end is_state_legacy_unclassified;
	function is_org_paid (
		org_id_in in number
	) return number is
		cursor paids is
			select	1
			from	rhnPaidOrgs
			where	org_id = org_id_in;
	begin
		for paid in paids loop return 1; end loop;
		return 0;
	end;
	function lookup_email_state (
		state_in in varchar2
	) return number is
		retval number;
	begin
		select id into retval from rhnEmailAddressState where label = state_in;
		return retval;
	exception
			when no_data_found then
				rhn_exception.raise_exception('invalid_state');
	end lookup_email_state;
	procedure check_org_state (
		state_id_in in number
	) is
		ignore number;
	begin
		select id into ignore from rhnOrgAvailableStates where id = state_id_in;
	exception
			when no_data_found then
				rhn_exception.raise_exception('invalid_state');
	end check_org_state;
	function lookup_org_state (
		state_in in varchar2
	) return number is
		retval number;
	begin
		select id into retval from rhnOrgAvailableStates where label = state_in;
		return retval;
	exception
			when no_data_found then
				rhn_exception.raise_exception('invalid_state');
	end lookup_org_state;
	procedure validate_org_state_change (
		from_state_in in number,
		to_state_in in number
	) is
		ignore	number;
	begin
		select	1
		into	ignore
		from	rhnOrgStateTransitions	rost
		where	1=1
			and rost.from_state = from_state_in
			and rost.to_state = to_state_in;
	exception
		when no_data_found then
			rhn_exception.raise_exception('invalid_state_transition');
	end;
	procedure join_rhn (
		org_id_in in number
	) is
		state_label	rhnOrgAvailableStates.label%TYPE;
	begin
	    	select OAS.label into state_label
		  from rhnOrgAvailableStates OAS,
		       rhnOrgState OS
		 where OS.state_id = OAS.id
		   and OS.org_id = org_id_in;
		if state_label = 'legacy_web'
		then
		    update rhnOrgState
		       set next_action = sysdate
		     where org_id = org_id_in;
    	    	    insert into rhnOrgStateLog
    	    	      (org_id, old_state_id, new_state_id, reason)
					  (
					  	select	org_id_in, os.state_id,
								rhn_bel.lookup_org_state('legacy_unclassified'),
								'rhn_bel.join_rhn package method'
						from	rhnOrgState os
						where	os.org_id = org_id_in
					);
		end if;
	end;
	procedure set_org_paid(
		org_id_in in number
	) is
	begin
    	insert into rhnOrgStateLog (
			org_id, old_state_id, new_state_id, reason
		) (
			select	org_id_in, os.state_id, rhn_bel.lookup_org_state('paid'),
					'rhn_bel.set_org_paid'
			from	rhnOrgState os
			where	os.org_id = org_id_in
		);
		update	rhnOrgState
		set		state_id =
				(select id from rhnOrgAvailableStates where label = 'paid'),
				next_action = NULL
		where	org_id = org_id_in;
    end set_org_paid;
	procedure set_org_unpaid (
		org_id_in in number
	) is
		cursor	org_state is
			select	state_id old_state_id,
					rhn_bel.lookup_org_state('falling_from_grace') new_state_id
			from rhnOrgState where org_id = org_id_in;
	begin
		for os in org_state loop
			insert into rhnOrgStateLog (
					org_id, old_state_id, new_state_id, reason
				) values (
					org_id_in, os.old_state_id, os.new_state_id,
					'rhn_bel.set_org_unpaid'
				);
			update	rhnOrgState
			set		state_id = os.new_state_id,
					next_action = sysdate
			where	org_id = org_id_in;
		end loop;
	end set_org_unpaid;
end;
/
show errors

select '../rhn/tables/rhnOrgState_triggers.sql' sql_file from dual;
-- SQL relevant contents from file ../rhn/tables/rhnOrgState_triggers.sql
create or replace trigger
rhn_ostate_mod_trig
before insert or update on rhnOrgState
for each row
begin
        :new.modified := sysdate;
	if :old.state_id <> :new.state_id then
		rhn_bel.validate_org_state_change(:old.state_id, :new.state_id);
	end if;
end;
/
show errors

select '../rhn/tables/rhnPackageChangeLog.sql' sql_file from dual;
-- SQL relevant contents from file ../rhn/tables/rhnPackageChangeLog.sql
create table
rhnPackageChangelog
(
        package_id      number
                        constraint rhn_pkg_changelog_pid_nn not null
                        constraint rhn_pkg_changelog_pid_fk
				references rhnPackage(id),
        name            varchar2(128)
			constraint rhn_pkg_changelog_name not null,
        text            varchar2(3000)
			constraint rhn_pkg_changelog_text not null,
        time            date
			constraint rhn_pkg_changelog_time not null,
        created         date default(sysdate)
			constraint rhn_pkg_changelog_created_nn not null,
        modified        date default(sysdate)
			constraint rhn_pkg_changelog_modified_nn not null
)
	storage ( freelists 16 )
	initrans 32;
create unique index rhn_pkg_cl_pid_n_txt_time_uq
        on rhnPackageChangelog(package_id, name, text, time)
        nologging tablespace [[32m_tbs]]
	storage ( freelists 16 )
	initrans 32;
create or replace trigger 
rhn_package_changelog_mod_trig
before insert or update on rhnPackageChangelog
for each row 
begin 
        :new.modified := sysdate; 
	update rhnPackage set last_modified = sysdate
		where id = :new.package_id;
end; 
/ 
show errors 

select '../rhn/tables/rhnPackageConflicts.sql' sql_file from dual;
-- SQL relevant contents from file ../rhn/tables/rhnPackageConflicts.sql
create table
rhnPackageConflicts
(
        package_id      number
                        constraint rhn_pkg_conflicts_pid_nn not null
                        constraint rhn_pkg_conflicts_package_fk
                                references rhnPackage(id),
        capability_id   number
                        constraint rhn_pkg_conflicts_cid_nn not null
                        constraint rhn_pkg_conflicts_cap_fk
                                references rhnPackageCapability(id),
        sense           number default(0) -- comes from RPMSENSE_*
                        constraint rhn_pkg_conflicts_sense_nn not null,
        created         date default (sysdate)
                        constraint rhn_pkg_conflicts_ctime_nn not null,
        modified        date default (sysdate)
                        constraint rhn_pkg_conflicts_mtime_nn not null
)
	storage ( freelists 16 )
	initrans 32;
create unique index rhn_pkg_confl_pid_cid_s_uq
	on rhnPackageConflicts(package_id, capability_id, sense)
	tablespace [[64k_tbs]]
	storage ( freelists 16 )
	initrans 32;
create index rhn_pkg_conflicts_cid_idx
	on rhnPackageConflicts(capability_id)
        tablespace [[64k_tbs]]
	storage ( freelists 16 )
	initrans 32
	nologging;
create or replace trigger
rhn_pkg_conflicts_mod_trig
before insert or update on rhnPackageConflicts
for each row
begin
        :new.modified := sysdate;
	update rhnPackage set last_modified = sysdate
		where id = :new.package_id;
end;
/
show errors

select '../rhn/tables/rhnTransactionOperation.sql' sql_file from dual;
-- SQL relevant contents from file ../rhn/tables/rhnTransactionOperation.sql
create table
rhnTransactionOperation
(
	id		number
			constraint rhn_transop_id_nn not null
			constraint rhn_transop_id_pk primary key
				using index tablespace [[8m_tbs]],
	label		varchar2(32)
			constraint rhn_transop_label_nn not null
			constraint rhn_transop_label_uq unique
				using index tablespace [[8m_tbs]],
	created		date default(sysdate)
			constraint rhn_transop_created_nn not null,
	modified	date default(sysdate)
			constraint rhn_transop_modified_nn not null
)
	storage ( freelists 16 )
	initrans 32;
create index rhn_transop_label_id_idx
	on rhnTransactionOperation(label,id)
	tablespace [[64k_tbs]]
	storage ( freelists 16 )
	initrans 32;

select '../rhn/tables/rhnTransactionPackage.sql' sql_file from dual;
-- SQL relevant contents from file ../rhn/tables/rhnTransactionPackage.sql
create table
rhnTransactionPackage
(
	id		number
			constraint rhn_transpack_id_nn not null
			constraint rhn_transpack_id_pk primary key
				using index tablespace [[8m_tbs]],
	operation	number
			constraint rhn_transpack_op_nn not null
			constraint rhn_transpack_op_fk
				references rhnTransactionOperation(id),
	name_id		number
			constraint rhn_transpack_nid_nn not null
			constraint rhn_transpack_nid_fk
				references rhnPackageName(id),
	evr_id		number
			constraint rhn_transpack_eid_nn not null
			constraint rhn_transpack_eid_fk
				references rhnPackageEVR(id),
	package_arch_id	number
			constraint rhn_transpack_paid_fk
				references rhnPackageArch(id)
)
	storage ( freelists 16 )
	initrans 32;
create unique index rhn_transpack_onea_uq
	on rhnTransactionPackage(operation, name_id, evr_id, package_arch_id)
	tablespace [[8m_tbs]]
	storage ( freelists 16 )
	initrans 32;
create sequence rhn_transpack_id_seq;

select '../rhn/tables/rhnPackageDeltaElement.sql' sql_file from dual;
-- SQL relevant contents from file ../rhn/tables/rhnPackageDeltaElement.sql
create table
rhnPackageDeltaElement
(
	package_delta_id	number
				constraint rhn_pdelement_pdid_nn not null
				constraint rhn_pdelement_pdid_fk
					references rhnPackageDelta(id)
					on delete cascade,
	transaction_package_id	number
				constraint rhn_pdelement_tpid_nn not null
				constraint rhn_pdelement_tpid_fk
					references rhnTransactionPackage(id)
)
	storage ( freelists 16 )
	initrans 32;
create unique index rhn_pdelement_pdid_tpid_uq
	on rhnPackageDeltaElement(package_delta_id, transaction_package_id)
	tablespace [[8m_tbs]]
	storage ( freelists 16 )
	initrans 32;

select '../rhn/tables/rhnPackageFileDeleteQueue.sql' sql_file from dual;
-- SQL relevant contents from file ../rhn/tables/rhnPackageFileDeleteQueue.sql
create table
rhnPackageFileDeleteQueue
(
        path            varchar2(1000),
	created			date default(sysdate)
				constraint rhn_pfdqueue_created_nn not null
)	storage ( freelists 16 )
	initrans 32;
alter table rhnPackageFileDeleteQueue add constraint rhn_pfdqueue_path_uq
	unique ( path );

select '../rhn/tables/rhnPackageFile.sql' sql_file from dual;
-- SQL relevant contents from file ../rhn/tables/rhnPackageFile.sql
create table
rhnPackageFile
(
	package_id	number
			constraint rhn_package_file_pid_nn not null
			constraint rhn_package_file_pid_fk
				references rhnPackage(id),
	capability_id	number
			constraint rhn_package_file_cid_nn not null
			constraint rhn_package_file_cid_fk
				references rhnPackageCapability(id),
	device		number
			constraint rhn_package_file_devices_nn not null,
	inode		number
			constraint rhn_package_file_inode_nn not null,
	file_mode	number
			constraint rhn_package_file_mode_nn not null,
	username	varchar2(32)
			constraint rhn_package_file_username_nn not null,
	groupname	varchar2(32)
			constraint rhn_package_file_groupname_nn not null,
	rdev		number
			constraint rhn_package_file_dev_nn not null,
	file_size	number
			constraint rhn_package_file_size_nn not null,
	mtime		date
			constraint rhn_package_file_mtime_nn not null,
	md5		varchar2(32),
	linkto		varchar2(256),
	flags		number
			constraint rhn_package_file_flags_nn not null,
	verifyflags	number
			constraint rhn_package_file_verify_nn not null,
	lang		varchar2(32),
	created		date default (sysdate)
			constraint rhn_package_file_created_nn not null,
	modified	date default (sysdate)
			constraint rhn_package_file_modified_nn not null
)
	storage ( pctincrease 1 freelists 16 )
	initrans 32;
create unique index rhn_package_file_pid_cid_uq
	on rhnPackageFile(package_id, capability_id)
	tablespace [[32m_tbs]]
	storage ( pctincrease 1 freelists 16 )
	initrans 32;
create index rhn_package_file_cid_pid_idx
	on rhnPackageFile(capability_id, package_id)
	tablespace [[32m_tbs]]
	storage ( pctincrease 1 freelists 16 )
	initrans 32
	nologging;
create or replace trigger
rhn_packagefile_mod_trig
before insert or update on rhnPackageFile
for each row
begin
	:new.modified := sysdate;
	update rhnPackage set last_modified = sysdate
		where id = :new.package_id;
end;
/
show errors

select '../rhn/tables/rhnPackageGroup_data.sql' sql_file from dual;
-- SQL relevant contents from file ../rhn/tables/rhnPackageGroup_data.sql
insert into rhnPackageGroup values (rhn_package_group_id_seq.nextval,'NoGroup',
        sysdate,sysdate);
commit;

select '../rhn/tables/rhnPackageObsoletes.sql' sql_file from dual;
-- SQL relevant contents from file ../rhn/tables/rhnPackageObsoletes.sql
create table
rhnPackageObsoletes
(
        package_id      number
                        constraint rhn_pkg_obsoletes_pid_nn not null
                        constraint rhn_pkg_obsoletes_package_fk
                                references rhnPackage(id),
        capability_id   number
                        constraint rhn_pkg_obsoletes_cid_nn not null
                        constraint rhn_pkg_obsoletes_cap_fk
                                references rhnPackageCapability(id),
        sense           number default(0) -- comes from RPMSENSE_*
                        constraint rhn_pkg_obsoletes_sense_nn not null,
        created         date default (sysdate)
                        constraint rhn_pkg_obsoletes_ctime_nn not null,
        modified        date default (sysdate)
                        constraint rhn_pkg_obsoletes_mtime_nn not null
)
	storage ( freelists 16 )
	initrans 32;
create unique index rhn_pkg_obsol_pid_cid_s_uq
	on rhnPackageObsoletes(package_id, capability_id, sense)
	tablespace [[64k_tbs]]
	storage ( freelists 16 )
	initrans 32;
create index rhn_pkg_obsoletes_cid_idx
	on rhnPackageObsoletes(capability_id)
        nologging tablespace [[64k_tbs]]
	storage ( freelists 16 )
	initrans 32;
create or replace trigger
rhn_pkg_obsoletes_mod_trig
before insert or update on rhnPackageObsoletes
for each row
begin
        :new.modified := sysdate;
	update rhnPackage set last_modified = sysdate
		where id = :new.package_id;
end;
/
show errors

select '../rhn/tables/rhnPackageProvides.sql' sql_file from dual;
-- SQL relevant contents from file ../rhn/tables/rhnPackageProvides.sql
create table
rhnPackageProvides
(
        package_id      number
                        constraint rhn_pkg_provides_pid_nn not null
                        constraint rhn_pkg_provides_package_fk
                                references rhnPackage(id),
        capability_id   number
                        constraint rhn_pkg_provides_cid_nn not null
                        constraint rhn_pkg_provides_capability_fk
                                references rhnPackageCapability(id),
        sense           number default(0) -- comes from RPMSENSE_*
                        constraint rhn_pkg_provides_sense_nn not null,
        created         date default (sysdate)
                        constraint rhn_pkg_provides_ctime_nn not null,
        modified        date default (sysdate)
                        constraint rhn_pkg_provides_mtime_nn not null
)
	storage ( freelists 16 )
	initrans 32;
create unique index rhn_pkg_prov_cid_pid_s_uq
	on rhnPackageProvides(capability_id, package_id, sense)
	tablespace [[2m_tbs]]
	storage ( freelists 16 )
	initrans 32;
create index rhn_pkg_provides_pid_idx
	on rhnPackageProvides(package_id)
        nologging tablespace [[2m_tbs]]
	storage ( freelists 16 )
	initrans 32;
create or replace trigger
rhn_pkg_provides_mod_trig
before insert or update on rhnPackageProvides
for each row
begin
        :new.modified := sysdate;
	update rhnPackage set last_modified = sysdate
		where id = :new.package_id;
end;
/
show errors

select '../rhn/tables/rhnPackageRequires.sql' sql_file from dual;
-- SQL relevant contents from file ../rhn/tables/rhnPackageRequires.sql
create table
rhnPackageRequires
(
        package_id      number
                        constraint rhn_pkg_requires_pid_nn not null
                        constraint rhn_pkg_requires_package_fk
                                references rhnPackage(id),
        capability_id   number
                        constraint rhn_pkg_requires_cid_nn not null
                        constraint rhn_pkg_requires_capability_fk
                                references rhnPackageCapability(id),
        sense           number default(0) -- comes from RPMSENSE_*
                        constraint rhn_pkg_requires_sense_nn not null,
        created         date default (sysdate)
                        constraint rhn_pkg_requires_ctime_nn not null,
        modified        date default (sysdate)
                        constraint rhn_pkg_requires_mtime_nn not null
)
	storage ( freelists 16 )
	initrans 32;
create unique index rhn_pkg_req_pid_cid_s_uq
	on rhnPackageRequires(package_id, capability_id, sense)
	tablespace [[4m_tbs]]
	storage ( freelists 16 )
	initrans 32;
create index rhn_pkg_requires_cid_idx
	on rhnPackageRequires(capability_id)
        nologging tablespace [[4m_tbs]]
	storage ( freelists 16 )
	initrans 32;
create or replace trigger
rhn_pkg_requires_mod_trig
before insert or update on rhnPackageRequires
for each row
begin
        :new.modified := sysdate;
	update rhnPackage set last_modified = sysdate
		where id = :new.package_id;
end;
/
show errors

select '../rhn/tables/rhnPackageSense.sql' sql_file from dual;
-- SQL relevant contents from file ../rhn/tables/rhnPackageSense.sql
create table
rhnPackageSense
(
	id		number
			constraint rhn_pkg_sense_id_nn not null
			constraint rhn_pkg_sense_id_pk primary key
			using index tablespace [[64k_tbs]],
	label		varchar2(32)
			constraint rhn_pkg_sense_label_nn not null
)
	storage ( freelists 16 )
	initrans 32;
create unique index rhn_pkg_sense_label_uq
	on rhnPackageSense(label)
	tablespace [[64k_tbs]]
	storage ( freelists 16 )
	initrans 32;

select '../rhn/tables/rhnPackageSense_data.sql' sql_file from dual;
-- SQL relevant contents from file ../rhn/tables/rhnPackageSense_data.sql
insert into rhnPackageSense(id, label) values (       0,'RPMSENSE_ANY');
insert into rhnPackageSense(id, label) values (       1,'RPMSENSE_SERIAL');
insert into rhnPackageSense(id, label) values (       2,'RPMSENSE_LESS');
insert into rhnPackageSense(id, label) values (       4,'RPMSENSE_GREATER');
insert into rhnPackageSense(id, label) values (       8,'RPMSENSE_EQUAL');
insert into rhnPackageSense(id, label) values (      16,'RPMSENSE_PROVIDES');
insert into rhnPackageSense(id, label) values (      32,'RPMSENSE_CONFLICTS');
insert into rhnPackageSense(id, label) values (      64,'RPMSENSE_PREREQ');
insert into rhnPackageSense(id, label) values (     128,'RPMSENSE_OBSOLETES');
insert into rhnPackageSense(id, label) values (     256,'RPMSENSE_INTERP');
insert into rhnPackageSense(id, label) values (     512,'RPMSENSE_SCRIPT_PRE');
insert into rhnPackageSense(id, label) values (    1024,'RPMSENSE_SCRIPT_POST');
insert into rhnPackageSense(id, label) values (    2048,'RPMSENSE_SCRIPT_PREUN');
insert into rhnPackageSense(id, label) values (    4096,'RPMSENSE_SCRIPT_POSTUN');
insert into rhnPackageSense(id, label) values (    8192,'RPMSENSE_SCRIPT_VERIFY');
insert into rhnPackageSense(id, label) values (   16384,'RPMSENSE_FIND_REQUIRES');
insert into rhnPackageSense(id, label) values (   32768,'RPMSENSE_FIND_PROVIDES');
insert into rhnPackageSense(id, label) values (   65536,'RPMSENSE_TRIGGERIN');
insert into rhnPackageSense(id, label) values (  131072,'RPMSENSE_TRIGGERUN');
insert into rhnPackageSense(id, label) values (  262144,'RPMSENSE_TRIGGERPOSTUN');
insert into rhnPackageSense(id, label) values (  524288,'RPMSENSE_MULTILIB');
insert into rhnPackageSense(id, label) values ( 1048576,'RPMSENSE_SCRIPT_PREP');
insert into rhnPackageSense(id, label) values ( 2097152,'RPMSENSE_SCRIPT_BUILD');
insert into rhnPackageSense(id, label) values ( 4194304,'RPMSENSE_SCRIPT_INSTALL');
insert into rhnPackageSense(id, label) values ( 8388608,'RPMSENSE_SCRIPT_CLEAN');
insert into rhnPackageSense(id, label) values (16777216,'RPMSENSE_RPMLIB');
insert into rhnPackageSense(id, label) values (33554432,'RPMSENSE_TRIGGERPREIN');

select '../rhn/tables/rhnPackageSenseMap.sql' sql_file from dual;
-- SQL relevant contents from file ../rhn/tables/rhnPackageSenseMap.sql
create table
rhnPackageSenseMap
(
	sense		number
			constraint rhn_pkg_sensemap_sense_nn not null,
	sense_id	number
			constraint rhn_pkg_sensemap_sid_nn not null
			constraint rhn_pkg_sensemap_sid_fk
				references rhnPackageSense(id)
)
	storage ( freelists 16 )
	initrans 32;
create unique index rhn_pkg_sensemap_s_sid_uq
	on rhnPackageSenseMap(sense,sense_id)
	tablespace [[64k_tbs]]
	storage ( freelists 16 )
	initrans 32;

select '../rhn/tables/rhnPackageSigType.sql' sql_file from dual;
-- SQL relevant contents from file ../rhn/tables/rhnPackageSigType.sql
create table
rhnPackageSigType
(
        id              number
			constraint rhn_pkg_sigtype_id_nn  not null
                        constraint rhn_pkg_sigtype_id_pk primary key
				using index tablespace [[64k_tbs]],
        name            varchar2(32)
			constraint rhn_pkg_sigtype_name_nn not null,
        created         date default (sysdate)
			constraint rhn_pkg_sigtype_created_nn not null,
        modified        date default (sysdate)
			constraint rhn_pkg_sigtype_modified_nn not null
)
	storage ( freelists 16 )
	initrans 32;
create sequence rhn_package_sig_type_id_seq;
create unique index rhn_pkg_sigtype_name_uq
	on rhnPackageSigType(name)
	tablespace [[64k_tbs]]
	storage ( freelists 16 )
	initrans 32;
create or replace trigger
rhn_package_sig_type_mod_trig
before insert or update on rhnPackageSigType
for each row
begin
	:new.modified := sysdate;
end;
/
show errors

select '../rhn/tables/rhnPackageSignature.sql' sql_file from dual;
-- SQL relevant contents from file ../rhn/tables/rhnPackageSignature.sql
create table
rhnPackageSignature
(
        id              number
			constraint rhn_pkg_sig_id_nn not null
                        constraint rhn_pkg_sig_id_pk primary key
                        using index tablespace [[64k_tbs]],
        package_id      number
			constraint rhn_pkg_sig_pid_nn not null
                        constraint rhn_pkg_sig_pid_fk
                                references rhnPackage(id),
        type_id         number
			constraint rhn_pkg_sig_tid_nn not null
                        constraint rhn_pkg_sig_tid_fk
                                references rhnPackageSigType(id),
        signature       varchar2(3000)
			constraint rhn_pkg_sig_signature_nn not null,
        created         date default (sysdate)
			constraint rhn_pkg_sig_created_nn not null,
        modified        date default (sysdate)
			constraint rhn_pkg_sig_modified_nn not null
)
	storage ( freelists 16 )
	initrans 32;
create sequence rhn_package_sig_id_seq;
create unique index rhn_pkg_sig_pid_tid_sig_uq
	on rhnPackageSignature(package_id, type_id, signature)
	tablespace [[64k_tbs]]
	storage ( freelists 16 )
	initrans 32;
create index rhn_pkg_sig_pid_idx
	on rhnPackageSignature(package_Id)
        nologging tablespace [[64k_tbs]]
	storage ( freelists 16 )
	initrans 32;
create or replace trigger
rhn_package_sig_mod_trig
before insert or update on rhnPackageSignature
for each row
begin
        :new.modified := sysdate;
	update rhnPackage set last_modified = sysdate
		where id = :new.package_id;
end;
/
show errors

select '../rhn/tables/rhnPackageSigType_data.sql' sql_file from dual;
-- SQL relevant contents from file ../rhn/tables/rhnPackageSigType_data.sql
insert into rhnPackageSigType values (
        rhn_package_sig_type_id_seq.nextval,
        'MD5',sysdate,sysdate
);
insert into rhnPackageSigType values (
        rhn_package_sig_type_id_seq.nextval,
        'SHA1',sysdate,sysdate
);
insert into rhnPackageSigType values (
        rhn_package_sig_type_id_seq.nextval,
        'PGP',sysdate,sysdate
);
insert into rhnPackageSigType values (
        rhn_package_sig_type_id_seq.nextval,
        'GPG',sysdate,sysdate
);
commit;

select '../rhn/tables/rhnPaidErrataTempCache.sql' sql_file from dual;
-- SQL relevant contents from file ../rhn/tables/rhnPaidErrataTempCache.sql
create global temporary table rhnPaidErrataTempCache
(
  errata_id number,
  user_id number,
  server_id number
) on commit preserve rows;
create index rhnpec_u_idx on rhnPaidErrataTempCache(user_id);

select '../rhn/tables/rhnPathChannelMap.sql' sql_file from dual;
-- SQL relevant contents from file ../rhn/tables/rhnPathChannelMap.sql
create table rhnPathChannelMap
(
	path		varchar2(128)
			constraint rhn_path_channel_map_p_nn not null,
	channel_id	number
			constraint rhn_path_channel_map_cid_nn not null
			constraint rhn_path_channel_map_cid_fk
				references rhnChannel(id) on delete cascade,
	is_source	varchar2(1),
	created		date default SYSDATE,
	modified	date default SYSDATE
)
	storage( freelists 16 )
	initrans 32;
create unique index rhn_path_channel_map_p_cid_uq 
	on rhnPathChannelMap(path, channel_id)
	tablespace [[64k_tbs]]
	storage( freelists 16 )
	initrans 32;
create index rhn_path_channel_map_cid_p_idx
	on rhnPathChannelMap(channel_id, path)
	tablespace [[64k_tbs]]
	storage( freelists 16 )
	initrans 32
	nologging;
create or replace trigger
rhn_path_channel_map_mod_trig
before insert or update on rhnPathChannelMap
for each row
begin
	:new.modified := SYSDATE;
end rhn_beehive_mod_trig;
/
show errors

select '../rhn/tables/rhnPayloaderConversion.sql' sql_file from dual;
-- SQL relevant contents from file ../rhn/tables/rhnPayloaderConversion.sql
create table
rhnPayloaderConversion
(
	org_id			number
				constraint rhn_plconv_oid_nn not null
				constraint rhn_plconv_oid_fk
					references web_customer(id)
					on delete cascade,
	reason			varchar2(256)
				constraint rhn_plconv_reason_nn not null,
	created			date default(sysdate)
				constraint rhn_plconv_created_nn not null
)
	storage ( freelists 16 )
	initrans 32;
create index rhn_plconv_oid_idx
	on rhnPayloaderConversion( org_id )
	tablespace [[4m_tbs]]
	storage ( freelists 16 )
	initrans 32;

select '../rhn/tables/rhnProductLine.sql' sql_file from dual;
-- SQL relevant contents from file ../rhn/tables/rhnProductLine.sql
create sequence rhn_prod_line_id_seq start with 101;
create table
rhnProductLine
(
	id		number
			constraint rhn_prod_line_id_nn not null,
	label		varchar2(128)
			constraint rhn_prod_line_label_nn not null,
	name		varchar2(128)
			constraint rhn_prod_line_name_nn not null,
	last_modified	date default (sysdate)
			constraint rhn_prod_line_lm_nn not null,
	created		date default (sysdate)
			constraint rhn_prod_line_created_nn not null,
	modified	date default (sysdate)
			constraint rhn_prod_line_modified_nn not null
)
	storage ( freelists 16 )
	initrans 32;
create index rhn_prod_line_id_idx
	on rhnProductLine ( id )
	tablespace [[64k_tbs]]
	storage ( freelists 16 )
	initrans 32;
alter table rhnProductLine add constraint rhn_prod_line_id_pk
	primary key ( id );
create index rhn_prod_line_label_idx
	on rhnProductLine(label)
	tablespace [[64k_tbs]]
	storage ( freelists 16 )
	initrans 32;
alter table rhnProductLine add constraint rhn_prod_line_label_uq
	unique ( label );
create index rhn_prod_line_name_idx
	on rhnProductLine(name)
	tablespace [[64k_tbs]]
	storage ( freelists 16 )
	initrans 32;
alter table rhnProductLine add constraint rhn_prod_line_name_uq
	unique ( name );
create or replace trigger
rhn_prod_line_mod_trig
before insert or update on rhnProductLine
for each row
begin
	:new.modified := sysdate;
	:new.last_modified := sysdate;
end;
/
show errors

select '../rhn/tables/rhnProduct.sql' sql_file from dual;
-- SQL relevant contents from file ../rhn/tables/rhnProduct.sql
create sequence rhn_product_id_seq start with 101;
create table
rhnProduct
(
	id		number
			constraint rhn_product_id_nn not null,
	label		varchar2(128)
			constraint rhn_product_label_nn not null,
	name		varchar2(128)
			constraint rhn_product_name_nn not null,
	product_line_id	number
        		constraint rhn_product_cat_nn not null 
			constraint rhn_product_cat_fk
				references rhnProductLine(id)
				on delete cascade,
	last_modified	date default (sysdate)
			constraint rhn_product_lm_nn not null,
	created		date default (sysdate)
			constraint rhn_product_created_nn not null,
	modified	date default (sysdate)
			constraint rhn_product_modified_nn not null
)
	storage ( freelists 16 )
	initrans 32;
create index rhn_product_id_idx
	on rhnProduct(id)
	tablespace [[64k_tbs]]
	storage ( freelists 16 )
	initrans 32;
alter table rhnProduct add constraint rhn_product_id_pk
	primary key ( id );
create index rhn_product_label_idx
	on rhnProduct(label)
	tablespace [[64k_tbs]]
	storage ( freelists 16 )
	initrans 32;
alter table rhnProduct add constraint rhn_product_label_uq
	unique ( label );
create index rhn_product_name_idx
	on rhnProduct(name)
	tablespace [[64k_tbs]]
	storage ( freelists 16 )
	initrans 32;
alter table rhnProduct add constraint rhn_product_name_uq
	unique ( name );
create or replace trigger
rhn_product_mod_trig
before insert or update on rhnProduct
for each row
begin
	:new.modified := sysdate;
	:new.last_modified := sysdate;
end;
/
show errors

select '../rhn/tables/rhnProductChannel.sql' sql_file from dual;
-- SQL relevant contents from file ../rhn/tables/rhnProductChannel.sql
create table
rhnProductChannel
(
	channel_id	number
			constraint rhn_pc_cid_nn not null 
			constraint rhn_pc_cid_fk
				references rhnChannel(id)
				on delete cascade,
	product_id	number
			constraint rhn_pc_pid_nn not null
			constraint rhn_pc_pid_fk
				references rhnProduct(id),
	created		date default (sysdate)
			constraint rhn_pc_created_nn not null,
	modified	date default (sysdate)
			constraint rhn_pc_modified_nn not null
)
	storage ( freelists 16 )
	initrans 32;
create index rhn_pc_cid_pid_idx
	on rhnProductChannel ( channel_id, product_id )
	tablespace [[64k_tbs]]
	storage ( freelists 16 )
	initrans 32;
alter table rhnProductChannel add constraint rhn_pc_cid_pid_idx
	unique ( channel_id, product_id );
create index rhn_pc_pid_cid_idx
	on rhnProductChannel ( product_id, channel_id )
	tablespace [[64k_tbs]]
	storage ( freelists 16 )
	initrans 32;

select '../rhn/tables/rhnProductChannel_data.sql' sql_file from dual;
-- SQL relevant contents from file ../rhn/tables/rhnProductChannel_data.sql
insert into rhnProductChannel
(channel_id, product_id)
select c.id, p.id
from rhnProduct p,
     rhnChannel c
where c.label in ('redhat-database-i386-7.1')
and p.label = 'rhdb71';
insert into rhnProductChannel
(channel_id, product_id)
select c.id, p.id
from rhnProduct p,
     rhnChannel c
where c.label in ('redhat-advanced-server-i386', 'redhat-linux-as-2.1-IPF')
and p.label = 'rh21as';
insert into rhnProductChannel
(channel_id, product_id)
select c.id, p.id
from rhnProduct p,
     rhnChannel c
where c.label in ('redhat-ent-linux-i386-es-2.1')
and p.label = 'rh21es';
insert into rhnProductChannel
(channel_id, product_id)
select c.id, p.id
from rhnProduct p,
     rhnChannel c
where c.label in ('redhat-ent-linux-i386-ws-2.1')
and p.label = 'rh21ws';
insert into rhnProductChannel
(channel_id, product_id)
select c.id, p.id
from rhnProduct p,
     rhnChannel c
where c.label in ('redhat-linux-aw-2.1-IPF')
and p.label = 'rh21aw';
insert into rhnProductChannel
(channel_id, product_id)
select c.id, p.id
from rhnProduct p,
     rhnChannel c
where c.label in ('redhat-stronghold-i386')
and p.label = 'rhshas';
insert into rhnProductChannel
(channel_id, product_id)
select c.id, p.id
from rhnProduct p,
     rhnChannel c
where c.label in ('redhat-linux-i386-9')
and p.label = 'rh9';
insert into rhnProductChannel
(channel_id, product_id)
select c.id, p.id
from rhnProduct p,
     rhnChannel c
where c.label in ('redhat-linux-i386-8.0')
and p.label = 'rh8';
insert into rhnProductChannel
(channel_id, product_id)
select c.id, p.id
from rhnProduct p,
     rhnChannel c
where c.label in ('redhat-linux-i386-7.3')
and p.label = 'rh73';
insert into rhnProductChannel
(channel_id, product_id)
select c.id, p.id
from rhnProduct p,
     rhnChannel c
where c.label in ('redhat-linux-i386-7.2', 'redhat-linux-ia64-7.2', 'redhat-linux-s390-7.2')
and p.label = 'rh72';
insert into rhnProductChannel
(channel_id, product_id)
select c.id, p.id
from rhnProduct p,
     rhnChannel c
where c.label in ('redhat-linux-i386-7.1', 'redhat-linux-ia64-7.1', 'redhat-linux-alpha-7.1')
and p.label = 'rh71';
insert into rhnProductChannel
(channel_id, product_id)
select c.id, p.id
from rhnProduct p,
     rhnChannel c
where c.label in ('redhat-linux-i386-7.0', 'redhat-linux-alpha-7.0')
and p.label = 'rh7';
insert into rhnProductChannel
(channel_id, product_id)
select c.id, p.id
from rhnProduct p,
     rhnChannel c
where c.label in ('redhat-linux-i386-6.2', 'redhat-linux-alpha-6.2', 'redhat-linux-sparc-6.2')
and p.label = 'rh62';
insert into rhnProductChannel
(channel_id, product_id)
select c.id, p.id
from rhnProduct p,
     rhnChannel c
where c.label in ('redhat-linux-ee-i386-6.2')
and p.label = 'rh62EE';
insert into rhnProductChannel
(channel_id, product_id)
select c.id, p.id
from rhnProduct p,
     rhnChannel c
where c.label in ('redhat-powertools-i386-7.1', 'redhat-powertools-alpha-7.1')
and p.label = 'rh71-powertools';
insert into rhnProductChannel
(channel_id, product_id)
select c.id, p.id
from rhnProduct p,
     rhnChannel c
where c.label in ('redhat-powertools-alpha-6.2', 'redhat-powertools-i386-6.2', 'redhat-powertools-sparc-6.2')
and p.label = 'rh62-powertools';
insert into rhnProductChannel
(channel_id, product_id)
select c.id, p.id
from rhnProduct p,
     rhnChannel c
where c.label in ('redhat-powertools-alpha-7.0', 'redhat-powertools-i386-7.0')
and p.label = 'rh7-powertools';
insert into rhnProductChannel
(channel_id, product_id)
select c.id, p.id
from rhnProduct p,
     rhnChannel c
where c.label = 'redhat-linux-iSeries-7.1'
and p.label = 'rh71iseries';
insert into rhnProductChannel
(channel_id, product_id)
select c.id, p.id
from rhnProduct p,
     rhnChannel c
where c.label = 'redhat-linux-pSeries-7.1'
and p.label = 'rh71pseries';
commit;

select '../rhn/tables/rhnProductLine_data.sql' sql_file from dual;
-- SQL relevant contents from file ../rhn/tables/rhnProductLine_data.sql
insert into rhnProductLine
(id, label, name)
values
(1, 'rhl', 'Red Hat Linux');
insert into rhnProductLine
(id, label, name)
values
(2, 'rhel', 'Red Hat Enterprise Linux');
insert into rhnProductLine
(id, label, name)
values
(3, 'rhdb', 'Red Hat Database');
insert into rhnProductLine
(id, label, name)
values
(4, 'stronghold', 'Stronghold');

select '../rhn/tables/rhnProxyInfo.sql' sql_file from dual;
-- SQL relevant contents from file ../rhn/tables/rhnProxyInfo.sql
create table
rhnProxyInfo
(
        server_id       number
			constraint rhn_proxy_info_sid_nn not null
                        constraint rhn_proxy_info_sid_fk
				references rhnServer(id) on delete cascade
)
	storage( freelists 16 )
	initrans 32;
create unique index rhn_proxy_info_sid_unq on
        rhnProxyInfo(server_id)
	storage( freelists 16 )
	initrans 32;

select '../rhn/tables/rhnRam.sql' sql_file from dual;
-- SQL relevant contents from file ../rhn/tables/rhnRam.sql
create table
rhnRam
(
        id              number
			constraint rhn_ram_id_nn not null
                        constraint rhn_ram_id_pk primary key
                        using index tablespace [[4m_tbs]],
        server_id       number
			constraint rhn_ram_sid_nn not null
                        constraint rhn_ram_sid_fk
                                references rhnServer(id) on delete cascade,
        ram             number
			constraint rhn_ram_ram_nn not null,
        swap            number
			constraint rhn_ram_swap_nn not null,
        created         date default(sysdate)
			constraint rhn_ram_created_nn not null,
        modified        date default(sysdate)
			constraint rhn_ram_modified_nn not null
)
	storage( freelists 16 )
	initrans 32;
create sequence rhn_ram_id_seq;
create index rhn_ram_sid_idx on
        rhnRam(server_id)
        tablespace [[4m_tbs]]
	storage( freelists 16 )
	initrans 32
	nologging;
create or replace trigger
rhn_ram_mod_trig
before insert or update on rhnRam
for each row
begin
        :new.modified := sysdate;
end;
/
show errors

select '../rhn/tables/rhnRedHatCanonVersion.sql' sql_file from dual;
-- SQL relevant contents from file ../rhn/tables/rhnRedHatCanonVersion.sql
create table rhnRedHatCanonVersion
(
        version         varchar2(32)
                        constraint rhn_rh_canon_ver_v_nn not null
                        constraint rhn_rh_canon_ver_v_pk primary key,
        canon_version   varchar2(32)
                        constraint rhn_rh_canon_ver_cv_nn not null,
	created		date default(sysdate)
			constraint rhn_rh_canon_ver_created_nn not null,
	modified	date default(sysdate)
			constraint rhn_rh_canon_ver_modified_nn not null
)
	storage( freelists 16 )
	initrans 32;

select '../rhn/tables/rhnRedHatCanonVersion_data.sql' sql_file from dual;
-- SQL relevant contents from file ../rhn/tables/rhnRedHatCanonVersion_data.sql
insert into rhnRedHatCanonVersion (version, canon_version) values (
    'Red Hat Linux 7.1'         , '7.1');
insert into rhnRedHatCanonVersion (version, canon_version) values (
    'Red_Hat_Linux_7.1'         , '7.1');
insert into rhnRedHatCanonVersion (version, canon_version) values (
    '7.1sbe'                    , '7.1');
insert into rhnRedHatCanonVersion (version, canon_version) values (
    'Red Hat Linux 7.0.91'      , '7.1');
insert into rhnRedHatCanonVersion (version, canon_version) values (
    'Red Hat Linux 7.0.95'      , '7.1');
insert into rhnRedHatCanonVersion (version, canon_version) values (
    '7.0.90'                    , '7.1');
insert into rhnRedHatCanonVersion (version, canon_version) values (
    '7.0.91'                    , '7.1');
insert into rhnRedHatCanonVersion (version, canon_version) values (
    '7.0.93'                    , '7.1');
insert into rhnRedHatCanonVersion (version, canon_version) values (
    '7.0.95'                    , '7.1');
insert into rhnRedHatCanonVersion (version, canon_version) values (
    'Red Hat Linux 7'           , '7.0');
insert into rhnRedHatCanonVersion (version, canon_version) values (
    'Red Hat Linux 7.0j'        , '7.0');
insert into rhnRedHatCanonVersion (version, canon_version) values (
    '7.0J'                      , '7.0');
insert into rhnRedHatCanonVersion (version, canon_version) values (
    '7.0.1J'                    , '7.0');
insert into rhnRedHatCanonVersion (version, canon_version) values (
    'Red Hat Linux 6.2'         , '6.2');
insert into rhnRedHatCanonVersion (version, canon_version) values (
    'Red_Hat_Linux_6.2'         , '6.2');
insert into rhnRedHatCanonVersion (version, canon_version) values (
    'Red_Hat_Linux_6.1'         , '6.2');
insert into rhnRedHatCanonVersion (version, canon_version) values (
    '6.2EE'                     , '6.2');
insert into rhnRedHatCanonVersion (version, canon_version) values (
    '6.2.2'                     , '6.2');
insert into rhnRedHatCanonVersion (version, canon_version) values (
    '6.2de'                     , '6.2');
insert into rhnRedHatCanonVersion (version, canon_version) values (
    '6.2fr'                     , '6.2');
insert into rhnRedHatCanonVersion (version, canon_version) values (
    '6.2es'                     , '6.2');
insert into rhnRedHatCanonVersion (version, canon_version) values (
    '6.2it'                     , '6.2');
insert into rhnRedHatCanonVersion (version, canon_version) values (
    '6.2ja'                     , '6.2');
insert into rhnRedHatCanonVersion (version, canon_version) values (
    'Red Hat Linux 7.2'         , '7.2');
insert into rhnRedHatCanonVersion (version, canon_version) values (
    'Red Hat Linux 7.2 i386'    , '7.2');
insert into rhnRedHatCanonVersion (version, canon_version) values (
    'redhat-linux-i686-7.0'     , '7.0');
insert into rhnRedHatCanonVersion (version, canon_version) values (
    'Red_Hat_Linux_7.2'         , '7.2');
insert into rhnRedHatCanonVersion (version, canon_version) values (
    '6.2-1'			, '6.2');
insert into rhnRedHatCanonVersion (version, canon_version) values (
    '7.0.98'			, '7.1');
insert into rhnRedHatCanonVersion (version, canon_version) values (
    '7.1.90'			, '7.2');
insert into rhnRedHatCanonVersion (version, canon_version) values (
    '7.1.90EE'			, '7.2');
insert into rhnRedHatCanonVersion (version, canon_version) values (
    '7.1.91AS'			, '7.2');
insert into rhnRedHatCanonVersion (version, canon_version) values (
    '7.1.93'			, '7.2');
insert into rhnRedHatCanonVersion (version, canon_version) values (
    '7.1.94'			, '7.2');
insert into rhnRedHatCanonVersion (version, canon_version) values (
    '7.2.93'                    , '7.3');
insert into rhnRedHatCanonVersion (version, canon_version) values (
    '7.2.94'                    , '7.3');
commit;

select '../rhn/tables/rhnRegTokenChannels.sql' sql_file from dual;
-- SQL relevant contents from file ../rhn/tables/rhnRegTokenChannels.sql
create table
rhnRegTokenChannels
(
	token_id	number
			constraint rhn_reg_tok_chn_tid_nn not null
			constraint rhn_reg_tok_chn_id_fk
				references rhnRegToken(id)
				on delete cascade,
        channel_id number
                        constraint rhn_reg_tok_chn_sg_nn not null
                        constraint rhn_reg_tok_chn_sgs_fk
                                references rhnChannel(id)
				on delete cascade
)
	storage( freelists 16 )
	initrans 32;
create unique index rhn_reg_tok_chn_uq
	on rhnRegTokenChannels(token_id, channel_id)
	tablespace [[4m_tbs]]
	storage( freelists 16 )
	initrans 32;

select '../rhn/tables/rhnRegTokenConfigChannels.sql' sql_file from dual;
-- SQL relevant contents from file ../rhn/tables/rhnRegTokenConfigChannels.sql
create table
rhnRegTokenConfigChannels
(
	token_id		number
				constraint rhn_regtok_confchan_tid_nn not null
				constraint rhn_regtok_confchan_tid_fk
					references rhnRegToken(id)
					on delete cascade,
	config_channel_id	number
				constraint rhn_regtok_confchan_ccid_nn not null
				constraint rhn_regtok_confchan_ccid_fk
					references rhnConfigChannel(id)
					on delete cascade,
	position		number
				constraint rhn_regtok_confchan_pos_nn not null
)
	storage ( freelists 16 )
	initrans 32;
create unique index rhn_regtok_confchan_t_cc_uq
	on rhnRegTokenConfigChannels( token_id, config_channel_id )
	tablespace [[4m_tbs]]
	storage ( freelists 16 )
	initrans 32;
create index rhn_regtok_confchan_ccid_idx
	on rhnRegTokenConfigChannels( config_channel_id )
	tablespace [[2m_tbs]]
	storage ( freelists 16 )
	initrans 32;

select '../rhn/tables/rhnRegTokenGroups.sql' sql_file from dual;
-- SQL relevant contents from file ../rhn/tables/rhnRegTokenGroups.sql
create table
rhnRegTokenGroups
(
	token_id	number
			constraint rhn_reg_tok_grp_tid_nn not null
			constraint rhn_reg_tok_grp_id_fk
				references rhnRegToken(id)
				on delete cascade,
        server_group_id number
                        constraint rhn_reg_tok_grp_sg_nn not null
                        constraint rhn_reg_tok_grp_sgs_fk
                                references rhnServerGroup(id)
				on delete cascade
)
	storage( freelists 16 )
	initrans 32;
create unique index rhn_reg_tok_grp_uq
	on rhnRegTokenGroups(token_id, server_group_id)
	tablespace [[4m_tbs]]
	storage( freelists 16 )
	initrans 32;

select '../rhn/tables/rhnRegTokenOrgDefault.sql' sql_file from dual;
-- SQL relevant contents from file ../rhn/tables/rhnRegTokenOrgDefault.sql
create table
rhnRegTokenOrgDefault
(
	org_id		number
			constraint rhn_reg_token_def_oid_nn not null
			constraint rhn_reg_token_def_oid_fk
				references web_customer(id)
				on delete cascade,
	reg_token_id	number
			constraint rhn_reg_token_def_tokid_fk
				references rhnRegToken(id)
				on delete cascade
);
create unique index rhn_reg_token_def_org_id_idx
	on rhnRegTokenOrgDefault(org_id)
	storage( freelists 16 )
	initrans 32;
create index rhn_reg_token_def_uid_idx
	on rhnRegTokenOrgDefault (reg_token_id, org_id)
	storage( freelists 16 )
	initrans 32;

select '../rhn/tables/rhnRegTokenPackages.sql' sql_file from dual;
-- SQL relevant contents from file ../rhn/tables/rhnRegTokenPackages.sql
create table
rhnRegTokenPackages
(
	token_id	number
			constraint rhn_reg_tok_pkg_tid_nn not null
			constraint rhn_reg_tok_pkg_id_fk
				references rhnRegToken(id)
				on delete cascade,
        name_id         number
                        constraint rhn_reg_tok_pkg_sg_nn not null
                        constraint rhn_reg_tok_pkg_sgs_fk
                                references rhnPackageName(id)
				on delete cascade
)
	storage( freelists 16 )
	initrans 32;
create unique index rhn_reg_tok_pkg_uq
	on rhnRegTokenPackages(token_id, name_id)
	tablespace [[4m_tbs]]
	storage( freelists 16 )
	initrans 32;
create index rhn_reg_tok_pkg_nid_idx
	on rhnRegtokenPackages(name_id)
	tablespace [[2m_tbs]]
	storage ( freelists 16 )
	initrans 32;

select '../rhn/tables/rhnRelationshipType_data.sql' sql_file from dual;
-- SQL relevant contents from file ../rhn/tables/rhnRelationshipType_data.sql
insert into rhnRelationshipType ( id, label, description ) values (
	rhn_reltype_id_seq.nextval, 'cloned_from',
	'was cloned from'
);

select '../rhn/tables/rhnSatelliteCert.sql' sql_file from dual;
-- SQL relevant contents from file ../rhn/tables/rhnSatelliteCert.sql
create table
rhnSatelliteCert
(
	label			varchar2(64)
				constraint rhn_satcert_label_nn not null,
	version			number,
	cert			varchar2(4000)
				constraint rhn_satcert_cert_nn not null,
	created			date default(sysdate)
				constraint rhn_satcert_created_nn not null,
	modified		date default(sysdate)
				constraint rhn_satcert_modified_nn not null
)
	storage ( freelists 16 )
	initrans 32;
create or replace trigger
rhn_satcert_mod_trig
before insert or update on rhnSatelliteCert 
for each row
begin
	:new.modified := sysdate;
end;
/
show errors
create unique index rhn_satcert_label_version_uq on
	rhnSatelliteCert ( label, version )
	tablespace [[64k_tbs]]
	storage ( freelists 16 )
	initrans 32;

select '../rhn/tables/rhnSatelliteChannelFamily.sql' sql_file from dual;
-- SQL relevant contents from file ../rhn/tables/rhnSatelliteChannelFamily.sql
create table
rhnSatelliteChannelFamily
(
        server_id       number
                        constraint rhn_sat_cf_sid_nn not null
                        constraint rhn_sat_cf_sid_fk
                                references rhnServer(id)
				on delete cascade,
        channel_family_id   number
                        constraint rhn_sat_cf_cfid_nn not null
                        constraint rhn_sat_cf_cfid_fk
                                references rhnChannelFamily(id)
                                on delete cascade,
        quantity        number,
        created         date default (sysdate)
                        constraint rhn_sat_cf_created_nn not null,
        modified        date default (sysdate)
                        constraint rhn_sat_cf_modified_nn not null
)
	storage( freelists 16 )
	initrans 32;
create or replace trigger
rhn_sat_cf_mod_trig
before insert or update on rhnSatelliteChannelFamily
for each row
begin
    :new.modified := sysdate;
end;
/
show errors
create index rhn_sat_cf_sid_cfid_idx on
	rhnSatelliteChannelFamily ( server_id, channel_family_id )
	tablespace [[2m_tbs]]
	storage( freelists 16 )
	initrans 32;
alter table rhnSatelliteChannelFamily add constraint rhn_sat_cf_sid_cfid_uq
	unique ( server_id, channel_family_id );
create index rhn_sat_cf_cfid_sid_idx on
        rhnSatelliteChannelFamily( channel_family_id, server_id )
	tablespace [[2m_tbs]]
	storage( freelists 16 )
	initrans 32;

select '../rhn/tables/rhnSatelliteInfo.sql' sql_file from dual;
-- SQL relevant contents from file ../rhn/tables/rhnSatelliteInfo.sql
create table
rhnSatelliteInfo
(
        server_id       number
                        constraint rhn_satellite_info_sid_nn not null
                        constraint rhn_satellite_info_sid_fk
                                references rhnServer(id)
				on delete cascade,
        cert            varchar2(4000)
                        constraint rhn_satellite_info_cert_nn not null,
        product         varchar2(256)
                        constraint rhn_satellite_info_product_nn not null,
        owner           varchar2(256)
                        constraint rhn_satellite_info_owner_nn not null,
        issued_string   varchar2(256),
        expiration_string varchar2(256),
        created         date default (sysdate)
                        constraint rhn_satellite_info_created_nn not null,
        modified        date default (sysdate)
                        constraint rhn_satellite_info_modified_nn not null
)
	storage( freelists 16 )
	initrans 32;
create or replace trigger
rhn_satellite_info_mod_trig
before insert or update on rhnSatelliteInfo
for each row
begin
    :new.modified := sysdate;
end;
/
show errors
create index rhn_satellite_info_sid_idx on
	rhnSatelliteInfo ( server_id )
	tablespace [[2m_tbs]]
	storage( freelists 16 )
	initrans 32;
alter table rhnSatelliteInfo add constraint rhn_satellite_info_sid_uq
	unique ( server_id );

select '../rhn/tables/rhnSatelliteServerGroup.sql' sql_file from dual;
-- SQL relevant contents from file ../rhn/tables/rhnSatelliteServerGroup.sql
create table
rhnSatelliteServerGroup
(
	server_id		number
				constraint rhn_satsg_sid_nn not null
				constraint rhn_satsg_sid_fk
					references rhnSatelliteInfo(server_id)
					on delete cascade,
	server_group_type	number
				constraint rhn_satsg_sgtype_nn not null
				constraint rhn_satsg_sgtype_fk
					references rhnServerGroupType(id),
	max_members		number,
	created			date default(sysdate)
				constraint rhn_satsg_creat_nn not null,
	modified		date default(sysdate)
				constraint rhn_satsg_mod_nn not null
)
	storage ( freelists 16 )
	initrans 32;
create unique index rhn_satsg_sid_sgt_uq
	on rhnSatelliteServerGroup( server_id, server_group_type )
	tablespace [[64k_tbs]]
	storage ( freelists 16 )
	initrans 32;
create or replace trigger
rhn_satsg_mod_trig
before insert or update on rhnSatelliteServerGroup
for each row
begin
	:new.modified := sysdate;
end;
/
show errors

select '../rhn/tables/rhnSavedSearchType.sql' sql_file from dual;
-- SQL relevant contents from file ../rhn/tables/rhnSavedSearchType.sql
create table
rhnSavedSearchType
(
	id		number
			constraint rhn_sstype_id_nn not null,
	label		varchar2(8)
			constraint rhn_sstype_label_nn not null,
	created		date default(sysdate)
			constraint rhn_sstype_created_nn not null,
	modified	date default(sysdate)
			constraint rhn_sstype_modified_nn not null
)
	storage( freelists 16 )
	initrans 32;
create sequence rhn_sstype_id_seq;
create index rhn_sstype_id_label_idx
	on rhnSavedSearchType(id,label)
	tablespace [[64k_tbs]]
	storage( freelists 16 )
	initrans 32;
alter table rhnSavedSearchType add
	constraint rhn_sstype_id_pk primary key (id);
create index rhn_sstype_label_id_idx
	on rhnSavedSearchType(label,id)
	tablespace [[64k_tbs]]
	storage( freelists 16 )
	initrans 32;
alter table rhnSavedSearchType add
	constraint rhn_sstype_label_uq unique (label);
insert into rhnSavedSearchType (id, label)
	values (rhn_sstype_id_seq.nextval, 'system');
insert into rhnSavedSearchType (id, label)
	values (rhn_sstype_id_seq.nextval, 'package');
insert into rhnSavedSearchType (id, label)
	values (rhn_sstype_id_seq.nextval, 'errata');
commit;

select '../rhn/tables/rhnSavedSearch.sql' sql_file from dual;
-- SQL relevant contents from file ../rhn/tables/rhnSavedSearch.sql
create table
rhnSavedSearch
(
	id		number
			constraint rhn_savedsearch_id_nn not null,
	web_contact_id	number
			constraint rhn_savedsearch_wcid_nn not null
			constraint rhn_savedsearch_wcid_fk
				references web_contact(id)
				on delete cascade,
	name		varchar2(16)
			constraint rhn_savedsearch_name_nn not null,
	type		number
			constraint rhn_savedsearch_type_nn not null
			constraint rhn_savedsearch_type_fk
				references rhnSavedSearchType(id),
	search_string	varchar2(4000)
			constraint rhn_savedsearch_sstring_nn not null,
	search_set	varchar2(16)
			constraint rhn_savedsearch_sset_nn not null
			constraint rhn_savedsearch_sset_ck
				check ( search_set in ('all','system_list')),
	search_field	varchar2(128)
			constraint rhn_savedsearch_sfield_nn not null,
	invert		char default('N')
			constraint rhn_savedsearch_invert_nn not null
			constraint rhn_savedsearch_invert_ck
				check (invert in ('Y','N'))
)
	storage( freelists 16 )
	initrans 32;
create sequence rhn_savedsearch_id_seq;
create index rhn_savedsearch_id_wcid_idx
	on rhnSavedSearch(id, web_contact_id)
	tablespace [[2m_tbs]]
	storage( freelists 16 )
	initrans 32;
alter table rhnSavedSearch add
	constraint rhn_savedsearch_id_pk primary key (id);
create index rhn_savedsearch_wcid_id_idx
	on rhnSavedSearch(web_contact_id, id)
	tablespace [[2m_tbs]]
	storage( freelists 16 )
	initrans 32;
create index rhn_savedsearch_name_wcid_idx
	on rhnSavedSearch(name, web_contact_id)
	tablespace [[2m_tbs]]
	storage( freelists 16 )
	initrans 32;
alter table rhnSavedSearch add 
	constraint rhn_savedsearch_name_wcid_uq unique (name, web_contact_id);

select '../rhn/tables/rhnServerChannelArchCompat.sql' sql_file from dual;
-- SQL relevant contents from file ../rhn/tables/rhnServerChannelArchCompat.sql
create table
rhnServerChannelArchCompat
(
        server_arch_id	number
                        constraint rhn_sc_ac_said_nn not null
                        constraint rhn_sc_ac_said_uq unique
                                using index tablespace [[64k_tbs]]
                        constraint rhn_sc_ac_said_fk 
				references rhnServerArch(id),
	channel_arch_id	number
			constraint rhn_sc_ac_caid_nn not null
			constraint rhn_sc_ac_caid_fk
				references rhnChannelArch(id),
	created		date default(sysdate)
			constraint rhn_sc_ac_created_nn not null,
	modified	date default(sysdate)
			constraint rhn_sc_ac_modified_nn not null
)
	storage( freelists 16 )
	initrans 32;
create index rhn_sc_ac_caid_paid
	on rhnServerChannelArchCompat(server_arch_id, channel_arch_id)
	tablespace [[64k_tbs]]
	storage( freelists 16 )
	initrans 32;
create index rhn_sc_ac_paid_caid
	on rhnServerChannelArchCompat(channel_arch_id, server_arch_id)
	tablespace [[64k_tbs]]
	storage( freelists 16 )
	initrans 32;
create or replace trigger
rhn_sc_ac_mod_trig
before insert or update on rhnServerChannelArchCompat
for each row
begin
        :new.modified := sysdate;
end;
/
show errors

select '../rhn/tables/rhnServerChannelArchCompat_data.sql' sql_file from dual;
-- SQL relevant contents from file ../rhn/tables/rhnServerChannelArchCompat_data.sql
insert into rhnServerChannelArchCompat (server_arch_id, channel_arch_id) values
(LOOKUP_SERVER_ARCH('i386-redhat-linux'), LOOKUP_CHANNEL_ARCH('channel-ia32'));
insert into rhnServerChannelArchCompat (server_arch_id, channel_arch_id) values
(LOOKUP_SERVER_ARCH('i486-redhat-linux'), LOOKUP_CHANNEL_ARCH('channel-ia32'));
insert into rhnServerChannelArchCompat (server_arch_id, channel_arch_id) values
(LOOKUP_SERVER_ARCH('i586-redhat-linux'), LOOKUP_CHANNEL_ARCH('channel-ia32'));
insert into rhnServerChannelArchCompat (server_arch_id, channel_arch_id) values
(LOOKUP_SERVER_ARCH('i686-redhat-linux'), LOOKUP_CHANNEL_ARCH('channel-ia32'));
insert into rhnServerChannelArchCompat (server_arch_id, channel_arch_id) values
(LOOKUP_SERVER_ARCH('athlon-redhat-linux'), LOOKUP_CHANNEL_ARCH('channel-ia32'));
insert into rhnServerChannelArchCompat (server_arch_id, channel_arch_id) values
(LOOKUP_SERVER_ARCH('alpha-redhat-linux'), LOOKUP_CHANNEL_ARCH('channel-alpha'));
insert into rhnServerChannelArchCompat (server_arch_id, channel_arch_id) values
(LOOKUP_SERVER_ARCH('alphaev6-redhat-linux'), LOOKUP_CHANNEL_ARCH('channel-alpha'));
insert into rhnServerChannelArchCompat (server_arch_id, channel_arch_id) values
(LOOKUP_SERVER_ARCH('ia64-redhat-linux'), LOOKUP_CHANNEL_ARCH('channel-ia64'));
insert into rhnServerChannelArchCompat (server_arch_id, channel_arch_id) values
(LOOKUP_SERVER_ARCH('sparc-redhat-linux'), LOOKUP_CHANNEL_ARCH('channel-sparc'));
insert into rhnServerChannelArchCompat (server_arch_id, channel_arch_id) values
(LOOKUP_SERVER_ARCH('sparcv9-redhat-linux'), LOOKUP_CHANNEL_ARCH('channel-sparc'));
insert into rhnServerChannelArchCompat (server_arch_id, channel_arch_id) values
(LOOKUP_SERVER_ARCH('sparc64-redhat-linux'), LOOKUP_CHANNEL_ARCH('channel-sparc'));
insert into rhnServerChannelArchCompat (server_arch_id, channel_arch_id) values
(LOOKUP_SERVER_ARCH('s390-redhat-linux'), LOOKUP_CHANNEL_ARCH('channel-s390'));
insert into rhnServerChannelArchCompat (server_arch_id, channel_arch_id) values
(LOOKUP_SERVER_ARCH('s390x-redhat-linux'), LOOKUP_CHANNEL_ARCH('channel-s390x'));
insert into rhnServerChannelArchCompat (server_arch_id, channel_arch_id) values
(LOOKUP_SERVER_ARCH('pSeries-redhat-linux'), LOOKUP_CHANNEL_ARCH('channel-pSeries'));
insert into rhnServerChannelArchCompat (server_arch_id, channel_arch_id) values
(LOOKUP_SERVER_ARCH('iSeries-redhat-linux'), LOOKUP_CHANNEL_ARCH('channel-iSeries'));
insert into rhnServerChannelArchCompat (server_arch_id, channel_arch_id) values
(LOOKUP_SERVER_ARCH('x86_64-redhat-linux'), LOOKUP_CHANNEL_ARCH('channel-x86_64'));
insert into rhnServerChannelArchCompat (server_arch_id, channel_arch_id) values
(LOOKUP_SERVER_ARCH('ppc64iseries-redhat-linux'), LOOKUP_CHANNEL_ARCH('channel-ppc'));
insert into rhnServerChannelArchCompat (server_arch_id, channel_arch_id) values
(LOOKUP_SERVER_ARCH('ppc64pseries-redhat-linux'), LOOKUP_CHANNEL_ARCH('channel-ppc'));
commit;

select '../rhn/tables/rhnServerChannel_triggers.sql' sql_file from dual;
-- SQL relevant contents from file ../rhn/tables/rhnServerChannel_triggers.sql
create or replace trigger
rhn_server_channel_mod_trig
before insert or update on rhnServerChannel
for each row
begin
        :new.modified := sysdate;
end;
/
show errors

select '../rhn/tables/rhnServerConfigChannel.sql' sql_file from dual;
-- SQL relevant contents from file ../rhn/tables/rhnServerConfigChannel.sql
create table
rhnServerConfigChannel
(
	server_id		number
				constraint rhn_servercc_sid_nn not null
				constraint rhn_servercc_sid_fk
					references rhnServer(id)
					on delete cascade,
	config_channel_id	number
				constraint rhn_servercc_ccid_nn not null
				constraint rhn_servercc_ccid_fk
					references rhnConfigChannel(id)
					on delete cascade,
	position		number,
	created			date default(sysdate)
				constraint rhn_servercc_creat_nn not null,
	modified		date default(sysdate)
				constraint rhn_servercc_mod_nn not null
)
	storage ( freelists 16 )
	initrans 32;
create unique index rhn_servercc_sid_ccid_uq
	on rhnServerConfigChannel( server_id, config_channel_id )
	tablespace [[2m_tbs]]
	storage ( freelists 16 )
	initrans 32;
create index rhn_servercc_ccid_idx
	on rhnServerConfigChannel( config_channel_id )
	tablespace [[2m_tbs]]
	storage ( freelists 16 )
	initrans 32;
create or replace trigger
rhn_servercc_mod_trig
before insert or update on rhnServerConfigChannel
for each row
begin
	:new.modified := sysdate;
end;
/
show errors

select '../rhn/tables/rhnServerCustomDataValue.sql' sql_file from dual;
-- SQL relevant contents from file ../rhn/tables/rhnServerCustomDataValue.sql
create table
rhnServerCustomDataValue
(
	server_id	number
			constraint rhn_scdv_sid_nn not null
			constraint rhn_scdv_sid_fk
				references rhnServer(id)
				on delete cascade,
	key_id		number
			constraint rhn_scdv_kid_nn not null
			constraint rhn_scdv_kid_fk
				references rhnCustomDataKey(id),
	value		varchar2(4000),  -- nullable?
	created_by	number
			constraint rhn_scdv_cb_fk
				references web_contact(id)
				on delete set null,
	last_modified_by number
			constraint rhn_scdv_lmb_fk
				references web_contact(id)
				on delete set null,
	created		date default (sysdate)
			constraint rhn_scdv_created_nn not null,
	modified	date default (sysdate)
			constraint rhn_scdv_modified_nn not null	
)
	storage ( freelists 16 )
	initrans 32;
create unique index rhn_scdv_sid_kid_uq
	on rhnServerCustomDataValue(server_id, key_id);
create index rhn_scdv_kid_sid_idx
	on rhnServerCustomDataValue(key_id, server_id);
create or replace trigger
rhn_scdv_mod_trig
before insert or update on rhnServerCustomDataValue
for each row
begin
	:new.modified := sysdate;
end;
/
show errors

select '../rhn/tables/rhnServerDMI.sql' sql_file from dual;
-- SQL relevant contents from file ../rhn/tables/rhnServerDMI.sql
create table
rhnServerDMI
(
        id              number
			constraint rhn_server_dmi_id_nn not null
                        constraint rhn_server_dmi_pk primary key
                        using index tablespace [[2m_tbs]],
        server_id       number
			constraint rhn_server_dmi_sid_nn not null
                        constraint rhn_server_dmi_fk
                                references rhnServer(id) on delete cascade,
	vendor		varchar2(256),
	system		varchar2(256),
	product		varchar2(256),
	bios_vendor	varchar2(256),
	bios_version	varchar2(256),
	bios_release	varchar2(256),
	asset		varchar2(256),
	board		varchar2(256),
        created         date default(sysdate)
			constraint rhn_server_dmi_created_nn not null,
        modified        date default(sysdate)
			constraint rhn_server_dmi_modified_nn not null
)
	storage( freelists 16 )
	initrans 32;
create sequence rhn_server_dmi_id_seq;
create index rhn_server_dmi_sid_idx on
        rhnServerDMI(server_id)
        tablespace [[2m_tbs]]
	storage( freelists 16 )
	initrans 32
	nologging;
create or replace trigger
rhn_server_dmi_mod_trig
before insert or update on rhnServerDMI
for each row
begin
        :new.modified := sysdate;
end;
/
show errors

select '../rhn/tables/rhnServerEvent.sql' sql_file from dual;
-- SQL relevant contents from file ../rhn/tables/rhnServerEvent.sql
create table
rhnServerEvent
(
	id		number
			constraint rhn_se_id_nn not null
			constraint rhn_se_id_pk primary key
				using index tablespace [[64k_tbs]],
	server_id	number
			constraint rhn_se_server_id_nn not null
			constraint rhn_se_server_id_fk
			       references rhnServer(id)
			       on delete cascade,
	details 	varchar2(4000)
			constraint rhn_se_details_nn not null,
	created		date default (sysdate)
			constraint rhn_se_created_nn not null,
	modified	date default (sysdate)
			constraint rhn_se_modified_nn not null
)
	storage( freelists 16 )
	initrans 32;
create index rhn_se_idx
	on rhnServerEvent(server_id)
	tablespace [[64k_tbs]]
	storage( freelists 16 )
	initrans 32;
create sequence rhn_se_id_seq;
create or replace trigger
rhn_se_mod_trig
before insert or update on rhnServerEvent
for each row
begin
	:new.modified := sysdate;
end;
/
show errors

select '../rhn/tables/rhnServerGroup_indexes.sql' sql_file from dual;
-- SQL relevant contents from file ../rhn/tables/rhnServerGroup_indexes.sql
create index rhn_sg_id_oid_name_idx
	on rhnServerGroup(id,org_id,name)
	parallel 6
        tablespace [[4m_tbs]]
	storage( pctincrease 1 freelists 16 )
	initrans 32
	nologging;
create index rhn_sg_oid_id_name_idx
	on rhnServerGroup(org_id,id,name)
	parallel 6
        tablespace [[8m_tbs]]
	storage( pctincrease 1 freelists 16 )
	initrans 32
	nologging;
create index rhn_sg_type_id_idx
	on rhnServerGroup(group_type,id)
	parallel 6
        tablespace [[4m_tbs]]
	storage( pctincrease 1 freelists 16 )
	initrans 32
	nologging;
create index rhn_sg_oid_type_id_idx
	on rhnServerGroup(org_id, group_type, id)
	parallel 6
        tablespace [[4m_tbs]]
	storage( pctincrease 1 freelists 16 )
	initrans 32
	nologging;

select '../rhn/tables/rhnServerGroupMembers.sql' sql_file from dual;
-- SQL relevant contents from file ../rhn/tables/rhnServerGroupMembers.sql
create table
rhnServerGroupMembers
(
        server_id       number
                        constraint rhn_sg_members_nn not null
                        constraint rhn_sg_members_fk
                                references rhnServer(id),
        server_group_id number
                        constraint rhn_sg_group_nn not null
                        constraint rhn_sg_groups_fk
                                references rhnServerGroup(id),
        created         date default(sysdate)
                        constraint rhn_sg_member_cre_nn not null,
        modified        date default(sysdate)
                        constraint rhn_sg_member_mod_nn not null
)
	storage( pctincrease 1 freelists 16 )
	initrans 32;

select '../rhn/tables/rhnServerGroupMembers_indexes.sql' sql_file from dual;
-- SQL relevant contents from file ../rhn/tables/rhnServerGroupMembers_indexes.sql
create unique index rhn_sgmembers_sid_sgid_uq
	on rhnServerGroupMembers(server_id, server_group_id)
	tablespace [[4m_tbs]]
	storage( pctincrease 1 freelists 16 )
	initrans 32;
create index rhn_sgmembers_sgid_sid_idx
	on rhnServerGroupMembers(server_group_id, server_id)
	parallel 6
        tablespace [[4m_tbs]]
	storage( pctincrease 1 freelists 16 )
	initrans 32
	nologging;

select '../rhn/tables/rhnServerGroupMembers_triggers.sql' sql_file from dual;
-- SQL relevant contents from file ../rhn/tables/rhnServerGroupMembers_triggers.sql
create or replace trigger
rhn_sg_member_mod_trig
before insert or update on rhnServerGroupMembers
for each row
begin
        :new.modified := sysdate;
end;
/
show errors
CREATE OR REPLACE TRIGGER
rhn_server_group_org_mapping
BEFORE INSERT OR UPDATE ON rhnServerGroupMembers
FOR EACH ROW
DECLARE
        same_org        NUMBER;
BEGIN
        same_org := 0;
        SELECT 1 INTO same_org
          FROM rhnServer S, rhnServerGroup SG
         WHERE SG.org_id = S.org_id
           AND S.id = :new.server_id
           AND SG.id = :new.server_group_id;
        IF same_org = 0 THEN
          rhn_exception.raise_exception('sgm_insert_diff_orgs');
        END IF;
EXCEPTION
        WHEN NO_DATA_FOUND THEN
          rhn_exception.raise_exception('sgm_insert_diff_orgs');
END;
/
SHOW ERRORS

select '../rhn/tables/rhnServerGroupNotes.sql' sql_file from dual;
-- SQL relevant contents from file ../rhn/tables/rhnServerGroupNotes.sql
create table
rhnServerGroupNotes
(
        id              number
                        constraint rhn_servergrp_note_id_nn not null
                        constraint rhn_servergrp_note_id_pk primary key
                                using index tablespace [[64k_tbs]],
        creator         number
                        constraint rhn_servergrp_note_creator_fk
                                   references web_contact(id)
				   on delete set null,
        server_group_id number
                        constraint rhn_servergrp_note_nn not null
                        constraint rhn_servergrp_note_fk
                                references rhnServerGroup(id) on delete cascade,
        subject         varchar2(80)
                        constraint rhn_servergrp_note_subject_nn not null,
        note            varchar2(4000)
                        constraint rhn_servergrp_note_note_nn not null,
        created         date default(sysdate)
                        constraint rhn_servergrp_note_created_nn not null,
        modified        date default(sysdate)
                        constraint rhn_servergrp_note_modified_nn not null
)
	storage ( freelists 16 )
	initrans 32;
create sequence rhn_servergrp_note_id_seq;
create index rhn_servergrp_note_srvr_id_idx
	on rhnServerGroupNotes(server_group_id)
	tablespace [[64k_tbs]]
	storage ( freelists 16 )
	initrans 32
	nologging;
create index rhn_servergrp_note_creator_idx
	on rhnServerGroupNotes ( creator )
	tablespace [[64k_tbs]]
	storage ( freelists 16 )
	initrans 32
	nologging;
CREATE OR REPLACE TRIGGER
rhn_servergroup_note_mod_trig
BEFORE INSERT OR UPDATE ON rhnServerGroupNotes
FOR EACH ROW
BEGIN
        :new.modified := sysdate;
END;
/
SHOW ERRORS

select '../rhn/tables/rhnUserGroup.sql' sql_file from dual;
-- SQL relevant contents from file ../rhn/tables/rhnUserGroup.sql
create table
rhnUserGroup
(
        id              number
                        constraint rhn_user_group_id_nn not null
                        constraint rhn_user_group_pk primary key
                                using index tablespace [[8m_tbs]]
				storage( pctincrease 1 freelists 16 )
				initrans 32,
        name            varchar2(64)
                        constraint rhn_user_group_name_nn not null,
        description     varchar2(1024)
                        constraint rhn_user_group_desc_nn not null,
        max_members     number,
        current_members number default(0)
                        constraint rhn_user_group_cm_nn not null,
        group_type      number
                        constraint rhn_usergroup_type_nn not null
                        constraint rhn_usergroup_type_fk
                                references rhnUserGroupType(id),
        org_id          number
                        constraint rhn_user_group_org_id_nn not null
                        constraint rhn_user_group_org_fk
                                references web_customer(id)
				on delete cascade,
        created         date default(sysdate)
                        constraint rhn_usergroup_type_created_nn not null,
        modified        date default(sysdate)
                        constraint rhn_usergroup_type_modified_nn not null
)
	storage ( pctincrease 1 freelists 16 )
	initrans 32;

select '../rhn/tables/rhnSnapshotServerGroup.sql' sql_file from dual;
-- SQL relevant contents from file ../rhn/tables/rhnSnapshotServerGroup.sql
create table
rhnSnapshotServerGroup
(
	snapshot_id		number
				constraint rhn_snapshotsg_sid_nn not null
				constraint rhn_snapshotsg_sid_fk
					references rhnSnapshot(id)
					on delete cascade,
	server_group_id		number
				constraint rhn_snapshotsg_sgid_nn not null
				constraint rhn_snapshotsg_sgid_fk
					references rhnServerGroup(id)
)
	storage ( freelists 16 )
	initrans 32;
create unique index rhn_snapshotsg_sid_sgid_uq
	on rhnSnapshotServerGroup( snapshot_id, server_group_id )
	tablespace [[4m_tbs]]
	storage ( freelists 16 )
	initrans 32;
create index rhn_snapshotsg_sgid_idx
	on rhnSnapshotServerGroup( server_group_id )
	tablespace [[2m_tbs]]
	storage ( freelists 16 )
	initrans 32;
create or replace trigger
rhn_snapshotsg_mod_trig
before insert or update on rhnSnapshotServerGroup
for each row
begin
	update rhnSnapshot set modified = sysdate where id = :new.snapshot_id;
end;
/
show errors

select '../rhn/tables/rhnServerGroup_triggers.sql' sql_file from dual;
-- SQL relevant contents from file ../rhn/tables/rhnServerGroup_triggers.sql
create or replace trigger
rhn_server_group_mod_trig
before insert or update on rhnServerGroup
for each row
begin
        :new.modified := sysdate;
end;
/
show errors
CREATE OR REPLACE TRIGGER
rhn_server_group_creation
AFTER INSERT ON rhnServerGroup
FOR EACH ROW
DECLARE
        org_admin_group      NUMBER;
        org_id_val           NUMBER;	
BEGIN
    	org_id_val := :new.org_id;
    	SELECT UG.id INTO org_admin_group
	  FROM rhnUserGroup UG,
	       rhnUserGroupType UGT
	 WHERE UGT.label = 'org_admin'
	   AND UGT.id = UG.group_type
	   AND UG.org_id = org_id_val;
EXCEPTION
        WHEN NO_DATA_FOUND THEN
          rhn_exception.raise_exception_val('no_org_admin_group', org_id_val);
END;
/
SHOW ERRORS
create or replace trigger
rhn_sg_del_trig
before delete on rhnServerGroup
for each row
declare
	cursor snapshots is
		select	snapshot_id id
		from	rhnSnapshotServerGroup
		where	server_group_id = :old.id;
begin
	IF :old.group_type IS NOT NULL
	THEN
	    	rhn_exception.raise_exception('sg_delete_typed');
	END IF;
	for snapshot in snapshots loop
		update rhnSnapshot
			set invalid = lookup_snapshot_invalid_reason('sg_removed')
			where id = snapshot.id;
		delete from rhnSnapshotServerGroup
			where snapshot_id = snapshot.id
				and server_group_id = :old.id;
	end loop;
end;
/
show errors

select '../rhn/tables/rhnServerGroupType_data.sql' sql_file from dual;
-- SQL relevant contents from file ../rhn/tables/rhnServerGroupType_data.sql
insert into rhnServerGroupType (id, label, name)
        values (rhn_servergroup_type_seq.nextval,
                'sw_mgr_entitled','RHN Update Entitled Servers'
        );
insert into rhnServerGroupType (id, label, name)
        values (rhn_servergroup_type_seq.nextval,
                'enterprise_entitled','RHN Management Entitled Servers'
        );
insert into rhnServerGroupType (id, label, name)
        values (rhn_servergroup_type_seq.nextval,
                'provisioning_entitled','RHN Provisioning Entitled Servers'
        );
commit;

select '../rhn/tables/rhnServerHistory.sql' sql_file from dual;
-- SQL relevant contents from file ../rhn/tables/rhnServerHistory.sql
create table
rhnServerHistory
(
        id              number
			constraint rhn_serverhistory_id_nn not null
                        constraint rhn_serverhistory_id_pk primary key
                        using index tablespace [[2m_tbs]],
        server_Id       number
			constraint rhn_serverhistory_sid_nn not null
                        constraint rhn_serverhistory_sid_fk
                                references rhnServer(id) on delete cascade,
        summary         varchar(256)
			constraint rhn_serverhistory_summary_nn not null,
        details         varchar(4000),
        created         date default (sysdate)
			constraint rhn_serverhistory_created_nn not null,
        modified        date default (sysdate)
			constraint rhn_serverhistory_modified_nn not null
)
	storage ( freelists 16 )
	initrans 32;
create index rhn_server_hist_server_id_idx
	on rhnServerHistory(server_id)
	tablespace [[4m_tbs]]
	storage ( freelists 16 )
	initrans 32;
create or replace trigger
rhn_serverhistory_mod_trig
before insert or update on rhnServerHistory
for each row
begin
        :new.modified := sysdate;
end;
/
show errors

select '../rhn/tables/rhnServerInfo.sql' sql_file from dual;
-- SQL relevant contents from file ../rhn/tables/rhnServerInfo.sql
create table
rhnServerInfo
(
        server_id       number
			constraint rhn_server_info_sid_nn not null
                        constraint rhn_server_info_sid_fk
				references rhnServer(id) on delete cascade,
	checkin		date default(sysdate),
	checkin_counter number default(0)
)
	storage ( pctincrease 1 freelists 16 )
	initrans 32
	nologging;
create unique index rhn_server_info_sid_unq on
        rhnServerInfo(server_id)
	tablespace [[4m_tbs]]
	storage( pctincrease 1 freelists 16 )
	initrans 32
	nologging;
create or replace trigger
rhn_server_info_mod_trig
before insert or update on rhnServerInfo
for each row
begin
	if :new.checkin is NULL
	then
	        :new.checkin := sysdate;
	end if;
end;
/
show errors

select '../rhn/tables/rhnServerInstallInfo.sql' sql_file from dual;
-- SQL relevant contents from file ../rhn/tables/rhnServerInstallInfo.sql
create table
rhnServerInstallInfo
(
	id		number
			constraint rhn_server_install_info_id_nn not null
			constraint rhn_server_install_info_id_pk primary key
				using index tablespace [[2m_tbs]],
        server_id       number
                        constraint rhn_server_instal_info_sid_nn not null
                        constraint rhn_server_install_info_sid_fk
                                references rhnServer(id) on delete cascade,
	install_method	varchar2(32)
			constraint rhn_server_install_info_im_nn not null,
	iso_status	number,
	mediasum	varchar2(64),
	created		date default(sysdate)
			constraint rhn_server_install_info_cr_nn not null,
	modified	date default(sysdate)
			constraint rhn_server_install_info_md_nn not null
)
	storage ( freelists 16 )
	initrans 32;
create sequence rhn_server_install_info_id_seq;
create index rhn_s_inst_info_sid_im_idx
	on rhnServerInstallInfo(server_id, install_method)
	tablespace [[2m_tbs]]
	storage ( freelists 16 )
	initrans 32;
create unique index rhn_server_install_info_sid_uq
	on rhnServerInstallInfo( server_id )
	tablespace [[2m_tbs]]
	storage ( freelists 16 )
	initrans 32;
create or replace trigger
rhn_s_inst_info_mod_trig
before insert or update on rhnServerInstallInfo
for each row
begin
	:new.modified := sysdate;
end;
/

select '../rhn/tables/rhnServerLocation.sql' sql_file from dual;
-- SQL relevant contents from file ../rhn/tables/rhnServerLocation.sql
create table
rhnServerLocation
(
        id              number
			constraint rhn_serverlocation_id_nn not null
                        constraint rhn_serverlocation_id_pk primary key
				using index tablespace [[64k_tbs]],
        server_id       number
			constraint rhn_serverlocation_sid_nn  not null
                        constraint rhn_serverlocation_sid_fk
                                references rhnServer(id) on delete cascade,
        machine         varchar2(64),
        rack            varchar2(64),
        room            varchar2(32),
        building        varchar2(128),
        address1        varchar2(128),
        address2        varchar2(128),
        city            varchar2(128),
        state           varchar2(60),
        country         char(2),
        created         date default (sysdate)
			constraint rhn_serverlocation_created_nn not null,
        modified        date default (sysdate)
			constraint rhn_serverlocation_modified_nn not null
)
	storage ( freelists 16 )
	initrans 32;
create sequence rhn_server_loc_id_seq;
create unique index rhn_serverlocation_sid_uq
	on rhnServerLocation ( server_id )
	tablespace [[2m_tbs]]
	storage ( freelists 16 )
	initrans 32;
create or replace trigger
rhn_serverlocation_mod_trig
before insert or update on rhnServerLocation
for each row
begin
        :new.modified := sysdate;
end;
/
show errors

select '../rhn/tables/rhnServerLock.sql' sql_file from dual;
-- SQL relevant contents from file ../rhn/tables/rhnServerLock.sql
create table
rhnServerLock
(
        server_id       number
			constraint rhn_server_lock_sid_nn not null
                        constraint rhn_server_lock_sid_fk
				references rhnServer(id) on delete cascade,
        locker_id       number
                        constraint rhn_server_lock_lid_fk
				references web_contact(id) on delete set null,
	reason          varchar2(4000),
        created         date default (sysdate)
			constraint rhn_server_lock_created_nn not null
)
	storage ( pctincrease 1 freelists 16 )
	initrans 32;
create unique index rhn_server_lock_sid_unq on
        rhnServerLock(server_id)
	tablespace [[4m_tbs]]
	storage( pctincrease 1 freelists 16 )
	initrans 32;
create index rhn_server_lock_lid_unq on
        rhnServerLock(locker_id)
	tablespace [[4m_tbs]]
	storage( pctincrease 1 freelists 16 )
	initrans 32;

select '../rhn/tables/rhnServerMessage.sql' sql_file from dual;
-- SQL relevant contents from file ../rhn/tables/rhnServerMessage.sql
create table
rhnServerMessage
(
	server_id	number
			constraint rhn_sm_server_id_nn not null
			constraint rhn_sm_server_id_fk
				references rhnServer(id)
				on delete cascade,
	message_id	number
			constraint rhn_sm_message_id_nn not null
			constraint rhn_sm_message_id_fk
				references rhnMessage(id)
				on delete cascade,
	server_event	number
			constraint rhn_sm_se_fk
				references rhnServerEvent(id)
				on delete cascade,
	created		date default (sysdate)
			constraint rhn_sm_created_nn not null,
	modified	date default (sysdate)
			constraint rhn_sm_modified_nn not null
)
	storage ( freelists 16 )
	initrans 32;
create unique index rhn_sm_uq
	on rhnServerMessage(server_id, message_id)
	tablespace [[64k_tbs]]
	storage ( freelists 16 )
	initrans 32;
create unique index rhn_sm_mi_sid_uq
	on rhnServerMessage(message_id, server_id)
	tablespace [[64k_tbs]]
	storage ( freelists 16 )
	initrans 32;
create or replace trigger
rhn_sm_mod_trig
before insert or update on rhnServerMessage
for each row
begin
	:new.modified := sysdate;
end;
/
show errors

select '../rhn/tables/rhnServerNeededPackageCache.sql' sql_file from dual;
-- SQL relevant contents from file ../rhn/tables/rhnServerNeededPackageCache.sql
create table rhnServerNeededPackageCache
(
	org_id
			number
			constraint rhn_sncp_oid_nn not null
			constraint rhn_sncp_oid_fk
				references web_customer(id)
				on delete cascade,
	server_id	number
			constraint rhn_sncp_sid_nn not null
			constraint rhn_sncp_sid_fk
				references rhnServer(id)
				on delete cascade,
	errata_id	number
			constraint rhn_sncp_eid_fk
				references rhnErrata(id)
				on delete cascade,
	package_id	number
			constraint rhn_sncp_pid_nn not null
			constraint rhn_sncp_pid_fk
				references rhnPackage(id)
				on delete cascade
)
	storage ( pctincrease 1 freelists 16 )
	initrans 32;
alter table rhnServerNeededPackageCache nologging;
create index rhn_snpc_pid_eid_sid_idx
	on rhnServerNeededPackageCache(package_id, errata_id, server_id)
	parallel 6
	tablespace [[128m_tbs]]
	storage ( pctincrease 1 freelists 16 )
	pctfree 10
	initrans 32
	nologging;
create index rhn_snpc_sid_pid_eid_idx
	on rhnServerNeededPackageCache(server_id, package_id, errata_id) 
	parallel 6
	tablespace [[128m_tbs]]
	storage ( pctincrease 1 freelists 16 )
	pctfree 10
	initrans 32
	nologging;
create index rhn_snpc_sid_eid_pid_idx
	on rhnServerNeededPackageCache(server_id, errata_id, package_id) 
	parallel 6
	tablespace [[128m_tbs]]
	storage ( pctincrease 1 freelists 16 )
	pctfree 10
	initrans 32
	nologging;
create index rhn_snpc_oid_eid_sid_idx
	on rhnServerNeededPackageCache(org_id, errata_id, server_id)
	parallel 6
	tablespace [[128m_tbs]]
	storage ( pctincrease 1 freelists 16 )
	pctfree 10
	initrans 32
	nologging;

select '../rhn/tables/rhnServerNeededPackageCache_indexes.sql' sql_file from dual;
-- SQL relevant contents from file ../rhn/tables/rhnServerNeededPackageCache_indexes.sql
create index rhn_snpc_eid_sid_idx
	on rhnServerNeededPackageCache(errata_id, server_id)
	parallel 6
	tablespace [[128m_tbs]]
	storage ( pctincrease 1 freelists 16 )
	pctfree 10
	initrans 32
	nologging;

select '../rhn/tables/rhnServerNetInterface.sql' sql_file from dual;
-- SQL relevant contents from file ../rhn/tables/rhnServerNetInterface.sql
create table
rhnServerNetInterface
(
	server_id	number
			constraint rhn_srv_net_iface_sid_nn not null
			constraint rhn_srv_net_iface_sid_fk 
				references rhnServer(id)
				on delete cascade,
	name		varchar2(32)
			constraint rhn_srv_net_iface_name_nn not null,
	ip_addr		varchar2(64),
	netmask		varchar2(64),
	broadcast	varchar2(64),
	hw_addr		varchar2(18),
	module		varchar2(128),
	created		date default sysdate
			constraint rhn_srv_net_iface_created_nn not null,
	modified	date default sysdate
			constraint rhn_srv_net_iface_modified_nn not null
)
	storage ( freelists 16 )
	initrans 32;
create or replace trigger
rhn_srv_net_iface_mod_trig
before insert or update on rhnServerNetInterface
for each row
begin
        :new.modified := sysdate;
end;
/
show errors
create index rhn_srv_net_iface_sid_name_idx
	on rhnServerNetInterface ( server_id, name )
	tablespace [[8m_tbs]]
	storage ( freelists 16 )
	initrans 32;
alter table rhnServerNetInterface add constraint rhn_srv_net_iface_sid_name_uq
	unique ( server_id, name );

select '../rhn/tables/rhnServerNetwork.sql' sql_file from dual;
-- SQL relevant contents from file ../rhn/tables/rhnServerNetwork.sql
create table
rhnServerNetwork
(
        id              number
			constraint rhn_servernetwork_id_nn not null
                        constraint rhn_servernetwork_id_pk primary key
                        using index tablespace [[4m_tbs]],
        server_id       number
			constraint rhn_servernetwork_sid_nn not null
                        constraint rhn_servernetwork_sid_fk
                                references rhnServer(id) on delete cascade,
        hostname        varchar(128),
        ipaddr          char(16),
        created         date default (sysdate)
			constraint rhn_servernetwork_created_nn not null,
        modified        date default (sysdate)
			constraint rhn_servernetwork_modified_nn not null
)
	storage ( freelists 16 )
	initrans 32;
create sequence rhn_server_net_id_seq;
create index rhn_servernetwork_sid_id_idx
	on rhnServerNetwork(server_id,id)
	tablespace [[4m_tbs]]
	storage ( freelists 16 )
	initrans 32
	nologging;
create or replace trigger
rhn_servernetwork_mod_trig
before insert or update on rhnServerNetwork
for each row
begin
        :new.modified := sysdate;
end;
/
show errors

select '../rhn/tables/rhnServerNotes.sql' sql_file from dual;
-- SQL relevant contents from file ../rhn/tables/rhnServerNotes.sql
create table
rhnServerNotes
(
        id              number
                        constraint rhn_servernotes_id_nn not null
                        constraint rhn_servernotes_id_pk primary key
                                using index tablespace [[64k_tbs]],
        creator         number
                        constraint rhn_servernotes_creator_fk
                                   references web_contact(id)
				   on delete set null,
        server_id       number
                        constraint rhn_servernotes_sid_nn not null
                        constraint rhn_servernotes_sid_fk
                                   references rhnServer(id)
				   on delete cascade,
        subject         varchar2(80)
                        constraint rhn_servernotes_subject_nn not null,
        note            varchar2(4000),
        created         date default(sysdate)
                        constraint rhn_servernotes_created_nn not null,
        modified        date default(sysdate)
                        constraint rhn_servernotes_modified_nn not null
)
	storage ( freelists 16 )
	initrans 32;
create sequence rhn_server_note_id_seq;
create index rhn_servernotes_sid_idx
	on rhnServerNotes(server_id)
	tablespace [[64k_tbs]]
	storage ( freelists 16 )
	initrans 32
	nologging;
create index rhn_servernotes_creator_idx
	on rhnServerNotes ( creator )
	tablespace [[64k_tbs]]
	storage ( freelists 16 )
	initrans 32
	nologging;
create or replace trigger
rhn_servernotes_mod_trig
before insert or update on rhnServerNotes
for each row
begin
        :new.modified := sysdate;
end;
/
show errors

select '../rhn/tables/rhnServerPackageArchCompat.sql' sql_file from dual;
-- SQL relevant contents from file ../rhn/tables/rhnServerPackageArchCompat.sql
create table
rhnServerPackageArchCompat
(
        server_arch_id	number
                        constraint rhn_sp_ac_said_nn not null
                        constraint rhn_sp_ac_said_fk 
				references rhnServerArch(id),
	package_arch_id	number
			constraint rhn_sp_ac_paid_nn not null
			constraint rhn_sp_ac_paid_fk
				references rhnPackageArch(id),
        preference      number
                        constraint rhn_sp_ac_pref_nn not null,
	created		date default(sysdate)
			constraint rhn_sp_ac_created_nn not null,
	modified	date default(sysdate)
			constraint rhn_sp_ac_modified_nn not null
)
	storage ( freelists 16 )
	initrans 32;
create index rhn_sp_ac_said_paid_pref
	on rhnServerPackageArchCompat(
		server_arch_id, package_arch_id, preference)
	tablespace [[64k_tbs]]
	storage ( freelists 16 )
	initrans 32;
alter table rhnServerPackageArchCompat add constraint rhn_sp_ac_said_paid_uq
	unique ( server_arch_id, package_arch_id );
create index rhn_sp_ac_paid_said_pref
	on rhnServerPackageArchCompat(
	 	package_arch_id, server_arch_id, preference)
	tablespace [[64k_tbs]]
	storage ( freelists 16 )
	initrans 32;
alter table rhnServerPackageArchCompat add constraint rhn_sp_ac_pref_said_uq
	unique ( preference, server_arch_id )
	using index tablespace [[64k_tbs]];
create or replace trigger
rhn_sp_ac_mod_trig
before insert or update on rhnServerPackageArchCompat
for each row
begin
        :new.modified := sysdate;
end;
/
show errors

select '../rhn/tables/rhnServerPackageArchCompat_data.sql' sql_file from dual;
-- SQL relevant contents from file ../rhn/tables/rhnServerPackageArchCompat_data.sql
insert into rhnServerPackageArchCompat
(server_arch_id, package_arch_id, preference) values
(LOOKUP_SERVER_ARCH('i486-redhat-linux'), LOOKUP_PACKAGE_ARCH('noarch'), 1000);
insert into rhnServerPackageArchCompat
(server_arch_id, package_arch_id, preference) values
(LOOKUP_SERVER_ARCH('i586-redhat-linux'), LOOKUP_PACKAGE_ARCH('i586'), 0);
insert into rhnServerPackageArchCompat
(server_arch_id, package_arch_id, preference) values
(LOOKUP_SERVER_ARCH('i586-redhat-linux'), LOOKUP_PACKAGE_ARCH('i486'), 10);
insert into rhnServerPackageArchCompat
(server_arch_id, package_arch_id, preference) values
(LOOKUP_SERVER_ARCH('i586-redhat-linux'), LOOKUP_PACKAGE_ARCH('i386'), 20);
insert into rhnServerPackageArchCompat
(server_arch_id, package_arch_id, preference) values
(LOOKUP_SERVER_ARCH('i586-redhat-linux'), LOOKUP_PACKAGE_ARCH('noarch'), 1000);
insert into rhnServerPackageArchCompat
(server_arch_id, package_arch_id, preference) values
(LOOKUP_SERVER_ARCH('i686-redhat-linux'), LOOKUP_PACKAGE_ARCH('i686'), 0);
insert into rhnServerPackageArchCompat
(server_arch_id, package_arch_id, preference) values
(LOOKUP_SERVER_ARCH('i686-redhat-linux'), LOOKUP_PACKAGE_ARCH('i586'), 10);
insert into rhnServerPackageArchCompat
(server_arch_id, package_arch_id, preference) values
(LOOKUP_SERVER_ARCH('i686-redhat-linux'), LOOKUP_PACKAGE_ARCH('i486'), 20);
insert into rhnServerPackageArchCompat
(server_arch_id, package_arch_id, preference) values
(LOOKUP_SERVER_ARCH('i686-redhat-linux'), LOOKUP_PACKAGE_ARCH('i386'), 30);
insert into rhnServerPackageArchCompat
(server_arch_id, package_arch_id, preference) values
(LOOKUP_SERVER_ARCH('i686-redhat-linux'), LOOKUP_PACKAGE_ARCH('noarch'), 1000);
insert into rhnServerPackageArchCompat
(server_arch_id, package_arch_id, preference) values
(LOOKUP_SERVER_ARCH('athlon-redhat-linux'), LOOKUP_PACKAGE_ARCH('athlon'), 0);
insert into rhnServerPackageArchCompat
(server_arch_id, package_arch_id, preference) values
(LOOKUP_SERVER_ARCH('athlon-redhat-linux'), LOOKUP_PACKAGE_ARCH('i686'), 10);
insert into rhnServerPackageArchCompat
(server_arch_id, package_arch_id, preference) values
(LOOKUP_SERVER_ARCH('athlon-redhat-linux'), LOOKUP_PACKAGE_ARCH('i586'), 20);
insert into rhnServerPackageArchCompat
(server_arch_id, package_arch_id, preference) values
(LOOKUP_SERVER_ARCH('athlon-redhat-linux'), LOOKUP_PACKAGE_ARCH('i486'), 30);
insert into rhnServerPackageArchCompat
(server_arch_id, package_arch_id, preference) values
(LOOKUP_SERVER_ARCH('athlon-redhat-linux'), LOOKUP_PACKAGE_ARCH('i386'), 40);
insert into rhnServerPackageArchCompat
(server_arch_id, package_arch_id, preference) values
(LOOKUP_SERVER_ARCH('athlon-redhat-linux'), LOOKUP_PACKAGE_ARCH('noarch'), 1000);
insert into rhnServerPackageArchCompat
(server_arch_id, package_arch_id, preference) values
(LOOKUP_SERVER_ARCH('alpha-redhat-linux'), LOOKUP_PACKAGE_ARCH('alpha'), 0);
insert into rhnServerPackageArchCompat
(server_arch_id, package_arch_id, preference) values
(LOOKUP_SERVER_ARCH('alpha-redhat-linux'), LOOKUP_PACKAGE_ARCH('noarch'), 1000);
insert into rhnServerPackageArchCompat
(server_arch_id, package_arch_id, preference) values
(LOOKUP_SERVER_ARCH('alphaev6-redhat-linux'), LOOKUP_PACKAGE_ARCH('alphaev6'), 0);
insert into rhnServerPackageArchCompat
(server_arch_id, package_arch_id, preference) values
(LOOKUP_SERVER_ARCH('alphaev6-redhat-linux'), LOOKUP_PACKAGE_ARCH('alpha'), 10);
insert into rhnServerPackageArchCompat
(server_arch_id, package_arch_id, preference) values
(LOOKUP_SERVER_ARCH('alphaev6-redhat-linux'), LOOKUP_PACKAGE_ARCH('noarch'), 1000);
insert into rhnServerPackageArchCompat
(server_arch_id, package_arch_id, preference) values
(LOOKUP_SERVER_ARCH('ia64-redhat-linux'), LOOKUP_PACKAGE_ARCH('ia64'), 0);
insert into rhnServerPackageArchCompat
(server_arch_id, package_arch_id, preference) values
(LOOKUP_SERVER_ARCH('ia64-redhat-linux'), LOOKUP_PACKAGE_ARCH('i386'), 100);
insert into rhnServerPackageArchCompat
(server_arch_id, package_arch_id, preference) values
(LOOKUP_SERVER_ARCH('ia64-redhat-linux'), LOOKUP_PACKAGE_ARCH('i486'), 200);
insert into rhnServerPackageArchCompat
(server_arch_id, package_arch_id, preference) values
(LOOKUP_SERVER_ARCH('ia64-redhat-linux'), LOOKUP_PACKAGE_ARCH('i586'), 300);
insert into rhnServerPackageArchCompat
(server_arch_id, package_arch_id, preference) values
(LOOKUP_SERVER_ARCH('ia64-redhat-linux'), LOOKUP_PACKAGE_ARCH('i686'), 400);
insert into rhnServerPackageArchCompat
(server_arch_id, package_arch_id, preference) values
(LOOKUP_SERVER_ARCH('ia64-redhat-linux'), LOOKUP_PACKAGE_ARCH('noarch'), 1000);
insert into rhnServerPackageArchCompat
(server_arch_id, package_arch_id, preference) values
(LOOKUP_SERVER_ARCH('sparc-redhat-linux'), LOOKUP_PACKAGE_ARCH('sparc'), 0);
insert into rhnServerPackageArchCompat
(server_arch_id, package_arch_id, preference) values
(LOOKUP_SERVER_ARCH('sparc-redhat-linux'), LOOKUP_PACKAGE_ARCH('noarch'), 1000);
insert into rhnServerPackageArchCompat
(server_arch_id, package_arch_id, preference) values
(LOOKUP_SERVER_ARCH('sparcv9-redhat-linux'), LOOKUP_PACKAGE_ARCH('sparcv9'), 0);
insert into rhnServerPackageArchCompat
(server_arch_id, package_arch_id, preference) values
(LOOKUP_SERVER_ARCH('sparcv9-redhat-linux'), LOOKUP_PACKAGE_ARCH('sparc'), 10);
insert into rhnServerPackageArchCompat
(server_arch_id, package_arch_id, preference) values
(LOOKUP_SERVER_ARCH('sparcv9-redhat-linux'), LOOKUP_PACKAGE_ARCH('noarch'), 1000);
insert into rhnServerPackageArchCompat
(server_arch_id, package_arch_id, preference) values
(LOOKUP_SERVER_ARCH('sparc64-redhat-linux'), LOOKUP_PACKAGE_ARCH('sparc64'), 0);
insert into rhnServerPackageArchCompat
(server_arch_id, package_arch_id, preference) values
(LOOKUP_SERVER_ARCH('sparc64-redhat-linux'), LOOKUP_PACKAGE_ARCH('sparcv9'), 10);
insert into rhnServerPackageArchCompat
(server_arch_id, package_arch_id, preference) values
(LOOKUP_SERVER_ARCH('sparc64-redhat-linux'), LOOKUP_PACKAGE_ARCH('sparc'), 20);
insert into rhnServerPackageArchCompat
(server_arch_id, package_arch_id, preference) values
(LOOKUP_SERVER_ARCH('sparc64-redhat-linux'), LOOKUP_PACKAGE_ARCH('noarch'), 1000);
insert into rhnServerPackageArchCompat
(server_arch_id, package_arch_id, preference) values
(LOOKUP_SERVER_ARCH('s390-redhat-linux'), LOOKUP_PACKAGE_ARCH('s390'), 0);
insert into rhnServerPackageArchCompat
(server_arch_id, package_arch_id, preference) values
(LOOKUP_SERVER_ARCH('s390-redhat-linux'), LOOKUP_PACKAGE_ARCH('noarch'), 1000);
insert into rhnServerPackageArchCompat
(server_arch_id, package_arch_id, preference) values
(LOOKUP_SERVER_ARCH('s390x-redhat-linux'), LOOKUP_PACKAGE_ARCH('s390x'), 0);
insert into rhnServerPackageArchCompat
(server_arch_id, package_arch_id, preference) values
(LOOKUP_SERVER_ARCH('s390x-redhat-linux'), LOOKUP_PACKAGE_ARCH('s390'), 10);
insert into rhnServerPackageArchCompat
(server_arch_id, package_arch_id, preference) values
(LOOKUP_SERVER_ARCH('s390x-redhat-linux'), LOOKUP_PACKAGE_ARCH('noarch'), 1000);
insert into rhnServerPackageArchCompat
(server_arch_id, package_arch_id, preference) values
(LOOKUP_SERVER_ARCH('ppc-redhat-linux'), LOOKUP_PACKAGE_ARCH('ppc'), 0);
insert into rhnServerPackageArchCompat
(server_arch_id, package_arch_id, preference) values
(LOOKUP_SERVER_ARCH('ppc-redhat-linux'), LOOKUP_PACKAGE_ARCH('noarch'), 1000);
insert into rhnServerPackageArchCompat
(server_arch_id, package_arch_id, preference) values
(LOOKUP_SERVER_ARCH('ppc64-redhat-linux'), LOOKUP_PACKAGE_ARCH('ppc64'), 0);
insert into rhnServerPackageArchCompat
(server_arch_id, package_arch_id, preference) values
(LOOKUP_SERVER_ARCH('ppc64-redhat-linux'), LOOKUP_PACKAGE_ARCH('ppc'), 10);
insert into rhnServerPackageArchCompat
(server_arch_id, package_arch_id, preference) values
(LOOKUP_SERVER_ARCH('ppc64-redhat-linux'), LOOKUP_PACKAGE_ARCH('noarch'), 1000);
insert into rhnServerPackageArchCompat
(server_arch_id, package_arch_id, preference) values
(LOOKUP_SERVER_ARCH('pSeries-redhat-linux'), LOOKUP_PACKAGE_ARCH('pSeries'), 0);
insert into rhnServerPackageArchCompat
(server_arch_id, package_arch_id, preference) values
(LOOKUP_SERVER_ARCH('pSeries-redhat-linux'), LOOKUP_PACKAGE_ARCH('ppc64'), 10);
insert into rhnServerPackageArchCompat
(server_arch_id, package_arch_id, preference) values
(LOOKUP_SERVER_ARCH('pSeries-redhat-linux'), LOOKUP_PACKAGE_ARCH('ppc'), 20);
insert into rhnServerPackageArchCompat
(server_arch_id, package_arch_id, preference) values
(LOOKUP_SERVER_ARCH('pSeries-redhat-linux'), LOOKUP_PACKAGE_ARCH('noarch'), 1000);
insert into rhnServerPackageArchCompat
(server_arch_id, package_arch_id, preference) values
(LOOKUP_SERVER_ARCH('iSeries-redhat-linux'), LOOKUP_PACKAGE_ARCH('iSeries'), 0);
insert into rhnServerPackageArchCompat
(server_arch_id, package_arch_id, preference) values
(LOOKUP_SERVER_ARCH('iSeries-redhat-linux'), LOOKUP_PACKAGE_ARCH('ppc64'), 10);
insert into rhnServerPackageArchCompat
(server_arch_id, package_arch_id, preference) values
(LOOKUP_SERVER_ARCH('iSeries-redhat-linux'), LOOKUP_PACKAGE_ARCH('ppc'), 20);
insert into rhnServerPackageArchCompat
(server_arch_id, package_arch_id, preference) values
(LOOKUP_SERVER_ARCH('iSeries-redhat-linux'), LOOKUP_PACKAGE_ARCH('noarch'), 1000);
insert into rhnServerPackageArchCompat
(server_arch_id, package_arch_id, preference) values
(LOOKUP_SERVER_ARCH('x86_64-redhat-linux'), LOOKUP_PACKAGE_ARCH('x86_64'), 0);
insert into rhnServerPackageArchCompat
(server_arch_id, package_arch_id, preference) values
(LOOKUP_SERVER_ARCH('x86_64-redhat-linux'), LOOKUP_PACKAGE_ARCH('athlon'), 100);
insert into rhnServerPackageArchCompat
(server_arch_id, package_arch_id, preference) values
(LOOKUP_SERVER_ARCH('x86_64-redhat-linux'), LOOKUP_PACKAGE_ARCH('i686'), 110);
insert into rhnServerPackageArchCompat
(server_arch_id, package_arch_id, preference) values
(LOOKUP_SERVER_ARCH('x86_64-redhat-linux'), LOOKUP_PACKAGE_ARCH('i586'), 120);
insert into rhnServerPackageArchCompat
(server_arch_id, package_arch_id, preference) values
(LOOKUP_SERVER_ARCH('x86_64-redhat-linux'), LOOKUP_PACKAGE_ARCH('i486'), 130);
insert into rhnServerPackageArchCompat
(server_arch_id, package_arch_id, preference) values
(LOOKUP_SERVER_ARCH('x86_64-redhat-linux'), LOOKUP_PACKAGE_ARCH('i386'), 140);
insert into rhnServerPackageArchCompat
(server_arch_id, package_arch_id, preference) values
(LOOKUP_SERVER_ARCH('x86_64-redhat-linux'), LOOKUP_PACKAGE_ARCH('noarch'), 1000);
insert into rhnServerPackageArchCompat
(server_arch_id, package_arch_id, preference) values
(LOOKUP_SERVER_ARCH('ppc64iseries-redhat-linux'), LOOKUP_PACKAGE_ARCH('ppc64iseries'), 0);
insert into rhnServerPackageArchCompat
(server_arch_id, package_arch_id, preference) values
(LOOKUP_SERVER_ARCH('ppc64iseries-redhat-linux'), LOOKUP_PACKAGE_ARCH('ppc64'), 10);
insert into rhnServerPackageArchCompat
(server_arch_id, package_arch_id, preference) values
(LOOKUP_SERVER_ARCH('ppc64iseries-redhat-linux'), LOOKUP_PACKAGE_ARCH('ppc'), 20);
insert into rhnServerPackageArchCompat
(server_arch_id, package_arch_id, preference) values
(LOOKUP_SERVER_ARCH('ppc64iseries-redhat-linux'), LOOKUP_PACKAGE_ARCH('noarch'), 1000);
insert into rhnServerPackageArchCompat
(server_arch_id, package_arch_id, preference) values
(LOOKUP_SERVER_ARCH('ppc64pseries-redhat-linux'), LOOKUP_PACKAGE_ARCH('ppc64pseries'), 0);
insert into rhnServerPackageArchCompat
(server_arch_id, package_arch_id, preference) values
(LOOKUP_SERVER_ARCH('ppc64pseries-redhat-linux'), LOOKUP_PACKAGE_ARCH('ppc64'), 10);
insert into rhnServerPackageArchCompat
(server_arch_id, package_arch_id, preference) values
(LOOKUP_SERVER_ARCH('ppc64pseries-redhat-linux'), LOOKUP_PACKAGE_ARCH('ppc'), 20);
insert into rhnServerPackageArchCompat
(server_arch_id, package_arch_id, preference) values
(LOOKUP_SERVER_ARCH('ppc64pseries-redhat-linux'), LOOKUP_PACKAGE_ARCH('noarch'), 1000);
commit;

select '../rhn/tables/rhnServerPackage.sql' sql_file from dual;
-- SQL relevant contents from file ../rhn/tables/rhnServerPackage.sql
create table
rhnServerPackage
(
        server_id       number,
        name_id         number,
        evr_id          number 
)
	tablespace [[server_package_tablespace]]
	storage( pctincrease 1 freelists 16 )
	initrans 32;
create sequence rhn_server_package_id_seq;

select '../rhn/tables/rhnServerPackage_constraints.sql' sql_file from dual;
-- SQL relevant contents from file ../rhn/tables/rhnServerPackage_constraints.sql
alter table rhnServerPackage modify server_id
	constraint rhn_serverpackage_sid_nn not null;
alter table rhnServerPackage modify name_id
	constraint rhn_serverpackage_nid_nn not null;
alter table rhnServerPackage modify evr_id
	constraint rhn_serverpackage_eid_nn not null;
alter table rhnServerPackage
	add constraint rhn_serverpackage_sid_fk
	foreign key (server_id) references rhnServer(id) on delete cascade;
alter table rhnServerPackage
	add constraint rhn_serverpackage_nid_fk
	foreign key (name_id) references rhnPackageName(id);
alter table rhnServerPackage
	add constraint rhn_serverpackage_eid_fk
	foreign key (evr_id) references rhnPackageEVR(id);

select '../rhn/tables/rhnServerPackage_indexes.sql' sql_file from dual;
-- SQL relevant contents from file ../rhn/tables/rhnServerPackage_indexes.sql
create index rhn_sp_sne_idx on
        rhnServerPackage(server_id, name_id, evr_id)
	parallel 6
        tablespace [[128m_tbs]]
	storage ( pctincrease 1 freelists 16 )
	initrans 32
	nologging;

select '../rhn/tables/rhnServerPath.sql' sql_file from dual;
-- SQL relevant contents from file ../rhn/tables/rhnServerPath.sql
create table
rhnServerPath
(
	server_id		number
				constraint rhn_serverpath_sid_nn not null
				constraint rhn_serverpath_sid_fk
					references rhnServer(id)
					on delete cascade,
	proxy_server_id		number
				constraint rhn_serverpath_psid_nn not null
				constraint rhn_serverpath_psid_fk
					references rhnServer(id)
					on delete cascade,
	position		number
				constraint rhn_serverpath_pos_nn not null,
	hostname		varchar2(256)
				constraint rhn_serverpath_hostname_nn not null,
	created			date default(sysdate)
				constraint rhn_serverpath_creat_nn not null,
	modified		date default(sysdate)
				constraint rhn_serverpath_mod_nn not null
)
	storage ( freelists 16 )
	initrans 32;
create unique index rhn_serverpath_sid_pos_uq
	on rhnServerPath( server_id, position )
	tablespace [[2m_tbs]]
	storage ( freelists 16 )
	initrans 32;
create unique index rhn_serverpath_psid_sid_uq
	on rhnServerPath( proxy_server_id, server_id )
	tablespace [[2m_tbs]]
	storage ( freelists 16 )
	initrans 32;
create or replace trigger rhn_serverpath_mod_trig
before insert or update on rhnServerPath
for each row
begin
	:new.modified := sysdate;
end;
/
show errors

select '../rhn/tables/rhnServerProfilePackage.sql' sql_file from dual;
-- SQL relevant contents from file ../rhn/tables/rhnServerProfilePackage.sql
create table
rhnServerProfilePackage
(
        server_profile_id       number
	    	    	    	constraint rhn_sprofile_spid_nn not null
	    	    	    	constraint rhn_sprofile_spid_fk
				    	references rhnServerProfile(id)
					on delete cascade,
        name_id                 number
	    	    	    	constraint rhn_sprofile_nid_nn not null
	    	    	    	constraint rhn_sprofile_nid_fk
				    	references rhnPackageName(id),
        evr_id                  number 
	    	    	    	constraint rhn_sprofile_evrid_nn not null
	    	    	    	constraint rhn_sprofile_evrid_fk
				    	references rhnPackageEvr(id)
)
	storage ( freelists 16 )
	initrans 32;
create index rhn_sprof_sp_sne_idx on
        rhnServerProfilePackage(server_profile_id, name_id, evr_id)
	tablespace [[64k_tbs]]
	storage ( freelists 16 )
	initrans 32
	nologging;

select '../rhn/tables/rhnServerProfileType_data.sql' sql_file from dual;
-- SQL relevant contents from file ../rhn/tables/rhnServerProfileType_data.sql
insert into rhnServerProfileType(id, label, name) values (
	rhn_sproftype_id_seq.nextval, 'normal',
	'A normal server profile');
insert into rhnServerProfileType(id, label, name) values (
	rhn_sproftype_id_seq.nextval, 'sync_profile',
	'A server profile associated with a package sync');
commit;

select '../rhn/tables/rhnServerTokenRegs.sql' sql_file from dual;
-- SQL relevant contents from file ../rhn/tables/rhnServerTokenRegs.sql
create table
rhnServerTokenRegs
(
	token_id	number
			constraint rhn_srv_reg_tok_tid_nn not null
			constraint rhn_srv_reg_tok_tid_fk
				references rhnRegToken(id)
				on delete cascade,
	server_id	number
			constraint rhn_srv_reg_tok_sid_nn not null
			constraint rhn_srv_reg_tok_sid_uq unique
				using index tablespace [[64k_tbs]]
			constraint rhn_srv_reg_tok_sid_fk
				references rhnServer(id)
				on delete cascade
)
	storage ( freelists 16 )
	initrans 32;
create index rhn_srv_reg_tok_ts_idx
	on rhnServerTokenRegs(token_id, server_id)
	tablespace [[64k_tbs]]
	storage ( freelists 16 )
	initrans 32
	nologging;

select '../rhn/tables/rhnSnapshotInvalidReason_data.sql' sql_file from dual;
-- SQL relevant contents from file ../rhn/tables/rhnSnapshotInvalidReason_data.sql
insert into rhnSnapshotInvalidReason (id, label, name)
	values (rhn_ssinvalid_id_seq.nextval, 'channel_removed',
		'A channel this snapshot was associated with no longer exists');
insert into rhnSnapshotInvalidReason (id, label, name)
	values (rhn_ssinvalid_id_seq.nextval, 'channel_modified',
		'A channel this snapshot is associated with has been modified');
insert into rhnSnapshotInvalidReason (id, label, name)
	values (rhn_ssinvalid_id_seq.nextval, 'sg_removed',
		'A server group this snapshot was associated with no longer exists');
insert into rhnSnapshotInvalidReason (id, label, name)
	values (rhn_ssinvalid_id_seq.nextval, 'ns_removed',
		'A namespace this snapshot was associated with no longer exists');
insert into rhnSnapshotInvalidReason (id, label, name)
	values (rhn_ssinvalid_id_seq.nextval, 'cr_removed',
		'A config revision this snapshot was associated with no longer exists');
insert into rhnSnapshotInvalidReason (id, label, name)
	values (rhn_ssinvalid_id_seq.nextval, 'cc_removed',
		'A config channel this snapshot was associated with no longer exists');
commit;

select '../rhn/tables/rhnSnapshotPackage.sql' sql_file from dual;
-- SQL relevant contents from file ../rhn/tables/rhnSnapshotPackage.sql
create table
rhnSnapshotPackage
(
	snapshot_id		number
				constraint rhn_snapshotpkg_sid_nn not null,
	nevra_id		number
				constraint rhn_snapshotpkg_nid_nn not null
)
	storage ( freelists 16 )
	initrans 32;
create index rhn_snapshotpkg_sid
    	on rhnSnapshotPackage( snapshot_id )
	tablespace [[8m_tbs]]
	storage ( freelists 16 )
	initrans 32;
create unique index rhn_snapshotpkg_sid_nid_uq
	on rhnSnapshotPackage( snapshot_id, nevra_id )
	tablespace [[32m_tbs]]
	storage ( freelists 16 )
	initrans 32;
create or replace trigger
rhn_snapshotpkg_mod_trig
before insert or update on rhnSnapshotPackage
for each row
begin
	update rhnSnapshot set modified = sysdate where id = :new.snapshot_id;
end;
/
show errors

select '../rhn/tables/rhnSnapshotTag.sql' sql_file from dual;
-- SQL relevant contents from file ../rhn/tables/rhnSnapshotTag.sql
create table
rhnSnapshotTag
(
	snapshot_id	number
			constraint rhn_st_ssid_nn not null
			constraint rhn_st_ssid_fk
				references rhnSnapshot(id)
				on delete cascade,
	tag_id          number
			constraint rhn_st_tid_nn not null
			constraint rhn_st_tid_fk
				references rhnTag(id),
	server_id	number
			constraint rhn_st_sid_fk
				references rhnServer(id)
				on delete cascade,
	created		date default (sysdate)
			constraint rhn_st_created_nn not null,
	modified	date default (sysdate)
			constraint rhn_st_modified_nn not null
);
create unique index rhn_ss_tag_ssid_tid_uq
    	on rhnSnapshotTag(snapshot_id, tag_id);
create unique index rhn_ss_tag_sid_tid_uq
    	on rhnSnapshotTag(server_id, tag_id);
create index rhn_ss_tag_tid_ssid_idx
    	on rhnSnapshotTag(tag_id, snapshot_id);
create index rhn_ss_tag_tid_sid_idx
    	on rhnSnapshotTag(tag_id, server_id);
create or replace trigger
rhn_ss_tag_mod_trig
before insert or update on rhnSnapshotTag
for each row
begin
        :new.modified := sysdate;
end;
/
show errors

select '../rhn/tables/rhnSNPErrataQueue.sql' sql_file from dual;
-- SQL relevant contents from file ../rhn/tables/rhnSNPErrataQueue.sql
create table rhnSNPErrataQueue
(
    	errata_id       number
	    	    	constraint rhn_snpErrQueue_eid_nn not null
	    	    	constraint rhn_snpErrQueue_eid_fk
				references rhnErrata(id)
				on delete cascade,
	processed	number default(0) -- this should get a check as well?
			constraint rhn_snpErrQueue_processed_nn not null
)
	storage ( freelists 16 )
	initrans 32;
create unique index rhn_snpErrQueue_eid_uq
	on rhnSNPErrataQueue(errata_id)
	tablespace [[64k_tbs]]
	storage ( freelists 16 )
	initrans 32;

select '../rhn/tables/rhnSNPServerQueue.sql' sql_file from dual;
-- SQL relevant contents from file ../rhn/tables/rhnSNPServerQueue.sql
create table rhnSNPServerQueue
(
    	server_id       number
	    	    	constraint rhn_sec_np_sid_nn not null
	    	    	constraint rhn_sec_np_sid_fk
				references rhnServer(id) on delete cascade,
	processed	number default(0)
			constraint rhn_sec_np_processed_nn not null
)
	storage ( freelists 16 )
	initrans 32;

select '../rhn/tables/rhnSurvey.sql' sql_file from dual;
-- SQL relevant contents from file ../rhn/tables/rhnSurvey.sql
create sequence rhn_survey_id_seq;
create table
rhnSurvey
(
	id			number
				constraint rhn_survey_id_nn not null,
	label			varchar2(64)
				constraint rhn_survey_label_nn not null,
	class			varchar2(64)
				constraint rhn_survey_class_nn not null,
	filename		varchar2(256),
	active			char(1) default('Y')
				constraint rhn_survey_active_nn not null
				constraint rhn_survey_active_ck check
					(active in ('Y','N'))
)
	storage ( freelists 16 )
	initrans 32;
create index rhn_survey_id_label_idx
	on rhnSurvey ( id, label )
	tablespace [[2m_tbs]]
	storage ( freelists 16 )
	initrans 32;
alter table rhnSurvey add
	constraint rhn_survey_id_pk primary key ( id );
create index rhn_survey_label_id_idx
	on rhnSurvey ( label, id )
	tablespace [[2m_tbs]]
	storage ( freelists 16 )
	initrans 32;
alter table rhnSurvey add
	constraint rhn_survey_label_uq unique ( label );

select '../rhn/tables/rhnSurveyQuestion.sql' sql_file from dual;
-- SQL relevant contents from file ../rhn/tables/rhnSurveyQuestion.sql
create sequence rhn_squestion_id_seq;
create table
rhnSurveyQuestion
(
	id			number
				constraint rhn_squestion_id_nn not null,
	survey_id		number
				constraint rhn_squestion_sid_nn not null
				constraint rhn_squestion_sid_fk
					references rhnSurvey(id),
	label			varchar2(64)
				constraint rhn_squestion_label_nn not null
)
	storage ( freelists 16 )
	initrans 32;
create index rhn_squestion_sid_id_idx
	on rhnSurveyQuestion ( survey_id, id )
	tablespace [[2m_tbs]]
	storage ( freelists 16 )
	initrans 32;
alter table rhnSurveyQuestion add
	constraint rhn_squestion_id_pk primary key ( id );
create index rhn_squestion_label_sid_id_idx
	on rhnSurveyQuestion ( label, survey_id, id )
	tablespace [[2m_tbs]]
	storage ( freelists 16 )
	initrans 32;
alter table rhnSurveyQuestion add
	constraint rhn_squestion_label_sid_uq unique ( label, survey_id );

select '../rhn/tables/rhnSurveyQuestionResponse.sql' sql_file from dual;
-- SQL relevant contents from file ../rhn/tables/rhnSurveyQuestionResponse.sql
create table
rhnSurveyQuestionResponse
(
	question_id		number
				constraint rhn_sqresponse_qid_nn not null
				constraint rhn_sqresponse_qid_fk
					references rhnSurveyQuestion(id)
					on delete cascade,
	user_id			number
				constraint rhn_sqresponse_uid_nn not null
				constraint rhn_sqresponse_uid_fk
					references web_contact(id)
					on delete cascade,
	response		varchar2(4000)
)
	storage ( freelists 16 )
	initrans 32;
create index rhn_sqresponse_qid_uid_idx
	on rhnSurveyQuestionResponse ( question_id, user_id )
	tablespace [[8m_tbs]]
	storage ( freelists 16 )
	initrans 32;
create index rhn_sqresponse_uid_idx
	on rhnSurveyQuestionResponse ( user_id )
	tablespace [[4m_tbs]]
	storage ( freelists 16 )
	initrans 32
	nologging;

select '../rhn/tables/rhnTaskQueue.sql' sql_file from dual;
-- SQL relevant contents from file ../rhn/tables/rhnTaskQueue.sql
create table 
rhnTaskQueue
(
	org_id		number
			constraint rhn_task_queue_org_id_nn not null
			constraint rhn_task_queue_org_id_fk
				references web_customer(id)
				on delete cascade,
	task_name	VARCHAR2(64)
			constraint rhn_task_queue_task_name_nn not null,
	task_data	number,
	priority	number default 0,
	earliest	date default sysdate
			constraint rhn_task_queue_earliest_nn not null
)
	storage ( freelists 16 )
	initrans 32
	nologging;
create index rhn_task_queue_org_task_idx
	on rhnTaskQueue(org_id, task_name)
	tablespace [[64k_tbs]]
	storage ( freelists 16 )
	initrans 32
	nologging;

select '../rhn/tables/rhnTemplateCategory.sql' sql_file from dual;
-- SQL relevant contents from file ../rhn/tables/rhnTemplateCategory.sql
create sequence rhn_template_cat_id_seq;
create table
rhnTemplateCategory
(
	id		number
			constraint rhn_template_cat_id_nn not null,
	label		varchar2(64)
			constraint rhn_template_cat_label_nn not null,
	description	varchar2(512)
			constraint rhn_template_cat_desc_nn not null,
	created		date default(sysdate)
			constraint rhn_template_cat_created_nn not null,
	modified	date default(sysdate)
			constraint rhn_template_cat_modified_nn not null
)
	storage ( freelists 16 )
	initrans 32;
create index rhn_template_cat_id_idx
	on rhnTemplateCategory ( id )
	tablespace [[64k_tbs]]
	storage ( freelists 16 )
	initrans 32;
alter table rhnTemplateCategory add constraint rhn_template_cat_id_pk
	primary key ( id );
create index rhn_template_cat_label_id_idx
	on rhnTemplateCategory ( label, id )
	tablespace [[64k_tbs]]
	storage ( freelists 16 )
	initrans 32;
alter table rhnTemplateCategory add constraint rhn_template_cat_label_uq
	unique ( label );
create or replace trigger
rhn_template_cat_mod_trig
before insert or update on rhnTemplateCategory
for each row
begin
	:new.modified := sysdate;
end;
/
show errors

select '../rhn/tables/rhnTemplateCategory_data.sql' sql_file from dual;
-- SQL relevant contents from file ../rhn/tables/rhnTemplateCategory_data.sql
INSERT INTO rhnTemplateCategory (id, label, description) 
     VALUES (rhn_template_cat_id_seq.nextval, 'org_strings', 'Organization specific strings.');
INSERT INTO rhnTemplateCategory (id, label, description)
     VALUES (rhn_template_cat_id_seq.nextval, 'email_strings', 'Strings appearing in e-mail sent to users.');

select '../rhn/tables/rhnTemplateString.sql' sql_file from dual;
-- SQL relevant contents from file ../rhn/tables/rhnTemplateString.sql
create sequence rhn_template_str_id_seq;
create table
rhnTemplateString
(
	id		number
			constraint rhn_template_str_id_nn not null,
	category_id	number
			constraint rhn_template_str_cid_nn not null
			constraint rhn_template_str_cid_fk
				references rhnTemplateCategory(id),
	label		varchar2(64)
			constraint rhn_template_str_key_nn not null,
	value		varchar2(4000),
	description	varchar2(512)
			constraint rhn_template_str_desc_nn not null,
	created		date default(sysdate)
			constraint rhn_template_str_created_nn not null,
	modified	date default(sysdate)
			constraint rhn_template_str_modified_nn not null
)
	storage ( freelists 16 )
	initrans 32;
create index rhn_template_str_icl_idx
	on rhnTemplateString ( id, category_id, label )
	tablespace [[4m_tbs]]
	storage ( freelists 16 )
	initrans 32;
alter table rhnTemplateString add constraint rhn_template_str_id_pk
	primary key ( id );
create index rhn_template_str_cid_label_idx
	on rhnTemplateString ( category_id, label )
	tablespace [[2m_tbs]]
	storage ( freelists 16 )
	initrans 32;
alter table rhnTemplateString add constraint rhn_template_str_cid_label_uq
	unique ( category_id, label );
create or replace trigger
rhn_template_str_mod_trig
before insert or update on rhnTemplateString
for each row
begin
	:new.modified := sysdate;
end;
/
show errors

select '../rhn/tables/rhnTemplateString_data.sql' sql_file from dual;
-- SQL relevant contents from file ../rhn/tables/rhnTemplateString_data.sql
SET SQLBLANKLINES ON
SET SCAN OFF
INSERT INTO rhnTemplateString (id, category_id, label, value, description) 
     VALUES (rhn_template_str_id_seq.nextval,
             (SELECT TC.id 
                FROM rhnTemplateCategory TC
	       WHERE TC.label = 'email_strings'),
	     'email_footer', '-' || '-the Red Hat Network Team', 'Footer for RHN e-mail');
INSERT INTO rhnTemplateString (id, category_id, label, value, description) 
     VALUES (rhn_template_str_id_seq.nextval,
             (SELECT TC.id 
                FROM rhnTemplateCategory TC
	       WHERE TC.label = 'email_strings'),
	     'email_account_info', '
Account Information:
  Your RHN login:         <login />
  Your RHN email address: <email-address />', 'Account info lines for RHN e-mail');

select '../rhn/tables/rhnTextMessage.sql' sql_file from dual;
-- SQL relevant contents from file ../rhn/tables/rhnTextMessage.sql
create table
rhnTextMessage
(
	message_id	number
			constraint rhn_tm_message_id_nn not null
			constraint rhn_tm_message_id_fk
				references rhnMessage(id)
				on delete cascade,
	message_body	varchar2(4000) -- the contents of the message
			constraint rhn_tm_message_body_nn not null,
	created		date default (sysdate)
			constraint rhn_tm_created_nn not null,
	modified	date default (sysdate)
			constraint rhn_tm_modified_nn not null
)
	storage ( freelists 16 )
	initrans 32;
create or replace trigger
rhn_tm_mod_trig
before insert or update on rhnTextMessage
for each row
begin
	:new.modified := sysdate;
end;
/
show errors

select '../rhn/tables/rhnTinyURL.sql' sql_file from dual;
-- SQL relevant contents from file ../rhn/tables/rhnTinyURL.sql
CREATE TABLE
rhnTinyURL
(
        token           varchar2(64)
                        constraint rhn_tu_token_nn not null,
        url             varchar2(512)
                        constraint rhn_tu_url_nn not null,
        enabled         varchar2(1)
                        constraint rhn_tu_enabled_nn not null
                        constraint rhn_tu_enabled_ck
                                check (enabled in ('Y','N')),
        created         date default (sysdate)
                        constraint rhn_tu_created_nn not null,
        expires         date default (sysdate)
                        constraint rhn_tu_expires_nn not null
)
        storage ( freelists 16 )
        initrans 32;
create unique index rhn_tu_token_uq
        on rhnTinyURL(token)
        tablespace [[2m_tbs]]
        storage ( freelists 16 )
        initrans 32;

select '../rhn/tables/rhnTransactionElement.sql' sql_file from dual;
-- SQL relevant contents from file ../rhn/tables/rhnTransactionElement.sql
create table
rhnTransactionElement
(
	transaction_id		number
				constraint rhn_transelem_tid_nn not null
				constraint rhn_transelem_tid_fk
					references rhnTransaction(id)
					on delete cascade,
	transaction_package_id	number
				constraint rhn_transelem_tpid_nn not null
				constraint rhn_transelem_tpid_fk
					references rhnTransactionPackage(id)
)
	storage ( freelists 16 )
	initrans 32;
create unique index rhn_transelem_tid_tpid_uq
	on rhnTransactionElement(transaction_id,transaction_package_id)
	tablespace [[8m_tbs]]
	storage ( freelists 16 )
	initrans 32;

select '../rhn/tables/rhnTransactionOperation_data.sql' sql_file from dual;
-- SQL relevant contents from file ../rhn/tables/rhnTransactionOperation_data.sql
insert into rhnTransactionOperation (id, label) values (1,'insert');
insert into rhnTransactionOperation (id, label) values (2,'delete');
insert into rhnTransactionOperation (id, label) values (3,'upgrade');

select '../rhn/tables/rhnTransactionOperation_triggers.sql' sql_file from dual;
-- SQL relevant contents from file ../rhn/tables/rhnTransactionOperation_triggers.sql
create or replace trigger
rhn_transop_mod_trig
before insert or update on rhnTransactionOperation
for each row
begin
	:new.modified := sysdate;
end;
/
show errors

select '../rhn/tables/rhnTransaction_triggers.sql' sql_file from dual;
-- SQL relevant contents from file ../rhn/tables/rhnTransaction_triggers.sql
create or replace trigger
rhn_trans_mod_trig
before insert or update on rhnTransaction
for each row
begin
	:new.modified := sysdate;
end;
/
show errors

select '../rhn/tables/rhnUserDefaultSystemGroups.sql' sql_file from dual;
-- SQL relevant contents from file ../rhn/tables/rhnUserDefaultSystemGroups.sql
create table
rhnUserDefaultSystemGroups
(
	user_id		number
			constraint rhn_udsg_uid_nn not null
			constraint rhn_udsg_uid_fk
				references web_contact(id)
				on delete cascade,
	system_group_id	number
			constraint rhn_udsg_cid_nn not null
			constraint rhn_udsg_cidffk
				references rhnServerGroup(id)
				on delete cascade
)
	storage ( freelists 16 )
	initrans 32;
create unique index rhn_udsg_uid_sgid_idx
	on rhnUserDefaultSystemGroups(user_id, system_group_id)
	tablespace [[2m_tbs]]
	storage ( freelists 16 )
	initrans 32;
create index rhn_udsg_sgid_uid_idx
	on rhnUserDefaultSystemGroups(system_group_id, user_id)
	tablespace [[2m_tbs]]
	storage ( freelists 16 )
	initrans 32;

select '../rhn/tables/rhnUserGroup_indexes.sql' sql_file from dual;
-- SQL relevant contents from file ../rhn/tables/rhnUserGroup_indexes.sql
create unique index rhn_ug_oid_name_uq
	on rhnUserGroup(org_id, name)
	tablespace [[32m_tbs]]
	storage ( pctincrease 1 freelists 16 )
	initrans 32;
create index rhn_ug_id_name_org
	on rhnUserGroup(id, name, org_id)
	parallel 6
	tablespace [[32m_tbs]]
	storage ( pctincrease 1 freelists 16 )
	initrans 32
	nologging;
create index rhn_ug_org_id_name_idx
	on rhnUserGroup(org_id, id, name)
	parallel 6
	tablespace [[32m_tbs]]
	storage ( pctincrease 1 freelists 16 )
	initrans 32
	nologging;
create index rhn_ug_org_id_type_idx
	on rhnUserGroup(group_type, id)
	parallel 6
	tablespace [[8m_tbs]]
	storage ( pctincrease 1 freelists 16 )
	initrans 32
	nologging;
create index rhn_ug_org_id_gtype_idx
	on rhnUserGroup(org_id, group_type, id)
	parallel 6
	tablespace [[8m_tbs]]
	storage ( pctincrease 1 freelists 16 )
	initrans 32
	nologging;

select '../rhn/tables/rhnUserGroupMembers.sql' sql_file from dual;
-- SQL relevant contents from file ../rhn/tables/rhnUserGroupMembers.sql
create table
rhnUserGroupMembers
(
	user_id		number
			constraint rhn_ugmembers_uid_nn not null
			constraint rhn_ugmembers_uid_fk
				references web_contact(id)
				on delete cascade,
	user_group_id	number
			constraint rhn_ugmembers_ugid_nn not null
			constraint rhn_ugmembers_ugid_fk
				references rhnUserGroup(id),
	created		date default(sysdate)
			constraint rhn_ugmembers_created_nn not null,
	modified	date default(sysdate)
			constraint rhn_ugmembers_modified_nn not null
)
	storage ( pctincrease 1 freelists 16 )
	initrans 32;

select '../rhn/tables/rhnUserGroupMembers_indexes.sql' sql_file from dual;
-- SQL relevant contents from file ../rhn/tables/rhnUserGroupMembers_indexes.sql
create unique index rhn_ugmembers_uid_ugid_uq
	on rhnUserGroupMembers(user_id, user_group_id)
	parallel 6
	tablespace [[8m_tbs]]
	storage ( pctincrease 1 freelists 16 )
	initrans 32;
create index rhn_ugmembers_ugid_uid_idx
	on rhnUserGroupMembers(user_group_id, user_id)
	parallel 6
	tablespace [[8m_tbs]]
	storage ( pctincrease 1 freelists 16 )
	initrans 32
	nologging;

select '../rhn/tables/rhnUserGroupMembers_triggers.sql' sql_file from dual;
-- SQL relevant contents from file ../rhn/tables/rhnUserGroupMembers_triggers.sql
create or replace trigger
rhn_ug_member_mod_trig
before insert or update on rhnUserGroupMembers
for each row
declare
        ug              rhnUserGroup%ROWTYPE;
begin
        :new.modified := sysdate;
        if inserting then
                select
                        * into ug
                from
                        rhnUserGroup
                where
                        id = :new.user_group_id;
                if ug.max_members is not null and
                ug.current_members+1 > ug.max_members then
                        rhn_exception.raise_exception('usergroup_max_members');
                end if;
                update rhnUserGroup
                set current_members = current_members + 1
                where id = :new.user_group_id;
        end if;
end;
/
show errors
CREATE OR REPLACE TRIGGER
rhn_user_group_org_mapping
BEFORE INSERT OR UPDATE ON rhnUserGroupMembers
FOR EACH ROW
DECLARE
        same_org        NUMBER;
BEGIN
        same_org := 0;
        SELECT 1 INTO same_org
          FROM web_contact U, rhnUserGroup UG
         WHERE UG.org_id = U.org_id
           AND U.id = :new.user_id
           AND UG.id = :new.user_group_id;
        IF same_org = 0 THEN
          rhn_exception.raise_exception('ugm_insert_diff_orgs');
        END IF;
EXCEPTION
        WHEN NO_DATA_FOUND THEN
          rhn_exception.raise_exception('ugm_insert_diff_orgs');
END;
/
SHOW ERRORS
create or replace trigger
rhn_ug_member_del_trig
before delete on rhnUserGroupMembers
for each row
begin
        update rhnUserGroup
        set current_members = current_members - 1
        where id = :old.user_group_id;
end;
/
show errors
create or replace trigger
rhn_ugm_applicant_fix
after delete on rhnUserGroupMembers
for each row
declare
    	group_type_val    NUMBER;
    	group_label_val   rhnUserGroupType.label%TYPE;	
begin
    	SELECT group_type INTO group_type_val
	  FROM rhnUserGroup
	 WHERE id = :old.user_group_id;
	IF group_type_val IS NOT NULL
	THEN
	    SELECT label INTO group_label_val
	      FROM rhnUserGroupType
	     WHERE id = group_type_val;
	    IF group_label_val = 'org_applicant'
	    THEN
	    	UPDATE web_contact SET password = old_password WHERE id = :old.user_id;
	    END IF;
	END IF;
end;
/
show errors

select '../rhn/tables/rhnUserGroup_sequences.sql' sql_file from dual;
-- SQL relevant contents from file ../rhn/tables/rhnUserGroup_sequences.sql
create sequence rhn_user_group_id_seq;

select '../rhn/tables/rhnUserGroup_triggers.sql' sql_file from dual;
-- SQL relevant contents from file ../rhn/tables/rhnUserGroup_triggers.sql
create or replace trigger
rhn_user_group_mod_trig
before insert or update on rhnUserGroup
for each row
begin
        :new.modified := sysdate;
end;
/
show errors
create or replace trigger
rhn_ug_del_trig
before delete on rhnUserGroup
for each row
begin
	IF :old.group_type IS NOT NULL
	THEN
	    	rhn_exception.raise_exception('ug_delete_typed');
	END IF;
end;
/
show errors

select '../rhn/tables/rhnUserGroupType_data.sql' sql_file from dual;
-- SQL relevant contents from file ../rhn/tables/rhnUserGroupType_data.sql
insert into rhnUserGroupType (id, label, name) values (
	rhn_usergroup_type_seq.nextval,
	'org_applicant',
	'Organization Applicant'
);
insert into rhnUserGroupType (id, label, name) values (
	rhn_usergroup_type_seq.nextval,
	'channel_admin',
	'Channel Administrator'
);
insert into rhnUserGroupType (id, label, name) values (
	rhn_usergroup_type_seq.nextval,
	'rhn_support',
	'Red Hat Network Support Admin'
);
insert into rhnUserGroupType (id, label, name) values (
	rhn_usergroup_type_seq.nextval,
	'rhn_superuser',
	'Red Hat Network Superuser'
);
insert into rhnUserGroupType (id, label, name) values (
	rhn_usergroup_type_seq.nextval,
	'coma_admin',
	'Coma CMS Admin'
);
insert into rhnUserGroupType (id, label, name) values (
	rhn_usergroup_type_seq.nextval,
	'coma_author',
	'Coma CMS Author'
);
insert into rhnUserGroupType (id, label, name) values (
	rhn_usergroup_type_seq.nextval,
	'coma_publisher',
	'Coma CMS Publisher'
);
INSERT
  INTO rhnUserGroupType
       (id, label, name)
VALUES (rhn_usergroup_type_seq.nextval, 'config_admin', 'Configuration Administrator');
commit;

select '../rhn/tables/rhnUserInfo.sql' sql_file from dual;
-- SQL relevant contents from file ../rhn/tables/rhnUserInfo.sql
create table 
rhnUserInfo
(
        user_id		number
                        constraint rhn_user_info_user_nn not null
                        constraint rhn_user_info_user_fk
                                references web_contact(id) on delete cascade,
	no_clear_sets	number default(0)
			constraint rhn_user_info_clearsets_nn not null,
	page_size	number default(20)
			constraint rhn_user_info_pagesize_nn not null,
	email_notify	number default(1)
			constraint rhn_user_info_notify_nn not null,
	bad_email	number default(0)
			constraint rhn_user_info_bademail_nn not null,
	tz_offset       number default(-5)
	    	    	constraint rhn_user_info_tzoffset_nn not null
			constraint rhn_user_info_tzoffset_ck
				check (tz_offset >= -11 and tz_offset <= 13),
	show_applied_errata
			char(1) default('N')
			constraint rhn_user_info_sea_nn not null
			constraint rhn_user_info_sea_ck check
				(show_applied_errata in ('Y','N')),
	show_system_group_list
			char(1) default('N')
			constraint rhn_user_info_ssgl_nn not null
			constraint rhn_user_info_ssgl_ck check
				(show_system_group_list in ('Y','N')),
	agreed_to_terms
			char(1) default('N')
			constraint rhn_user_info_agreed_nn not null
			constraint rhn_user_info_agreed_ck check
				(agreed_to_terms in ('Y','N')),
	use_pam_authentication
			char(1) default('N')
			constraint rhn_user_info_pam_nn not null
			constraint rhn_user_info_pam_ck check
				(use_pam_authentication in ('Y','N')),
	last_logged_in 	date,
	created		date default(sysdate)
			constraint rhn_user_info_created_nn not null,
	modified	date default(sysdate)
			constraint rhn_user_info_modified_nn not null
)
	storage ( freelists 16 )
	initrans 32;
create index rhn_user_info_uid_email_idx
	on rhnUserInfo ( user_id, email_notify )
	tablespace [[4m_tbs]]
	storage ( pctincrease 1 freelists 16 )
	initrans 32;
alter table rhnUserInfo add
	constraint rhn_user_info_uid_uq unique ( user_id );
create or replace trigger
rhn_user_info_mod_trig
before insert or update on rhnUserInfo
for each row
begin
	:new.modified := sysdate;
end;
/
show errors

select '../rhn/tables/rhnUserMessageStatus.sql' sql_file from dual;
-- SQL relevant contents from file ../rhn/tables/rhnUserMessageStatus.sql
create table
rhnUserMessageStatus
(
	id		number
			constraint rhn_um_status_id_nn not null
			constraint rhn_um_status_id_pk primary key
				using index tablespace [[64k_tbs]],
	label		varchar2(48)
			constraint rhn_um_status_label_nn not null
)
	storage ( freelists 16 )
	initrans 32;
create sequence rhn_um_status_id_seq;
create unique index rhn_um_status_label_uq
	on rhnUserMessageStatus(label)
	tablespace [[64k_tbs]]
	storage ( freelists 16 )
	initrans 32;
create index rhn_um_status_label_id_idx
	on rhnUserMessageStatus(label,id)
	tablespace [[64k_tbs]]
	storage ( freelists 16 )
	initrans 32;

select '../rhn/tables/rhnUserMessage.sql' sql_file from dual;
-- SQL relevant contents from file ../rhn/tables/rhnUserMessage.sql
create table
rhnUserMessage
(
	user_id		number
			constraint rhn_um_user_id_nn not null
			constraint rhn_um_user_id_fk
				references web_contact(id),
	message_id	number
			constraint rhn_um_message_id_nn not null
			constraint rhn_um_message_id_fk
				references rhnMessage(id)
				on delete cascade,
	status		number
			constraint rhn_um_status_nn not null
			constraint rhn_um_status_fk
				references rhnUserMessageStatus(id)
)
	storage ( freelists 16 )
	initrans 32;
create unique index rhn_um_uid_mid_uq
	on rhnUserMessage(user_id, message_id)
	tablespace [[64k_tbs]]
	storage ( freelists 16 )
	initrans 32;

select '../rhn/tables/rhnUserMessageStatus_data.sql' sql_file from dual;
-- SQL relevant contents from file ../rhn/tables/rhnUserMessageStatus_data.sql
insert into rhnUserMessageStatus values (
	rhn_um_status_id_seq.nextval, 'New'
);
insert into rhnUserMessageStatus values (
	rhn_um_status_id_seq.nextval, 'Viewed'
);
insert into rhnUserMessageStatus values (
	rhn_um_status_id_seq.nextval, 'Archived'
);
commit;

select '../rhn/tables/rhnUserMessageType.sql' sql_file from dual;
-- SQL relevant contents from file ../rhn/tables/rhnUserMessageType.sql
create table
rhnUserMessageType
(
	id		number
			constraint rhn_um_type_id_nn not null
			constraint rhn_um_type_pk primary key
				using index tablespace [[64k_tbs]],
	label		varchar2(48)
			constraint rhn_um_type_label_nn not null,
	name		varchar2(96)
			constraint rhn_um_type_name_nn not null
)
	storage ( freelists 16 )
	initrans 32;
create unique index rhn_um_type_label_uq
	on rhnUserMessageType(label)
	tablespace [[64k_tbs]]
	storage ( freelists 16 )
	initrans 32;
create unique index rhn_um_type_name_uq
	on rhnUserMessageType(name)
	tablespace [[64k_tbs]]
	storage ( freelists 16 )
	initrans 32;

select '../rhn/tables/rhnUserReserved.sql' sql_file from dual;
-- SQL relevant contents from file ../rhn/tables/rhnUserReserved.sql
create table
rhnUserReserved
(
	login		varchar2(64)
			constraint rhn_user_res_login_nn not null,
	login_uc	varchar2(64)
			constraint rhn_user_res_login_uc_nn not null,
	password	varchar2(38)
			constraint rhn_user_res_pwd_nn not null,
        created         date default(sysdate)
			constraint rhn_user_res_created_nn not null,
        modified        date default(sysdate)
			constraint rhn_user_res_modified_nn not null
)
	storage ( freelists 16 )
	initrans 32;
create unique index rhn_user_res_login_uc_uq
	on rhnUserReserved(login_uc)
	tablespace [[64k_tbs]]
	storage ( freelists 16 )
	initrans 32;
create or replace trigger
rhn_user_res_mod_trig
before insert or update on rhnUserreserved
for each row
begin
	:new.login_uc := upper(:new.login);
        :new.modified := sysdate;
end;
/
show errors

select '../rhn/tables/rhnUserServerGroupPerms.sql' sql_file from dual;
-- SQL relevant contents from file ../rhn/tables/rhnUserServerGroupPerms.sql
create table
rhnUserServerGroupPerms
(
        user_id         number
                        constraint rhn_usgp_user_nn not null
                        constraint rhn_usgp_user_fk
                                references web_contact(id) on delete cascade,
        server_group_id number
                        constraint rhn_usgp_server_nn not null
                        constraint rhn_usgp_server_fk
                                references rhnServerGroup(id) on delete cascade,
        created         date default(sysdate)
                        constraint rhn_usgp_created_nn not null,
        modified        date default(sysdate)
                        constraint rhn_usgp_modified_nn not null
)
	storage ( freelists 16 )
	initrans 32;
create UNIQUE index rhn_usgp_u_sg_p_uq
	on rhnUserServerGroupPerms(user_id, server_group_id)
        tablespace [[4m_tbs]]
	storage ( freelists 16 )
	initrans 32;
create index rhn_usgp_sg_u_p_idx
        on rhnUserServerGroupPerms(server_group_id, user_id)
        tablespace [[4m_tbs]]
	storage ( freelists 16 )
	initrans 32
	nologging;

select '../rhn/tables/rhnUserServerPrefs.sql' sql_file from dual;
-- SQL relevant contents from file ../rhn/tables/rhnUserServerPrefs.sql
create table
rhnUserServerPrefs
(
        user_id		number
                        constraint rhn_userServerPrefs_uid_nn not null
                        constraint rhn_userServerPrefs_uid_fk
                                references web_contact(id)
				on delete cascade,
        server_id	number
                        constraint rhn_userServerPrefs_sid_nn not null
                        constraint rhn_userServerPrefs_sid_fk
                                references rhnServer(id) on delete cascade,
        name            varchar2(64)
                        constraint rhn_userServerPrefs_name_nn not null,
        value           varchar2(1)
                        constraint rhn_userServerPrefs_value_nn not null,
        created         date default(sysdate)
                        constraint rhn_userServerPrefs_created_nn not null,
        modified        date default(sysdate)
                        constraint rhn_userServerPrefs_mod_nn not null
)
	storage ( freelists 16 )
	initrans 32;
create unique index rhn_usprefs_uid_sid_n_uq
	on rhnUserServerPrefs(user_id, server_id, name)
	tablespace [[2m_tbs]]
	storage ( freelists 16 )
	initrans 32;
create index rhn_usprefs_n_sid_uid_idx
	on rhnUserServerPrefs(name, server_id, user_id)
	tablespace [[2m_tbs]]
	storage ( freelists 16 )
	initrans 32
	nologging;
create index rhn_usprefs_sid_uid_n_idx
	on rhnUserServerPrefs(server_id, user_id, name)
	tablespace [[2m_tbs]]
	storage ( freelists 16 )
	initrans 32
	nologging;
create or replace trigger
rhn_u_s_prefs_mod_trig
before insert or update on rhnUserServerPrefs
for each row
begin
        :new.modified := sysdate;
        :new.value := upper(:new.value);
end;
/
show errors

select '../rhn/tables/rhnUserSurveyStatusType.sql' sql_file from dual;
-- SQL relevant contents from file ../rhn/tables/rhnUserSurveyStatusType.sql
create sequence rhn_usurveystype_id_seq;
create table
rhnUserSurveyStatusType
(
	id		number
			constraint rhn_usurveystype_id_nn not null,
	label		varchar2(32)
			constraint rhn_usurveystype_label_nn not null
)
	storage ( freelists 16 )
	initrans 32;
insert into rhnUserSurveyStatusType values
	( rhn_usurveystype_id_seq.nextval, 'viewed' );
insert into rhnUserSurveyStatusType values
	( rhn_usurveystype_id_seq.nextval, 'partial' );
insert into rhnUserSurveyStatusType values
	( rhn_usurveystype_id_seq.nextval, 'complete' );
insert into rhnUserSurveyStatusType values
	( rhn_usurveystype_id_seq.nextval, 'scheduled' );
create index rhn_usurveystype_id_label_idx
	on rhnUserSurveyStatusType ( id, label )
	tablespace [[64k_tbs]]
	storage ( freelists 16 )
	initrans 32;
alter table rhnUserSurveyStatusType add constraint
	rhn_usurveystype_id_pk primary key ( id );
create index rhn_usurveystype_label_id_idx
	on rhnUserSurveyStatusType ( label, id )
	tablespace [[64k_tbs]]
	storage ( freelists 16 )
	initrans 32;
alter table rhnUserSurveyStatusType add constraint 
	rhn_usurveystype_label_uq unique ( label );

select '../rhn/tables/rhnUserSurveyStatus.sql' sql_file from dual;
-- SQL relevant contents from file ../rhn/tables/rhnUserSurveyStatus.sql
create table
rhnUserSurveyStatus
(
	user_id			number
				constraint rhn_usurveystatus_uid_nn not null
				constraint rhn_usurveystatus_uid_fk
					references web_contact(id)
					on delete cascade,
	survey_id		number
				constraint rhn_usurveystatus_sid_nn not null
				constraint rhn_usurveystatus_sid_fk
					references rhnSurvey(id)
					on delete cascade,
	status			number
				constraint rhn_usurveystatus_status_nn not null
				constraint rhn_usurveystatus_status_fk
					references rhnUserSurveyStatusType( id )
)
	storage ( freelists 16 )
	initrans 32;
create index rhn_usurveystatus_uid_sid_idx
	on rhnUserSurveyStatus ( user_id, survey_id )
	tablespace [[4m_tbs]]
	storage ( freelists 16 )
	initrans 32;
alter table rhnUserSurveyStatus add
	constraint rhn_usurveystatus_uid_sid_uq unique ( user_id, survey_id );
create index rhn_usurveystatus_ssu_idx
	on rhnUserSurveyStatus ( survey_id, status, user_id )
	tablespace [[8m_tbs]]
	storage ( freelists 16 )
	initrans 32;

select '../rhn/tables/rhnVersionInfo.sql' sql_file from dual;
-- SQL relevant contents from file ../rhn/tables/rhnVersionInfo.sql
create table
rhnVersionInfo
(
	label		varchar2(64)
			constraint rhn_versioninfo_label_nn not null,
	name_id		number
			constraint rhn_versioninfo_nid_nn not null
			constraint rhn_versioninfo_nid_fk
				references rhnPackageName(id),
	evr_id		number
			constraint rhn_versioninfo_eid_nn not null
			constraint rhn_versioninfo_eid_fk
				references rhnPackageEVR(id),
	created		date default(sysdate)
			constraint rhn_versioninfo_created_nn not null,
	modified		date default(sysdate)
			constraint rhn_versioninfo_modified_nn not null
)
	storage ( freelists 16 )
	initrans 32;
create unique index rhn_versioninfo_label_uq
	on rhnVersionInfo(label)
	tablespace [[64k_tbs]]
	storage ( pctincrease 1 freelists 16 )
	initrans 32;
create index rhn_vinfo_label_eid_nid_idx
	on rhnVersionInfo(label, name_id, evr_id)
	tablespace [[64k_tbs]]
	storage ( pctincrease 1 freelists 16 )
	initrans 32;
create unique index rhn_versioninfo_nid_eid_uq
	on rhnVersionInfo(name_id,evr_id)
	tablespace [[64k_tbs]]
	storage ( pctincrease 1 freelists 16 )
	initrans 32;
create or replace trigger
rhn_versioninfo_mod_trig
before insert or update on rhnVersionInfo
for each row
begin
	:new.modified := sysdate;
end;
/
show errors

select '../rhn/tables/web_customer_notification.sql' sql_file from dual;
-- SQL relevant contents from file ../rhn/tables/web_customer_notification.sql
create sequence web_cust_notif_seq start with 1000000;
create table
web_customer_notification
(
	id			number
				constraint web_cust_not_id_nn not null
				constraint web_cust_not_id_pk primary key
					using index tablespace [[64k_tbs]],
	org_id			number
				constraint web_cust_not_oid_nn not null
				constraint web_cust_not_oid_fk
					references web_customer(id)
					on delete cascade,
	contact_email_address	varchar2(150)
				constraint web_cust_not_ea_nn not null,
	creation_date		date
				constraint web_cust_not_creat_nn not null
)
	organization heap
	storage ( freelists 16 )
	initrans 32
	nocache nomonitoring;

select '../rhn/views/rhnActionOverview.sql' sql_file from dual;
-- SQL relevant contents from file ../rhn/views/rhnActionOverview.sql
CREATE OR REPLACE VIEW
rhnActionOverview
(
	org_id,
	action_id,
	type_id,
	type_name,
	name,
    	scheduler,
	scheduler_login,
	earliest_action,
	total_count,
	successful_count,
	failed_count,
	in_progress_count,
	archived
)
AS
SELECT    A.org_id,
	  A.id,
	  AT.id,
	  AT.name,
	  A.name,
	  A.scheduler,
	  U.login,
	  A.earliest_action,
	  (SELECT COUNT(*) FROM rhnServerAction WHERE action_id = A.id),
	  (SELECT COUNT(*) FROM rhnServerAction WHERE action_id = A.id AND status = 2), -- XXX: don''t hard code status here :)
	  (SELECT COUNT(*) FROM rhnServerAction WHERE action_id = A.id AND status = 3),
	  (SELECT COUNT(*) FROM rhnServerAction WHERE action_id = A.id AND status NOT IN (2, 3)),
	  A.archived
FROM
	  web_contact U,
	  rhnActionType AT,
	  rhnAction A
WHERE	  A.scheduler = U.id(+)
AND	  A.action_type = AT.id
ORDER BY  A.earliest_action;

select '../rhn/views/rhnChannelTreeView.sql' sql_file from dual;
-- SQL relevant contents from file ../rhn/views/rhnChannelTreeView.sql
CREATE OR REPLACE VIEW rhnChannelTreeView
(
             id,
             depth,
	     name,
             padded_name,
	     channel_arch_id,
             last_modified,
             label,
	     parent_or_self_label,
	     end_of_life
)
AS
  SELECT     
             id,
             (CASE WHEN parent_channel IS NULL THEN 1 ELSE 2 END) depth,
	     name,
             (CASE WHEN parent_channel IS NULL THEN '  ' ELSE '' END) || name,
	     channel_arch_id,
             last_modified,
             label,
	     (CASE WHEN parent_channel IS NULL THEN label ELSE (select c2.label from rhnChannel c2 where c2.id = c.parent_channel) END),
	     end_of_life
        FROM rhnChannel C
  ORDER BY (CASE WHEN parent_channel IS NULL THEN label ELSE (select c2.label from rhnChannel c2 where c2.id = c.parent_channel) END), parent_channel NULLS FIRST
/

select '../rhn/views/rhnChannelPermissions.sql' sql_file from dual;
-- SQL relevant contents from file ../rhn/views/rhnChannelPermissions.sql
create or replace view
rhnChannelPermissions
(
    channel_id, org_id
)
as
select CFM.channel_id, CFP.org_id
  from rhnChannelFamilyMembers CFM,
       rhnChannelFamilyPermissions CFP
 where CFM.channel_family_id = CFP.channel_family_id;

select '../rhn/packages/rhn_set.pkb' sql_file from dual;
-- SQL relevant contents from file ../rhn/packages/rhn_set.pkb
CREATE OR REPLACE
PACKAGE BODY rhn_set
IS
END rhn_set;
/
SHOW ERRORS

select '../rhn/views/rhnServerNeededPackageView.sql' sql_file from dual;
-- SQL relevant contents from file ../rhn/views/rhnServerNeededPackageView.sql
CREATE OR REPLACE VIEW
rhnServerNeededPackageView
(
    org_id,
    server_id,
    errata_id,
    package_id
)
AS
SELECT   S.org_id,
         S.id,
	  (SELECT EP.errata_id
	     FROM rhnErrataPackage EP,
	          rhnChannelErrata CE,
		  rhnServerChannel SC
	    WHERE SC.server_id = S.id
	      AND SC.channel_id = CE.channel_id
	      AND CE.errata_id = EP.errata_id
	      AND EP.package_id = P.id
	      AND ROWNUM = 1),
	 P.id
FROM
	 rhnPackage P,
	 rhnServerPackageArchCompat SPAC,
	 rhnPackageEVR P_EVR,
	 rhnPackageEVR SP_EVR,
	 rhnServerPackage SP,
	 rhnChannelPackage CP,
	 rhnServerChannel SC,
         rhnServer S
WHERE
    	 SC.server_id = S.id
  AND  	 SC.channel_id = CP.channel_id
  AND    CP.package_id = P.id
  AND    p.package_arch_id = spac.package_arch_id
  AND    spac.server_arch_id = s.server_arch_id
  AND    SP_EVR.id = SP.evr_id
  AND    P_EVR.id = P.evr_id
  AND    SP.server_id = S.id
  AND    SP.name_id = P.name_id
  AND    SP.evr_id != P.evr_id
  AND    SP_EVR.evr < P_EVR.evr
  AND    SP_EVR.evr = (SELECT MAX(PE.evr) FROM rhnServerPackage SP2, rhnPackageEvr PE WHERE PE.id = SP2.evr_id AND SP2.server_id = SP.server_id AND SP2.name_id = SP.name_id)
/

select '../rhn/procs/queue_server.sql' sql_file from dual;
-- SQL relevant contents from file ../rhn/procs/queue_server.sql
CREATE OR REPLACE PROCEDURE
queue_server(server_id_in IN NUMBER, immediate_in IN NUMBER := 1)
IS
    org_id_tmp NUMBER;
BEGIN
    IF immediate_in > 0
    THEN
        DELETE FROM rhnServerNeededPackageCache WHERE server_id = server_id_in;
        INSERT INTO rhnServerNeededPackageCache
       	    (SELECT org_id, server_id, errata_id, package_id
	       FROM rhnServerNeededPackageView
              WHERE server_id = server_id_in);
    ELSE
          SELECT org_id INTO org_id_tmp FROM rhnServer WHERE id = server_id_in;
	  INSERT
            INTO rhnTaskQueue
                 (org_id, task_name, task_data)
          VALUES (org_id_tmp, 
                  'update_server_errata_cache',
                  server_id_in);
    END IF;
END;
/
SHOW ERRORS

select '../rhn/views/rhnChannelFamilyServers.sql' sql_file from dual;
-- SQL relevant contents from file ../rhn/views/rhnChannelFamilyServers.sql
create or replace view rhnChannelFamilyServers as
	select	rs.org_id			customer_id,
		rcfm.channel_family_id		channel_family_id,
		rsc.server_id			server_id,
		rsc.created			created,
		rsc.modified			modified
	from	rhnChannelFamilyMembers		rcfm,
		rhnChannelFamily		rcf,
		rhnServerChannel		rsc,
		rhnServer			rs
	where
		rcfm.channel_id = rsc.channel_id
		and rcfm.channel_family_id = rcf.id
		and rsc.server_id = rs.id;

select '../rhn/views/rhnChannelNewestPackageView.sql' sql_file from dual;
-- SQL relevant contents from file ../rhn/views/rhnChannelNewestPackageView.sql
create or replace view
rhnChannelNewestPackageView
as
select  cp.channel_id		channel_id,
		p.name_id			name_id,
		p.evr_id			evr_id,
		p.package_arch_id	package_arch_id,
		p.id				package_id
from	rhnPackageEVR		pe,
		rhnPackage			p,
		rhnChannelPackage	cp
where	cp.package_id = p.id
		and p.evr_id = pe.id
		and pe.evr = (
			select	max(sq_pe.evr)
			from	rhnChannelPackage sq_cp,
					rhnPackage sq_p,
					rhnPackageEVR sq_pe
			where	1=1
				and sq_cp.channel_id = cp.channel_id
				and sq_cp.package_id = sq_p.id
				and sq_p.name_id = p.name_id
				and sq_pe.id = sq_p.evr_id
		)
/

select '../rhn/packages/rhn_channel.pkb' sql_file from dual;
-- SQL relevant contents from file ../rhn/packages/rhn_channel.pkb
CREATE OR REPLACE
PACKAGE BODY rhn_channel
IS
    cursor base_channel_cursor(
	release_in varchar2, server_arch_id_in number, org_id_in number
    ) return rhnChannel%ROWTYPE
    is
	select distinct
	    c.*
	  from rhnChannelPermissions cp,
	       rhnDistChannelMap dcm,
	       rhnChannel c,
	       rhnServerChannelArchCompat scac
	 where scac.server_arch_id = server_arch_id_in
	   and scac.channel_arch_id = dcm.channel_arch_id
	   and dcm.release = release_in
	   and dcm.channel_id = c.id
	   and dcm.channel_arch_id = c.channel_arch_id
	   and cp.channel_id = c.id
	   and ((cp.org_id = org_id_in) or (cp.org_id is NULL))
	   and c.parent_channel is null
	   ;
    FUNCTION get_license_path(channel_id_in IN NUMBER)
    RETURN VARCHAR2
    IS
    	license_val VARCHAR2(1000);
    BEGIN
    	SELECT CFL.license_path INTO license_val
	  FROM rhnChannelFamilyLicense CFL, rhnChannelFamilyMembers CFM
	 WHERE CFM.channel_id = channel_id_in
	   AND CFM.channel_family_id = CFL.channel_family_id;
    	RETURN license_val;
    EXCEPTION
    	WHEN NO_DATA_FOUND
	    THEN
	    RETURN NULL;
    END get_license_path;
    PROCEDURE license_consent(channel_id_in IN NUMBER, user_id_in IN NUMBER, server_id_in IN NUMBER)
    IS
    	channel_family_id_val NUMBER;
    BEGIN
    	channel_family_id_val := rhn_channel.family_for_channel(channel_id_in);
	IF channel_family_id_val IS NULL
	THEN
	    rhn_exception.raise_exception('channel_subscribe_no_family');
	END IF;
	IF rhn_channel.get_license_path(channel_id_in) IS NULL
	THEN
	    rhn_exception.raise_exception('channel_consent_no_license');
	END IF;
	INSERT INTO rhnChannelFamilyLicenseConsent (channel_family_id, user_id, server_id)
	VALUES (channel_family_id_val, user_id_in, server_id_in);
    END license_consent;
    PROCEDURE subscribe_server(server_id_in IN NUMBER, channel_id_in NUMBER, immediate_in NUMBER := 1, user_id_in in number := null)
    IS
        channel_parent_val      rhnChannel.parent_channel%TYPE;
        parent_subscribed       BOOLEAN;
        server_has_base_chan    BOOLEAN;
	server_already_in_chan  BOOLEAN;
	channel_family_id_val   NUMBER;
	server_org_id_val       NUMBER;
	available_subscriptions NUMBER;
	consenting_user         NUMBER;
	allowed			number := 0;
    BEGIN
    	if user_id_in is not null then
		allowed := rhn_channel.user_role_check(channel_id_in, user_id_in, 'subscribe');
	else
		allowed := 1;
	end if;
	if allowed = 0 then
		rhn_exception.raise_exception('no_subscribe_permissions');
	end if;
        SELECT parent_channel INTO channel_parent_val FROM rhnChannel WHERE id = channel_id_in;
        IF channel_parent_val IS NOT NULL
        THEN    
            parent_subscribed := FALSE;    
            FOR check_subscription IN check_server_subscription(server_id_in, channel_parent_val)
            LOOP
                parent_subscribed := TRUE;
            END LOOP check_subscription;
            IF NOT parent_subscribed
            THEN
    	    	RETURN;
            END IF;
        ELSE
            server_has_base_chan := FALSE;
            FOR base IN server_base_subscriptions(server_id_in)
            LOOP
                server_has_base_chan := TRUE;
            END LOOP base;
            IF server_has_base_chan
            THEN
                rhn_exception.raise_exception('channel_server_one_base');
            END IF;
        END IF;
        FOR check_subscription IN check_server_subscription(server_id_in, channel_id_in)
        LOOP
            server_already_in_chan := TRUE;
        END LOOP check_subscription;
        IF server_already_in_chan
        THEN
    	    RETURN;
        END IF;
	channel_family_id_val := rhn_channel.family_for_channel(channel_id_in);
	IF channel_family_id_val IS NULL
	THEN
	    rhn_exception.raise_exception('channel_subscribe_no_family');
	END IF;
	SELECT org_id INTO server_org_id_val
	  FROM rhnServer
	 WHERE id = server_id_in;
	available_subscriptions := rhn_channel.available_family_subscriptions(channel_family_id_val, server_org_id_val);
	IF available_subscriptions IS NULL OR available_subscriptions > 0
	THEN
	    IF rhn_channel.get_license_path(channel_id_in) IS NOT NULL
	    THEN
	    	BEGIN
	    	SELECT user_id INTO consenting_user
		  FROM rhnChannelFamilyLicenseConsent
		 WHERE channel_family_id = channel_family_id_val
		   AND server_id = server_id_in;
		EXCEPTION
    	    	    WHEN NO_DATA_FOUND
		    	THEN
			    rhn_exception.raise_exception('channel_subscribe_no_consent');
		END;
	    END IF;
	    insert into rhnServerHistory (id,server_id,summary,details) (
	    	select	rhn_event_id_seq.nextval,
			server_id_in,
			'subscribed to channel ' || SUBSTR(c.label, 0, 106),
			c.label
		from	rhnChannel c
		where	c.id = channel_id_in
	    );
            INSERT INTO rhnServerChannel (server_id, channel_id) VALUES (server_id_in, channel_id_in);
    	    rhn_channel.update_family_counts(channel_family_id_val, server_org_id_val);
    	    queue_server(server_id_in, immediate_in);
	ELSE
	    rhn_exception.raise_exception('channel_family_no_subscriptions');
	END IF;
    END subscribe_server;
    PROCEDURE bulk_subscribe_server(channel_id_in IN NUMBER, set_label_in IN VARCHAR2, set_uid_in IN NUMBER)
    IS
    BEGIN
        FOR server IN rhn_set.set_iterator(set_label_in, set_uid_in)
        LOOP
            rhn_channel.subscribe_server(server.element, channel_id_in, 0, set_uid_in);
        END LOOP server;
    END bulk_subscribe_server;
    PROCEDURE bulk_server_base_change(channel_id_in IN NUMBER, set_label_in IN VARCHAR2, set_uid_in IN NUMBER)
    IS
    BEGIN
        FOR server IN rhn_set.set_iterator(set_label_in, set_uid_in)
        LOOP
	    IF rhn_server.can_change_base_channel(server.element) = 1
	    THEN
                rhn_channel.clear_subscriptions(TO_NUMBER(server.element));
                rhn_channel.subscribe_server(server.element, channel_id_in, 0, set_uid_in);
            END IF;
        END LOOP server;
    END bulk_server_base_change;
    procedure bulk_server_basechange_from(
	set_label_in in varchar2,
	set_uid_in in number,
	old_channel_id_in in number,
	new_channel_id_in in number
    ) is
	cursor channels(server_id_in in number) is
	    select	rsc.channel_id
	    from	rhnServerChannel rsc,
			rhnChannel rc
	    where	server_id_in = rsc.server_id
			and rsc.channel_id = rc.id
			and rc.parent_channel is null;
    begin
	for server in rhn_set.set_iterator(set_label_in, set_uid_in)
	loop
	    for channel in channels(server.element)
	    loop
		if channel.channel_id = old_channel_id_in 
		then
		    insert into rhnSet (user_id, label, element) values (set_uid_in, set_label_in || 'basechange', server.element);
		end if;
	    end loop channel;
	end loop server;
	bulk_server_base_change(new_channel_id_in, set_label_in||'basechange',set_uid_in);
	delete from rhnSet where label = set_label_in||'basechange' and user_id = set_uid_in;
    end;
    procedure bulk_guess_server_base(
	set_label_in in varchar2,
	set_uid_in in number
    ) is
	channel_id number;
    begin
	for server in rhn_set.set_iterator(set_label_in, set_uid_in)
	loop
	    begin
	    	if rhn_server.can_change_base_channel(server.element) = 1
		then
    	            channel_id := guess_server_base(TO_NUMBER(server.element));
	    	    rhn_channel.clear_subscriptions(TO_NUMBER(server.element));
	    	    rhn_channel.subscribe_server(TO_NUMBER(server.element), channel_id, 0, set_uid_in);
		end if;
	    exception when others then
	    	null;
	    end;
	end loop server;
    end;
    function guess_server_base(
    	server_id_in in number
    ) RETURN number is
	cursor server_cursor is
	    select s.server_arch_id, s.release, s.org_id
	      from rhnServer s
	     where s.id = server_id_in;
    begin
	for s in server_cursor loop
	    for channel in base_channel_cursor(s.release,
		s.server_arch_id, s.org_id) 
	    loop
		return channel.id;
	    end loop base_channel_cursor;
        end loop server_cursor;
        return null;
    end;
    function normalize_server_arch(server_arch_in in varchar2)
    return varchar2
    is
	suffix VARCHAR2(128) := '-redhat-linux';
	suffix_len NUMBER := length(suffix);
    begin
	if server_arch_in is NULL then
	    return NULL;
	end if;
	if substr(server_arch_in, -suffix_len, suffix_len) = suffix
	then
	    return server_arch_in;
	end if;
	return server_arch_in || suffix;
    end normalize_server_arch;
    function base_channel_for_release_arch(
	release_in in varchar2,
	server_arch_in in varchar2,
	org_id_in in number := -1,
	user_id_in in number := null
    ) return number is
	server_arch varchar2(256) := normalize_server_arch(server_arch_in);
	server_arch_id number;
    begin
	begin
	    select id
	      into server_arch_id
	      from rhnServerArch
	     where label = server_arch;
	exception
	    when no_data_found then
		rhn_exception.raise_exception('server_arch_not_found');
	end;
	return base_channel_rel_archid(release_in, server_arch_id,
	    org_id_in, user_id_in);
    end base_channel_for_release_arch;
    function base_channel_rel_archid(
	release_in in varchar2,
	server_arch_id_in in number,
	org_id_in in number := -1,
	user_id_in in number := null
    ) return number is
	denied_channel_id number := null;
	valid_org_id number := org_id_in;
	valid_user_id number := user_id_in;
	channel_subscribable number;
    begin
	if org_id_in = -1 and user_id_in is not null then
	    begin
		select org_id
		  into valid_org_id
		  from web_contact
		 where id = user_id_in;
	    exception
		when no_data_found then
		    valid_user_id := null;
		    valid_org_id := -1;
	    end;
	end if;
	for c in base_channel_cursor(release_in, server_arch_id_in, valid_org_id)
	loop
	    if valid_user_id is null then
		return c.id;
	    end if;
	    select loose_user_role_check(c.id, user_id_in, 'subscribe')
	      into channel_subscribable
	      from dual;
	    if channel_subscribable = 1 then
		return c.id;
	    end if;
	    denied_channel_id := c.id;
	end loop base_channel_fetch;
	if denied_channel_id is not null then
	    rhn_exception.raise_exception('no_subscribe_permissions');
	end if;
	return NULL;
    end base_channel_rel_archid;
    procedure bulk_guess_server_base_from(
	set_label_in in varchar2,
	set_uid_in in number,
	channel_id_in in number
    ) is
	cursor channels(server_id_in in number) is
	    select	rsc.channel_id
	    from	rhnServerChannel rsc,
			rhnChannel rc
	    where	server_id_in = rsc.server_id
			and rsc.channel_id = rc.id
			and rc.parent_channel is null;
    begin
	for server in rhn_set.set_iterator(set_label_in, set_uid_in)
	loop
	    for channel in channels(server.element)
	    loop
		if channel.channel_id = channel_id_in
		then
		    insert into rhnSet (user_id, label, element) values (set_uid_in, set_label_in || 'baseguess', server.element);
		end if;
	    end loop channel;
	end loop server;
	bulk_guess_server_base(set_label_in||'baseguess',set_uid_in);
	delete from rhnSet where label = set_label_in||'baseguess' and user_id = set_uid_in;
    end;
    PROCEDURE clear_subscriptions(server_id_in IN NUMBER)
    IS
    	cursor server_channels(server_id_in in number) is
		select	s.org_id, sc.channel_id, cfm.channel_family_id
		from	rhnServer s,
			rhnServerChannel sc,
			rhnChannelFamilyMembers cfm
		where	s.id = server_id_in
			and s.id = sc.server_id
			and sc.channel_id = cfm.channel_id;
    BEGIN
    	for channel in server_channels(server_id_in)
	loop
		unsubscribe_server(server_id_in, channel.channel_id, 1, 1);
		rhn_channel.update_family_counts(channel.channel_family_id, channel.org_id);
	end loop channel;
    END clear_subscriptions;
    PROCEDURE unsubscribe_server(server_id_in IN NUMBER, channel_id_in NUMBER, immediate_in NUMBER := 1, unsubscribe_children_in number := 0)
    IS
	channel_family_id_val   NUMBER;
	server_org_id_val       NUMBER;
	available_subscriptions NUMBER;	
	server_already_in_chan  BOOLEAN;
	cursor	channel_family_is_proxy(channel_family_id_in in number) is
		select	1
		from	rhnChannelFamily
		where	id = channel_family_id_in
		    and label = 'rhn-proxy';
	cursor	channel_family_is_satellite(channel_family_id_in in number) is
		select	1
		from	rhnChannelFamily
		where	id = channel_family_id_in
		    and label = 'rhn-satellite';
	cursor local_chk_server_parent_memb (
			server_id_in number,
			channel_id_in number ) is
		select	c.id
		from	rhnChannel			c,
				rhnServerChannel	sc
		where	1=1
			and c.parent_channel = channel_id_in
			and c.id = sc.channel_id
			and sc.server_id = server_id_in;
    BEGIN
        FOR child IN local_chk_server_parent_memb(server_id_in, channel_id_in)
        LOOP
	    if unsubscribe_children_in = 1 then
	    	unsubscribe_server(server_id_in => server_id_in,
								channel_id_in => child.id,
								immediate_in => immediate_in,
								unsubscribe_children_in => unsubscribe_children_in);
	    else
	    	rhn_exception.raise_exception('channel_unsubscribe_child_exists');
	    end if;
        END LOOP child;
	server_already_in_chan := FALSE;
        FOR check_subscription IN check_server_subscription(server_id_in, channel_id_in)
        LOOP
            server_already_in_chan := TRUE;
        END LOOP check_subscription;
        IF NOT server_already_in_chan
        THEN
    	    RETURN;
        END IF;
	insert into rhnServerHistory (id,server_id,summary,details) (
	    select  rhn_event_id_seq.nextval,
	    	    server_id_in,
		    'unsubscribed from channel ' || SUBSTR(c.label, 0, 106),
		    c.label
	    from    rhnChannel c
	    where   c.id = channel_id_in
	);
        DELETE FROM rhnServerChannel WHERE server_id = server_id_in AND channel_id = channel_id_in;
    	queue_server(server_id_in, immediate_in);
	channel_family_id_val := rhn_channel.family_for_channel(channel_id_in);
	IF channel_family_id_val IS NULL
	THEN
	    rhn_exception.raise_exception('channel_unsubscribe_no_family');
	END IF;
	for ignore in channel_family_is_satellite(channel_family_id_val) loop
		delete from rhnSatelliteInfo where server_id = server_id_in;
		delete from rhnSatelliteChannelFamily where server_id = server_id_in;
	end loop;
	for ignore in channel_family_is_proxy(channel_family_id_val) loop
		delete from rhnProxyInfo where server_id = server_id_in;
	end loop;
	DELETE FROM rhnChannelFamilyLicenseConsent
	 WHERE channel_family_id = channel_family_id_val
	   AND server_id = server_id_in;
	SELECT org_id INTO server_org_id_val
	  FROM rhnServer
	 WHERE id = server_id_in;
	rhn_channel.update_family_counts(channel_family_id_val, server_org_id_val);
    END unsubscribe_server;
    PROCEDURE bulk_unsubscribe_server(channel_id_in IN NUMBER, set_label_in IN VARCHAR2, set_uid_in IN NUMBER)
    IS
    BEGIN
        FOR server IN rhn_set.set_iterator(set_label_in, set_uid_in)
        LOOP
            rhn_channel.unsubscribe_server(server.element, channel_id_in, 0);
        END LOOP server;
    END bulk_unsubscribe_server;
    FUNCTION subscription_count(channel_id_in NUMBER) 
    RETURN VARCHAR2
    IS
    	sub_count_val NUMBER;
	null_org    NUMBER;
    BEGIN
        SELECT COUNT(*) INTO sub_count_val FROM rhnChannelPermissions WHERE channel_id = channel_id_in;
	IF sub_count_val = 1
	THEN
	    SELECT org_id INTO null_org FROM rhnChannelPermissions WHERE channel_id = channel_id_in AND org_id IS NULL;
	    IF null_org IS NULL
	    THEN
	    	RETURN '(public)';
	    END IF;
	END IF;
	RETURN sub_count_val;
    EXCEPTION
        WHEN NO_DATA_FOUND
	THEN
	    RETURN 1;	
    END subscription_count;
    FUNCTION family_for_channel(channel_id_in IN NUMBER)
    RETURN NUMBER
    IS
    	channel_family_id_val NUMBER;
    BEGIN
    	SELECT channel_family_id INTO channel_family_id_val
	  FROM rhnChannelFamilyMembers
         WHERE channel_id = channel_id_in;
	RETURN channel_family_id_val;
    EXCEPTION
        WHEN NO_DATA_FOUND
	THEN
	    RETURN NULL;
    END family_for_channel;
    FUNCTION available_family_subscriptions(channel_family_id_in IN NUMBER, org_id_in IN NUMBER)
    RETURN NUMBER
    IS
    	cfp channel_family_perm_cursor%ROWTYPE;
    	current_members_val NUMBER;
	max_members_val     NUMBER;
	found               NUMBER;
    BEGIN
	IF NOT channel_family_perm_cursor%ISOPEN
	THEN
	    OPEN channel_family_perm_cursor(channel_family_id_in, org_id_in);
	END IF;
	FETCH channel_family_perm_cursor INTO cfp;
	WHILE channel_family_perm_cursor%FOUND
    	LOOP
	    found := 1;
	    current_members_val := cfp.current_members;
	    max_members_val := cfp.max_members;
	    FETCH channel_family_perm_cursor INTO cfp;
	END LOOP;
	IF channel_family_perm_cursor%ISOPEN
	THEN
	    CLOSE channel_family_perm_cursor;
	END IF;
	IF found IS NULL
	THEN
	    RETURN 0;
	END IF;
	IF max_members_val IS NULL
	THEN
	    RETURN NULL;
	END IF;
	RETURN max_members_val - current_members_val;			
    END available_family_subscriptions;
    PROCEDURE update_family_counts(channel_family_id_in IN NUMBER, org_id_in IN NUMBER)
    IS
    BEGIN
    	UPDATE rhnChannelFamilyPermissions 
	   SET current_members = (SELECT COUNT(server_id) 
	                            FROM rhnServerChannel
				   WHERE channel_id IN (SELECT channel_id FROM rhnChannelFamilyMembers
				                         WHERE channel_family_id = channel_family_id_in)
				     AND server_id IN (SELECT id FROM rhnServer WHERE org_id = org_id_in))
	 WHERE channel_family_id = channel_family_id_in
	   AND org_id = org_id_in;
    END update_family_counts;
    FUNCTION available_chan_subscriptions(channel_id_in IN NUMBER, org_id_in IN NUMBER)
    RETURN NUMBER
    IS
	channel_family_id_val NUMBER;
    BEGIN
    	SELECT channel_family_id INTO channel_family_id_val
	  FROM rhnChannelFamilyMembers
	 WHERE channel_id = channel_id_in;
	 RETURN rhn_channel.available_family_subscriptions(channel_family_id_val, org_id_in);
    END available_chan_subscriptions;
    procedure entitle_customer(customer_id_in in number, channel_family_id_in in number, quantity_in in number)
    is
		cursor permissions is
			select	1
			from	rhnChannelFamilyPermissions rcfp
			where	rcfp.org_id = customer_id_in
				and	rcfp.channel_family_id = channel_family_id_in; 
    begin
		for perm in permissions loop
			set_family_maxmembers(
				customer_id_in,
				channel_family_id_in,
				quantity_in
			);
			rhn_channel.update_family_counts(
				channel_family_id_in,
				customer_id_in
			);
			return;
		end loop;
		insert
        into    rhnChannelFamilyPermissions
               (channel_family_id, org_id, max_members, current_members)
        values  (channel_family_id_in, customer_id_in, quantity_in, 0);
    end;
    procedure set_family_maxmembers(customer_id_in in number, channel_family_id_in in number, quantity_in in number)
    is
	cursor servers is
	    select  server_id from (
		select	rownum row_number, server_id, modified from (
		    select  rcfs.server_id,
			    rcfs.modified
		    from    rhnChannelFamilyServers rcfs
		    where   rcfs.customer_id = customer_id_in
			    and rcfs.channel_family_id = channel_family_id_in
		    order by modified
		)
		where rownum > quantity_in
	    );
    begin
	for server in servers
	loop
	    rhn_channel.unsubscribe_server_from_family(server.server_id, channel_family_id_in);
	end loop;
	update	rhnChannelFamilyPermissions rcfp
	set	rcfp.max_members = quantity_in
	where	rcfp.channel_family_id = channel_family_id_in
		and rcfp.org_id = customer_id_in;
    end;
    procedure unsubscribe_server_from_family(server_id_in in number, channel_family_id_in in number)
    is
    begin
	delete
	from	rhnServerChannel rsc
	where	rsc.server_id = server_id_in
		and channel_id in (
			select	rcfm.channel_id
			from	rhnChannelFamilyMembers rcfm
			where	rcfm.channel_family_id = channel_family_id_in);
    end;
    function get_org_id(channel_id_in in number)
    return number
    is
    	org_id_out number;
    begin
    	select org_id into org_id_out
	  from rhnChannel
	 where id = channel_id_in;
	return org_id_out;
    end get_org_id;
    function get_cfam_org_access(cfam_id_in in number, org_id_in in number)
    return number
    is
    	throwaway number;
    begin
	select distinct 1 into throwaway
	  from rhnChannelFamilyPermissions CFP
	 where CFP.channel_family_id = cfam_id_in
	   and (CFP.org_id = org_id_in OR CFP.org_id IS NULL);
	return 1;
    exception
    	when no_data_found
	    then
	    return 0;
    end;
    function get_org_access(channel_id_in in number, org_id_in in number)
    return number
    is
    	throwaway number;
    begin
	select distinct 1 into throwaway
	  from rhnChannelFamilyMembers CFM,
	       rhnChannelFamilyPermissions CFP
	 where CFM.channel_family_id = CFP.channel_family_id
	   and CFM.channel_id = channel_id_in
	   and (CFP.org_id = org_id_in OR CFP.org_id IS NULL);
	return 1;
    exception
    	when no_data_found
	    then
	    return 0;
    end;
    function user_role_check_debug(channel_id_in in number, user_id_in in number, role_in in varchar2, reason_out out varchar2)
    return number
    is
    	org_id number;
    begin
    	org_id := rhn_user.get_org_id(user_id_in);
    	if role_in = 'manage' and NVL(rhn_channel.get_org_id(channel_id_in), -1) <> org_id
	then
	    reason_out := 'channel_not_owned';
	    return 0;
	end if;
    	if role_in = 'subscribe' and rhn_channel.get_org_access(channel_id_in, org_id) = 0
	then
	    reason_out := 'channel_not_available';
	    return 0;
	end if;
    	if rhn_user.check_role_implied(user_id_in, 'channel_admin') = 1
	then
	    reason_out := 'channel_admin';
	    return 1;
	end if;
	if role_in = 'subscribe'
	then
	    if rhn_channel.org_channel_setting(channel_id_in, org_id, 'not_globally_subscribable') = 0
	    then
	    	reason_out := 'globally_subscribable';
		return 1;
	    end if;
	end if;
	reason_out := 'direct_permission';
	return rhn_channel.direct_user_role_check(channel_id_in, user_id_in, role_in);
    end;
    function user_role_check(channel_id_in in number, user_id_in in number, role_in in varchar2)
    return number
    is
  	throwaway varchar2(256);
    begin
    	return rhn_channel.user_role_check_debug(channel_id_in, user_id_in, role_in, throwaway);
    end;
    function loose_user_role_check(channel_id_in in number, user_id_in in number, role_in in varchar2)
    return number
    is
    begin
        if user_id_in is null then
            return 1;
        end if;
        return user_role_check(channel_id_in, user_id_in, role_in);
    end loose_user_role_check;
    function direct_user_role_check(channel_id_in in number, user_id_in in number, role_in in varchar2)
    return number
    is
    	throwaway number;
    begin
	select 1 into throwaway
	  from rhnChannelPermissionRole CPR,
	       rhnChannelPermission CP
	 where CP.user_id = user_id_in
	   and CP.channel_id = channel_id_in
	   and CPR.label = role_in
	   and CP.role_id = CPR.id;
	return 1;
    exception
    	when no_data_found
	    then
	    return 0;
    end;
    function org_channel_setting(channel_id_in in number, org_id_in in number, setting_in in varchar2)
    return number
    is
    	throwaway number;
    begin
	select 1 into throwaway
	  from rhnOrgChannelSettingsType OCST,
	       rhnOrgChannelSettings OCS
	 where OCS.org_id = org_id_in
	   and OCS.channel_id = channel_id_in
	   and OCST.label = setting_in
	   and OCS.setting_id = OCST.id;
	return 1;
    exception
    	when no_data_found
	    then
	    return 0;
    end;
    procedure delete_server_channels(server_id_in in number)
    is
    begin
	update	rhnChannelFamilyPermissions
	set	current_members = current_members -1
	where	org_id in (
			select	org_id
			from	rhnServer
			where	id = server_id_in
		)
		and channel_family_id in (
			select	rcfm.channel_family_id
			from	rhnChannelFamilyMembers rcfm,
				rhnServerChannel rsc
			where	rsc.server_id = server_id_in
				and rsc.channel_id = rcfm.channel_id
		);
    end;
	procedure refresh_newest_package(channel_id_in in number, caller_in in varchar2 := '(unknown)')
	is
	begin
		delete from rhnChannelNewestPackage where channel_id = channel_id_in;
		insert into rhnChannelNewestPackage
			( channel_id, name_id, evr_id, package_id, package_arch_id ) 
			(	select	channel_id,
						name_id, evr_id,
						package_id, package_arch_id
				from	rhnChannelNewestPackageView
				where	channel_id = channel_id_in
			);
                insert into rhnChannelNewestPackageAudit (channel_id, caller)
                    values (channel_id_in, caller_in);
                update rhnChannel 
                    set last_modified = greatest(sysdate, last_modified + 1/86400)
                    where id = channel_id_in; 
	end;
END rhn_channel;
/
SHOW ERRORS

select '../rhn/views/rhnAvailableChannels.sql' sql_file from dual;
-- SQL relevant contents from file ../rhn/views/rhnAvailableChannels.sql
create or replace view
rhnAvailableChannels
(
    	org_id,
	channel_id,
	channel_depth,
	channel_name,
	channel_arch_id,
	padded_name,
	current_members,
	available_members,
        last_modified,
        channel_label,
	parent_or_self_label
)
as
select
     o.id, 
     cperm.channel_id, 
     CT.depth, 
     CT.name, 
     CT.channel_arch_id, 
     CT.padded_name,
     (SELECT COUNT(1) 
        FROM rhnServer S 
       WHERE S.org_id = o.id
         AND EXISTS (SELECT 1 FROM rhnServerChannel WHERE channel_id = cperm.channel_id AND server_id = S.id)),
     rhn_channel.available_chan_subscriptions(cperm.channel_id, o.id),
     CT.last_modified,
     CT.label,
     CT.parent_or_self_label
from
     web_customer O,
     rhnChannelTreeView CT,
     rhnChannelPermissions CPerm
where
    CT.id = CPerm.channel_id
and (o.id = cperm.org_id
 or cperm.org_id is null)
/

select '../rhn/views/rhnCDDevice.sql' sql_file from dual;
-- SQL relevant contents from file ../rhn/views/rhnCDDevice.sql
create or replace view 
rhnCDDevice
(id, server_Id, class, bus, detached, device, driver, 
description, dev_host, dev_id, dev_channel, dev_lun, pcitype)
as select 
	d.id,
	d.server_Id,
	d.class,
	d.bus,
	d.detached,
	d.device,
	d.driver,
	d.description,
	d.prop1,
	d.prop2,
	d.prop3,
	d.prop4,
	d.pcitype
from rhndevice d
where d.class = 'CDROM';

select '../rhn/views/rhnChannelFamilyOverview.sql' sql_file from dual;
-- SQL relevant contents from file ../rhn/views/rhnChannelFamilyOverview.sql
create or replace view
rhnChannelFamilyOverview
(
    	org_id,
    	id,
	name,
	url,
	current_members,
	max_members,
	has_subscription
)
AS
SELECT WC.id,
       CF.id,
       CF.name,
       CF.product_url,
       NVL((SELECT CFP.current_members
          FROM rhnChannelFamilyPermissions CFP
	 WHERE CFP.channel_family_id = CF.id
	   AND CFP.org_id = WC.id), 0),
       (SELECT CFP.max_members
          FROM rhnChannelFamilyPermissions CFP
	 WHERE CFP.channel_family_id = CF.id
	   AND CFP.org_id = WC.id),
       NVL((SELECT 1
          FROM rhnChannelFamilyPermissions CFP
	 WHERE CFP.channel_family_id = CF.id
	   AND CFP.org_id = WC.id), 0)
  FROM web_customer WC,
       rhnChannelFamily CF
 WHERE EXISTS (SELECT 1 FROM rhnChannelFamilyPermissions WHERE org_id = WC.id AND channel_family_id = CF.id)
/

select '../rhn/views/rhnChannelPackageOverview.sql' sql_file from dual;
-- SQL relevant contents from file ../rhn/views/rhnChannelPackageOverview.sql
create or replace view
rhnChannelPackageOverview
(
    	channel_id,
	name_id,
	evr
)
as
select  cp.channel_id,
	p.name_id,
	max(p_evr.evr)
from
	rhnPackageEVR p_evr,
	rhnPackage p,
	rhnChannelPackage cp
where
    	cp.package_id = p.id
    and p.evr_id = p_evr.id
group by cp.channel_id, p.name_id
/

select '../rhn/views/rhnEntitledServers.sql' sql_file from dual;
-- SQL relevant contents from file ../rhn/views/rhnEntitledServers.sql
create or replace view
rhnEntitledServers
as
select distinct
    S.id,
    S.org_id,
    S.digital_server_id,
    S.server_arch_id,
    S.os,
    S.release,
    S.name,
    S.description,
    S.info,
    S.secret
from
    rhnServerGroup SG,
    rhnServerGroupType SGT,
    rhnServerGroupMembers SGM,
    rhnServer S
where
    S.id = SGM.server_id
and SG.id = SGM.server_group_id
and SGT.label IN ('sw_mgr_entitled', 'enterprise_entitled', 'provisioning_entitled')
and SG.group_type = SGT.id
and SG.org_id = S.org_id
/

select '../web/tables/web_user_prefix.sql' sql_file from dual;
-- SQL relevant contents from file ../web/tables/web_user_prefix.sql
create table
web_user_prefix
(
	text			varchar2(12)
				constraint wup_text_nn not null
				constraint wup_text_pk primary key
);
insert into WEB_USER_PREFIX values (' ');
insert into WEB_USER_PREFIX values ('.');
insert into WEB_USER_PREFIX values ('Mr.');
insert into WEB_USER_PREFIX values ('Mrs.');
insert into WEB_USER_PREFIX values ('Miss');
insert into WEB_USER_PREFIX values ('Ms.');
insert into WEB_USER_PREFIX values ('Dr.');
insert into WEB_USER_PREFIX values ('Hr.');
insert into WEB_USER_PREFIX values ('Sr.');

select '../web/tables/web_user_personal_info.sql' sql_file from dual;
-- SQL relevant contents from file ../web/tables/web_user_personal_info.sql
create table
web_user_personal_info
(
	web_user_id		number
				constraint wupi_wuid_nn not null
				constraint personal_info_web_user_id_fk
					references web_contact(id)
					on delete cascade,
	prefix			varchar(12) default ' '
				constraint wupi_prefix_nn not null
				constraint wupi_prefix_fk
					references web_user_prefix(text),
	first_names		varchar2(128)
				constraint wupi_fn_nn not null,
	last_name		varchar2(128)
				constraint wupi_ln_nn not null,
	genqual			varchar2(12),
	parent_company		varchar2(128),
	company			varchar2(128),
	title			varchar2(128),
	phone			varchar2(128),
	fax			varchar2(128),
	email			varchar2(128),
	email_uc		varchar2(128),
	pin			number,
	created			date default(sysdate)
				constraint wupi_created_nn not null,
	modified		date default(sysdate)
				constraint wupi_modified_nn not null,
	first_names_ol		varchar2(128),
	last_name_ol		varchar2(128),
	genqual_ol		varchar2(12),
	parent_company_ol	varchar2(128),
	company_ol		varchar2(128),
	title_ol		varchar2(128)
);
create or replace trigger
web_user_pi_timestamp
before insert or update on web_user_personal_info
for each row
begin
  :new.email_uc := upper(:new.email);
  :new.modified := sysdate;
end;
/
show errors
create index wupi_email_uc_idx
	on web_user_personal_info ( email_uc );

select '../rhn/views/rhnFreeErrataMail.sql' sql_file from dual;
-- SQL relevant contents from file ../rhn/views/rhnFreeErrataMail.sql
create or replace view
rhnFreeErrataMail as
select
	w.login login, 
	w.login_uc login_uc,
	ea.address email,
	w.id user_id,
	s.id server_id,  
	w.org_id org_id, 
	s.name server_name,  
	sa.name server_arch,  
	s.release server_release,  
	ce.errata_id errata_id,
	e.advisory advisory
from
	rhnChannelErrata ce,
	rhnServerChannel sc,
	rhnServerGroupMembers sgm,
	rhnOrgState os,
	rhnServerGroup sg,
	rhnServer s,
	web_contact w, 
	rhnEmailAddress ea,
	rhnUserInfo ui,
	rhnErrata e,
	rhnServerArch sa
where	1=1
	and ce.channel_id = sc.channel_id
	and sc.server_id = sgm.server_id
	and sgm.server_group_id = sg.id
	and sg.org_id = w.org_id
	and not exists (
		select	usprefs.server_id 
            	from	rhnUserServerPrefs usprefs
	   	where	1=1
	      		and usprefs.name = 'receive_notifications'
			and w.id = usprefs.user_id 
	      		and sc.server_id = usprefs.server_id 
	)
	and ea.state_id = 4
	and w.id = ea.user_id
	and w.id = ui.user_id
    	and ui.email_notify = 1
	and os.state_id in (5, 6, 7, 8, 11)
	and sg.org_id = os.org_id
	and s.server_arch_id = sa.id
	and sc.server_id = s.id
	and ce.errata_id = e.id
/
show errors

select '../rhn/views/rhnHistoryView.sql' sql_file from dual;
-- SQL relevant contents from file ../rhn/views/rhnHistoryView.sql
create or replace function 
rhnHistoryView_pkglist(action_id IN NUMBER, separator IN VARCHAR2 DEFAULT chr(10))
return VARCHAR2
is
    store_var  VARCHAR2(4000);
    store_tmp  VARCHAR2(4000);
    select_sql VARCHAR2(4000);
    trimmed NUMBER;
    cursor pkg_cursor(action_id_in IN NUMBER)
    is
       select
           pn.name||'-'||pevr.version||'-'||pevr.release||'.'||pa.name
       from
           rhnPackageName pn, rhnPackageEVR pevr, rhnPackageArch pa,
	   rhnActionPackage ap
       where
               ap.name_id = pn.id
	   and ap.evr_id = pevr.id
	   and ap.package_arch_id = pa.id(+)
	   and ap.action_id = action_id_in;
begin
    store_var := NULL;
    trimmed := 0;
    open pkg_cursor(action_id);
    loop
	fetch pkg_cursor into store_tmp;
	exit when pkg_cursor%NOTFOUND;
	if store_var is NULL then
	   store_var := store_tmp;
	else
	   trimmed := 1;
	   exit when length(store_var) + length(separator) + length(store_tmp) > 3700;
	   store_var := store_var || separator || store_tmp;
	   trimmed := 0;
	end if;
    end loop;
    close pkg_cursor;
    if trimmed <> 0 then
        store_var := store_var || separator || '...';
    end if;
    return store_var;
end;
/
show errors
create or replace function 
rhnHistoryView_erratalist(action_id IN NUMBER, separator IN VARCHAR2 DEFAULT chr(10))
return VARCHAR2
is
    store_var  VARCHAR2(4000);
    store_tmp  VARCHAR2(4000);
    select_sql VARCHAR2(4000);
    trimmed NUMBER;
    cursor errata_cursor(action_id_in IN NUMBER, separator IN VARCHAR2 DEFAULT chr(10))
    is
       select
           'Errata Advisory: ' || e.advisory || separator ||
	   'Errata Synopsis: ' || e.synopsis || separator
       from
           rhnActionErrataUpdate ae, rhnErrata e
       where
           e.id = ae.errata_id
       and ae.action_id = action_id_in;
begin
    store_var := NULL;
    trimmed := 0;
    open errata_cursor(action_id);
    loop
	fetch errata_cursor into store_tmp;
	exit when errata_cursor%NOTFOUND;
	if store_var is NULL then
	   store_var := store_tmp;
	else
	   trimmed := 1;
	   exit when length(store_var) + length(separator) + length(store_tmp) > 3700;
	   store_var := store_var || separator || store_tmp;
	   trimmed := 0;
	end if;
    end loop;
    close errata_cursor;
    if trimmed <> 0 then
        store_var := store_var || separator || '...';
    end if;
    return store_var;
end;
/
show errors
create or replace view 
rhnHistoryView_refresh
as
select 
    sa.action_id event_id, 
    sa.server_id, 
    at.name || ' scheduled by ' || contact.login || ' (' || astat.name || ')' summary,
    'This action will be executed after ' || 
        to_char(a.earliest_action, 'YYYY-MM-DD HH24:MI:SS') || ' EST' || chr(10) || chr(10) ||
	'The current action status is: ' || astat.name || chr(10) ||
	nvl2(sa.pickup_time, 
	    'The client picked up this action on ' || 
	        to_char(sa.pickup_time, 'YYYY-MM-DD HH24:MI:SS') || ' EST',
	    'This action has not been picked up') || chr(10) ||
	nvl2(sa.completion_time,
	    'The client reported completion on execution on ' ||
	        to_char(sa.completion_time, 'YYYY-MM-DD HH24:MI:SS') || ' EST',
	    'This action has not been fully executed') || chr(10) ||
	nvl2(sa.result_code,
	    'Client execution returned code '||to_char(sa.result_code)||
	        ' ('||nvl(sa.result_msg, 'SUCCESS')||')',
	    '') || 
	chr(10) ||
	'' details,
    a.created, 
    sa.modified
from
    rhnAction a, rhnServerAction sa, 
    rhnActionType at, rhnActionStatus astat,
    web_contact contact
where
    sa.action_id = a.id
and a.action_type = at.id
and a.scheduler = contact.id
and sa.status = astat.id
and at.label in ('packages.refresh_list', 'hardware.refresh_list', 'reboot.reboot', 'rollback.rollback')
with
    read only;
create or replace view
rhnHistoryView_packages
as
select 
    sa.action_id event_id, 
    sa.server_id, 
    at.name || ( select ' (' || count(name_id) || 
                        decode(count(name_id), 1, ' package) ',  ' packages) ')
                 from rhnActionPackage ap where ap.action_id = sa.action_id ) ||
    ' scheduled by ' || contact.login || ' (' || astat.name || ')' summary,
    'This action will be executed after ' || 
        to_char(a.earliest_action, 'YYYY-MM-DD HH24:MI:SS') || ' EST' || chr(10) || chr(10) ||
	'The current action status is: ' || astat.name || chr(10) || 
	nvl2(sa.pickup_time, 
	    'The client picked up this action on ' || 
	        to_char(sa.pickup_time, 'YYYY-MM-DD HH24:MI:SS') || ' EST',
	    'This action has not been picked up') || chr(10) ||
	nvl2(sa.completion_time,
	    'The client reported completion on execution on ' ||
	        to_char(sa.completion_time, 'YYYY-MM-DD HH24:MI:SS') || ' EST',
	    'This action has not been fully executed') || chr(10) ||
	nvl2(sa.result_code,
	    'Client execution returned code '||to_char(sa.result_code)||
	        ' ('||nvl(sa.result_msg, 'SUCCESS')||')',
	    '') || 
	chr(10) || chr(10) ||
	'Package list:' || chr(10) || rhnHistoryView_pkglist(sa.action_id) ||
	'' details,
    a.created, 
    sa.modified
from
    rhnAction a, rhnServerAction sa,
    rhnActionType at, rhnActionStatus astat,
    web_contact contact
where
    sa.action_id = a.id
and a.action_type = at.id
and a.scheduler = contact.id
and sa.status = astat.id
and at.label in ('packages.update', 'packages.remove')
with
    read only;
create or replace view
rhnHistoryView_errata
as
select 
    sa.action_id event_id, 
    sa.server_id, 
    at.name || ( select ' (' || count(errata_id) || 
                        decode(count(errata_id), 1, ' erratum) ', ' errata) ')
                 from rhnActionErrataUpdate aeu where aeu.action_id = sa.action_id ) ||
    ' scheduled by ' || contact.login || ' (' || astat.name || ')' summary,   
    'This action will be executed after ' || 
        to_char(a.earliest_action, 'YYYY-MM-DD HH24:MI:SS') || ' EST' || chr(10) || chr(10) ||
	'The current action status is: ' || astat.name || chr(10) ||
	nvl2(sa.pickup_time, 
	    'The client picked up this action on ' || 
	        to_char(sa.pickup_time, 'YYYY-MM-DD HH24:MI:SS') || ' EST',
	    'This action has not been picked up') || chr(10) ||
	nvl2(sa.completion_time,
	    'The client reported completion on execution on ' ||
	        to_char(sa.completion_time, 'YYYY-MM-DD HH24:MI:SS') || ' EST',
	    'This action has not been fully executed') || chr(10) ||
	nvl2(sa.result_code,
	    'Client execution returned code '||to_char(sa.result_code)||
	        ' ('||nvl(sa.result_msg, 'SUCCESS')||')',
	    '') || 
	chr(10) || chr(10) ||
	'Errata list:' || chr(10) || rhnHistoryView_erratalist(sa.action_id) ||
	'' details,
    a.created, 
    sa.modified
from
    rhnAction a, rhnServerAction sa,
    rhnActionType at, rhnActionStatus astat,
    web_contact contact
where
    sa.action_id = a.id
and a.action_type = at.id
and a.scheduler = contact.id
and sa.status = astat.id
and at.label = 'errata.update'
with 
    read only;
create or replace view
rhnHistoryView
as
select 
    id event_id, server_id, summary, details, created, modified
from
    rhnServerHistory
UNION
select * from rhnHistoryView_refresh
UNION
select * from rhnHistoryView_packages
UNION
select * from rhnHistoryView_errata
with
    read only;

select '../rhn/views/rhnHWDevice.sql' sql_file from dual;
-- SQL relevant contents from file ../rhn/views/rhnHWDevice.sql
create or replace view 
rhnHWDevice
(id, server_Id, class, bus, detached, device, driver, 
description, vendor_id, device_id, subvendor_Id, subdevice_Id, pcitype)
as
select 
	d.id,
	d.server_Id,
	d.class,
	d.bus,
	d.detached,
	d.device,
	d.driver,
	d.description,
	d.prop1,
	d.prop2,
	d.prop3,
	d.prop4,
	d.pcitype
from rhnDevice d
where d.class in ('AUDIO', 'MODEM', 'MOUSE', 'NETWORK', 
	        'SCSI', 'OTHER', 'USB', 'VIDEO', 'CAPTURE',
		'SCANNER', 'TAPE', 'RAID', 'SOCKET');

select '../rhn/views/rhnOrgErrata.sql' sql_file from dual;
-- SQL relevant contents from file ../rhn/views/rhnOrgErrata.sql
create or replace view
rhnOrgErrata
(
    	org_id,
	errata_id,
	channel_id
)
as
select
    ac.org_id,
    ce.errata_id,
    ac.channel_id
from
    rhnChannelErrata ce,
    rhnAvailableChannels ac
where
    ce.channel_id = ac.channel_id
/

select '../rhn/packages/rhn_package.pkb' sql_file from dual;
-- SQL relevant contents from file ../rhn/packages/rhn_package.pkb
CREATE OR REPLACE
PACKAGE BODY rhn_package
IS
    FUNCTION canonical_name(name_in IN VARCHAR2, evr_in IN EVR_T, 
    	                    arch_in IN VARCHAR2)
    RETURN VARCHAR2
    IS
    	name_out     VARCHAR2(256);
    BEGIN
    	name_out := name_in || '-' || evr_in.as_vre_simple();
	IF arch_in IS NOT NULL
	THEN
	    name_out := name_out || '-' || arch_in;
	END IF;
        RETURN name_out;
    END canonical_name;
    FUNCTION channel_occupancy_string(package_id_in IN NUMBER, separator_in VARCHAR2 := ', ') 
    RETURN VARCHAR2
    IS
    	list_out    VARCHAR2(4000);
    BEGIN
    	FOR channel IN channel_occupancy_cursor(package_id_in)
	LOOP
	    IF list_out IS NULL
	    THEN
	    	list_out := channel.channel_name;
	    ELSE
	        list_out := channel.channel_name || separator_in || list_out;
	    END IF;
	END LOOP;
	RETURN list_out;
    END channel_occupancy_string;
END rhn_package;
/
SHOW ERRORS

select '../rhn/views/rhnOrgPackageOverview.sql' sql_file from dual;
-- SQL relevant contents from file ../rhn/views/rhnOrgPackageOverview.sql
create or replace view
rhnOrgPackageOverview
as
select
    p.org_id org_id,
    cpac.channel_arch_id,
    p.id package_id,
    rhn_package.canonical_name(p_name.name, p_evr.evr, pa.name) package_nvrea
from
    rhnPackageName p_name,
    rhnPackageEVR p_evr,
    rhnPackageArch pa,
    rhnChannelPackageArchCompat cpac,
    rhnPackage p
where
        p_name.id = p.name_id
    and p_evr.id = p.evr_id
    and cpac.package_arch_id = p.package_arch_id
    and p.package_arch_id = pa.id
order by package_nvrea, p.created
/

select '../rhn/views/rhnPaidErrataMail.sql' sql_file from dual;
-- SQL relevant contents from file ../rhn/views/rhnPaidErrataMail.sql
create or replace view
rhnPaidErrataMail as
select
	w.login login, 
	w.login_uc login_uc,
	ea.address email,
	w.id user_id,
	s.id server_id,  
	w.org_id org_id, 
	s.name server_name,  
	sa.name server_arch,  
	s.release server_release,  
	ce.errata_id errata_id,
	e.advisory advisory
from
	rhnChannelErrata ce,
	rhnServerChannel sc,
	rhnServerGroupMembers sgm,
	rhnOrgState os,
	rhnServerGroup sg,
	rhnServer s,
	web_contact w, 
	rhnEmailAddress ea,
	rhnUserInfo ui,
	rhnErrata e,
	rhnServerArch sa
where	1=1
	and ce.channel_id = sc.channel_id
	and sc.server_id = sgm.server_id
	and sgm.server_group_id = sg.id
	and os.state_id = 4
	and sg.org_id = os.org_id
	and sg.org_id = w.org_id
	and ea.state_id = 4
	and w.id = ea.user_id
	and not exists (
		select	usprefs.server_id 
            	from	rhnUserServerPrefs usprefs
	   	where	1=1
	      		and usprefs.name = 'receive_notifications'
			and w.id = usprefs.user_id 
	      		and sc.server_id = usprefs.server_id 
	)
	and w.id = ui.user_id
    	and ui.email_notify = 1
	and exists (
		select	1
		from	
			rhnUserGroupType	ugt,
			rhnUserGroup		ug,
			rhnUserGroupMembers	ugm
		where	1=1
			and ugt.label = 'org_admin'
			and ugt.id = ug.group_type
			and ug.id = ugm.user_group_id
			and ugm.user_id = w.id
		union all
		select	1
		from
			rhnServerGroupMembers	sq_sgm,
			rhnUserServerGroupPerms	usg
		where	sc.server_id = sq_sgm.server_id
			and sq_sgm.server_group_id = usg.server_group_id
			and usg.user_id = w.id
	)
	and sc.server_id = s.id
    	and exists (
        	select 1
		from
	    		rhnPackageEVR			p_evr,
	    		rhnPackageEVR			sp_evr,
	    		rhnServerPackage 		sp,
	    		rhnChannelPackage		cp,
	    		rhnPackage			p,
	    		rhnErrataPackage		ep,
	    		rhnServerPackageArchCompat	spac
		where	1=1
			and sc.channel_id = cp.channel_id
			and cp.package_id = p.id
			and ce.errata_id = ep.errata_id
			and ep.package_id = p.id
			and sc.channel_id = ce.channel_id
			and ce.errata_id = ep.errata_id
			and sc.server_id = sp.server_id
			and sp.name_id = p.name_id
			and sp.evr_id = sp_evr.id
			and p.evr_id = p_evr.id
			and sp.evr_id != p.evr_id
			and sp_evr.evr < p_evr.evr
			and p.package_arch_id = spac.package_arch_id
			and s.server_arch_id = spac.server_arch_id
	)
	and s.server_arch_id = sa.id
	and ce.errata_id = e.id
/
show errors

select '../rhn/views/rhnPrivateErrataMail.sql' sql_file from dual;
-- SQL relevant contents from file ../rhn/views/rhnPrivateErrataMail.sql
create or replace view
rhnPrivateErrataMail
as
select
	w.login, 
	w.login_uc,
	wpi.email,  
	w.id user_id,
	s.id server_id,  
	w.org_id org_id, 
	s.name server_name,  
	sa.name server_arch,  
	s.release server_release,  
	ce.errata_id errata_id,
	e.advisory
from
	rhnServer s,
	web_user_personal_info wpi,
	rhnUserInfo ui,
	rhnErrata e,
	rhnServerArch sa,
	rhnChannelErrata ce,
	web_contact w, 
	rhnServerChannel sc,
	rhnServerGroupMembers sgm,
	rhnServerGroup sg
where	1=1
	and sg.id = sgm.server_group_id
	and sgm.server_id = sc.server_id
	and sg.org_id = w.org_id
	and not exists (
		select	usprefs.server_id 
            	from	rhnUserServerPrefs usprefs
	   	where	1=1
			and w.id = usprefs.user_id 
	      		and sc.server_id = usprefs.server_id 
	      		and usprefs.name = 'receive_notifications'
	)
	and w.id = wpi.web_user_id
	and wpi.email is not null
	and w.id = ui.user_id
    	and ui.email_notify = 1
	and exists (
		select	1
		from	
			rhnUserGroupType	ugt,
			rhnUserGroup		ug,
			rhnUserGroupMembers	ugm
		where	1=1
			and ugt.label = 'org_admin'
			and ugt.id = ug.group_type
			and ug.id = ugm.user_group_id
			and ugm.user_id = w.id
		union all
		select	1
		from
			rhnServerGroupMembers	sq_sgm,
			rhnUserServerGroupPerms	usg
		where	sc.server_id = sq_sgm.server_id
			and sq_sgm.server_group_id = usg.server_group_id
			and usg.user_id = w.id
	)
	and sc.channel_id = ce.channel_id
	and sc.server_id = s.id
    	and exists (
        	select 1
		from
	    		rhnPackageEVR			p_evr,
	    		rhnPackageEVR			sp_evr,
	    		rhnServerPackage 		sp,
	    		rhnChannelPackage		cp,
	    		rhnPackage			p,
	    		rhnErrataPackage		ep,
	    		rhnServerPackageArchCompat	spac
		where	1=1
			and sc.channel_id = cp.channel_id
			and cp.package_id = p.id
			and ce.errata_id = ep.errata_id
			and ep.package_id = p.id
			and sc.channel_id = ce.channel_id
			and ce.errata_id = ep.errata_id
			and sc.server_id = sp.server_id
			and sp.name_id = p.name_id
			and sp.evr_id = sp_evr.id
			and p.evr_id = p_evr.id
			and sp.evr_id != p.evr_id
			and sp_evr.evr < p_evr.evr
			and sp_evr.evr = (
				select	max(sq2_pe.evr)
				from	rhnServerPackage	sq2_sp,
					rhnPackageEVR		sq2_pe
				where	sp.server_id = sq2_sp.server_id
					and sp.name_id = sq2_sp.name_id
					and sq2_sp.evr_id = sq2_pe.id
			)
			and p.package_arch_id = spac.package_arch_id
			and s.server_arch_id = spac.server_arch_id
	)
	and s.server_arch_id = sa.id
	and ce.errata_id = e.id
/

select '../rhn/views/rhnServerErrataTypeView.sql' sql_file from dual;
-- SQL relevant contents from file ../rhn/views/rhnServerErrataTypeView.sql
CREATE OR REPLACE VIEW rhnServerErrataTypeView
(
    	server_id,
	errata_id,
	errata_type,
	package_count
)
AS
SELECT
    	SNPC.server_id,
	SNPC.errata_id,
	E.advisory_type,
	COUNT(SNPC.package_id)
FROM    rhnErrata E,
    	rhnServerNeededPackageCache SNPC
WHERE   E.id = SNPC.errata_id
GROUP BY SNPC.server_id, SNPC.errata_id, E.advisory_type
/

select '../rhn/views/rhnServerGroupMembership.sql' sql_file from dual;
-- SQL relevant contents from file ../rhn/views/rhnServerGroupMembership.sql
CREATE OR REPLACE VIEW rhnServerGroupMembership (
         ORG_ID, SERVER_ID, GROUP_ID, GROUP_NAME, GROUP_TYPE, CURRENT_MEMBERS, MAX_MEMBERS
)
AS
SELECT   SG.org_id, SGM.server_id, SG.id, SG.name, SGT.label, SG.current_members, SG.max_members
  FROM   rhnServerGroupType SGT, 
	 rhnServerGroupMembers SGM,
    	 rhnServerGroup SG
 WHERE   SG.id = SGM.server_group_id(+)
   AND   SG.group_type = SGT.id(+)
/

select '../rhn/views/rhnUserManagedServerGroups.sql' sql_file from dual;
-- SQL relevant contents from file ../rhn/views/rhnUserManagedServerGroups.sql
create or replace view
rhnUserManagedServerGroups (
    user_id, server_group_id
)
as
select user_id, server_group_id from rhnUserServerGroupPerms
union
select wc.id, sg.id
  from rhnServerGroup sg,
       rhnUserGroup ug,
       rhnUserGroupMembers ugm,
       web_contact wc
 where wc.org_id = sg.org_id
   and wc.id = ugm.user_id
   and ugm.user_group_id = ug.id
   and ug.group_type = (select id from rhnUserGroupType where label = 'org_admin')
/

select '../rhn/views/rhnServerGroupOverview.sql' sql_file from dual;
-- SQL relevant contents from file ../rhn/views/rhnServerGroupOverview.sql
CREATE OR REPLACE VIEW rhnServerGroupOverview (
         ORG_ID, SECURITY_ERRATA, BUG_ERRATA, ENHANCEMENT_ERRATA, GROUP_ID, GROUP_NAME, GROUP_ADMINS, SERVER_COUNT, NOTE_COUNT, MODIFIED, MAX_MEMBERS
)
AS
  SELECT SG.org_id, 
         (SELECT COUNT(E.id)
	    FROM rhnErrata E
	   WHERE E.advisory_type = 'Security Advisory'
	     AND EXISTS (SELECT 1 FROM rhnServerNeededPackageCache SNEC, rhnServerGroupMembers SGM
	                         WHERE SGM.server_id = SNEC.server_id
				   AND SNEC.errata_id = E.id
				   AND SGM.server_group_id = SG.id)),
         (SELECT COUNT(E.id)
	    FROM rhnErrata E
	   WHERE E.advisory_type = 'Bug Fix Advisory'
	     AND EXISTS (SELECT 1 FROM rhnServerNeededPackageCache SNEC, rhnServerGroupMembers SGM
	                         WHERE SGM.server_id = SNEC.server_id
				   AND SNEC.errata_id = E.id
				   AND SGM.server_group_id = SG.id)),
         (SELECT COUNT(E.id)
	    FROM rhnErrata E
	   WHERE E.advisory_type = 'Product Enhancement Advisory'
	     AND EXISTS (SELECT 1 FROM rhnServerNeededPackageCache SNEC, rhnServerGroupMembers SGM
	                         WHERE SGM.server_id = SNEC.server_id
				   AND SNEC.errata_id = E.id
				   AND SGM.server_group_id = SG.id)),
	 SG.id, SG.name, 
	 (SELECT COUNT(*) FROM rhnUserManagedServerGroups UMSG WHERE UMSG.server_group_id = SG.id),
	 (SELECT COUNT(*) FROM rhnServerGroupMembers SGM WHERE SGM.server_group_id = SG.id), 
	 0, SYSDATE, MAX_MEMBERS
    FROM rhnServerGroup SG;

select '../rhn/views/rhnServerGroupOVLiteHelper.sql' sql_file from dual;
-- SQL relevant contents from file ../rhn/views/rhnServerGroupOVLiteHelper.sql
create or replace view
rhnServerGroupOVLiteHelper as
select	sgm.server_group_id						server_group_id,
		e.advisory_type							advisory_type
from	rhnErrata								e,
		rhnServerNeededPackageCache				snpc,
		rhnServerGroupMembers					sgm
where   1=1
	and sgm.server_id = snpc.server_id
	and snpc.errata_id = e.id
/

select '../rhn/views/rhnServerOutdatedPackages.sql' sql_file from dual;
-- SQL relevant contents from file ../rhn/views/rhnServerOutdatedPackages.sql
CREATE OR REPLACE VIEW
rhnServerOutdatedPackages
(
    server_id,
    package_name_id,
    package_evr_id,    
    package_nvre,
    errata_id,
    errata_advisory
)
AS
SELECT DISTINCT SNPC.server_id,
       P.name_id, 
       P.evr_id, 
       PN.name || '-' || PE.evr.as_vre_simple(),
       E.id,
       E.advisory
  FROM rhnErrata E,
       rhnPackageName PN,
       rhnPackageEVR PE,
       rhnPackage P,
       rhnServerNeededPackageCache SNPC
 WHERE SNPC.package_id = P.id
   AND P.name_id = PN.id
   AND P.evr_id = PE.id
   AND SNPC.errata_id = E.id(+)
/

select '../rhn/views/rhnUserServerPermsDupes.sql' sql_file from dual;
-- SQL relevant contents from file ../rhn/views/rhnUserServerPermsDupes.sql
create or replace view rhnUserServerPermsDupes (
         user_id, server_id
)
as
select
    usg.user_id, sgm.server_id
from
    rhnServerGroupMembers sgm,
    rhnUserServerGroupPerms usg
where
   usg.server_group_id = sgm.server_group_id
union all
select ugm.user_id, s.id
  from 
       rhnUserGroup ug,
       rhnUserGroupMembers ugm,
       rhnServer S,
       web_contact U
 where ugm.user_group_id = ug.id
   and u.id = ugm.user_id
   and ug.group_type = (SELECT id FROM rhnUserGroupType WHERE label = 'org_admin')
   and s.org_id = u.org_id
/

select '../rhn/views/rhnUserServerPerms.sql' sql_file from dual;
-- SQL relevant contents from file ../rhn/views/rhnUserServerPerms.sql
create or replace view rhnUserServerPerms (
         user_id, server_id
)
as
select distinct
    user_id, server_id
from
    rhnUserServerPermsDupes
/

select '../rhn/views/rhnVisibleServerGroupMembers.sql' sql_file from dual;
-- SQL relevant contents from file ../rhn/views/rhnVisibleServerGroupMembers.sql
CREATE OR REPLACE VIEW
rhnVisibleServerGroupMembers
AS
  SELECT SGM.*
    FROM rhnServerGroup SG,
         rhnServerGroupMembers SGM
   WHERE SGM.server_group_id = SG.id
     AND SG.group_type IS NULL;

select '../rhn/packages/rhn_entitlements.pkb' sql_file from dual;
-- SQL relevant contents from file ../rhn/packages/rhn_entitlements.pkb
create or replace
package body rhn_entitlements
is
	function entitlement_grants_service (
	    entitlement_in in varchar2,
	    service_level_in in varchar2
	) return number	is
	begin
	    if service_level_in = 'provisioning' then
	    	if entitlement_in = 'provisioning_entitled' then
		    return 1;
		else
		    return 0;
		end if;
	    elsif service_level_in = 'management' then
    	    	if entitlement_in = 'provisioning_entitled' then
		    return 1;
		elsif entitlement_in = 'enterprise_entitled' then
		    return 1;
		else
		    return 0;
		end if;
	    elsif service_level_in = 'updates' then
		return 1;	    
	    else
	    	return 0;
	    end if;
	end entitlement_grants_service;
	function lookup_entitlement_group (
		org_id_in in number,
		type_label_in in varchar2 := 'sw_mgr_entitled'
	) return number is
		cursor server_groups is
			select	sg.id				server_group_id
			from	rhnServerGroup		sg,
					rhnServerGroupType	sgt
			where	sgt.label = type_label_in
				and sgt.id = sg.group_type
				and sg.org_id = org_id_in;
	begin
		for sg in server_groups loop
			return sg.server_group_id;
		end loop;
		return rhn_entitlements.create_entitlement_group(
				org_id_in, 
				type_label_in
			);
	end lookup_entitlement_group;
	function create_entitlement_group (
		org_id_in in number,
		type_label_in in varchar2 := 'sw_mgr_entitled'
	) return number is
		sg_id_val number;
	begin
		select	rhn_server_group_id_seq.nextval
		into	sg_id_val
		from	dual;
		insert into rhnServerGroup (
				id, name, description, max_members, current_members,
				group_type, org_id
			) (
				select	sg_id_val, sgt.label, sgt.label,
						0, 0, sgt.id, org_id_in
				from	rhnServerGroupType sgt
				where	sgt.label = type_label_in
			);
		return sg_id_val;
	end create_entitlement_group;
	function get_server_entitlement (
		server_id_in in number
	) return varchar2 is
		cursor server_groups is
			select	sgt.label
			from	rhnServerGroupType		sgt,
					rhnServerGroup			sg,
					rhnServerGroupMembers	sgm
			where	1=1
				and sgm.server_id = server_id_in
				and sg.id = sgm.server_group_id
				and sgt.id = sg.group_type
				and sgt.label in ('sw_mgr_entitled','enterprise_entitled',
					'provisioning_entitled');
	begin
		for sg in server_groups loop
			return sg.label;
		end loop;
		return 'none';
	end get_server_entitlement;
	procedure unentitle_server (
		server_id_in in number,
		type_label_in in varchar2 := 'sw_mgr_entitled'
	) is
		group_id number;
	begin
		select	sg.id
		into	group_id
		from	rhnServerGroupType sgt,
				rhnServerGroup sg,
				rhnServerGroupMembers sgm,
				rhnServer s
		where	s.id = server_id_in
			and s.id = sgm.server_id
			and sgm.server_group_id = sg.id
			and sg.org_id = s.org_id
			and sgt.label = type_label_in
			and sgt.id = sg.group_type;
		rhn_server.delete_from_servergroup(server_id_in, group_id);
		exception
		when no_data_found then
    	    	    null;
	end unentitle_server;
	procedure upgrade_server (
		server_id_in in number
	) is
		old_sgid number;
		new_sgid number;
		new_sg_max number;
		new_sg_used number;
	begin
		begin
			select	sg0.id, sg1.id, 
					sg1.max_members, sg1.current_members
			into	old_sgid, new_sgid,
					new_sg_max, new_sg_used
			from	rhnServerGroup sg1,
					rhnServerGroupType sgt1,
					rhnServerGroupMembers sgm,
					rhnServerGroup sg0,
					rhnServerGroupType sgt0,
					rhnServer s
			where	s.id = server_id_in
				and s.org_id = sg0.org_id
				and sgt0.label = 'enterprise_entitled'
				and sgt0.id = sg0.group_type
				and s.id = sgm.server_id
				and sgm.server_group_id = sg0.id
				and s.org_id = sg1.org_id
				and sgt1.label = 'provisioning_entitled'
				and sgt1.id = sg1.group_type;
		exception
			when no_data_found then
				rhn_exception.raise_exception('invalid_upgrade');
		end;
		if new_sg_used >= new_sg_max then
			rhn_exception.raise_exception('servergroup_max_members');
		end if;
		rhn_server.delete_from_servergroup(server_id_in, old_sgid);
		rhn_server.insert_into_servergroup(server_id_in, new_sgid);
	end upgrade_server;
	procedure entitle_server (
		server_id_in in number,
		type_label_in in varchar2 := 'sw_mgr_entitled'
	) is
		sg_id_val number;
		previous_ent rhnServerGroupType.label%TYPE;
	begin
		previous_ent := rhn_entitlements.get_server_entitlement(server_id_in);
		if previous_ent != 'none' then
			rhn_exception.raise_exception(
								'no_server_multiple_swmgr_entitlements');
		end if;
		begin
			select	sg.id
			into	sg_id_val
			from	rhnServerGroupType sgt,
					rhnServerGroup sg,
					rhnServer s
			where	s.id = server_id_in
				and s.org_id = sg.org_id
				and sgt.label = type_label_in
				and sg.group_type = sgt.id;
			rhn_server.insert_into_servergroup(server_id_in, sg_id_val);
		exception
			when no_data_found then
				rhn_exception.raise_exception('servergroup_max_members');
		end;
	end entitle_server;
	procedure set_customer_enterprise (
		customer_id in number
	) is
		entitlement_type_id number;
		status number;
	begin
		select	roet.id, roe.org_id
		into	entitlement_type_id, status
		from	rhnOrgEntitlementType	roet,
				rhnOrgEntitlements		roe
		where	1=1
			and roet.label = 'sw_mgr_enterprise'
			and roet.id = roe.entitlement_id(+)
			and roe.org_id(+) = customer_id;
		if status is null then
			insert into rhnOrgEntitlements (
					org_id, entitlement_id
				) values (
					customer_id, entitlement_type_id
			);
		end if;
		update		rhnUserGroup
			set		max_members = null
			where	1=1
				and org_id = customer_id
				and group_type in (
					select	id
					from	rhnUserGroupType
					where	label in ('org_admin', 'org_applicant')
				);
	end set_customer_enterprise;
	procedure set_customer_provisioning (
		customer_id_in in number
	) is
		cursor entitlements is
			select	roet.id entitlement_type_id,
					roe.org_id status
			from	rhnOrgEntitlements		roe,
					rhnOrgEntitlementType	roet
			where	1=1
				and roet.label in ('rhn_provisioning','sw_mgr_enterprise')
				and roet.id = roe.entitlement_id(+)
				and roe.org_id(+) = customer_id_in;
	begin
		for e in entitlements loop
			if e.status is null then
				insert into rhnOrgEntitlements (
						org_id, entitlement_id
					) values (
						customer_id_in, e.entitlement_type_id
					);
			end if;
		end loop;
	end set_customer_provisioning;
	procedure unset_customer_enterprise (
		customer_id in number
	) is
	begin
		delete	from	rhnOrgEntitlements
				where	1=1
					and org_id = customer_id
					and entitlement_id in (
						select	id
						from	rhnOrgEntitlementType
						where	label = 'sw_mgr_enterprise'
					);
		update		rhnUserGroup
			set		max_members = null
			where	1=1
				and org_id = customer_id
				and group_type in (
					select	id
					from	rhnUserGroupType
					where	label in ('org_admin', 'org_applicant')
				);
	end unset_customer_enterprise;
	procedure unset_customer_provisioning (
		customer_id_in in number
	) is
		usergroup number;
	begin
		delete from rhnOrgEntitlements
			where	1=1
				and org_id = customer_id_in
				and entitlement_id in (
					select	id
					from	rhnOrgEntitlementType
					where	label = 'rhn_config'
				);
	end;
	procedure prune_group (
		group_id_in in number,
		type_in in char,
		quantity_in in number
	) is
		cursor usergroups is
			select	user_id, user_group_id, ugt.label
			from	rhnUserGroupType	ugt,
					rhnUserGroup		ug,
					rhnUserGroupMembers	ugm
			where	1=1
				and ugm.user_group_id = group_id_in
				and ugm.user_id in (
					select	user_id
					from	(
						select	rownum row_number,
								user_id,
								time
						from	(
							select	user_id,
									modified time
							from	rhnUserGroupMembers
							where	user_group_id = group_id_in
							order by time asc
						)
					)
					where	row_number > quantity_in
				)
				and ugm.user_group_id = ug.id
				and ug.group_type = ugt.id;
		cursor servergroups is
			select	server_id, server_group_id, sgt.label
			from	rhnServerGroupType		sgt,
					rhnServerGroup			sg,
					rhnServerGroupMembers	sgm
			where	1=1
				and sgm.server_group_id = group_id_in
				and sgm.server_id in (
					select	server_id
					from	(
						select	rownum row_number,
								server_id,
								time
						from	(
							select	server_id,
									modified time
							from	rhnServerGroupMembers
							where	server_group_id = group_id_in
							order by time asc
						)
					)
					where	row_number > quantity_in
				)
				and sgm.server_group_id = sg.id
				and sg.group_type = sgt.id;
	begin
		if type_in = 'U' then
			update		rhnUserGroup
				set		max_members = quantity_in
				where	id = group_id_in;
			for ug in usergroups loop
				delete
					from	rhnUserGroupMembers
					where	user_group_id = ug.user_group_id
						and user_id = ug.user_id;
			end loop;
		elsif type_in = 'S' then
			update		rhnServerGroup
				set		max_members = quantity_in
				where	id = group_id_in;
			for sg in servergroups loop
				unentitle_server(sg.server_id, sg.label);
				rhn_channel.clear_subscriptions(sg.server_id);
			end loop;
		end if;
	end prune_group;
	procedure set_group_count (
		customer_id_in in number,
		type_in in char,
		group_type_in in number,
		quantity_in in number
	) is
		group_id number;
		quantity number;
	begin
		quantity := quantity_in;
		if quantity is not null and quantity < 0 then
			quantity := 0;
		end if;
		if type_in = 'U' then
			select	rug.id
			into	group_id
			from	rhnUserGroup rug
			where	1=1
				and rug.org_id = customer_id_in
				and rug.group_type = group_type_in;
		elsif type_in = 'S' then
			select	rsg.id
			into	group_id
			from	rhnServerGroup rsg
			where	1=1
				and rsg.org_id = customer_id_in
				and rsg.group_type = group_type_in;
		end if;
		rhn_entitlements.prune_group(
			group_id,
			type_in,
			quantity
		);
	exception
		when no_data_found then
			if type_in = 'U' then
				insert into rhnUserGroup (
						id, name, description, max_members, current_members,
						group_type, org_id, created, modified
					) (
						select	rhn_user_group_id_seq.nextval, name, name,
								quantity, 0, id, customer_id_in,
								sysdate, sysdate
						from	rhnUserGroupType
						where	id = group_type_in
				);
			elsif type_in = 'S' then
				insert into rhnServerGroup (
						id, name, description, max_members, current_members,
						group_type, org_id, created, modified
					) (
						select	rhn_server_group_id_seq.nextval, name, name,
								quantity, 0, id, customer_id_in,
								sysdate, sysdate
						from	rhnServerGroupType
						where	id = group_type_in
				);
			end if;
	end set_group_count;
	procedure prune_family (
		customer_id_in in number,
		channel_family_id_in in number,
		quantity_in in number
	) is
		cursor serverchannels is
			select	sc.server_id,
					sc.channel_id
			from	rhnServerChannel sc,
					rhnChannelFamilyMembers cfm
			where	1=1
				and cfm.channel_family_id = channel_family_id_in
				and cfm.channel_id = sc.channel_id
				and server_id in (
					select	server_id
					from	(
						select	server_id,
								time,
								rownum row_number
						from	(
							select	rs.id					server_id,
									rcfm.modified			time
							from	rhnServer				rs,
									rhnServerChannel		rsc,
									rhnChannelFamilyMembers	rcfm
							where	1=1
								and rs.org_id = customer_id_in
								and rs.id = rsc.server_id
								and rsc.channel_id = rcfm.channel_id
								and rcfm.channel_family_id =
									channel_family_id_in
							order by time asc
						)
					)
					where row_number > quantity_in
				);
	begin
		if customer_id_in is null then
			return;
		end if;
		update		rhnChannelFamilyPermissions
			set		max_members = quantity_in
			where	1=1
				and org_id = customer_id_in
				and channel_family_id = channel_family_id_in;
		for sc in serverchannels loop
			rhn_channel.unsubscribe_server(sc.server_id, sc.channel_id, 1, 1);
		end loop;
	end prune_family;
	procedure set_family_count (
		customer_id_in in number,
		channel_family_id_in in number,
		quantity_in in number
	) is
		perm_exists number;
		quantity number;
	begin
		quantity := quantity_in;
		if quantity is not null and quantity < 0 then
			quantity := 0;
		end if;
		select	1
		into	perm_exists
		from	rhnChannelFamilyPermissions
		where	1=1
			and channel_family_id = channel_family_id_in
			and (org_id = customer_id_in or
				(org_id is null and customer_id_in is null));
		rhn_entitlements.prune_family(
				customer_id_in,
				channel_family_id_in,
				quantity
			);
	exception
		when no_data_found then
			insert into rhnChannelFamilyPermissions (
					channel_family_id, org_id, max_members, current_members
				) values (
					channel_family_id_in, customer_id_in, quantity, 0
				);
	end set_family_count;
	procedure entitle_last_modified_servers (
		customer_id_in in number,
		type_label_in in varchar2,
		quantity_in in number
	) is
		cursor servers(cid_in in number, quant_in in number) is
			select	server_id
			from	(
						select	rownum row_number,
								server_id
						from	(
									select	rs.id server_iD
									from	rhnServer rs
									where	1=1
										and rs.org_id = cid_in
										and not exists (
											select	1
											from	rhnServerGroup sg,
													rhnServerGroupMembers rsgm
											where	rsgm.server_id = rs.id
												and rsgm.server_group_id = sg.id
												and sg.group_type is not null
										)
									order by modified desc
								)
					)
			where	row_number <= quant_in;
	begin
		for server in servers(customer_id_in, quantity_in) loop
			rhn_entitlements.entitle_server(server.server_id, type_label_in);
		end loop;
	end entitle_last_modified_servers;
	procedure get_available_slots (
		customer_id_in in number,
		type_label_in in varchar2,
		server_group_id_out out number,
		available_out out number,
		upgrade_out out number
	) is
		mgmt_slots_unused number;
		mgmt_slots_used number;
		prov_slots_unused number;
		prov_slots_used number;
		swmgr_slots_unused number;
		sgid number;
	begin
		if type_label_in = 'sw_mgr_entitled' then
			select	max_members - current_members, sg.id
			into	swmgr_slots_unused, sgid
			from	rhnServerGroup		sg,
					rhnServerGroupType	sgt
			where	sgt.label = 'sw_mgr_entitled'
				and sg.org_id = customer_id_in
				and sg.group_type = sgt.id;
			available_out := swmgr_slots_unused;
			upgrade_out := 0;
			server_group_id_out := sgid;
			return;
		end if;
		begin
			select	sg.current_members,
					sg.max_members - sg.current_members,
					sg.id
			into	mgmt_slots_used,
					mgmt_slots_unused,
					sgid
			from	rhnServerGroup		sg,
					rhnServerGroupType	sgt
			where	sgt.label = 'enterprise_entitled'
				and sg.org_id = customer_id_in
				and sg.group_type = sgt.id;
		exception 
			when no_data_found then
				available_out := 0;
				upgrade_out := 0;
				server_group_id_out := null;
				return;
		end;
		if type_label_in = 'enterprise_entitled' then
			available_out := mgmt_slots_unused;
			upgrade_out := 0;
			server_group_id_out := sgid;
			return;
		end if;
		begin
			select	sg.current_members,
					sg.max_members - sg.current_members,
					sg.id
			into	prov_slots_used,
					prov_slots_unused,
					sgid
			from	rhnServerGroup		sg,
					rhnServerGroupType	sgt
			where	sgt.label = 'provisioning_entitled'
				and sg.org_id = customer_id_in
				and sg.group_type = sgt.id;
		exception 
			when no_data_found then
				available_out := 0;
				upgrade_out := 0;
				server_group_id_out := null;
				return;
		end;
		if prov_slots_unused - mgmt_slots_unused < 0 then
			available_out := prov_slots_unused;
			upgrade_out := 0;
		elsif prov_slots_unused > 0 then
			upgrade_out := prov_slots_unused - mgmt_slots_unused;
			available_out := prov_slots_unused - (prov_slots_unused - mgmt_slots_unused);
		else
			upgrade_out := 0;
			available_out := 0;
		end if;
		server_group_id_out := sgid;
		return;
	end get_available_slots;
	procedure prune_everything (
		customer_id_in in number
	) is
		cursor everything is
			select	sg.id					id,
					'S'						type,
					sg.max_members			quantity
			from	rhnServerGroup			sg
			where	sg.org_id = customer_id_in
			union
			select	ug.id					id,
					'U'						type,
					ug.max_members 			quantity
			from	rhnUserGroup			ug
			where	ug.org_id = customer_id_in
			union ( 
			select	cfp.channel_family_id	id,
					'C'						type,
					cfp.max_members			quantity
			from	rhnChannelFamilyPermissions cfp
			where	cfp.org_id = customer_id_in
				or	cfp.org_id is null
			union
			select	cfm.channel_family_id	id,
					'C'						type,
					0						quantity
			from	rhnChannelFamily		cf,
					rhnChannelFamilyMembers	cfm,
					rhnServerChannel		sc,
					rhnServer				s
			where	s.org_id = customer_id_in
				and s.id = sc.server_id
				and sc.channel_id = cfm.channel_id
				and not exists (
					select	1
					from	rhnChannelFamilyPermissions cfp
					where	(cfp.org_id = customer_id_in or cfp.org_id is null)
					)
				and cfm.channel_family_id = cf.id
				and cf.org_id is not null
				and cf.org_id != customer_id_in
			);
	begin
		for one in everything loop
			if one.type in ('U','S') then
				prune_group(one.id, one.type, one.quantity);
			else
				prune_family(customer_id_in, one.id, one.quantity);
			end if;
		end loop;
	end prune_everything;
	procedure subscribe_newest_servers (
		customer_id_in in number
	) is
		cursor servers(cid_in in number) is
			select	s.id
			from	rhnServer			s
			where	1=1
				and s.org_id = cid_in
				and not exists (
						select 1
						from	rhnChannel			c,
								rhnServerChannel	sc
						where	sc.server_id = s.id
							and sc.channel_id = c.id
							and c.parent_channel is null
					)
			order by s.modified desc;
		channel_id number;
	begin
		for server in servers(customer_id_in) loop
			channel_id := rhn_channel.guess_server_base(server.id);
			if channel_id is not null then
				begin
					rhn_channel.subscribe_server(server.id, channel_id);
					commit;
				exception
					when others then
						null;
				end;
			end if;
		end loop;
	end subscribe_newest_servers;
end rhn_entitlements;
/
show errors

select '../rhn/views/rhnServerOverview.sql' sql_file from dual;
-- SQL relevant contents from file ../rhn/views/rhnServerOverview.sql
create or replace view
rhnServerOverview
(
    org_id, 
    server_id, 
    server_name, 
    note_count, 
    modified, 
    server_admins, 
    group_count, 
    channel_labels, 
    history_count, 
    security_errata, 
    bug_errata, 
    enhancement_errata,
    outdated_packages,
    entitlement_level,
    last_checkin_days_ago,
    last_checkin,
    pending_updates,
    os,
    release,
    server_arch_name,
    locked
)
as
select
    s.org_id, s.id, s.name, 0, s.modified, 
    ( select count(user_id) from rhnUserServerPerms ap 
      where server_id = s.id ), 
    ( select count(server_group_id) from rhnVisibleServerGroupMembers
      where server_id = s.id ),
    NVL(( select C.name
        from rhnChannel C,
	     rhnServerChannel SC
       where SC.server_id = S.id
         and SC.channel_id = C.id
	 and C.parent_channel IS NULL), '(none)'),
    ( select count(id) from rhnServerHistory
      where
            server_id = S.id),
    ( select count(*) from rhnServerErrataTypeView sev 
      where
            sev.server_id = s.id
        and sev.errata_type = 'Security Advisory'), 
    ( select count(*) from rhnServerErrataTypeView sev 
      where 
            sev.server_id = s.id
        and sev.errata_type = 'Bug Fix Advisory'),
    ( select count(*) from rhnServerErrataTypeView sev 
      where 
            sev.server_id = s.id
        and sev.errata_type = 'Product Enhancement Advisory'),
    ( select count(distinct p.name_id) from rhnPackage p, rhnServerNeededPackageCache snpc
      where
             snpc.server_id = S.id
	 and p.id = snpc.package_id
	 ),    
    rhn_entitlements.get_server_entitlement(S.id),
    ( select sysdate - checkin from rhnServerInfo where server_id = S.id ),
    ( select TO_CHAR(checkin, 'YYYY-MM-DD HH24:MI:SS') from rhnServerInfo where server_id = S.id ),
    ( select count(1) 
        from rhnServerAction
       where server_id = S.id
         and status in (0, 1)),
    os,
    release,
    ( select name from rhnServerArch where id = s.server_arch_id),
    NVL((select 1 from rhnServerLock SL WHERE SL.server_id = S.id), 0)
from 
    rhnServer S
/

select '../rhn/views/rhnStorageDevice.sql' sql_file from dual;
-- SQL relevant contents from file ../rhn/views/rhnStorageDevice.sql
create or replace view 
rhnStorageDevice
(id, server_Id, class, bus, detached, device, driver, 
description, physical, logical, pcitype)
as select 
	d.id,
	d.server_Id,
	d.class,
	d.bus,
	d.detached,
	d.device,
	d.driver,
	d.description,
	d.prop1,
	d.prop2,
	d.pcitype
from rhnDevice d
where d.class in ('HD', 'FLOPPY');

select '../rhn/views/rhnUserActionOverview.sql' sql_file from dual;
-- SQL relevant contents from file ../rhn/views/rhnUserActionOverview.sql
create or replace view rhnUserActionOverview as
select	ao.org_id                                       org_id,
	uspd.user_id                                    user_id,
    	ao.action_id                                    id,
	ao.type_name                                    type_name,
        ao.scheduler                                    scheduler,
	ao.earliest_action                              earliest_action,
	decode(ao.name, null, ao.type_name, ao.name)	action_name,
	sa.status					action_status_id,
	astat.name                                      action_status,
	count(sa.action_id)				tally,
	ao.archived                                     archived
from	rhnActionStatus            astat,
    	rhnUserServerPermsDupes    uspd,
	rhnServerAction            sa,
	rhnActionOverview	   ao
where	ao.action_id = sa.action_id
  and   sa.server_id = uspd.server_id
  and   sa.status = astat.id
group by ao.org_id,
	 uspd.user_id,
	 ao.action_id,
	 ao.type_name,
	 ao.scheduler,
	 ao.earliest_action,
	 decode(ao.name, null, ao.type_name, ao.name),
	 sa.status,
	 astat.name,
	 ao.archived
order by earliest_action;

select '../rhn/views/rhnUserAppletOverview.sql' sql_file from dual;
-- SQL relevant contents from file ../rhn/views/rhnUserAppletOverview.sql
CREATE OR REPLACE VIEW
rhnUserAppletOverview
(
    	    user_id,
    	    security_count,
	    bug_count,
	    enhancement_count
)
AS
SELECT      USP.user_id,
    	    SUM((SELECT COUNT(*) FROM rhnServerErrataTypeView SEV 
	         WHERE SEV.server_id = USP.server_id
	         AND SEV.errata_type = 'Security Advisory')),
    	    SUM((SELECT COUNT(*) FROM rhnServerErrataTypeView SEV 
	         WHERE SEV.server_id = USP.server_id
	         AND SEV.errata_type = 'Bug Fix Advisory')),
    	    SUM((SELECT COUNT(*) FROM rhnServerErrataTypeView SEV 
	         WHERE SEV.server_id = USP.server_id
	         AND SEV.errata_type = 'Product Enhancement Advisory'))
FROM        rhnUserServerPerms USP
GROUP BY    USP.user_id
/

select '../rhn/views/rhnUserAvailableChannels.sql' sql_file from dual;
-- SQL relevant contents from file ../rhn/views/rhnUserAvailableChannels.sql
create or replace view
rhnUserAvailableChannels
(
    	user_id,
	channel_id,
	channel_depth,
	channel_name,
	channel_arch_id,
	padded_name,
	current_members,
	available_members,
        last_modified,
        channel_label,
	parent_or_self_label,
	end_of_life
)
as
select
     wc.id, 
     cperm.channel_id, 
     CT.depth, 
     CT.name, 
     CT.channel_arch_id, 
     CT.padded_name,
     (
     SELECT COUNT(1) 
       FROM rhnUserServerPerms USP
      WHERE USP.user_id = wc.id
        AND EXISTS (SELECT 1 FROM rhnServerChannel WHERE channel_id = cperm.channel_id AND server_id = USP.server_id)
     ),
     rhn_channel.available_chan_subscriptions(cperm.channel_id, wc.org_id),
     CT.last_modified,
     CT.label,
     CT.parent_or_self_label,
     CT.end_of_life
from
     web_contact wc,
     rhnChannelTreeView CT,
     rhnChannelPermissions CPerm
where
    CT.id = CPerm.channel_id
and (wc.org_id = cperm.org_id
 or cperm.org_id is null)
/

select '../rhn/views/rhnUserChannel.sql' sql_file from dual;
-- SQL relevant contents from file ../rhn/views/rhnUserChannel.sql
create or replace view rhnUserChannel as
select wc.id as user_id,
       wc.org_id as org_id,
       ac.channel_id as channel_id,
       'manage' as role
  from web_contact wc,
       rhnAvailableChannels ac
 where wc.org_id = ac.org_id
   and rhn_channel.user_role_check(ac.channel_id, wc.id, 'manage') = 1
union
select wc.id as user_id,
       wc.org_id as org_id,
       ac.channel_id as channel_id,
       'subscribe' as role
  from web_contact wc,
       rhnAvailableChannels ac
 where wc.org_id = ac.org_id
   and rhn_channel.user_role_check(ac.channel_id, wc.id, 'subscribe') = 1
/

select '../rhn/views/rhnUserGroupMembership.sql' sql_file from dual;
-- SQL relevant contents from file ../rhn/views/rhnUserGroupMembership.sql
CREATE OR REPLACE VIEW rhnUserGroupMembership (
         ORG_ID, USER_ID, GROUP_ID, GROUP_NAME, GROUP_TYPE
)
AS
SELECT   UG.org_id, UGM.user_id, UG.id, UG.name, UGT.label
  FROM   rhnUserGroupType UGT, 
    	 rhnUserGroup UG, 
	 rhnUserGroupMembers UGM
 WHERE   UG.id = UGM.user_group_id(+)
   AND   UG.group_type = UGT.id
/

select '../rhn/views/rhnVisibleServerGroup.sql' sql_file from dual;
-- SQL relevant contents from file ../rhn/views/rhnVisibleServerGroup.sql
CREATE OR REPLACE VIEW
rhnVisibleServerGroup
AS
  SELECT *
    FROM rhnServerGroup SG
   WHERE SG.group_type IS NULL;

select '../rhn/views/rhnUserTypeBase.sql' sql_file from dual;
-- SQL relevant contents from file ../rhn/views/rhnUserTypeBase.sql
create or replace view rhnUserTypeBase (
       user_id, type_id, type_label, type_name
)
AS
select distinct
    ugm.user_id, ugt.id, ugt.label, ugt.name
from   
    rhnUserGroupMembers ugm, rhnUserGroupType ugt, rhnUserGroup ug
where   
    ugm.user_group_id = ug.id
and ugt.id = ug.group_type;

select '../rhn/views/rhnUserTypeArray.sql' sql_file from dual;
-- SQL relevant contents from file ../rhn/views/rhnUserTypeArray.sql
create or replace view rhnUserTypeArray (
       user_id, type_id_t, type_label_t, type_name_t
)
as
select
    U.id,
    cast(multiset(select utb.type_id
    	    	  from rhnUserTypeBase utb 
    	    	  where utb.user_id = u.id)
	 as user_group_id_t),
    cast(multiset(select utb.type_label
    	    	  from rhnUserTypeBase utb
    	    	  where utb.user_id = u.id)
	 as user_group_label_t),
    cast(multiset(select utb.type_name
    	    	  from rhnUserTypeBase utb
    	    	  where utb.user_id = u.id)
	 as user_group_name_t)
from 
    web_contact u
/

select '../rhn/procs/name_join.sql' sql_file from dual;
-- SQL relevant contents from file ../rhn/procs/name_join.sql
CREATE OR REPLACE FUNCTION
NAME_JOIN(sep_in IN VARCHAR2, ugi_in IN user_group_name_t)
RETURN VARCHAR2
IS
	ret	VARCHAR2(4000);
	i	BINARY_INTEGER;
BEGIN
	ret := '';
	i := ugi_in.FIRST;
	IF i IS NULL
	THEN
		RETURN ret;
	END IF;
	ret := ugi_in(i);
	i := ugi_in.NEXT(i);
	WHILE i IS NOT NULL
	LOOP
		ret := ret || sep_in || ugi_in(i);
		i := ugi_in.NEXT(i);
	END LOOP;
	RETURN ret;
END;
/
SHOW ERRORS

select '../rhn/procs/label_join.sql' sql_file from dual;
-- SQL relevant contents from file ../rhn/procs/label_join.sql
CREATE OR REPLACE FUNCTION
LABEL_JOIN(sep_in IN VARCHAR2, ugi_in IN user_group_label_t)
RETURN VARCHAR2
IS
	ret	VARCHAR2(4000);
	i	BINARY_INTEGER;
BEGIN
	ret := '';
	i := ugi_in.FIRST;
	IF i IS NULL
	THEN
		RETURN ret;
	END IF;
	ret := ugi_in(i);
	i := ugi_in.NEXT(i);
	WHILE i IS NOT NULL
	LOOP
		ret := ret || sep_in || ugi_in(i);
		i := ugi_in.NEXT(i);
	END LOOP;
	RETURN ret;
END;
/
SHOW ERRORS

select '../rhn/procs/id_join.sql' sql_file from dual;
-- SQL relevant contents from file ../rhn/procs/id_join.sql
CREATE OR REPLACE FUNCTION
ID_JOIN(sep_in IN VARCHAR2, ugi_in IN user_group_id_t)
RETURN VARCHAR2
IS
	ret	VARCHAR2(4000);
	i	BINARY_INTEGER;
BEGIN
	ret := '';
	i := ugi_in.FIRST;
	IF i IS NULL
	THEN
		RETURN ret;
	END IF;
	ret := ugi_in(i);
	i := ugi_in.NEXT(i);
	WHILE i IS NOT NULL
	LOOP
		ret := ret || sep_in || ugi_in(i);
		i := ugi_in.NEXT(i);
	END LOOP;
	RETURN ret;
END;
/
SHOW ERRORS

select '../rhn/views/rhnUserTypeCommaView.sql' sql_file from dual;
-- SQL relevant contents from file ../rhn/views/rhnUserTypeCommaView.sql
create or replace view rhnUserTypeCommaView (
       user_id, ids, labels, names
)
as
select
    uta.user_id,
    id_join(', ', uta.type_id_t),
    label_join(', ', uta.type_label_t),
    name_join(', ', uta.type_name_t)
from	   
    rhnUserTypeArray uta
/

select '../web/tables/web_user_site_type.sql' sql_file from dual;
-- SQL relevant contents from file ../web/tables/web_user_site_type.sql
create table
web_user_site_type
(
	type			char(1)
				constraint wust_type_nn not null
				constraint wust_type_pk primary key,
	description		varchar2(64)
				constraint wust_desc_nn not null
);
insert into WEB_USER_SITE_TYPE VALUES('M', 'MARKET');
insert into WEB_USER_SITE_TYPE VALUES('B', 'BILL_TO');
insert into WEB_USER_SITE_TYPE VALUES('S', 'SHIP_TO');
insert into WEB_USER_SITE_TYPE VALUES('R', 'SERVICE');

select '../web/tables/web_user_site_info.sql' sql_file from dual;
-- SQL relevant contents from file ../web/tables/web_user_site_info.sql
create table
web_user_site_info
(
	id			number
				constraint wusi_id_nn not null
				constraint wusi_id_pk primary key,
	web_user_id		number
				constraint wusi_wuid_fk
					references web_contact(id)
					on delete cascade,
	email			varchar2(128),
	email_uc		varchar2(128),
	alt_first_names		varchar2(128),
	alt_last_name		varchar2(128),
	address1		varchar2(128)
				constraint wusi_addr1_nn not null,
	address2		varchar2(128),
	address3		varchar2(128),
	address4		varchar2(128),
	city			varchar2(128)
				constraint wusi_city_nn not null,
	state			varchar2(64),
	zip			varchar2(64),
	country			char(2)
				constraint wusi_country_nn not null,
	phone			varchar2(32),
	fax			varchar2(32),
	url			varchar2(128),
	is_po_box		char(1) default '0'
				constraint wusi_ipb_ck
					check (is_po_box in ('1','0')),
	type			char(1)
				constraint wusi_type_fk
					references web_user_site_type(type),
	oracle_site_id		varchar2(32),
	notes			varchar2(2000),
	created			date default(sysdate),
	modified		date default(sysdate),
	alt_first_names_ol	varchar2(128),
	alt_last_name_ol	varchar2(128),
	address1_ol		varchar2(128),
	address2_ol		varchar2(128),
	address3_ol		varchar2(128),
	city_ol			varchar2(128),
	state_ol		varchar2(32),
	zip_ol			varchar2(32)
);
create sequence web_user_site_info_id_seq;
create index web_user_site_info_wuid 
    on web_user_site_info(web_user_id)
    parallel 6;
create index wusi_email_uc_idx
    on web_user_site_info ( email_uc );
create or replace trigger
web_user_si_timestamp
before insert or update on web_user_site_info
for each row
begin
  :new.email_uc := upper(:new.email);
  :new.modified := sysdate;
end;
/
show errors

select '../rhn/views/rhnUsersInOrgOverview.sql' sql_file from dual;
-- SQL relevant contents from file ../rhn/views/rhnUsersInOrgOverview.sql
create or replace view rhnUsersInOrgOverview as
select    
	u.org_id					org_id,
	u.id						user_id,
	u.login						user_login,
	pi.first_names					user_first_name,
	pi.last_name					user_last_name,
	u.modified					user_modified, 
    	(	select	count(server_id)
		from	rhnUserServerPerms sp
		where	sp.user_id = u.id)
							server_count, 
	(	select	count(server_group_id)
		from	rhnUserManagedServerGroups umsg
		where	umsg.user_id = u.id and exists (
			select	1
			from	rhnVisibleServerGroup sg
			where	sg.id = umsg.server_group_id))
							server_group_count,
	(	select	nvl(utcv.names, '(normal user)')
		from	rhnUserTypeCommaView utcv
		where	utcv.user_id = u.id)
							role_names
from	web_user_personal_info pi, 
	web_contact u 
where
	u.id = pi.web_user_id;

select '../rhn/views/rhnVisServerGroupMembership.sql' sql_file from dual;
-- SQL relevant contents from file ../rhn/views/rhnVisServerGroupMembership.sql
CREATE OR REPLACE VIEW rhnVisServerGroupMembership (
         ORG_ID, SERVER_ID, GROUP_ID, GROUP_NAME, GROUP_TYPE, CURRENT_MEMBERS, MAX_MEMBERS
)
AS
SELECT   SG.org_id, SGM.server_id, SG.id, SG.name, SGT.label, SG.current_members, SG.max_members
  FROM   rhnServerGroupType SGT, 
	 rhnServerGroupMembers SGM,
    	 rhnVisibleServerGroup SG
 WHERE   SG.id = SGM.server_group_id(+)
   AND   SG.group_type = SGT.id(+)
/

select '../rhn/views/rhnVisServerGroupOverviewLite.sql' sql_file from dual;
-- SQL relevant contents from file ../rhn/views/rhnVisServerGroupOverviewLite.sql
create or replace view
rhnVisServerGroupOverviewLite as
select	sg.org_id					org_id,
		case when exists (
			select	1
			from	rhnServerGroupOVLiteHelper
			where	server_group_id = sg.id
				and advisory_type = 'Security Advisory'
			)
			then 1
			else 0
			end						security_errata,
		case when exists (
			select	1
			from	rhnServerGroupOVLiteHelper
			where	server_group_id = sg.id
				and advisory_type = 'Bug Fix Advisory'
			)
			then 1
			else 0
			end						bug_errata,
		case when exists (
			select	1
			from	rhnServerGroupOVLiteHelper
			where	server_group_id = sg.id
				and advisory_type = 'Product Enhancement Advisory'
			)
			then 1
			else 0
			end						enhancement_errata,
		sg.id						group_id,
		sg.name						group_name,
		(	select	count(*)
			from	rhnUserManagedServerGroups	umsg
			where	umsg.server_group_id = sg.id
		)							group_admins,
		(	select	count(*)
			from	rhnServerGroupMembers		sgm
			where	sgm.server_group_id = sg.id
		)							server_count,
		0							note_count,
		sysdate						modified,
		max_members					max_members
from	rhnVisibleServerGroup		sg
/

select '../rhn/views/rhnVisServerGroupOverview.sql' sql_file from dual;
-- SQL relevant contents from file ../rhn/views/rhnVisServerGroupOverview.sql
CREATE OR REPLACE VIEW rhnVisServerGroupOverview (
         ORG_ID, SECURITY_ERRATA, BUG_ERRATA, ENHANCEMENT_ERRATA, GROUP_ID, GROUP_NAME, GROUP_ADMINS, SERVER_COUNT, NOTE_COUNT, MODIFIED, MAX_MEMBERS
)
AS
  SELECT SG.org_id, 
         (SELECT COUNT(E.id)
	    FROM rhnErrata E
	   WHERE E.advisory_type = 'Security Advisory'
	     AND EXISTS (SELECT 1 FROM rhnServerNeededPackageCache SNEC, rhnServerGroupMembers SGM
	                         WHERE SGM.server_id = SNEC.server_id
				   AND SNEC.errata_id = E.id
				   AND SGM.server_group_id = SG.id)),
         (SELECT COUNT(E.id)
	    FROM rhnErrata E
	   WHERE E.advisory_type = 'Bug Fix Advisory'
	     AND EXISTS (SELECT 1 FROM rhnServerNeededPackageCache SNEC, rhnServerGroupMembers SGM
	                         WHERE SGM.server_id = SNEC.server_id
				   AND SNEC.errata_id = E.id
				   AND SGM.server_group_id = SG.id)),
         (SELECT COUNT(E.id)
	    FROM rhnErrata E
	   WHERE E.advisory_type = 'Product Enhancement Advisory'
	     AND EXISTS (SELECT 1 FROM rhnServerNeededPackageCache SNEC, rhnServerGroupMembers SGM
	                         WHERE SGM.server_id = SNEC.server_id
				   AND SNEC.errata_id = E.id
				   AND SGM.server_group_id = SG.id)),
	 SG.id, SG.name, 
	 (SELECT COUNT(*) FROM rhnUserManagedServerGroups UMSG WHERE UMSG.server_group_id = SG.id),
	 (SELECT COUNT(*) FROM rhnServerGroupMembers SGM WHERE SGM.server_group_id = SG.id), 
	 0, SYSDATE, MAX_MEMBERS
    FROM rhnVisibleServerGroup SG;

select '../web/tables/valid_countries.sql' sql_file from dual;
-- SQL relevant contents from file ../web/tables/valid_countries.sql
create table valid_countries (
    code       varchar(2)    NOT NULL
                             CONSTRAINT valid_countries_pk
                             PRIMARY KEY,
    short_name varchar(80) NOT NULL,
    name       varchar(240)
);
insert into valid_countries(code,short_name,name) values ('AD','Andorra','Principality of Andorra');
insert into valid_countries(code,short_name,name) values ('AE','United Arab Emirates','United Arab Emirates');
insert into valid_countries(code,short_name,name) values ('AF','Afghanistan','Islamic State of Afghanistan');
insert into valid_countries(code,short_name,name) values ('AG','Antigua and Barbuda','Antigua and Barbuda (includes Redonda)');
insert into valid_countries(code,short_name,name) values ('AI','Anguilla','Anguilla');
insert into valid_countries(code,short_name,name) values ('AL','Albania','Republic of Albania');
insert into valid_countries(code,short_name,name) values ('AM','Armenia','Republic of Armenia');
insert into valid_countries(code,short_name,name) values ('AN','Netherlands Antilles','Netherlands Antilles (includes Bonaire, Curacao, Saba, St. Eustatius, and Southern St. Martin)');
insert into valid_countries(code,short_name,name) values ('AO','Angola','Republic of Angola');
insert into valid_countries(code,short_name,name) values ('AQ','Antarctica','Territory south of 60 degrees south latitude');
insert into valid_countries(code,short_name,name) values ('AR','Argentina','Argentine Republic');
insert into valid_countries(code,short_name,name) values ('AS','American Samoa','American Samoa');
insert into valid_countries(code,short_name,name) values ('AT','Austria','Republic of Austria');
insert into valid_countries(code,short_name,name) values ('AU','Australia','Australia (includes Lord Howe Island, Macquarie Islands, Ashmore Islands and Cartier Island, and Coral Sea Islands are Australian external territories)');
insert into valid_countries(code,short_name,name) values ('AW','Aruba','Aruba');
insert into valid_countries(code,short_name,name) values ('AZ','Azerbaijan','Azerbaijani Republic');
insert into valid_countries(code,short_name,name) values ('BA','Bosnia and Herzegovina','Republic of Bosnia and Herzegovina');
insert into valid_countries(code,short_name,name) values ('BB','Barbados','Barbados');
insert into valid_countries(code,short_name,name) values ('BD','Bangladesh','Bangladesh');
insert into valid_countries(code,short_name,name) values ('BE','Belgium','Kingdom of Belgium');
insert into valid_countries(code,short_name,name) values ('BF','Burkina Faso','Burma see Myanmar');
insert into valid_countries(code,short_name,name) values ('BG','Bulgaria','Republic of Bulgaria');
insert into valid_countries(code,short_name,name) values ('BH','Bahrain','State of Bahrain');
insert into valid_countries(code,short_name,name) values ('BI','Burundi','Republic of Burundi');
insert into valid_countries(code,short_name,name) values ('BJ','Benin','Republic of Benin');
insert into valid_countries(code,short_name,name) values ('BM','Bermuda','Bermuda');
insert into valid_countries(code,short_name,name) values ('BN','Brunei Darussalam','Brunei Darussalam');
insert into valid_countries(code,short_name,name) values ('BO','Bolivia','Republic of Bolivia');
insert into valid_countries(code,short_name,name) values ('BR','Brazil','Federative Republic of Brazil (includes Rocas, Fernando de Noronha Archipelago, Trindade, Ilhas Martim Vaz, and Sao Pedro e Sao Paulo)');
insert into valid_countries(code,short_name,name) values ('BS','Bahamas','Commonwealth of the Bahamas (Turks and Caicos Islands not included)');
insert into valid_countries(code,short_name,name) values ('BT','Bhutan','Kingdom of Bhutan');
insert into valid_countries(code,short_name,name) values ('BV','Bouvet Island','Bouvet Island (also called Bouvetoya)');
insert into valid_countries(code,short_name,name) values ('BW','Botswana','Republic of Botswana');
insert into valid_countries(code,short_name,name) values ('BY','Belarus','Republic of Belarus');
insert into valid_countries(code,short_name,name) values ('BZ','Belize','Belize');
insert into valid_countries(code,short_name,name) values ('CA','Canada','Canada');
insert into valid_countries(code,short_name,name) values ('CC','Cocos (Keeling) Islands','Cocos (Keeling) Islands');
insert into valid_countries(code,short_name,name) values ('CF','Central African Republic','Central African Republic');
insert into valid_countries(code,short_name,name) values ('CG','Congo','Republic of the Congo');
insert into valid_countries(code,short_name,name) values ('CH','Switzerland','Swiss Confederation');
insert into valid_countries(code,short_name,name) values ('CI','Cote d''Ivoire','Republic of Cote d''Ivoire');
insert into valid_countries(code,short_name,name) values ('CK','Cook Islands','Cook Islands');
insert into valid_countries(code,short_name,name) values ('CL','Chile','Republic of Chile (includes Easter Island, Juan Fernandez Islands, San Felix and Sala y Gomez)');
insert into valid_countries(code,short_name,name) values ('CM','Cameroon','Republic of Cameroon');
insert into valid_countries(code,short_name,name) values ('CN','China','People''s Republic of China');
insert into valid_countries(code,short_name,name) values ('CO','Colombia','Republic of Colombia (includes San Andres y Providencia, Malpelo Island, Roncador Bank, Serrana Bank and Serranilla Bank)');
insert into valid_countries(code,short_name,name) values ('CR','Costa Rica','Republic of Costa Rica (includes Cocos Island)');
insert into valid_countries(code,short_name,name) values ('CU','Cuba','Republic of Cuba');
insert into valid_countries(code,short_name,name) values ('CV','Cape Verde','Republic of Cape Verde (includes Boa Vista, Brava, Fogo, Maio, Sal,  Santo Antao, Sao Nicolau, Sao Tiago and Sao Vicente)');
insert into valid_countries(code,short_name,name) values ('CX','Christmas Island','Australian Christmas Island');
insert into valid_countries(code,short_name,name) values ('CY','Cyprus','Republic of Cyprus');
insert into valid_countries(code,short_name,name) values ('CZ','Czech Republic','Czech Republic');
insert into valid_countries(code,short_name,name) values ('DE','Germany','Federal Republic of Germany');
insert into valid_countries(code,short_name,name) values ('DJ','Djibouti','Republic of Djibouti');
insert into valid_countries(code,short_name,name) values ('DK','Denmark','Kingdom of Denmark');
insert into valid_countries(code,short_name,name) values ('DM','Dominica','Commonwealth of Dominica');
insert into valid_countries(code,short_name,name) values ('DO','Dominican Republic','Dominican Republic');
insert into valid_countries(code,short_name,name) values ('DZ','Algeria','People''s Democratic Republic of Algeria');
insert into valid_countries(code,short_name,name) values ('EC','Ecuador','Republic of Ecuador (includes Galapagos Islands (Archipelago de Colon))');
insert into valid_countries(code,short_name,name) values ('EE','Estonia','Republic of Estonia');
insert into valid_countries(code,short_name,name) values ('EG','Egypt','Arab Republic of Egypt');
insert into valid_countries(code,short_name,name) values ('EH','Western Sahara','Western Sahara');
insert into valid_countries(code,short_name,name) values ('ER','Eritrea','Eritrea');
insert into valid_countries(code,short_name,name) values ('ES','Spain','Kingdom of Spain');
insert into valid_countries(code,short_name,name) values ('ET','Ethiopia','Ethiopia');
insert into valid_countries(code,short_name,name) values ('FI','Finland','Republic of Finland');
insert into valid_countries(code,short_name,name) values ('FJ','Fiji','Fiji');
insert into valid_countries(code,short_name,name) values ('FK','Falkland Islands (Malvinas)','Falkland Islands (Malvinas) (includes West Falkland, and East Falkland)');
insert into valid_countries(code,short_name,name) values ('FM','Micronesia (Federated States of)','Caroline Islands except Palau (includes Yap, Chuuk, Pohnpei, Kosrae)');
insert into valid_countries(code,short_name,name) values ('FO','Faroe Islands','Faroe Islands');
insert into valid_countries(code,short_name,name) values ('FR','France','French Republic');
insert into valid_countries(code,short_name,name) values ('FX','France, Metropolitan','France, Metropolitan');
insert into valid_countries(code,short_name,name) values ('GA','Gabon','Gabonese Republic');
insert into valid_countries(code,short_name,name) values ('GB','United Kingdom','United Kingdom of Great Britain and Northern Ireland (includes Orkney Islands and Shetland Island)');
insert into valid_countries(code,short_name,name) values ('GD','Grenada','Grenada (includes Southern Grenadine Islands)');
insert into valid_countries(code,short_name,name) values ('GE','Georgia','Republic of Georgia');
insert into valid_countries(code,short_name,name) values ('GF','French Guiana','Department of Guiana');
insert into valid_countries(code,short_name,name) values ('GH','Ghana','Republic of Ghana');
insert into valid_countries(code,short_name,name) values ('GI','Gibraltar','Gibraltar');
insert into valid_countries(code,short_name,name) values ('GL','Greenland','Greenland');
insert into valid_countries(code,short_name,name) values ('GM','Gambia','Republic of the Gambia');
insert into valid_countries(code,short_name,name) values ('GN','Guinea','Republic of Guinea');
insert into valid_countries(code,short_name,name) values ('GP','Guadeloupe','Department of Guadeloupe (includes Grande Terre, Basse Terre, Marie Galante, Les Saintes, Iles de la Petite Terre, Desirade, Saint-Barthelemy, and Northern St. Martin)');
insert into valid_countries(code,short_name,name) values ('GQ','Equatorial Guinea','Republic of Equatorial Guinea (includes Rio Muni, Bioko, Annobon, Corisco, Elobey Chico, and Elobey Grande)');
insert into valid_countries(code,short_name,name) values ('GR','Greece','Hellenic Republic (includes Aegean Islands, Ionian Islands, Dodecanese Islands, Crete, and Mount Athos autonomous area)');
insert into valid_countries(code,short_name,name) values ('GS','South Georgia and the South Sandwich Island','South Georgia and the South Sandwich Island');
insert into valid_countries(code,short_name,name) values ('GT','Guatemala','Republic of Guatemala');
insert into valid_countries(code,short_name,name) values ('GU','Guam','Guam');
insert into valid_countries(code,short_name,name) values ('GW','Guinea-Bissau','Republic of Guinea-Bissau');
insert into valid_countries(code,short_name,name) values ('GY','Guyana','Republic of Guyana');
insert into valid_countries(code,short_name,name) values ('HK','Hong Kong','Hong Kong (also called Hisiangkang, or Xianggang)');
insert into valid_countries(code,short_name,name) values ('HM','Heard Island and McDonald Islands','Heard Island and McDonald Islands');
insert into valid_countries(code,short_name,name) values ('HN','Honduras','Republic of Honduras (includes Swan Islands)');
insert into valid_countries(code,short_name,name) values ('HR','Croatia','Republic of Croatia');
insert into valid_countries(code,short_name,name) values ('HT','Haiti','Republic of Haiti');
insert into valid_countries(code,short_name,name) values ('HU','Hungary','Republic of Hungary');
insert into valid_countries(code,short_name,name) values ('ID','Indonesia','Republic of Indonesia');
insert into valid_countries(code,short_name,name) values ('IE','Ireland','Ireland');
insert into valid_countries(code,short_name,name) values ('IL','Israel','State of Israel');
insert into valid_countries(code,short_name,name) values ('IN','India','Republic of India (includes Amindivis, Laccadives, Minicoy, Andaman Islands, Nicobar Islands, and Sikkim)');
insert into valid_countries(code,short_name,name) values ('IO','British Indian Ocean Territory','Chagos Archipelago');
insert into valid_countries(code,short_name,name) values ('IQ','Iraq','Republic of Iraq');
insert into valid_countries(code,short_name,name) values ('IR','Iran (Islamic Republic of)','Islamic Republic of Iran');
insert into valid_countries(code,short_name,name) values ('IS','Iceland','Republic of Iceland');
insert into valid_countries(code,short_name,name) values ('IT','Italy','Italian Republic');
insert into valid_countries(code,short_name,name) values ('JM','Jamaica','Jamaica (includes Morant Cays, and Pedro Cays)');
insert into valid_countries(code,short_name,name) values ('JO','Jordan','Hashemite Kingdom of Jordan');
insert into valid_countries(code,short_name,name) values ('JP','Japan','Japan');
insert into valid_countries(code,short_name,name) values ('KE','Kenya','Republic of Kenya');
insert into valid_countries(code,short_name,name) values ('KG','Kyrgyzstan','Kyrgyz Republic');
insert into valid_countries(code,short_name,name) values ('KH','Cambodia','Kingdom of Cambodia');
insert into valid_countries(code,short_name,name) values ('KI','Kiribati','Kiribati (includes Fanning Island, Washington Island, and Christmas Island (all in the Line Islands), Ocean Island, Phoenix Islands (Birnie, Gardner, Hull, McKean, Phoenix, Sydney, Canton and Enderbury))');
insert into valid_countries(code,short_name,name) values ('KM','Comoros','Islamic Federal Republic of the Comoros (includes Anjouan, Grande Comore, Moheli, and other islands)');
insert into valid_countries(code,short_name,name) values ('KN','Saint Kitts and Nevis','Saint Kitts and Nevis');
insert into valid_countries(code,short_name,name) values ('KP','Korea, Democratic People''s Republic of','Korea, Democratic People''s Republic of');
insert into valid_countries(code,short_name,name) values ('KR','Korea, Republic of','Korea, Republic of');
insert into valid_countries(code,short_name,name) values ('KW','Kuwait','State of Kuwait');
insert into valid_countries(code,short_name,name) values ('KY','Cayman Islands','Cayman Islands (includes Grand Cayman, Cayman Brac and Little Cayman)');
insert into valid_countries(code,short_name,name) values ('KZ','Kazakhstan','Republic of Kazakhstan');
insert into valid_countries(code,short_name,name) values ('LA','Lao People''s Democratic Republic','Lao People''s Democratic Republic');
insert into valid_countries(code,short_name,name) values ('LB','Lebanon','Lebanese Republic');
insert into valid_countries(code,short_name,name) values ('LC','Saint Lucia','Saint Lucia');
insert into valid_countries(code,short_name,name) values ('LI','Liechtenstein','Principality of Liechtenstein');
insert into valid_countries(code,short_name,name) values ('LK','Sri Lanka','Democratic Socialist Republic of Sri Lanka');
insert into valid_countries(code,short_name,name) values ('LR','Liberia','Republic of Liberia');
insert into valid_countries(code,short_name,name) values ('LS','Lesotho','Kingdom of Lesotho');
insert into valid_countries(code,short_name,name) values ('LT','Latin America','Latin America');
insert into valid_countries(code,short_name,name) values ('LU','Luxembourg','Grand Duchy of Luxembourg');
insert into valid_countries(code,short_name,name) values ('LV','Latvia','Republic of Latvia');
insert into valid_countries(code,short_name,name) values ('LX','Lithuania','Republic of Lithuania');
insert into valid_countries(code,short_name,name) values ('LY','Libyan Arab Jamahiriya','Socialist People''s Libyan Arab Jamahiriya');
insert into valid_countries(code,short_name,name) values ('MA','Morocco','Kingdom of Morocco');
insert into valid_countries(code,short_name,name) values ('MC','Monaco','Principality of Monaco');
insert into valid_countries(code,short_name,name) values ('MD','Moldova, Republic of','Republic of Moldova');
insert into valid_countries(code,short_name,name) values ('MG','Madagascar','Republic of Madagascar');
insert into valid_countries(code,short_name,name) values ('MH','Marshall Islands','Republic of the Marshall Islands');
insert into valid_countries(code,short_name,name) values ('MK','Macedonia','Macedonia, the Former Yugoslav Republic of');
insert into valid_countries(code,short_name,name) values ('ML','Mali','Republic of Mali');
insert into valid_countries(code,short_name,name) values ('MM','Myanmar','Union of Myanmar');
insert into valid_countries(code,short_name,name) values ('MN','Mongolia','Mongolia');
insert into valid_countries(code,short_name,name) values ('MO','Macau','Macau (also called Ao-men)');
insert into valid_countries(code,short_name,name) values ('MP','Northern Mariana Islands','Commonwealth of the Northern Mariana Islands except Guam');
insert into valid_countries(code,short_name,name) values ('MQ','Martinique','Department of Martinique');
insert into valid_countries(code,short_name,name) values ('MR','Mauritania','Islamic Republic of Mauritania');
insert into valid_countries(code,short_name,name) values ('MS','Montserrat','Montserrat');
insert into valid_countries(code,short_name,name) values ('MT','Malta','Republic of Malta');
insert into valid_countries(code,short_name,name) values ('MU','Mauritius','Republic of Mauritius (includes Rodrigues, Agalega Islands, and Cargados Carajos)');
insert into valid_countries(code,short_name,name) values ('MV','Maldives','Republic of Maldives');
insert into valid_countries(code,short_name,name) values ('MW','Malawi','Republic of Malawi');
insert into valid_countries(code,short_name,name) values ('MX','Mexico','United Mexican States');
insert into valid_countries(code,short_name,name) values ('MY','Malaysia','Malaysia (includes Peninsular Malaysia, Sabah, and Sarawak)');
insert into valid_countries(code,short_name,name) values ('MZ','Mozambique','Republic of Mozambique');
insert into valid_countries(code,short_name,name) values ('NA','Namibia','Republic of Namibia');
insert into valid_countries(code,short_name,name) values ('NC','New Caledonia','New Caledonia (includes Isle of Pines, Loyalty Islands, Huon Islands,  Belep Archipelago, Chesterfield Islands, and Walpole)');
insert into valid_countries(code,short_name,name) values ('NE','Niger','Republic of the Niger');
insert into valid_countries(code,short_name,name) values ('NF','Norfolk Island','Norfolk Island');
insert into valid_countries(code,short_name,name) values ('NG','Nigeria','Federal Republic of Nigeria');
insert into valid_countries(code,short_name,name) values ('NI','Nicaragua','Republic of Nicaragua');
insert into valid_countries(code,short_name,name) values ('NL','Netherlands','Kingdom of the Netherlands');
insert into valid_countries(code,short_name,name) values ('NO','Norway','Kingdom of Norway');
insert into valid_countries(code,short_name,name) values ('NP','Nepal','Kingdom of Nepal');
insert into valid_countries(code,short_name,name) values ('NR','Nauru','Republic of Nauru');
insert into valid_countries(code,short_name,name) values ('NU','Niue','Niue');
insert into valid_countries(code,short_name,name) values ('NZ','New Zealand','New Zealand (includes Antipodes Islands, Auckland Islands, Bounty Islands, Campbell Islands, Kermadec Islands, Chatham Islands, and Snares Islands)');
insert into valid_countries(code,short_name,name) values ('OM','Oman','Sultanate of Oman');
insert into valid_countries(code,short_name,name) values ('PA','Panama','Republic of Panama');
insert into valid_countries(code,short_name,name) values ('PE','Peru','Republic of Peru');
insert into valid_countries(code,short_name,name) values ('PF','French Polynesia','French Polynesia (includes Society Archipelago, Tuamotu Archipelago, Marquezas Islands, Bambier Islands, Austral Islands, and Clipperton Island)');
insert into valid_countries(code,short_name,name) values ('PG','Papua New Guinea','Papua New Guinea (includes Bismarck and Louisiade Archipelagos, Admiralty Islands, d''Entrecasteaux Islands, Northern Solomon Islands, Trobriand Islands, New Britain, New Ireland, Woodlark, and associated islands)');
insert into valid_countries(code,short_name,name) values ('PH','Philippines','Republic of the Philippines');
insert into valid_countries(code,short_name,name) values ('PK','Pakistan','Islamic Republic of Pakistan');
insert into valid_countries(code,short_name,name) values ('PL','Poland','Republic of Poland');
insert into valid_countries(code,short_name,name) values ('PM','Saint Pierre and Miquelon','Territorial collectivity of St. Pierre and Miquelon');
insert into valid_countries(code,short_name,name) values ('PN','Pitcairn','Pitcairn (includes Henderson, Ducie, and Oeno)');
insert into valid_countries(code,short_name,name) values ('PR','Puerto Rico','Puerto Rico');
insert into valid_countries(code,short_name,name) values ('PT','Portugal','Portuguese Republic');
insert into valid_countries(code,short_name,name) values ('PW','Palau','Republic of Palau');
insert into valid_countries(code,short_name,name) values ('PY','Paraguay','Republic of Paraguay');
insert into valid_countries(code,short_name,name) values ('QA','Qatar','State of Qatar');
insert into valid_countries(code,short_name,name) values ('RE','Reunion','Department of Reunion');
insert into valid_countries(code,short_name,name) values ('RO','Romania','Romania');
insert into valid_countries(code,short_name,name) values ('RU','Russian Federation','Russian Federation');
insert into valid_countries(code,short_name,name) values ('RW','Rwanda','Rwandese Republic');
insert into valid_countries(code,short_name,name) values ('SA','Saudi Arabia','Kingdom of Saudi Arabia');
insert into valid_countries(code,short_name,name) values ('SB','Solomon Islands','Solomon Islands (includes Southern Solomon Islands, primarily Guadalcanal, Malaita, San Cristobal, Santa Isabel, Choiseul)');
insert into valid_countries(code,short_name,name) values ('SC','Seychelles','Republic of Seychelles (includes Alphonse, Bijoutier, St. Francois Islands, St. Pierre Islet, Cosmoledo Islands, Amirantes, Aldabra, Farquhar, and Desroches)');
insert into valid_countries(code,short_name,name) values ('SD','Sudan','Republic of the Sudan');
insert into valid_countries(code,short_name,name) values ('SG','Singapore','Singapore');
insert into valid_countries(code,short_name,name) values ('SH','Saint Helena','Saint Helena (includes Ascension, Gough Island, Inaccessible, Nightingale Islands, and Tristan da Cunha)');
insert into valid_countries(code,short_name,name) values ('SI','Slovenia','Republic of Slovenia');
insert into valid_countries(code,short_name,name) values ('SJ','Svalbard and Jan Mayen Islands','Svalbard and Jan Mayen Islands (includes Bear Island)');
insert into valid_countries(code,short_name,name) values ('SK','Slovakia','Slovak Republic');
insert into valid_countries(code,short_name,name) values ('SL','Sierra Leone','Republic of Sierra Leone');
insert into valid_countries(code,short_name,name) values ('SM','San Marino','Republic of San Marino');
insert into valid_countries(code,short_name,name) values ('SN','Senegal','Republic of Senegal');
insert into valid_countries(code,short_name,name) values ('SO','Somalia','Somali Democratic Republic');
insert into valid_countries(code,short_name,name) values ('SR','Suriname','Republic of Suriname');
insert into valid_countries(code,short_name,name) values ('ST','Sao Tome and Principe','Democratic Republic of Sao Tome and Principe');
insert into valid_countries(code,short_name,name) values ('SV','El Salvador','Republic of El Salvador');
insert into valid_countries(code,short_name,name) values ('SY','Syrian Arab Republic','Syrian Arab Republic');
insert into valid_countries(code,short_name,name) values ('SZ','Swaziland','Kingdom of Swaziland');
insert into valid_countries(code,short_name,name) values ('TC','Turks and Caicos Islands','Turks and Caicos Islands');
insert into valid_countries(code,short_name,name) values ('TD','Chad','Republic of Chad');
insert into valid_countries(code,short_name,name) values ('TF','French Southern Territories','French Southern Territories (includes Kerguelen Islands, Amsterdam, St. Paul, Crozet Islands)');
insert into valid_countries(code,short_name,name) values ('TG','Togo','Togolese Republic');
insert into valid_countries(code,short_name,name) values ('TH','Thailand','Kingdom of Thailand');
insert into valid_countries(code,short_name,name) values ('TJ','Tajikistan','Republic of Tajikistan');
insert into valid_countries(code,short_name,name) values ('TK','Tokelau','Tokelau');
insert into valid_countries(code,short_name,name) values ('TM','Turkmenistan','Turkmenistan');
insert into valid_countries(code,short_name,name) values ('TN','Tunisia','Republic of Tunisia');
insert into valid_countries(code,short_name,name) values ('TO','Tonga','Kingdom of Tonga');
insert into valid_countries(code,short_name,name) values ('TP','East Timor','East Timor (includes the exclave of Oe-Cussi)');
insert into valid_countries(code,short_name,name) values ('TR','Turkey','Republic of Turkey');
insert into valid_countries(code,short_name,name) values ('TT','Trinidad and Tobago','Republic of Trinidad and Tobago');
insert into valid_countries(code,short_name,name) values ('TV','Tuvalu','Tuvalu (includes Funafuti, Nanumanga, Nui, Nanomea, Nurakita, Niutao, Nukufetau, Nukulaelae, and Vaitupu)');
insert into valid_countries(code,short_name,name) values ('TW','Taiwan, Republic of China','Taiwan, Republic of China');
insert into valid_countries(code,short_name,name) values ('TZ','Tanzania, United Republic of','United Republic of Tanzania (includes Zanzibar and Pemba)');
insert into valid_countries(code,short_name,name) values ('UA','Ukraine','Ukraine');
insert into valid_countries(code,short_name,name) values ('UG','Uganda','Republic of Uganda');
insert into valid_countries(code,short_name,name) values ('UM','United States Minor Outlying Islands','United States Minor Outlying Islands (includes i.a. Baker Island, Howland Island, Jarvis Island, Johnston Atoll, Kingman Reef, Midway Islands,  Palmyra Islands, and Wake Island)');
insert into valid_countries(code,short_name,name) values ('US','United States','United States of America');
insert into valid_countries(code,short_name,name) values ('UY','Uruguay','Eastern Republic of Uruguay');
insert into valid_countries(code,short_name,name) values ('UZ','Uzbekistan','Republic of Uzbekistan');
insert into valid_countries(code,short_name,name) values ('VA','Vatican City State (Holy See)','Vatican City State (Holy See)');
insert into valid_countries(code,short_name,name) values ('VC','Saint Vincent and the Grenadines','Saint Vincent and the Grenadines (includes Northern Grenadine Islands)');
insert into valid_countries(code,short_name,name) values ('VE','Venezuela','Republic of Venezuela');
insert into valid_countries(code,short_name,name) values ('VG','Virgin Islands (British)','Virgin Islands (British) (includes Anegada, Jost Van Dyke, Tortola, and Virgin Gorda)');
insert into valid_countries(code,short_name,name) values ('VI','Virgin Islands (U.S.)','Virgin Islands of the United States (includes Saint Croix, Saint John, and Saint Thomas)');
insert into valid_countries(code,short_name,name) values ('VN','Viet Nam','Socialist Republic of Viet Nam');
insert into valid_countries(code,short_name,name) values ('VU','Vanuatu','Republic of Vanuatu');
insert into valid_countries(code,short_name,name) values ('WF','Wallis and Futuna Islands','Wallis and Futuna Islands (includes Iles Wallis (Uvea), and Iles de Hoorn (Futuna and Alofi))');
insert into valid_countries(code,short_name,name) values ('WS','Samoa','Independent State of Western Samoa');
insert into valid_countries(code,short_name,name) values ('YE','Yemen','Republic of Yemen (includes Perim, Kamaran, Socotra, and associated islands)');
insert into valid_countries(code,short_name,name) values ('YT','Mayotte','Territorial collectivity of Mayotte (includes Grande-Terre, and Pamandzi)');
insert into valid_countries(code,short_name,name) values ('YU','Yugoslavia','Federal Republic of Yugoslavia');
insert into valid_countries(code,short_name,name) values ('ZA','South Africa','Republic of South Africa (includes Walvis Bay, Marion Island, and Prince  Edward Island)');
insert into valid_countries(code,short_name,name) values ('ZM','Zambia','Republic of Zambia');
insert into valid_countries(code,short_name,name) values ('ZR','Zaire','Republic of Zaire');
insert into valid_countries(code,short_name,name) values ('ZW','Zimbabwe','Republic of Zimbabwe');
insert into valid_countries(code,short_name,name) values ('SE','Sweden','Kingom of Sweden');
create table valid_countries_tl (
    lang          char(2)     NOT NULL,
    code          varchar(2)  NOT NULL
			      CONSTRAINT valid_countries_tl_code
                                REFERENCES valid_countries(code),
    short_name_tl varchar(80) NOT NULL,
                              CONSTRAINT valid_countries_tl_unq
                                UNIQUE (lang, code)
);
insert into valid_countries_tl(lang,code,short_name_tl) values ('ja','AD','????');
insert into valid_countries_tl(lang,code,short_name_tl) values ('ja','AE','????????');
insert into valid_countries_tl(lang,code,short_name_tl) values ('ja','AF','???????');
insert into valid_countries_tl(lang,code,short_name_tl) values ('ja','AG','????????????');
insert into valid_countries_tl(lang,code,short_name_tl) values ('ja','AI','????');
insert into valid_countries_tl(lang,code,short_name_tl) values ('ja','AL','?????');
insert into valid_countries_tl(lang,code,short_name_tl) values ('ja','AM','?????');
insert into valid_countries_tl(lang,code,short_name_tl) values ('ja','AN','???????????');
insert into valid_countries_tl(lang,code,short_name_tl) values ('ja','AO','????');
insert into valid_countries_tl(lang,code,short_name_tl) values ('ja','AQ','Antarctica');
insert into valid_countries_tl(lang,code,short_name_tl) values ('ja','AR','??????');
insert into valid_countries_tl(lang,code,short_name_tl) values ('ja','AS','?????');
insert into valid_countries_tl(lang,code,short_name_tl) values ('ja','AT','??????');
insert into valid_countries_tl(lang,code,short_name_tl) values ('ja','AU','???????');
insert into valid_countries_tl(lang,code,short_name_tl) values ('ja','AW','???');
insert into valid_countries_tl(lang,code,short_name_tl) values ('ja','AZ','????????');
insert into valid_countries_tl(lang,code,short_name_tl) values ('ja','BA','????????????');
insert into valid_countries_tl(lang,code,short_name_tl) values ('ja','BB','?????');
insert into valid_countries_tl(lang,code,short_name_tl) values ('ja','BD','???????');
insert into valid_countries_tl(lang,code,short_name_tl) values ('ja','BE','????');
insert into valid_countries_tl(lang,code,short_name_tl) values ('ja','BF','????????');
insert into valid_countries_tl(lang,code,short_name_tl) values ('ja','BG','?????');
insert into valid_countries_tl(lang,code,short_name_tl) values ('ja','BH','?????');
insert into valid_countries_tl(lang,code,short_name_tl) values ('ja','BI','????');
insert into valid_countries_tl(lang,code,short_name_tl) values ('ja','BJ','???');
insert into valid_countries_tl(lang,code,short_name_tl) values ('ja','BM','???????');
insert into valid_countries_tl(lang,code,short_name_tl) values ('ja','BN','????');
insert into valid_countries_tl(lang,code,short_name_tl) values ('ja','BO','????');
insert into valid_countries_tl(lang,code,short_name_tl) values ('ja','BR','????');
insert into valid_countries_tl(lang,code,short_name_tl) values ('ja','BS','???');
insert into valid_countries_tl(lang,code,short_name_tl) values ('ja','BT','????');
insert into valid_countries_tl(lang,code,short_name_tl) values ('ja','BV','Bouvet Island');
insert into valid_countries_tl(lang,code,short_name_tl) values ('ja','BW','????');
insert into valid_countries_tl(lang,code,short_name_tl) values ('ja','BY','?????');
insert into valid_countries_tl(lang,code,short_name_tl) values ('ja','BZ','????');
insert into valid_countries_tl(lang,code,short_name_tl) values ('ja','CA','???');
insert into valid_countries_tl(lang,code,short_name_tl) values ('ja','CC','?????');
insert into valid_countries_tl(lang,code,short_name_tl) values ('ja','CF','??????');
insert into valid_countries_tl(lang,code,short_name_tl) values ('ja','CG','???');
insert into valid_countries_tl(lang,code,short_name_tl) values ('ja','CH','???');
insert into valid_countries_tl(lang,code,short_name_tl) values ('ja','CI','????????');
insert into valid_countries_tl(lang,code,short_name_tl) values ('ja','CK','?????');
insert into valid_countries_tl(lang,code,short_name_tl) values ('ja','CL','??');
insert into valid_countries_tl(lang,code,short_name_tl) values ('ja','CM','?????');
insert into valid_countries_tl(lang,code,short_name_tl) values ('ja','CN','??');
insert into valid_countries_tl(lang,code,short_name_tl) values ('ja','CO','?????');
insert into valid_countries_tl(lang,code,short_name_tl) values ('ja','CR','?????');
insert into valid_countries_tl(lang,code,short_name_tl) values ('ja','CU','????');
insert into valid_countries_tl(lang,code,short_name_tl) values ('ja','CV','??????');
insert into valid_countries_tl(lang,code,short_name_tl) values ('ja','CX','??????');
insert into valid_countries_tl(lang,code,short_name_tl) values ('ja','CY','????');
insert into valid_countries_tl(lang,code,short_name_tl) values ('ja','CZ','???');
insert into valid_countries_tl(lang,code,short_name_tl) values ('ja','DE','???');
insert into valid_countries_tl(lang,code,short_name_tl) values ('ja','DJ','???');
insert into valid_countries_tl(lang,code,short_name_tl) values ('ja','DK','?????');
insert into valid_countries_tl(lang,code,short_name_tl) values ('ja','DM','????');
insert into valid_countries_tl(lang,code,short_name_tl) values ('ja','DO','???????');
insert into valid_countries_tl(lang,code,short_name_tl) values ('ja','DZ','??????');
insert into valid_countries_tl(lang,code,short_name_tl) values ('ja','EC','?????');
insert into valid_countries_tl(lang,code,short_name_tl) values ('ja','EE','?????');
insert into valid_countries_tl(lang,code,short_name_tl) values ('ja','EG','????');
insert into valid_countries_tl(lang,code,short_name_tl) values ('ja','EH','????');
insert into valid_countries_tl(lang,code,short_name_tl) values ('ja','ER','?????');
insert into valid_countries_tl(lang,code,short_name_tl) values ('ja','ES','????');
insert into valid_countries_tl(lang,code,short_name_tl) values ('ja','ET','?????');
insert into valid_countries_tl(lang,code,short_name_tl) values ('ja','FI','??????');
insert into valid_countries_tl(lang,code,short_name_tl) values ('ja','FJ','????');
insert into valid_countries_tl(lang,code,short_name_tl) values ('ja','FK','?????????');
insert into valid_countries_tl(lang,code,short_name_tl) values ('ja','FM','??????');
insert into valid_countries_tl(lang,code,short_name_tl) values ('ja','FO','??????');
insert into valid_countries_tl(lang,code,short_name_tl) values ('ja','FR','????');
insert into valid_countries_tl(lang,code,short_name_tl) values ('ja','FX','France, Metropolitan');
insert into valid_countries_tl(lang,code,short_name_tl) values ('ja','GA','???');
insert into valid_countries_tl(lang,code,short_name_tl) values ('ja','GB','????');
insert into valid_countries_tl(lang,code,short_name_tl) values ('ja','GD','????');
insert into valid_countries_tl(lang,code,short_name_tl) values ('ja','GE','????');
insert into valid_countries_tl(lang,code,short_name_tl) values ('ja','GF','????????');
insert into valid_countries_tl(lang,code,short_name_tl) values ('ja','GH','???');
insert into valid_countries_tl(lang,code,short_name_tl) values ('ja','GI','??????');
insert into valid_countries_tl(lang,code,short_name_tl) values ('ja','GL','???????');
insert into valid_countries_tl(lang,code,short_name_tl) values ('ja','GM','????');
insert into valid_countries_tl(lang,code,short_name_tl) values ('ja','GN','???');
insert into valid_countries_tl(lang,code,short_name_tl) values ('ja','GP','???????');
insert into valid_countries_tl(lang,code,short_name_tl) values ('ja','GQ','?????');
insert into valid_countries_tl(lang,code,short_name_tl) values ('ja','GR','????');
insert into valid_countries_tl(lang,code,short_name_tl) values ('ja','GS','S. Georgia and S. Sandwich Isls.');
insert into valid_countries_tl(lang,code,short_name_tl) values ('ja','GT','?????');
insert into valid_countries_tl(lang,code,short_name_tl) values ('ja','GU','???');
insert into valid_countries_tl(lang,code,short_name_tl) values ('ja','GW','??????');
insert into valid_countries_tl(lang,code,short_name_tl) values ('ja','GY','????');
insert into valid_countries_tl(lang,code,short_name_tl) values ('ja','HK','??');
insert into valid_countries_tl(lang,code,short_name_tl) values ('ja','HM','Heard and McDonald Islands');
insert into valid_countries_tl(lang,code,short_name_tl) values ('ja','HN','??????');
insert into valid_countries_tl(lang,code,short_name_tl) values ('ja','HR','?????');
insert into valid_countries_tl(lang,code,short_name_tl) values ('ja','HT','???');
insert into valid_countries_tl(lang,code,short_name_tl) values ('ja','HU','?????');
insert into valid_countries_tl(lang,code,short_name_tl) values ('ja','ID','??????');
insert into valid_countries_tl(lang,code,short_name_tl) values ('ja','IE','??????');
insert into valid_countries_tl(lang,code,short_name_tl) values ('ja','IL','?????');
insert into valid_countries_tl(lang,code,short_name_tl) values ('ja','IN','???');
insert into valid_countries_tl(lang,code,short_name_tl) values ('ja','IO','British Indian Ocean Territory');
insert into valid_countries_tl(lang,code,short_name_tl) values ('ja','IQ','???');
insert into valid_countries_tl(lang,code,short_name_tl) values ('ja','IR','???');
insert into valid_countries_tl(lang,code,short_name_tl) values ('ja','IS','??????');
insert into valid_countries_tl(lang,code,short_name_tl) values ('ja','IT','????');
insert into valid_countries_tl(lang,code,short_name_tl) values ('ja','JM','?????');
insert into valid_countries_tl(lang,code,short_name_tl) values ('ja','JO','????');
insert into valid_countries_tl(lang,code,short_name_tl) values ('ja','JP','??');
insert into valid_countries_tl(lang,code,short_name_tl) values ('ja','KE','???');
insert into valid_countries_tl(lang,code,short_name_tl) values ('ja','KG','??????');
insert into valid_countries_tl(lang,code,short_name_tl) values ('ja','KH','?????');
insert into valid_countries_tl(lang,code,short_name_tl) values ('ja','KI','????');
insert into valid_countries_tl(lang,code,short_name_tl) values ('ja','KM','???');
insert into valid_countries_tl(lang,code,short_name_tl) values ('ja','KN','Saint Kitts and Nevis');
insert into valid_countries_tl(lang,code,short_name_tl) values ('ja','KP','???');
insert into valid_countries_tl(lang,code,short_name_tl) values ('ja','KR','??');
insert into valid_countries_tl(lang,code,short_name_tl) values ('ja','KW','?????');
insert into valid_countries_tl(lang,code,short_name_tl) values ('ja','KY','??????');
insert into valid_countries_tl(lang,code,short_name_tl) values ('ja','KZ','??????');
insert into valid_countries_tl(lang,code,short_name_tl) values ('ja','LA','???');
insert into valid_countries_tl(lang,code,short_name_tl) values ('ja','LB','????');
insert into valid_countries_tl(lang,code,short_name_tl) values ('ja','LC','??????');
insert into valid_countries_tl(lang,code,short_name_tl) values ('ja','LI','?????????');
insert into valid_countries_tl(lang,code,short_name_tl) values ('ja','LK','?????');
insert into valid_countries_tl(lang,code,short_name_tl) values ('ja','LR','????');
insert into valid_countries_tl(lang,code,short_name_tl) values ('ja','LS','???');
insert into valid_countries_tl(lang,code,short_name_tl) values ('ja','LT','?????');
insert into valid_countries_tl(lang,code,short_name_tl) values ('ja','LU','???????');
insert into valid_countries_tl(lang,code,short_name_tl) values ('ja','LV','????');
insert into valid_countries_tl(lang,code,short_name_tl) values ('ja','LY','???');
insert into valid_countries_tl(lang,code,short_name_tl) values ('ja','MA','????');
insert into valid_countries_tl(lang,code,short_name_tl) values ('ja','MC','???');
insert into valid_countries_tl(lang,code,short_name_tl) values ('ja','MD','?????');
insert into valid_countries_tl(lang,code,short_name_tl) values ('ja','MG','??????');
insert into valid_countries_tl(lang,code,short_name_tl) values ('ja','MH','???????');
insert into valid_countries_tl(lang,code,short_name_tl) values ('ja','MK','?????');
insert into valid_countries_tl(lang,code,short_name_tl) values ('ja','ML','??');
insert into valid_countries_tl(lang,code,short_name_tl) values ('ja','MM','?????');
insert into valid_countries_tl(lang,code,short_name_tl) values ('ja','MN','????');
insert into valid_countries_tl(lang,code,short_name_tl) values ('ja','MO','???');
insert into valid_countries_tl(lang,code,short_name_tl) values ('ja','MP','Northern Mariana Islands');
insert into valid_countries_tl(lang,code,short_name_tl) values ('ja','MQ','??????');
insert into valid_countries_tl(lang,code,short_name_tl) values ('ja','MR','??????');
insert into valid_countries_tl(lang,code,short_name_tl) values ('ja','MS','??????');
insert into valid_countries_tl(lang,code,short_name_tl) values ('ja','MT','????');
insert into valid_countries_tl(lang,code,short_name_tl) values ('ja','MU','??????');
insert into valid_countries_tl(lang,code,short_name_tl) values ('ja','MV','????');
insert into valid_countries_tl(lang,code,short_name_tl) values ('ja','MW','????');
insert into valid_countries_tl(lang,code,short_name_tl) values ('ja','MX','????');
insert into valid_countries_tl(lang,code,short_name_tl) values ('ja','MY','?????');
insert into valid_countries_tl(lang,code,short_name_tl) values ('ja','MZ','??????');
insert into valid_countries_tl(lang,code,short_name_tl) values ('ja','NA','????');
insert into valid_countries_tl(lang,code,short_name_tl) values ('ja','NC','????????');
insert into valid_countries_tl(lang,code,short_name_tl) values ('ja','NE','?????');
insert into valid_countries_tl(lang,code,short_name_tl) values ('ja','NF','???????');
insert into valid_countries_tl(lang,code,short_name_tl) values ('ja','NG','??????');
insert into valid_countries_tl(lang,code,short_name_tl) values ('ja','NI','?????');
insert into valid_countries_tl(lang,code,short_name_tl) values ('ja','NL','????');
insert into valid_countries_tl(lang,code,short_name_tl) values ('ja','NO','?????');
insert into valid_countries_tl(lang,code,short_name_tl) values ('ja','NP','????');
insert into valid_countries_tl(lang,code,short_name_tl) values ('ja','NR','???');
insert into valid_countries_tl(lang,code,short_name_tl) values ('ja','NU','???');
insert into valid_countries_tl(lang,code,short_name_tl) values ('ja','NZ','????????');
insert into valid_countries_tl(lang,code,short_name_tl) values ('ja','OM','????');
insert into valid_countries_tl(lang,code,short_name_tl) values ('ja','PA','???');
insert into valid_countries_tl(lang,code,short_name_tl) values ('ja','PE','???');
insert into valid_countries_tl(lang,code,short_name_tl) values ('ja','PF','??????????');
insert into valid_countries_tl(lang,code,short_name_tl) values ('ja','PG','?????????');
insert into valid_countries_tl(lang,code,short_name_tl) values ('ja','PH','?????');
insert into valid_countries_tl(lang,code,short_name_tl) values ('ja','PK','?????');
insert into valid_countries_tl(lang,code,short_name_tl) values ('ja','PL','?????');
insert into valid_countries_tl(lang,code,short_name_tl) values ('ja','PM','?????????????');
insert into valid_countries_tl(lang,code,short_name_tl) values ('ja','PN','Pitcairn');
insert into valid_countries_tl(lang,code,short_name_tl) values ('ja','PR','??????');
insert into valid_countries_tl(lang,code,short_name_tl) values ('ja','PT','?????');
insert into valid_countries_tl(lang,code,short_name_tl) values ('ja','PW','???');
insert into valid_countries_tl(lang,code,short_name_tl) values ('ja','PY','?????');
insert into valid_countries_tl(lang,code,short_name_tl) values ('ja','QA','????');
insert into valid_countries_tl(lang,code,short_name_tl) values ('ja','RE','?????');
insert into valid_countries_tl(lang,code,short_name_tl) values ('ja','RO','?????');
insert into valid_countries_tl(lang,code,short_name_tl) values ('ja','RU','???');
insert into valid_countries_tl(lang,code,short_name_tl) values ('ja','RW','????');
insert into valid_countries_tl(lang,code,short_name_tl) values ('ja','SA','???????');
insert into valid_countries_tl(lang,code,short_name_tl) values ('ja','SB','??????');
insert into valid_countries_tl(lang,code,short_name_tl) values ('ja','SC','?????');
insert into valid_countries_tl(lang,code,short_name_tl) values ('ja','SD','????');
insert into valid_countries_tl(lang,code,short_name_tl) values ('ja','SE','??????');
insert into valid_countries_tl(lang,code,short_name_tl) values ('ja','SG','??????');
insert into valid_countries_tl(lang,code,short_name_tl) values ('ja','SH','???????');
insert into valid_countries_tl(lang,code,short_name_tl) values ('ja','SI','?????');
insert into valid_countries_tl(lang,code,short_name_tl) values ('ja','SJ','Svalbard and Jan Mayen Islands');
insert into valid_countries_tl(lang,code,short_name_tl) values ('ja','SK','?????');
insert into valid_countries_tl(lang,code,short_name_tl) values ('ja','SL','??????');
insert into valid_countries_tl(lang,code,short_name_tl) values ('ja','SM','?????');
insert into valid_countries_tl(lang,code,short_name_tl) values ('ja','SN','????');
insert into valid_countries_tl(lang,code,short_name_tl) values ('ja','SO','????');
insert into valid_countries_tl(lang,code,short_name_tl) values ('ja','SR','????');
insert into valid_countries_tl(lang,code,short_name_tl) values ('ja','ST','??????????');
insert into valid_countries_tl(lang,code,short_name_tl) values ('ja','SV','???????');
insert into valid_countries_tl(lang,code,short_name_tl) values ('ja','SY','???');
insert into valid_countries_tl(lang,code,short_name_tl) values ('ja','SZ','??????');
insert into valid_countries_tl(lang,code,short_name_tl) values ('ja','TC','?????????????');
insert into valid_countries_tl(lang,code,short_name_tl) values ('ja','TD','???');
insert into valid_countries_tl(lang,code,short_name_tl) values ('ja','TF','French Southern Territories');
insert into valid_countries_tl(lang,code,short_name_tl) values ('ja','TG','???');
insert into valid_countries_tl(lang,code,short_name_tl) values ('ja','TH','??');
insert into valid_countries_tl(lang,code,short_name_tl) values ('ja','TJ','??????');
insert into valid_countries_tl(lang,code,short_name_tl) values ('ja','TK','Tokelau');
insert into valid_countries_tl(lang,code,short_name_tl) values ('ja','TM','????????');
insert into valid_countries_tl(lang,code,short_name_tl) values ('ja','TN','?????');
insert into valid_countries_tl(lang,code,short_name_tl) values ('ja','TO','???');
insert into valid_countries_tl(lang,code,short_name_tl) values ('ja','TP','?????');
insert into valid_countries_tl(lang,code,short_name_tl) values ('ja','TR','???');
insert into valid_countries_tl(lang,code,short_name_tl) values ('ja','TT','??????????');
insert into valid_countries_tl(lang,code,short_name_tl) values ('ja','TV','???');
insert into valid_countries_tl(lang,code,short_name_tl) values ('ja','TW','??');
insert into valid_countries_tl(lang,code,short_name_tl) values ('ja','TZ','?????');
insert into valid_countries_tl(lang,code,short_name_tl) values ('ja','UA','?????');
insert into valid_countries_tl(lang,code,short_name_tl) values ('ja','UG','????');
insert into valid_countries_tl(lang,code,short_name_tl) values ('ja','UM','US Minor Outlying Islands');
insert into valid_countries_tl(lang,code,short_name_tl) values ('ja','US','???????');
insert into valid_countries_tl(lang,code,short_name_tl) values ('ja','UY','?????');
insert into valid_countries_tl(lang,code,short_name_tl) values ('ja','UZ','???????');
insert into valid_countries_tl(lang,code,short_name_tl) values ('ja','VA','??????');
insert into valid_countries_tl(lang,code,short_name_tl) values ('ja','VC','????????????????????');
insert into valid_countries_tl(lang,code,short_name_tl) values ('ja','VE','?????');
insert into valid_countries_tl(lang,code,short_name_tl) values ('ja','VG','????????');
insert into valid_countries_tl(lang,code,short_name_tl) values ('ja','VI','????????');
insert into valid_countries_tl(lang,code,short_name_tl) values ('ja','VN','????');
insert into valid_countries_tl(lang,code,short_name_tl) values ('ja','VU','????');
insert into valid_countries_tl(lang,code,short_name_tl) values ('ja','WF','Wallis and Futuna Islands');
insert into valid_countries_tl(lang,code,short_name_tl) values ('ja','WS','???');
insert into valid_countries_tl(lang,code,short_name_tl) values ('ja','YE','????');
insert into valid_countries_tl(lang,code,short_name_tl) values ('ja','YT','Mayotte');
insert into valid_countries_tl(lang,code,short_name_tl) values ('ja','YU','???????');
insert into valid_countries_tl(lang,code,short_name_tl) values ('ja','ZA','?????');
insert into valid_countries_tl(lang,code,short_name_tl) values ('ja','ZM','????');
insert into valid_countries_tl(lang,code,short_name_tl) values ('ja','ZR','????');
insert into valid_countries_tl(lang,code,short_name_tl) values ('ja','ZW','?????');
insert into valid_countries_tl(lang,code,short_name_tl) values ('de','AD','Andorra');
insert into valid_countries_tl(lang,code,short_name_tl) values ('de','AE','Vereinigte Arabische Emirate');
insert into valid_countries_tl(lang,code,short_name_tl) values ('de','AF','Afghanistan');
insert into valid_countries_tl(lang,code,short_name_tl) values ('de','AG','Antigua und Barbuda');
insert into valid_countries_tl(lang,code,short_name_tl) values ('de','AI','Anguilla');
insert into valid_countries_tl(lang,code,short_name_tl) values ('de','AL','Albanien');
insert into valid_countries_tl(lang,code,short_name_tl) values ('de','AM','Armenien');
insert into valid_countries_tl(lang,code,short_name_tl) values ('de','AN','Niederlandische Antillen');
insert into valid_countries_tl(lang,code,short_name_tl) values ('de','AO','Angola');
insert into valid_countries_tl(lang,code,short_name_tl) values ('de','AQ','Antarktika');
insert into valid_countries_tl(lang,code,short_name_tl) values ('de','AR','Argentinien');
insert into valid_countries_tl(lang,code,short_name_tl) values ('de','AS','Ostsamoa');
insert into valid_countries_tl(lang,code,short_name_tl) values ('de','AT','osterreich');
insert into valid_countries_tl(lang,code,short_name_tl) values ('de','AU','Australien');
insert into valid_countries_tl(lang,code,short_name_tl) values ('de','AW','Aruba');
insert into valid_countries_tl(lang,code,short_name_tl) values ('de','AZ','Aserbaidschan');
insert into valid_countries_tl(lang,code,short_name_tl) values ('de','BA','Bosnien-Herzegovina');
insert into valid_countries_tl(lang,code,short_name_tl) values ('de','BB','Barbados');
insert into valid_countries_tl(lang,code,short_name_tl) values ('de','BD','Bangladesch');
insert into valid_countries_tl(lang,code,short_name_tl) values ('de','BE','Belgien');
insert into valid_countries_tl(lang,code,short_name_tl) values ('de','BF','Burkina Faso');
insert into valid_countries_tl(lang,code,short_name_tl) values ('de','BG','Bulgarien');
insert into valid_countries_tl(lang,code,short_name_tl) values ('de','BH','Bahrain');
insert into valid_countries_tl(lang,code,short_name_tl) values ('de','BI','Burundi');
insert into valid_countries_tl(lang,code,short_name_tl) values ('de','BJ','Benin');
insert into valid_countries_tl(lang,code,short_name_tl) values ('de','BM','Bermuda-Inseln');
insert into valid_countries_tl(lang,code,short_name_tl) values ('de','BN','Brunei');
insert into valid_countries_tl(lang,code,short_name_tl) values ('de','BO','Bolivien');
insert into valid_countries_tl(lang,code,short_name_tl) values ('de','BR','Brazilien');
insert into valid_countries_tl(lang,code,short_name_tl) values ('de','BS','Bahamas');
insert into valid_countries_tl(lang,code,short_name_tl) values ('de','BT','Bhutan');
insert into valid_countries_tl(lang,code,short_name_tl) values ('de','BV','Bouvet Insel');
insert into valid_countries_tl(lang,code,short_name_tl) values ('de','BW','Botswana');
insert into valid_countries_tl(lang,code,short_name_tl) values ('de','BY','Wei?ru?land');
insert into valid_countries_tl(lang,code,short_name_tl) values ('de','BZ','Belize');
insert into valid_countries_tl(lang,code,short_name_tl) values ('de','CA','Kanada');
insert into valid_countries_tl(lang,code,short_name_tl) values ('de','CC','Kokos-Inseln');
insert into valid_countries_tl(lang,code,short_name_tl) values ('de','CF','Zentral Afrikanische Republik');
insert into valid_countries_tl(lang,code,short_name_tl) values ('de','CG','Kongo');
insert into valid_countries_tl(lang,code,short_name_tl) values ('de','CH','Schweiz');
insert into valid_countries_tl(lang,code,short_name_tl) values ('de','CI','Elfenbeinkuste');
insert into valid_countries_tl(lang,code,short_name_tl) values ('de','CK','Cook-Inseln');
insert into valid_countries_tl(lang,code,short_name_tl) values ('de','CL','Chile');
insert into valid_countries_tl(lang,code,short_name_tl) values ('de','CM','Kamerun');
insert into valid_countries_tl(lang,code,short_name_tl) values ('de','CN','China');
insert into valid_countries_tl(lang,code,short_name_tl) values ('de','CO','Kolumbien');
insert into valid_countries_tl(lang,code,short_name_tl) values ('de','CR','Costa Rica');
insert into valid_countries_tl(lang,code,short_name_tl) values ('de','CU','Kuba');
insert into valid_countries_tl(lang,code,short_name_tl) values ('de','CV','Kap Verde');
insert into valid_countries_tl(lang,code,short_name_tl) values ('de','CX','Weihnachtsinsel');
insert into valid_countries_tl(lang,code,short_name_tl) values ('de','CY','Zypern');
insert into valid_countries_tl(lang,code,short_name_tl) values ('de','CZ','Tschechische Republik');
insert into valid_countries_tl(lang,code,short_name_tl) values ('de','DE','Deutschland');
insert into valid_countries_tl(lang,code,short_name_tl) values ('de','DJ','Dschibuti');
insert into valid_countries_tl(lang,code,short_name_tl) values ('de','DK','Danemark');
insert into valid_countries_tl(lang,code,short_name_tl) values ('de','DM','Dominica');
insert into valid_countries_tl(lang,code,short_name_tl) values ('de','DO','Dominikanische Republik');
insert into valid_countries_tl(lang,code,short_name_tl) values ('de','DZ','Algerien');
insert into valid_countries_tl(lang,code,short_name_tl) values ('de','EC','Ecuador');
insert into valid_countries_tl(lang,code,short_name_tl) values ('de','EE','Estland');
insert into valid_countries_tl(lang,code,short_name_tl) values ('de','EG','agypten');
insert into valid_countries_tl(lang,code,short_name_tl) values ('de','EH','(West) Sahara');
insert into valid_countries_tl(lang,code,short_name_tl) values ('de','ER','Eritrea');
insert into valid_countries_tl(lang,code,short_name_tl) values ('de','ES','Spanien');
insert into valid_countries_tl(lang,code,short_name_tl) values ('de','ET','athiopien');
insert into valid_countries_tl(lang,code,short_name_tl) values ('de','FI','Finnland');
insert into valid_countries_tl(lang,code,short_name_tl) values ('de','FJ','Fidschi');
insert into valid_countries_tl(lang,code,short_name_tl) values ('de','FK','Falkland-Inseln');
insert into valid_countries_tl(lang,code,short_name_tl) values ('de','FM','Mikronesien');
insert into valid_countries_tl(lang,code,short_name_tl) values ('de','FO','Faroer');
insert into valid_countries_tl(lang,code,short_name_tl) values ('de','FR','Frankreich');
insert into valid_countries_tl(lang,code,short_name_tl) values ('de','FX','Frankreich (Europaisches Territorium)');
insert into valid_countries_tl(lang,code,short_name_tl) values ('de','GA','Gabun');
insert into valid_countries_tl(lang,code,short_name_tl) values ('de','GB','Gro?britannien');
insert into valid_countries_tl(lang,code,short_name_tl) values ('de','GD','Grenada');
insert into valid_countries_tl(lang,code,short_name_tl) values ('de','GE','Georgien');
insert into valid_countries_tl(lang,code,short_name_tl) values ('de','GF','Franzosisch Guayana');
insert into valid_countries_tl(lang,code,short_name_tl) values ('de','GH','Ghana');
insert into valid_countries_tl(lang,code,short_name_tl) values ('de','GI','Gibraltar');
insert into valid_countries_tl(lang,code,short_name_tl) values ('de','GL','Gronland');
insert into valid_countries_tl(lang,code,short_name_tl) values ('de','GM','Gambia');
insert into valid_countries_tl(lang,code,short_name_tl) values ('de','GN','Guinea Bissau');
insert into valid_countries_tl(lang,code,short_name_tl) values ('de','GP','Guadeloupe (Franzosisch)');
insert into valid_countries_tl(lang,code,short_name_tl) values ('de','GQ','Guinea');
insert into valid_countries_tl(lang,code,short_name_tl) values ('de','GR','Griechenland');
insert into valid_countries_tl(lang,code,short_name_tl) values ('de','GS','S. Georgia und S. Sandwich Inseln');
insert into valid_countries_tl(lang,code,short_name_tl) values ('de','GT','Guatemala');
insert into valid_countries_tl(lang,code,short_name_tl) values ('de','GU','Guam (USA)');
insert into valid_countries_tl(lang,code,short_name_tl) values ('de','GW','Guinea Bissau');
insert into valid_countries_tl(lang,code,short_name_tl) values ('de','GY','Guyana');
insert into valid_countries_tl(lang,code,short_name_tl) values ('de','HK','Hong Kong');
insert into valid_countries_tl(lang,code,short_name_tl) values ('de','HM','Heard und McDonald Inseln');
insert into valid_countries_tl(lang,code,short_name_tl) values ('de','HN','Honduras');
insert into valid_countries_tl(lang,code,short_name_tl) values ('de','HR','Kroatien');
insert into valid_countries_tl(lang,code,short_name_tl) values ('de','HT','Haiti');
insert into valid_countries_tl(lang,code,short_name_tl) values ('de','HU','Ungarn');
insert into valid_countries_tl(lang,code,short_name_tl) values ('de','ID','Indonesien');
insert into valid_countries_tl(lang,code,short_name_tl) values ('de','IE','Irland');
insert into valid_countries_tl(lang,code,short_name_tl) values ('de','IL','Israel');
insert into valid_countries_tl(lang,code,short_name_tl) values ('de','IN','Indien');
insert into valid_countries_tl(lang,code,short_name_tl) values ('de','IO','Britisches Indischer Ozean Territorium');
insert into valid_countries_tl(lang,code,short_name_tl) values ('de','IQ','Irak');
insert into valid_countries_tl(lang,code,short_name_tl) values ('de','IR','Iran');
insert into valid_countries_tl(lang,code,short_name_tl) values ('de','IS','Island');
insert into valid_countries_tl(lang,code,short_name_tl) values ('de','IT','Italien');
insert into valid_countries_tl(lang,code,short_name_tl) values ('de','JM','Jamaica');
insert into valid_countries_tl(lang,code,short_name_tl) values ('de','JO','Jordanien');
insert into valid_countries_tl(lang,code,short_name_tl) values ('de','JP','Japan');
insert into valid_countries_tl(lang,code,short_name_tl) values ('de','KE','Kenia');
insert into valid_countries_tl(lang,code,short_name_tl) values ('de','KG','Kirgizstan');
insert into valid_countries_tl(lang,code,short_name_tl) values ('de','KH','Kambodscha');
insert into valid_countries_tl(lang,code,short_name_tl) values ('de','KI','Kiribati');
insert into valid_countries_tl(lang,code,short_name_tl) values ('de','KM','Komoren');
insert into valid_countries_tl(lang,code,short_name_tl) values ('de','KN','Saint Kitts und Nevis Anguilla');
insert into valid_countries_tl(lang,code,short_name_tl) values ('de','KP','Nordkorea');
insert into valid_countries_tl(lang,code,short_name_tl) values ('de','KR','Sudkorea');
insert into valid_countries_tl(lang,code,short_name_tl) values ('de','KW','Kuwait');
insert into valid_countries_tl(lang,code,short_name_tl) values ('de','KY','Cayman-Inseln');
insert into valid_countries_tl(lang,code,short_name_tl) values ('de','KZ','Kasachstan');
insert into valid_countries_tl(lang,code,short_name_tl) values ('de','LA','Laos');
insert into valid_countries_tl(lang,code,short_name_tl) values ('de','LB','Libanon');
insert into valid_countries_tl(lang,code,short_name_tl) values ('de','LC','Saint Lucia');
insert into valid_countries_tl(lang,code,short_name_tl) values ('de','LI','Liechtenstein');
insert into valid_countries_tl(lang,code,short_name_tl) values ('de','LK','Sri Lanka');
insert into valid_countries_tl(lang,code,short_name_tl) values ('de','LR','Liberia');
insert into valid_countries_tl(lang,code,short_name_tl) values ('de','LS','Lesotho');
insert into valid_countries_tl(lang,code,short_name_tl) values ('de','LT','Litauen');
insert into valid_countries_tl(lang,code,short_name_tl) values ('de','LU','Luxemburg');
insert into valid_countries_tl(lang,code,short_name_tl) values ('de','LV','Lettland');
insert into valid_countries_tl(lang,code,short_name_tl) values ('de','LY','Libyen');
insert into valid_countries_tl(lang,code,short_name_tl) values ('de','MA','Marokko');
insert into valid_countries_tl(lang,code,short_name_tl) values ('de','MC','Monaco');
insert into valid_countries_tl(lang,code,short_name_tl) values ('de','MD','Moldawien');
insert into valid_countries_tl(lang,code,short_name_tl) values ('de','MG','Madagakar');
insert into valid_countries_tl(lang,code,short_name_tl) values ('de','MH','Marshall-Inseln');
insert into valid_countries_tl(lang,code,short_name_tl) values ('de','MK','Mazedonien');
insert into valid_countries_tl(lang,code,short_name_tl) values ('de','ML','Mali');
insert into valid_countries_tl(lang,code,short_name_tl) values ('de','MM','Myanmar');
insert into valid_countries_tl(lang,code,short_name_tl) values ('de','MN','Mongolien');
insert into valid_countries_tl(lang,code,short_name_tl) values ('de','MO','Macau');
insert into valid_countries_tl(lang,code,short_name_tl) values ('de','MP','Nordlichen Mariana-Inseln');
insert into valid_countries_tl(lang,code,short_name_tl) values ('de','MQ','Martinique (Franzosisch)');
insert into valid_countries_tl(lang,code,short_name_tl) values ('de','MR','Mauritanien');
insert into valid_countries_tl(lang,code,short_name_tl) values ('de','MS','Montserrat');
insert into valid_countries_tl(lang,code,short_name_tl) values ('de','MT','Malta');
insert into valid_countries_tl(lang,code,short_name_tl) values ('de','MU','Mauritius');
insert into valid_countries_tl(lang,code,short_name_tl) values ('de','MV','Malediven');
insert into valid_countries_tl(lang,code,short_name_tl) values ('de','MW','Malawi');
insert into valid_countries_tl(lang,code,short_name_tl) values ('de','MX','Mexico');
insert into valid_countries_tl(lang,code,short_name_tl) values ('de','MY','Malaysia');
insert into valid_countries_tl(lang,code,short_name_tl) values ('de','MZ','Mosambik');
insert into valid_countries_tl(lang,code,short_name_tl) values ('de','NA','Namibia');
insert into valid_countries_tl(lang,code,short_name_tl) values ('de','NC','Neukaledonien (Franzosisch)');
insert into valid_countries_tl(lang,code,short_name_tl) values ('de','NE','Niger');
insert into valid_countries_tl(lang,code,short_name_tl) values ('de','NF','Norfolk-Inseln');
insert into valid_countries_tl(lang,code,short_name_tl) values ('de','NG','Nigeria');
insert into valid_countries_tl(lang,code,short_name_tl) values ('de','NI','Nicaragua');
insert into valid_countries_tl(lang,code,short_name_tl) values ('de','NL','Niederlande');
insert into valid_countries_tl(lang,code,short_name_tl) values ('de','NO','Norwegen');
insert into valid_countries_tl(lang,code,short_name_tl) values ('de','NP','Nepal');
insert into valid_countries_tl(lang,code,short_name_tl) values ('de','NR','Nauru');
insert into valid_countries_tl(lang,code,short_name_tl) values ('de','NU','Niue');
insert into valid_countries_tl(lang,code,short_name_tl) values ('de','NZ','Neuseeland');
insert into valid_countries_tl(lang,code,short_name_tl) values ('de','OM','Oman');
insert into valid_countries_tl(lang,code,short_name_tl) values ('de','PA','Panama');
insert into valid_countries_tl(lang,code,short_name_tl) values ('de','PE','Peru');
insert into valid_countries_tl(lang,code,short_name_tl) values ('de','PF','Polynesien (Franzosisch)');
insert into valid_countries_tl(lang,code,short_name_tl) values ('de','PG','Papua Neuguinea');
insert into valid_countries_tl(lang,code,short_name_tl) values ('de','PH','Philippinen');
insert into valid_countries_tl(lang,code,short_name_tl) values ('de','PK','Pakistan');
insert into valid_countries_tl(lang,code,short_name_tl) values ('de','PL','Polen');
insert into valid_countries_tl(lang,code,short_name_tl) values ('de','PM','Saint Pierre und Miquelon');
insert into valid_countries_tl(lang,code,short_name_tl) values ('de','PN','Pitcairn-Insel');
insert into valid_countries_tl(lang,code,short_name_tl) values ('de','PR','Puerto Rico');
insert into valid_countries_tl(lang,code,short_name_tl) values ('de','PT','Portugal');
insert into valid_countries_tl(lang,code,short_name_tl) values ('de','PW','Palau');
insert into valid_countries_tl(lang,code,short_name_tl) values ('de','PY','Paraguay');
insert into valid_countries_tl(lang,code,short_name_tl) values ('de','QA','Qatar');
insert into valid_countries_tl(lang,code,short_name_tl) values ('de','RE','Reunion (Franzosisch)');
insert into valid_countries_tl(lang,code,short_name_tl) values ('de','RO','Rumanien');
insert into valid_countries_tl(lang,code,short_name_tl) values ('de','RU','Russische Foderation');
insert into valid_countries_tl(lang,code,short_name_tl) values ('de','RW','Rwanda');
insert into valid_countries_tl(lang,code,short_name_tl) values ('de','SA','Saudi-Arabien');
insert into valid_countries_tl(lang,code,short_name_tl) values ('de','SB','Solomon-Inseln');
insert into valid_countries_tl(lang,code,short_name_tl) values ('de','SC','Seychellen');
insert into valid_countries_tl(lang,code,short_name_tl) values ('de','SD','Sudan');
insert into valid_countries_tl(lang,code,short_name_tl) values ('de','SE','Schweden');
insert into valid_countries_tl(lang,code,short_name_tl) values ('de','SG','Singapur');
insert into valid_countries_tl(lang,code,short_name_tl) values ('de','SH','St. Helena');
insert into valid_countries_tl(lang,code,short_name_tl) values ('de','SI','Slowenien');
insert into valid_countries_tl(lang,code,short_name_tl) values ('de','SJ','Svalbard und Jan Mayen Inseln');
insert into valid_countries_tl(lang,code,short_name_tl) values ('de','SK','Slowakische Republik');
insert into valid_countries_tl(lang,code,short_name_tl) values ('de','SL','Sierra Leone');
insert into valid_countries_tl(lang,code,short_name_tl) values ('de','SM','San Marino');
insert into valid_countries_tl(lang,code,short_name_tl) values ('de','SN','Senegal');
insert into valid_countries_tl(lang,code,short_name_tl) values ('de','SO','Somalia');
insert into valid_countries_tl(lang,code,short_name_tl) values ('de','SR','Surinam');
insert into valid_countries_tl(lang,code,short_name_tl) values ('de','ST','St. Tome und Principe');
insert into valid_countries_tl(lang,code,short_name_tl) values ('de','SV','El Salvador');
insert into valid_countries_tl(lang,code,short_name_tl) values ('de','SY','Syrien');
insert into valid_countries_tl(lang,code,short_name_tl) values ('de','SZ','Swasiland');
insert into valid_countries_tl(lang,code,short_name_tl) values ('de','TC','Turks und Caicos Inseln');
insert into valid_countries_tl(lang,code,short_name_tl) values ('de','TD','Tschad');
insert into valid_countries_tl(lang,code,short_name_tl) values ('de','TF','Franzosische Sud Territorien');
insert into valid_countries_tl(lang,code,short_name_tl) values ('de','TG','Togo');
insert into valid_countries_tl(lang,code,short_name_tl) values ('de','TH','Thailand');
insert into valid_countries_tl(lang,code,short_name_tl) values ('de','TJ','Tadschikistan');
insert into valid_countries_tl(lang,code,short_name_tl) values ('de','TK','Tokelau');
insert into valid_countries_tl(lang,code,short_name_tl) values ('de','TM','Turkmenistan');
insert into valid_countries_tl(lang,code,short_name_tl) values ('de','TN','Tunisien');
insert into valid_countries_tl(lang,code,short_name_tl) values ('de','TO','Tonga');
insert into valid_countries_tl(lang,code,short_name_tl) values ('de','TP','Osttimor');
insert into valid_countries_tl(lang,code,short_name_tl) values ('de','TR','Turkei');
insert into valid_countries_tl(lang,code,short_name_tl) values ('de','TT','Trinidad und Tobago');
insert into valid_countries_tl(lang,code,short_name_tl) values ('de','TV','Tuvalu');
insert into valid_countries_tl(lang,code,short_name_tl) values ('de','TW','Taiwan');
insert into valid_countries_tl(lang,code,short_name_tl) values ('de','TZ','Tansania');
insert into valid_countries_tl(lang,code,short_name_tl) values ('de','UA','Ukraine');
insert into valid_countries_tl(lang,code,short_name_tl) values ('de','UG','Uganda');
insert into valid_countries_tl(lang,code,short_name_tl) values ('de','UM','USA Kleinere Exterritoriale Inseln');
insert into valid_countries_tl(lang,code,short_name_tl) values ('de','US','Vereinigte Staaten');
insert into valid_countries_tl(lang,code,short_name_tl) values ('de','UY','Uruguay');
insert into valid_countries_tl(lang,code,short_name_tl) values ('de','UZ','Usbekistan');
insert into valid_countries_tl(lang,code,short_name_tl) values ('de','VA','Vatikan Staat');
insert into valid_countries_tl(lang,code,short_name_tl) values ('de','VC','St. Vincent');
insert into valid_countries_tl(lang,code,short_name_tl) values ('de','VE','Venezuela');
insert into valid_countries_tl(lang,code,short_name_tl) values ('de','VG','Virgin-Inseln (Britisch)');
insert into valid_countries_tl(lang,code,short_name_tl) values ('de','VI','Virgin-Inseln (USA)');
insert into valid_countries_tl(lang,code,short_name_tl) values ('de','VN','Vietnam');
insert into valid_countries_tl(lang,code,short_name_tl) values ('de','VU','Vanuatu');
insert into valid_countries_tl(lang,code,short_name_tl) values ('de','WF','Wallis und Futuna Inseln');
insert into valid_countries_tl(lang,code,short_name_tl) values ('de','WS','Westsamoa');
insert into valid_countries_tl(lang,code,short_name_tl) values ('de','YE','Jemen');
insert into valid_countries_tl(lang,code,short_name_tl) values ('de','YT','Mayotte');
insert into valid_countries_tl(lang,code,short_name_tl) values ('de','YU','Jugoslawien');
insert into valid_countries_tl(lang,code,short_name_tl) values ('de','ZA','Sudafrika');
insert into valid_countries_tl(lang,code,short_name_tl) values ('de','ZM','Sambia');
insert into valid_countries_tl(lang,code,short_name_tl) values ('de','ZR','Ehemaliges Zaire');
insert into valid_countries_tl(lang,code,short_name_tl) values ('de','ZW','Simbabwe');
commit;

select '../web/tables/web_contact_indexes.sql' sql_file from dual;
-- SQL relevant contents from file ../web/tables/web_contact_indexes.sql
create index web_contact_oid_id
	on web_contact(org_id, id)
	parallel 6
	tablespace [[web_index_tablespace_2]]
	storage(pctincrease 1);
create index web_contact_id_oid_cust_luc on
	web_contact(id,oracle_contact_id,org_id,login_uc)
	parallel 6
	tablespace [[web_index_tablespace_2]]
	storage(pctincrease 1);

select '../web/tables/web_contact_triggers.sql' sql_file from dual;
-- SQL relevant contents from file ../web/tables/web_contact_triggers.sql
create or replace trigger
web_contact_mod_trig
before insert or update on web_contact
for each row
begin
        :new.modified := sysdate;
        :new.login_uc := UPPER(:new.login);
        IF :new.password <> :old.password THEN
                :new.old_password := :old.password;
        END IF;
end;
/
show errors

select '../web/tables/web_customer_triggers.sql' sql_file from dual;
-- SQL relevant contents from file ../web/tables/web_customer_triggers.sql
create or replace trigger
web_customer_mod_trig
before insert or update on web_customer
for each row
begin
        :new.modified := sysdate;
end;
/
show errors

select '../web/tables/web_user_contact_permission.sql' sql_file from dual;
-- SQL relevant contents from file ../web/tables/web_user_contact_permission.sql
create table
web_user_contact_permission
(
	web_user_id		number
				constraint wucp_wuid_nn not null
				constraint contperm_wbuserid_fk
					references web_contact(id)
					on delete cascade,
	email			char(1) default('N')
				constraint wucp_email_ck
					check (email in ('Y','N')),
	mail			char(1) default('N')
				constraint wucp_mail_ck
					check (mail in ('Y','N')),
	call			char(1) default('N')
				constraint wucp_call_ck
					check (call in ('Y','N')),
	fax			char(1) default('N')
				constraint wucp_fax_ck
					check (fax in ('Y','N')),
	created			date default(sysdate)
				constraint wucp_created_nn not null,
	modified		date default(sysdate)
				constraint wucp_modified_nn not null
);
create or replace trigger
web_user_cp_timestamp
BEFORE INSERT OR UPDATE ON web_user_contact_permission
FOR EACH ROW
BEGIN
  :new.modified := sysdate;
END;
/
show errors

select '../web/tables/web_user_contact_permission_triggers.sql' sql_file from dual;
-- SQL relevant contents from file ../web/tables/web_user_contact_permission_triggers.sql
create or replace trigger
web_user_pi_timestamp
BEFORE INSERT OR UPDATE ON web_user_personal_info
FOR EACH ROW
BEGIN
  :new.modified := sysdate;
END;
/
show errors

select '../rhn/procs/is_satellite.sql' sql_file from dual;
-- SQL relevant contents from file ../rhn/procs/is_satellite.sql
create or replace function
is_satellite
return number
is
	cursor schemas is
		select	1
		from	rhnVersionInfo
		where	label = 'schema'
		and	name_id = lookup_package_name('rhn-satellite-schema');
begin
	for schema in schemas loop return 1; end loop;
	return 0;
end is_satellite;
/
show errors

select '../web/procs/xxrh_contact_del_check.sql' sql_file from dual;
-- SQL relevant contents from file ../web/procs/xxrh_contact_del_check.sql
create or replace function
xxrh_contact_del_check(
	pin_web_contact_id in number
) return boolean
is
begin
	if is_satellite() = 1 then
		return true;
	end if;
	return false;
end xxrh_contact_del_check;
/
show errors

select '../rhn/procs/adler32.sql' sql_file from dual;
-- SQL relevant contents from file ../rhn/procs/adler32.sql
create or replace function
adler32(
	buf in varchar2,
	adler in number := 1
) return number
deterministic
is
	s1 number;
	s2 number;
	signed boolean;
	currchar number;
	our_adler number;
begin
	our_adler := mod(adler,4294967296);
        if buf is null then
        	return our_adler;
        end if;
	if our_adler > 2147483647 then
		our_adler := our_adler - 2147483648;
		signed := true;
	else
		our_adler := our_adler;
		signed := false;
	end if;
	s1 := bitand(our_adler,65535);
	s2 := bitand(our_adler,2147418112) / 65536;
	if signed then
		s2 := s2 + 32768;
	end if;
	for n in 1..length(buf) loop
		currchar := ascii(substr(buf,n,1));
		s1 := mod((s1+currchar), 65521);
		s2 := mod((s2 + s1), 65521);
	end loop;
	return s2 * 65536 + s1;
end;
/
show errors

select '../rhn/procs/channel_name_join.sql' sql_file from dual;
-- SQL relevant contents from file ../rhn/procs/channel_name_join.sql
create or replace function
channel_name_join(sep_in in varchar2, ch_in in channel_name_t)
return varchar2
is
	ret	varchar2(4000);
	i	binary_integer;
begin
	ret := '';
	i := ch_in.first;
	if i is null
	then
		return ret;
	end if;
	ret := ch_in(i);
	i := ch_in.next(i);
	while i is not null
	loop
		ret := ret || sep_in || ch_in(i);
		i := ch_in.next(i);
	end loop;
	return ret;
end;
/

select '../rhn/procs/check_email_uniqueness.sql' sql_file from dual;
-- SQL relevant contents from file ../rhn/procs/check_email_uniqueness.sql
create or replace function
check_email_uniqueness (
	email_in in varchar2
)
return number
is
	cursor sources(email_cin in varchar2) is
		select	1
		from	web_user_personal_info	wupi
		where	wupi.email = email_cin;
begin
	for source in sources(email_in)
	loop
		return 0;
	end loop;
	return 1;
end;
/
show errors

select '../rhn/procs/create_first_org.sql' sql_file from dual;
-- SQL relevant contents from file ../rhn/procs/create_first_org.sql
create or replace procedure
create_first_org
(
	name_in in varchar2,
	password_in in varchar2
) is
	ug_type			number;
	group_val		number;
begin
	insert into web_customer (
		id, name, password,
		oracle_customer_id, oracle_customer_number,
		customer_type
	) values (
		1, name_in, password_in,
		1, 1, 'B'
	);
	select rhn_user_group_id_seq.nextval into group_val from dual;
	select	id
	into	ug_type
	from	rhnUserGroupType
	where	label = 'org_admin';
	insert into rhnUserGroup (
		id, name,
		description,
		max_members, group_type, org_id
	) values (
		group_val, 'Organization Admins',
		'Organization Admins for Org ' || name_in || ' (1)',
		NULL, ug_type, 1
	);
	select rhn_user_group_id_seq.nextval into group_val from dual;
	select	id
	into	ug_type
	from	rhnUserGroupType
	where	label = 'org_applicant';
	insert into rhnUserGroup (
		id, name,
		description,
		max_members, group_type, org_id
	) values (
		group_val, 'Organization Applicants',
		'Organization Applicants for Org ' || name_in || ' (1)',
		NULL, ug_type, 1
	);
	select rhn_user_group_id_seq.nextval into group_val from dual;
	select	id
	into	ug_type
	from	rhnUserGroupType
	where	label = 'config_admin';
	insert into rhnUserGroup (
		id, name,
		description,
		max_members, group_type, org_id
	) values (
		4, 'Configuration Administrator',
		'Configuration Administrator for Org ' || ' (1)',
		NULL, 9, 1
	);
	select rhn_user_group_id_seq.nextval into group_val from dual;
	select	id
	into	ug_type
	from	rhnUserGroupType
	where	label = 'channel_admin';
	insert into rhnUserGroup (
		id, name,
		description,
		max_members, group_type, org_id
	) values (
		group_val, 'Channel Administrator',
		'Channel Administrator for Org ' || name_in || ' (1)',
		NULL, ug_type, 1
	);
	insert into rhnOrgState (org_id, state_id)
	select 1, id
	  from rhnOrgAvailableStates
	 where label = 'paid';
        insert into rhnServerGroup 
		( id, name, description, max_members, group_type, org_id )
		select rhn_server_group_id_seq.nextval, sgt.name, sgt.name, 
			0, sgt.id, 1
		from rhnServerGroupType sgt
		where sgt.label = 'sw_mgr_entitled';
end;
/
show errors

select '../rhn/procs/create_new_user.sql' sql_file from dual;
-- SQL relevant contents from file ../rhn/procs/create_new_user.sql
create or replace function
create_new_user
(
    org_id_in		in number, 
    login_in		in varchar2,
    password_in		in varchar2,
    oracle_contact_id_in in number,
    prefix_in		in varchar2,
    first_names_in	in varchar2,
    last_name_in	in varchar2,
    genqual_in		in varchar2, 
    parent_company_in	in varchar2,
    company_in		in varchar2,
    title_in		in varchar2,
    phone_in		in varchar2, 
    fax_in		in varchar2,
    email_in		in varchar2,
    pin_in		in varchar2,
    first_names_ol_in	in varchar2,
    last_name_ol_in	in varchar2,
    address1_in		in varchar2, 
    address2_in		in varchar2,
    address3_in		in varchar2,
    city_in		in varchar2, 
    state_in		in varchar2, 
    zip_in		in varchar2, 
    country_in		in varchar2,
    alt_first_names_in  in varchar2,
    alt_last_name_in    in varchar2,
    contact_call_in	varchar2 := 'N', 
    contact_mail_in	varchar2 := 'N',
    contact_email_in	varchar2 := 'N',
    contact_fax_in	varchar2 := 'N'
)
return number
is
    user_id		number;
begin
    select web_contact_id_seq.nextval into user_id from dual;
    insert into web_contact
        (id, org_id, login, login_uc, password, old_password, oracle_contact_id)
    values
        (user_id, org_id_in, login_in, upper(login_in), password_in, null, oracle_contact_id_in);
    insert into web_user_contact_permission
        (web_user_id, call, mail, email, fax)
    values
        (user_id, contact_call_in, contact_mail_in, contact_email_in, contact_fax_in);
    insert into web_user_personal_info 
        (web_user_id, prefix, first_names, last_name, genqual,
	parent_company, company, title, phone, fax, email, pin,
	first_names_ol, last_name_ol)
    values
        (user_id, prefix_in, first_names_in, last_name_in, genqual_in, 
	parent_company_in, company_in, title_in, phone_in, fax_in, email_in, pin_in,
	first_names_ol_in, last_name_ol_in);
    insert into web_user_site_info
        (id, web_user_id, email, address1, address2, address3, 
	city, state, zip, country, phone, fax, type, alt_first_names, alt_last_name)
    values
        (web_user_site_info_id_seq.nextval, 
	user_id, email_in, address1_in, address2_in, address3_in,
	city_in, state_in, zip_in, country_in, phone_in, fax_in, 'M', alt_first_names_in, alt_last_name_in);
    insert into rhnUserInfo
        (user_id)
    values
        (user_id);
    return user_id;
end;
/
show errors

select '../rhn/procs/create_pxt_session.sql' sql_file from dual;
-- SQL relevant contents from file ../rhn/procs/create_pxt_session.sql
create or replace function
create_pxt_session(web_user_id in number, expires in number, value in varchar)
return number
is
pragma autonomous_transaction;
	id number;
begin
	select
		pxt_id_seq.nextval into id
	from
		dual;
	insert into PXTSessions (id, value, expires, web_user_id)
	values (id, value, expires, web_user_id);
	commit;
	return id;
end;
/
show errors

select '../rhn/procs/delete_channel.sql' sql_file from dual;
-- SQL relevant contents from file ../rhn/procs/delete_channel.sql
create or replace
procedure delete_channel (
	channel_id_in in number
) is
begin
        delete from rhnChannelPackage where channel_id = channel_id_in;
        delete from rhnChannelErrata where channel_id = channel_id_in;
        delete from rhnServerChannel where channel_id = channel_id_in;
        delete from rhnRegTokenChannels where channel_id = channel_id_in;
        delete from rhnDistChannelMap where channel_id = channel_id_in;
        delete from rhnChannelFamilyMembers where channel_id = channel_id_in;
        delete from rhnServerProfilePackage where server_profile_id in (
            select id from rhnServerProfile where base_channel = channel_id_in
        );
        delete from rhnServerProfile where base_channel = channel_id_in;
        delete from rhnChannel where id = channel_id_in;
end;
/
show errors

select '../rhn/procs/delete_errata.sql' sql_file from dual;
-- SQL relevant contents from file ../rhn/procs/delete_errata.sql
create or replace procedure
delete_errata (
	errata_id_in in number
) is
begin
	delete from rhnPaidErrataTempCache where errata_id = errata_id_in;
	delete from rhnErrata where id = errata_id_in;
	delete from rhnErrataTmp where id = errata_id_in;
end delete_errata;
/
show errors

select '../rhn/procs/delete_server_bulk.sql' sql_file from dual;
-- SQL relevant contents from file ../rhn/procs/delete_server_bulk.sql
create or replace
procedure delete_server_bulk (
	user_id_in in number
) is
	cursor systems is
		select	s.element id
		from	rhnSet s
		where	s.user_id = user_id_in
			and s.label = 'system_list';
	cursor sessions is
		select	kss.id session_id,
			case when kss.old_server_id = s.element
				then null
				else kss.old_server_id
				end old_server_id,
			case when kss.new_server_id = s.element
				then null
				else kss.new_server_id
				end new_server_id
		from	rhnKickstartSession kss,
			rhnSet s
		where	s.user_id = user_id_in
			and s.label = 'system_list'
			and s.element in (kss.old_server_id, kss.new_server_id)
		for update of kss.old_server_id, kss.new_server_id;
	cursor servergroups is
		select	sgm.server_group_id, sgm.server_id
		from	rhnServerGroupMembers sgm,
			rhnSet s
		where	s.user_id = user_id_in
			and s.label = 'system_list'
			and s.element = sgm.server_id;
	cursor configchannels is
		select	cc.id
		from	rhnConfigChannel cc,
			rhnConfigChannelType cct,
			rhnServerConfigChannel scc,
			rhnSet s
		where	1=1
			and s.user_id = user_id_in
			and s.label = 'system_list'
			and s.element = scc.server_id
			and scc.config_channel_id = cc.id
			and cct.label in
				('local_override','server_import')
			and cct.id = cc.confchan_type_id;
begin
	for cc in configchannels loop
		rhn_config.delete_channel(cc.id);
	end loop;
	for sgm in servergroups loop
		rhn_server.delete_from_servergroup(
			sgm.server_id, sgm.server_group_id);
	end loop;
	for s in sessions loop
		update rhnKickstartSession
			set old_server_id = s.old_server_id,
			    new_server_id = s.new_server_id
			where current of sessions;
	end loop;
	for s in systems loop
		rhn_channel.clear_subscriptions(s.id);
		delete from rhnServer
			where id = s.id;
		delete from rhnSet
			where user_id = user_id_in
			and label = 'system_list'
			and element = s.id;
	end loop;
end;
/
show errors

select '../rhn/procs/delete_server.sql' sql_file from dual;
-- SQL relevant contents from file ../rhn/procs/delete_server.sql
create or replace
procedure delete_server (
	server_id_in in number
) is
    cursor sessions is
		select	kss.id session_id,
				case when kss.old_server_id = server_id_in
					then null
					else kss.old_server_id
					end old_server_id,
				case when kss.new_server_id = server_id_in
					then null
					else kss.new_server_id
					end new_server_id
		from	rhnKickstartSession kss
		where	server_id_in in (kss.old_server_id, kss.new_server_id)
		for update of kss.old_server_id, kss.new_server_id;
	cursor servergroups is
		select	server_id, server_group_id
		from	rhnServerGroupMembers sgm
		where	sgm.server_id = server_id_in;
	cursor configchannels is
		select	cc.id
		from	rhnConfigChannel cc,
			rhnConfigChannelType cct,
			rhnServerConfigChannel scc
		where	1=1
			and scc.server_id = server_id_in
			and scc.config_channel_id = cc.id
			and cct.label in
				('local_override','server_import')
			and cct.id = cc.confchan_type_id;
begin
	rhn_channel.delete_server_channels(server_id_in);
	delete
	from	rhnSet
	where	1=1
		and user_id in (
			select	wc.id
			from	rhnServer rs,
				web_contact wc
			where	rs.id = server_id_in
				and rs.org_id = wc.org_id
		)
		and label = 'system_list'
		and element = server_id_in;
	for configchannel in configchannels loop
	  rhn_config.delete_channel(configchannel.id);
	end loop;
	for sgm in servergroups loop
		rhn_server.delete_from_servergroup(
			sgm.server_id, sgm.server_group_id);
	end loop;
	for s in sessions loop
		update rhnKickstartSession
			set old_server_id = s.old_server_id,
				new_server_id = s.new_server_id
			where current of sessions;
	end loop;
	delete
	from	rhnServer
		where id = server_id_in;
end;
/
show errors

select '../rhn/procs/does_user_have_role.sql' sql_file from dual;
-- SQL relevant contents from file ../rhn/procs/does_user_have_role.sql
create or replace function
does_user_have_role
(
	user_id_in in number,
	role_in in varchar2
)
return number
is
	org_admin	number;
begin
	select	1
	into	org_admin
	from
		rhnUserGroupType	ugt,
		rhnUserGroup		ug,
		rhnUserGroupMembers	ugm
	where	1=1
		and ugm.user_id = user_id_in
		and ugm.user_group_id = ug.id
		and ugt.label = role_in
		and ugt.id = ug.group_type;
	return org_admin;
exception
	when no_data_found then
		return 0;
end;
/
show errors

select '../rhn/procs/is_user_applicant.sql' sql_file from dual;
-- SQL relevant contents from file ../rhn/procs/is_user_applicant.sql
create or replace function
is_user_applicant
(
    user_id_in IN number
)
return number
is
    org_id_val		number;
    app_group_val	number;
    applicant           number;
begin
    select org_id into org_id_val
      from web_contact
     where id = user_id_in;
    select id into app_group_val
      from rhnUserGroup
     where org_id = org_id_val
       and group_type = (
		select	id
		from	rhnUserGroupType
		where	label = 'org_applicant'
	   );
    select count(1) into applicant
      from rhnUserGroupMembers
     where user_group_id = app_group_val
       and user_id = user_id_in;
   return applicant;
end;
/
show errors

select '../rhn/procs/is_user_org_admin.sql' sql_file from dual;
-- SQL relevant contents from file ../rhn/procs/is_user_org_admin.sql
create or replace function
is_user_org_admin
(
    user_id_in IN number
)
return number
is
    org_id_val		number;
    app_group_val	number;
    org_admin           number;
begin
    select org_id into org_id_val
      from web_contact
     where id = user_id_in;
    select id into app_group_val
      from rhnUserGroup
     where org_id = org_id_val
       and group_type = (
		select	id
		from	rhnUserGroupType
		where	label = 'org_admin'
	   );
    select count(1) into org_admin
      from rhnUserGroupMembers
     where user_group_id = app_group_val
       and user_id = user_id_in;
   return org_admin;
end;
/
show errors

select '../rhn/procs/lookup_cf_state.sql' sql_file from dual;
-- SQL relevant contents from file ../rhn/procs/lookup_cf_state.sql
create or replace function
lookup_cf_state(
	label_in in varchar2
) return number deterministic
is
	state_id number;
begin
	select	id
	into	state_id
	from	rhnConfigFileState
	where	label = label_in;
	return state_id;
end;
/
show errors

select '../rhn/procs/lookup_client_capability.sql' sql_file from dual;
-- SQL relevant contents from file ../rhn/procs/lookup_client_capability.sql
CREATE OR REPLACE FUNCTION
LOOKUP_CLIENT_CAPABILITY(name_in IN VARCHAR2)
RETURN NUMBER
DETERMINISTIC
IS
	PRAGMA AUTONOMOUS_TRANSACTION;
	cap_name_id		NUMBER;
BEGIN
	SELECT id
          INTO cap_name_id
          FROM rhnClientCapabilityName
         WHERE name = name_in;
	RETURN cap_name_id;
EXCEPTION
        WHEN NO_DATA_FOUND THEN
            INSERT INTO rhnClientCapabilityName (id, name) 
                VALUES (rhn_client_capname_id_seq.nextval, name_in)
                RETURNING id INTO cap_name_id;
            COMMIT;
	RETURN cap_name_id;
END;
/
SHOW ERRORS

select '../rhn/procs/lookup_config_filename.sql' sql_file from dual;
-- SQL relevant contents from file ../rhn/procs/lookup_config_filename.sql
CREATE OR REPLACE FUNCTION
LOOKUP_CONFIG_FILENAME(name_in IN VARCHAR2)
RETURN NUMBER
DETERMINISTIC
IS
	PRAGMA AUTONOMOUS_TRANSACTION;
	name_id		NUMBER;
BEGIN
	SELECT id
          INTO name_id
          FROM rhnConfigFileName
         WHERE path = name_in;
	RETURN name_id;
EXCEPTION
        WHEN NO_DATA_FOUND THEN
            INSERT INTO rhnConfigFileName (id, path) 
                VALUES (rhn_cfname_id_seq.nextval, name_in)
                RETURNING id INTO name_id;
            COMMIT;
	RETURN name_id;
END;
/
SHOW ERRORS

select '../rhn/procs/lookup_config_info.sql' sql_file from dual;
-- SQL relevant contents from file ../rhn/procs/lookup_config_info.sql
create or replace function
lookup_config_info (
    username_in     in varchar2,
    groupname_in    in varchar2,
    filemode_in     in varchar2
) return number
deterministic
is
    pragma autonomous_transaction;
    v_id    number;
    cursor lookup_cursor is
        select id
          from rhnConfigInfo
         where 1=1
           and username = username_in
           and groupname = groupname_in
           and filemode = filemode_in;
begin
    for r in lookup_cursor loop
        return r.id;
    end loop;
    select rhn_confinfo_id_seq.nextval
      into v_id
      from dual;
    insert into rhnConfigInfo (id, username, groupname, filemode)
    values (v_id, username_in, groupname_in, filemode_in);
    commit;
    return v_id;
end lookup_config_info;
/
show errors

select '../rhn/procs/lookup_first_matching_cf.sql' sql_file from dual;
-- SQL relevant contents from file ../rhn/procs/lookup_first_matching_cf.sql
create or replace function
lookup_first_matching_cf (
	server_id_in in number,
	path_in in varchar2
) return number is
	retval number := -1;
begin
	begin
		select	a.cfid
		into	retval
		from	(
			select	b.cfid,
				rownum rn
			from (
				select	cf.id cfid
				from	rhnConfigFile		cf,
					rhnConfigFileName	cfn,
					rhnConfigChannel	cc,
					rhnServerConfigChannel	scc
				where	scc.server_id = server_id_in
					and scc.config_channel_id = cc.id
					and cc.id = cf.config_channel_id
					and cf.state_id != lookup_cf_state('dead')
					and cfn.path = path_in
					and cf.config_file_name_id = cfn.id
				order by scc.position asc
				) b
			) a
		where a.rn = 1;
	exception
		when no_data_found then
			null;
	end;
	return retval;
end lookup_first_matching_cf;
/
show errors

select '../rhn/procs/lookup_package_delta.sql' sql_file from dual;
-- SQL relevant contents from file ../rhn/procs/lookup_package_delta.sql
CREATE OR REPLACE FUNCTION
LOOKUP_PACKAGE_DELTA(n_in IN VARCHAR2)
RETURN NUMBER
DETERMINISTIC
IS
	PRAGMA AUTONOMOUS_TRANSACTION;
	name_id         NUMBER;
BEGIN
	SELECT id INTO name_id
	  FROM rhnPackageDelta
	 WHERE label = n_in;
	RETURN name_id;
EXCEPTION
	WHEN NO_DATA_FOUND THEN
	    INSERT INTO rhnPackageDelta (id, label)
	    VALUES (rhn_packagedelta_id_seq.nextval, n_in)
	    RETURNING id INTO name_id;
	COMMIT;
	RETURN name_id;
END;
/
SHOW ERRORS

select '../rhn/procs/lookup_transaction_package.sql' sql_file from dual;
-- SQL relevant contents from file ../rhn/procs/lookup_transaction_package.sql
CREATE OR REPLACE FUNCTION
LOOKUP_TRANSACTION_PACKAGE(o_in IN VARCHAR2, n_in IN VARCHAR2, 
    e_in IN VARCHAR2, v_in IN VARCHAR2, r_in IN VARCHAR2, a_in IN VARCHAR2)
RETURN NUMBER
DETERMINISTIC
IS
	PRAGMA AUTONOMOUS_TRANSACTION;
        o_id        NUMBER;
        n_id        NUMBER;
	e_id	    NUMBER;
        p_arch_id   NUMBER;
        tp_id       NUMBER;
BEGIN
	BEGIN
	    SELECT id
	      INTO o_id
	      FROM rhnTransactionOperation
	     WHERE label = o_in;
	EXCEPTION
	    WHEN NO_DATA_FOUND THEN
		rhn_exception.raise_exception('invalid_transaction_operation');
	END;
	SELECT LOOKUP_PACKAGE_NAME(n_in)
	  INTO n_id
	  FROM dual;
	SELECT LOOKUP_EVR(e_in, v_in, r_in)
	  INTO e_id
	  FROM dual;
	p_arch_id := NULL;
	IF a_in IS NOT NULL
	THEN
		SELECT LOOKUP_PACKAGE_ARCH(a_in)
		  INTO p_arch_id
		  FROM dual;
	END IF;
	SELECT id
	  INTO tp_id
	  FROM rhnTransactionPackage
	 WHERE operation = o_id
	   AND name_id = n_id
	   AND evr_id = e_id
	   AND (package_arch_id = p_arch_id OR (p_arch_id IS NULL AND package_arch_id IS NULL));
	RETURN tp_id;
EXCEPTION
        WHEN NO_DATA_FOUND THEN
	    INSERT INTO rhnTransactionPackage 
		(id, operation, name_id, evr_id, package_arch_id)
	    VALUES (rhn_transpack_id_seq.nextval, o_id, n_id, e_id, p_arch_id)
	    RETURNING id INTO tp_id;
	    COMMIT;
	    RETURN tp_id;
END;
/
SHOW ERRORS

select '../rhn/procs/new_user_postop.sql' sql_file from dual;
-- SQL relevant contents from file ../rhn/procs/new_user_postop.sql
create or replace procedure
new_user_postop
(
    user_id_in IN number
)
is
    org_id_val		number;
    admin_group_val	number;
begin
    select org_id into org_id_val
      from web_contact
     where id = user_id_in;
    select id into admin_group_val
      from rhnUserGroup
     where org_id = org_id_val
       and group_type = (
		select	id
		from	rhnUserGroupType
		where	label = 'org_admin'
	   );
    insert into rhnUserGroupMembers
        (user_group_id, user_id)
    values
        (admin_group_val, user_id_in);
    insert into rhnUserInfo
        (user_id)
    values
        (user_id_in);
end;
/
show errors
declare
    CURSOR user_cursor
    is
    select wc.id
      from web_contact wc
     where not exists (select 1
                         from rhnUserGroupMembers
		        where user_id = wc.id);
   i NUMBER;
begin
    i := 0;
    for user_rec in user_cursor
    loop
    	new_user_postop(user_rec.id);
	i := i + 1;
	if mod(i, 500) = 0
	then
	    commit;
	end if;
    end loop;
    commit;
end;
/
show errors

select '../rhn/procs/process_errata_cache_queue.sql' sql_file from dual;
-- SQL relevant contents from file ../rhn/procs/process_errata_cache_queue.sql
CREATE OR REPLACE PROCEDURE
process_errata_cache_queue
IS
	CURSOR errata_queue IS SELECT rowid, errata_id FROM rhnSNPErrataQueue WHERE processed = 0 FOR UPDATE;
BEGIN
	FOR errata IN errata_queue
	LOOP
	    	DELETE FROM rhnServerNeededPackageCache WHERE errata_id = errata.errata_id;
		INSERT INTO rhnServerNeededPackageCache
		       (SELECT org_id, server_id, errata_id, package_id
			FROM   rhnServerNeededPackageView
			WHERE  errata_id = errata.errata_id);
		COMMIT;
	END LOOP;
END;
/
SHOW ERRORS

select '../rhn/procs/queue_errata.sql' sql_file from dual;
-- SQL relevant contents from file ../rhn/procs/queue_errata.sql
CREATE OR REPLACE PROCEDURE
queue_errata(errata_id_in IN NUMBER)
IS
BEGIN
	INSERT INTO rhnSNPErrataQueue (errata_id) VALUES (errata_id_in);
EXCEPTION
	WHEN DUP_VAL_ON_INDEX THEN
	     UPDATE rhnSNPErrataQueue SET processed = 0 WHERE errata_id = errata_id_in;
END;
/
SHOW ERRORS

select '../rhn/procs/set_ks_session_history_message.sql' sql_file from dual;
-- SQL relevant contents from file ../rhn/procs/set_ks_session_history_message.sql
create or replace procedure
set_ks_session_history_message (
	kickstart_session_id_in in number,
	state_label_in in varchar2,
	message_in in varchar2
) is
	cursor states is
		select	id
		from	rhnKickstartSessionState
		where	label = state_label_in;
	cursor history_items(state_id_in in number) is
		select	id
		from	rhnKickstartSessionHistory
		where	kickstart_session_id = kickstart_session_id_in
			and state_id = state_id_in
		order by time desc;
begin
	for state in states loop
		for item in history_items(state.id) loop
			update rhnKickstartSessionHistory
				set message = message_in
				where id = item.id;
			return;
		end loop;
		insert into rhnKickstartSessionHistory (
				id, kickstart_session_id, state_id, message
			) values (
				rhn_ks_sessionhist_id_seq.nextval,
				kickstart_session_id_in,
				state.id,
				message_in
			);
		return;
	end loop;
end;
/
show errors

select '../rhn/procs/truncateCacheQueue.sql' sql_file from dual;
-- SQL relevant contents from file ../rhn/procs/truncateCacheQueue.sql
create or replace procedure  truncateCacheQueue as
curnum number;
begin
curnum  := dbms_sql.open_cursor;
dbms_sql.parse(curnum, 'Truncate Table rhnOrgErrataCacheQueue', dbms_sql.v7);
dbms_sql.close_cursor(curnum);
end;
/

select '../rhn/procs/xxrh_contact_del_check_num.sql' sql_file from dual;
-- SQL relevant contents from file ../rhn/procs/xxrh_contact_del_check_num.sql
create or replace function
xxrh_contact_del_check_num(
	contact_id_in in number
) return number
is
begin
	if xxrh_contact_del_check(contact_id_in) = true then
		return 1;
	end if;
	return 0;
end xxrh_contact_del_check_num;
/
show errors

select '../rhn/packages/rhn_config.pkb' sql_file from dual;
-- SQL relevant contents from file ../rhn/packages/rhn_config.pkb
create or replace package body
rhn_config
is
	procedure prune_org_configs (
		org_id_in in number,
		total_in in number
	) is
	begin
		null;
	end prune_org_configs;
	function insert_revision (
		revision_in in number,
		config_file_id_in in number,
		config_content_id_in in number,
		config_info_id_in in number,
		delim_start_in in varchar2 := '{@',
		delim_end_in in varchar2 := '@}'
	) return number is
		retval number;
	begin
		insert into rhnConfigRevision(id, revision, config_file_id,
				config_content_id, config_info_id, delim_start, delim_end
			) values (
				rhn_confrevision_id_seq.nextval, revision_in, config_file_id_in,
				config_content_id_in, config_info_id_in, delim_start_in,
				delim_end_in
			)
			returning id into retval;
			return retval;
	end insert_revision;
	procedure delete_revision (
		config_revision_id_in in number,
		org_id_in in number := -1
	) is
		cfid number;
		ccid number;
		oid number;
		latest_crid number;
		others number := 0;
		cursor snapshots is
			select	scr.snapshot_id id
			from	rhnSnapshot s,
					rhnSnapshotConfigRevision scr
			where	scr.config_revision_id = config_revision_id_in
					and scr.snapshot_id = s.id
					and s.invalid is null;
		cursor other_revisions(config_content_id_in in number) is
			select	1
			from	rhnConfigRevision
			where	config_content_id = config_content_id_in;
	begin
		for snapshot in snapshots loop
			update		rhnSnapshot s
				set		s.invalid =
							lookup_snapshot_invalid_reason('cr_removed')
				where	s.id = snapshot.id;
		end loop;
		if org_id_in < 0 then
			select	cr.config_content_id, cc.org_id
			into	ccid, oid
			from	rhnConfigChannel cc,
					rhnConfigFile cf,
					rhnConfigRevision cr
			where	cr.id = config_revision_id_in
				and cr.config_file_id = cf.id
				and cf.config_channel_id = cc.id;
		else
			select	cr.config_content_id, org_id_in
			into	ccid, oid
			from	rhnConfigRevision cr
			where	cr.id = config_revision_id_in;
		end if;
		delete from rhnConfigRevision where id = config_revision_id_in;
		for other_revision in other_revisions(ccid) loop
			others := 1;
			exit;
		end loop;
		if others = 0 then
			delete from rhnConfigContent where id = ccid;
		end if;
		if org_id_in < 0 then
			select	cf.latest_config_revision_id,
					cf.id
			into	latest_crid,
					cfid
			from	rhnConfigFile cf,
					rhnConfigRevision cr
			where	cr.id = config_revision_id_in
				and cr.config_file_id = cf.id;
			if latest_crid = config_revision_id_in then
				latest_crid := rhn_config.get_latest_revision(cfid);
				if latest_crid is not null then
					update rhnConfigFile set latest_config_revision_id = latest_crid
						where id = cfid;
				else
					delete from rhnConfigFile where id = cfid;
				end if;
			end if;
			rhn_quota.update_org_quota(oid);
		end if;
	end delete_revision;
	function get_latest_revision (
		config_file_id_in in number
	) return number is
		cursor revisions is
			select	cr.id
			from	rhnConfigRevision cr
			where	cr.config_file_id = config_file_id_in
			order by revision desc;
	begin
		for revision in revisions loop
			return revision.id;
		end loop;
		return null;
	end get_latest_revision;
	function insert_file (
		config_channel_id_in in number,
		name_in in varchar2
	) return number is
		retval number;
	begin
		select	rhn_conffile_id_seq.nextval
		into	retval
		from	dual;
		insert into rhnConfigFile(id, config_channel_id, config_file_name_id, 
				state_id
			) (
				select	retval,
						config_channel_id_in,
						lookup_config_filename(name_in),
						id
				from	rhnConfigFileState
				where	label = 'alive'
			);
		return retval;
	end insert_file;
	procedure delete_file (
		config_file_id_in in number
	) is
		cursor revisions is
			select	cr.id, cc.org_id
			from	rhnConfigChannel cc,
					rhnConfigRevision cr,
					rhnConfigFile cf
			where	cf.id = config_file_id_in
				and cf.config_channel_id = cc.id
				and cr.config_file_id = cf.id;
		org_id number;
	begin
		for revision in revisions loop
			rhn_config.delete_revision(revision.id, revision.org_id);
			org_id := revision.org_id;
		end loop;
		rhn_quota.update_org_quota(org_id);
		delete from rhnConfigFile where id = config_file_id_in;
	end delete_file;
	function insert_channel (
		org_id_in in number,
		type_in in varchar2,
		name_in in varchar2,
		label_in in varchar2,
		description_in in varchar2
	) return number is
		retval number;
	begin
		select	rhn_confchan_id_seq.nextval
		into	retval
		from	dual;
		insert into rhnConfigChannel(id, org_id, confchan_type_id,
				name, label, description
			) (
				select	retval,
						org_id_in,
						cct.id,
						name_in,
						label_in,
						description_in
				from	rhnConfigChannelType cct
				where	label = type_in
			);
		return retval;
	end insert_channel;
	procedure delete_channel (
		config_channel_id_in in number
	) is
		cursor config_files is
			select	id
			from	rhnConfigFile
			where	config_channel_id = config_channel_id_in;
	begin
		for config_file in config_files loop
			rhn_config.delete_file(config_file.id);
		end loop;
		delete from rhnConfigChannel where id = config_channel_id_in;
	end delete_channel;
end rhn_config;
/
show errors

select '../rhn/packages/rhn_config_channel.pkb' sql_file from dual;
-- SQL relevant contents from file ../rhn/packages/rhn_config_channel.pkb
CREATE OR REPLACE
PACKAGE BODY rhn_config_channel
IS
    FUNCTION action_diff_revision_status(action_config_revision_id_in IN NUMBER)
    RETURN VARCHAR2
    IS
    	failure_reason VARCHAR2(4000);
	result_is_null NUMBER;
	result_exists NUMBER;
    BEGIN
	SELECT ACRR.action_config_revision_id,
	       NVL2(ACRR.result, 0, 1),
	       CFF.name
	  INTO result_exists,
	       result_is_null,
	       failure_reason
	  FROM rhnConfigFileFailure CFF,
	       rhnActionConfigRevisionResult ACRR,
	       rhnActionConfigRevision ACR
	 WHERE ACR.id = action_config_revision_id_in
	   AND ACR.id = ACRR.action_config_revision_id (+)
	   AND ACR.failure_id = CFF.id (+);
    	IF failure_reason IS NOT NULL
	THEN
	    RETURN failure_reason;
	END IF;
    	IF result_exists IS NOT NULL
	THEN
	    IF result_is_null = 1
	    THEN
	    	RETURN 'No differences';
	    END IF;
	    RETURN 'Differences exist';
	END IF;
    	RETURN NULL;
    END action_diff_revision_status;
    FUNCTION get_user_chan_access(config_channel_id_in IN NUMBER, user_id_in IN NUMBER)
    RETURN NUMBER
    IS
    	server_id NUMBER;
    BEGIN
    	IF rhn_user.check_role_implied(user_id_in, 'config_admin') = 1
	THEN
	    RETURN 1;
	END IF;
    	server_id := rhn_config_channel.get_config_channel_server(config_channel_id_in, 'local_override');
	IF server_id IS NULL
	THEN
	    RETURN 0;
	END IF;
    	IF rhn_server.check_user_access(server_id, user_id_in) = 1
	THEN
	    RETURN 1;
	END IF;
	RETURN 0;
    END get_user_chan_access;
    FUNCTION get_config_channel_server(config_channel_id_in IN NUMBER, config_channel_type_in IN VARCHAR2)
    RETURN NUMBER
    IS
    	server_id NUMBER;
    BEGIN
    	SELECT SCC.server_id INTO server_id
	  FROM rhnConfigChannelType CCT,
	       rhnConfigChannel C,
	       rhnServerConfigChannel SCC
	 WHERE SCC.config_channel_id = C.id
	   AND C.confchan_type_id = CCT.id
	   AND CCT.label = config_channel_type_in
	   AND SCC.config_channel_id = config_channel_id_in;
	RETURN server_id;
    EXCEPTION
    	WHEN NO_DATA_FOUND
	    THEN
	    RETURN NULL;
    END get_config_channel_server;
    FUNCTION get_user_revision_access(config_revision_id_in IN NUMBER, user_id_in IN NUMBER)    
    RETURN NUMBER
    IS
    	config_channel_id NUMBER;
    BEGIN
    	SELECT CF.config_channel_id INTO config_channel_id
	  FROM rhnConfigFile CF,
	       rhnConfigRevision CR
	 WHERE CF.id = CR.config_file_id
	   AND CR.id = config_revision_id_in;
	RETURN rhn_config_channel.get_user_chan_access(config_channel_id, user_id_in);
    END get_user_revision_access;
    FUNCTION get_user_file_access(config_file_id_in IN NUMBER, user_id_in IN NUMBER)    
    RETURN NUMBER
    IS
    	config_channel_id NUMBER;
    BEGIN
    	SELECT CF.config_channel_id INTO config_channel_id
	  FROM rhnConfigFile CF
	 WHERE CF.id = config_file_id_in;
	RETURN rhn_config_channel.get_user_chan_access(config_channel_id, user_id_in);
    END get_user_file_access;
END rhn_config_channel;
/
SHOW ERRORS

select '../rhn/packages/rhn_date_manip.pkb' sql_file from dual;
-- SQL relevant contents from file ../rhn/packages/rhn_date_manip.pkb
create or replace
package body rhn_date_manip
is
	function get_reporting_period_start
	return date is
		months_ago	number;
		weeks_ago	number;
		target_date	date;
		day_number	number;
	begin
		months_ago := rhn_date_manip.periods_ago/2;
		weeks_ago := mod(rhn_date_manip.periods_ago,2);
		target_date := trunc(add_months(sysdate,-months_ago)-(7*weeks_ago));
		day_number := to_char(target_date,'DD');
		if day_number > 16 then
			target_date := target_date - (day_number - 16);
		else
			target_date := target_date - (day_number - 1);
		end if;
		return target_date;
	end get_reporting_period_start;
	function get_reporting_period_end
	return date is
		months_ago	number;
		weeks_ago	number;
		target_date	date;
		day_number	number;
	begin
		months_ago := rhn_date_manip.periods_ago/2;
		weeks_ago := mod(rhn_date_manip.periods_ago,2);
		target_date := trunc(add_months(sysdate,-months_ago)-(7*weeks_ago));
		day_number := to_char(target_date,'DD');
		if day_number > 16 then
			target_date := last_day(target_date);
		else
			target_date := target_date + (-day_number + 15) + (1-1/86400);
		end if;
		return target_date;
	end get_reporting_period_end;
end rhn_date_manip;
/
show errors

select '../rhn/packages/rhn_org.pkb' sql_file from dual;
-- SQL relevant contents from file ../rhn/packages/rhn_org.pkb
CREATE OR REPLACE
PACKAGE BODY rhn_org
IS
    FUNCTION find_server_group_by_type(org_id_in NUMBER, group_label_in VARCHAR2) 
    RETURN NUMBER
    IS
	server_group       server_group_by_label%ROWTYPE;
    BEGIN
    	OPEN server_group_by_label(org_id_in, group_label_in);
	FETCH server_group_by_label INTO server_group;
	CLOSE server_group_by_label;
	RETURN server_group.id;
    END find_server_group_by_type;
    PROCEDURE update_errata_cache(org_id_in NUMBER, threshold_in NUMBER)
    IS
    	records_present NUMBER;
    BEGIN
    	SELECT NVL(SUM(server_count), 0) INTO records_present 
	  FROM rhnOrgErrataCacheQueue
	 WHERE org_id = org_id_in 
	   AND processed = 0;
	IF records_present < 1 OR records_present > threshold_in
	THEN
	    RETURN;
	END IF;
    	DELETE FROM rhnOrgErrataCacheQueue WHERE org_id = org_id_in;
	DELETE FROM rhnServerNeededPackageCache
	      WHERE server_id IN (SELECT id
	      	    	    	    FROM rhnServer
				   WHERE org_id = org_id_in);
        INSERT INTO rhnServerNeededPackageCache
        SELECT *
	  FROM rhnServerNeededPackageView 
	 WHERE server_id IN (SELECT id
	    	    	       FROM rhnServer
			      WHERE org_id = org_id_in);	
    END update_errata_cache;
	procedure delete_user(user_id_in in number) is
		cursor is_admin is
			select	1
			from	rhnUserGroupType	ugt,
					rhnUserGroup		ug,
					rhnUserGroupMembers	ugm
			where	ugm.user_id = user_id_in
				and ugm.user_group_id = ug.id
				and ug.group_type = ugt.id
				and ugt.label = 'org_admin';
		cursor servergroups_needing_admins is
			select	usgp.server_group_id	server_group_id
			from	rhnUserServerGroupPerms	usgp
			where	1=1
				and usgp.user_id = user_id_in
				and not exists (
					select	1
					from	rhnUserServerGroupPerms	sq_usgp
					where	1=1
						and sq_usgp.server_group_id = usgp.server_group_id
						and	sq_usgp.user_id != user_id_in
				);
		cursor servergroups_for_deletion(org_id_in in number) is
			select	sgm.server_id, sgm.server_group_id
			from	rhnServerGroupMembers sgm,
					rhnServerGroup sg
			where	sg.org_id = org_id_in
				and sg.id = sgm.server_group_id;
		cursor messages is
			select	message_id id
			from	rhnUserMessage
			where	user_id = user_id_in;
		users			number;
		our_org_id		number;
		del_check_ok	number;
		other_users		number;
		other_org_admin	number;
	begin
		select	wc.org_id, xxrh_contact_del_check_num(user_id_in)
		into	our_org_id, del_check_ok
		from	web_contact wc
		where	id = user_id_in;
		if del_check_ok != 1 then
			rhn_exception.raise_exception('cannot_delete_user');
			return;
		end if;
		begin
			select	1
			into	other_users
			from	web_contact
			where	1=1
				and org_id = our_org_id
				and id != user_id_in
				and rownum = 1;
		exception
			when no_data_found then
				other_users := 0;
		end;
		if other_users != 0 then
			for ignore in is_admin loop
				begin 
					select	new_ugm.user_id
					into	other_org_admin
					from	rhnUserGroupMembers	new_ugm,
							rhnUserGroupType	ugt,
							rhnUserGroup		ug,
							rhnUserGroupMembers	ugm
					where	ugm.user_id = user_id_in
						and ugm.user_group_id = ug.id
						and ug.group_type = ugt.id
						and ugt.label = 'org_admin'
						and ug.id = new_ugm.user_group_id
						and new_ugm.user_id != user_id_in
						and rownum = 1;
				exception
					when no_data_found then
						rhn_exception.raise_exception('cannot_delete_user');
				end;
				for sg in servergroups_needing_admins loop
					insert into rhnUserServerGroupPerms
						( user_id , server_group_id )
						values ( other_org_admin, sg.server_group_id );
				end loop;
			end loop;
		end if;
		for message in messages loop
			delete
				from	rhnUserMessage
				where	user_id = user_id_in
					and message_id = message.id;
			begin
				select	1
				into	users
				from	rhnUserMessage
				where	message_id = message.id
					and rownum = 1;
				delete
					from	rhnMessage
					where	id = message.id;
			exception
				when no_data_found then
					null;
			end;
		end loop;
		if other_users != 0 then
			update		rhnRegToken
				set		user_id = other_org_admin
				where	org_id = our_org_id
					and user_id = user_id_in;
			delete from web_contact where id = user_id_in;
		else
			for sgm in servergroups_for_deletion(our_org_id) loop
				rhn_server.delete_from_servergroup(
						sgm.server_id, sgm.server_group_id);
			end loop;
			update rhnServerGroup set group_type = null
				where org_id = our_org_id;
			delete from web_contact where id = user_id_in;
			delete from web_customer where id = our_org_id;
		end if;
		return;
	end delete_user;
END rhn_org;
/
SHOW ERRORS

select '../rhn/packages/rhn_qos.pkb' sql_file from dual;
-- SQL relevant contents from file ../rhn/packages/rhn_qos.pkb
create or replace package body rhn_qos is
	function slot_count(org_id_in in number, label_in in varchar2) return number is
		tally		number;
	begin
		select	max_members
		into	tally
		from	rhnServerGroupType	rsgt,
				rhnServerGroup		rsg
		where	1=1
				and rsgt.label = label_in
				and rsgt.id = rsg.group_type
				and rsg.org_id = org_id_in;
		return tally;
	exception
		when no_data_found then
			return 0;
	end slot_count;
	function basic_slot_count(org_id_in in number) return number is
	begin
		return slot_count(org_id_in, 'sw_mgr_entitled');
	end basic_slot_count;
	function workgroup_slot_count(org_id_in in number) return number is
	begin
		return slot_count(org_id_in, 'enterprise_entitled');
	end workgroup_slot_count;
	function channel_slot_count(org_id_in in number, label_in in number) return number is
		tally		number;
	begin
		select	max_members
		into	tally
		from	rhnChannelFamily			rcf,
				rhnChannelFamilyPermissions rcfp
		where	1=1
				and rcf.label = label_in
				and rcf.id = rcfp.channel_family_id
				and rcfp.org_id = org_id_in;
		return tally;
	exception
		when no_data_found then
			return 0;
	end channel_slot_count;
	function as_slot_count(org_id_in in number) return number is
	begin
		return channel_slot_count(org_id_in, 'rh-advanced-server');
	end as_slot_count;
end rhn_qos;
/
show errors

select '../rhn/packages/rhn_quota.pkb' sql_file from dual;
-- SQL relevant contents from file ../rhn/packages/rhn_quota.pkb
create or replace package body
rhn_quota
is
	function recompute_org_quota_used (
		org_id_in in number
	) return number is
		retval number := 0;
	begin
		begin
			select	NVL(sum(a.file_size),0)
			into	retval
			from	(
				select	distinct content.id, content.file_size
				from	rhnConfigContent	content,
						rhnConfigRevision	cr,
						rhnConfigFile		cf,
						rhnConfigChannel	cc
				where	cc.org_id = org_id_in
					and cc.id = cf.config_channel_id
					and cf.id = cr.config_file_id
					and cr.config_content_id = content.id
				) a;
		exception
			when others then
				null;
		end;
		return retval;
	end recompute_org_quota_used;
	function get_org_for_config_content (
		config_content_id_in in number
	) return number is
		org_id number;
	begin
		select	cc.org_id
		into	org_id
		from	rhnConfigChannel	cc,
				rhnConfigFile		cf,
				rhnConfigRevision	cr
		where	cr.config_content_id = config_content_id_in
			and cr.config_file_id = cf.id
			and cf.config_channel_id = cc.id;
		return org_id;
	end get_org_for_config_content;
	procedure set_org_quota_total (
		org_id_in in number,
		total_in in number
	) is
		available number;
	begin
		select	total_in + oq.bonus
		into	available
		from	rhnOrgQuota oq
		where	oq.org_id = org_id_in;
		rhn_config.prune_org_configs(org_id_in, available);
		update		rhnOrgQuota
			set		total = total_in
			where	org_id = org_id_in;
	exception
		when no_data_found then
			insert into rhnOrgQuota ( org_id, total )
				values (org_id_in, total_in);
		when others then
			null;
	end set_org_quota_total;
	procedure update_org_quota (
		org_id_in in number
	) is
	begin
		update rhnOrgQuota
			set used = rhn_quota.recompute_org_quota_used(org_id_in)
			where org_id = org_id_in;
	end update_org_quota;
end rhn_quota;
/
show errors

select '../rhn/packages/rhn_server.pkb' sql_file from dual;
-- SQL relevant contents from file ../rhn/packages/rhn_server.pkb
create or replace
package body rhn_server
is
    function system_service_level(
    	server_id_in in number,
	service_level_in in varchar2
    ) return number is
    begin
    	return rhn_entitlements.entitlement_grants_service(
	    rhn_entitlements.get_server_entitlement(server_id_in),
	    service_level_in
	);
    end system_service_level;
    function can_change_base_channel(server_id_in IN NUMBER)
    return number
    is
    	throwaway number;
    begin
	select 1 into throwaway
	  from rhnServer S
	 where S.id = server_id_in
	   and not exists (select 1 from rhnSatelliteInfo SI where SI.server_id = S.id)
	   and not exists (select 1 from rhnProxyInfo PI where PI.server_id = S.id);
	return 1;
    exception
    	when no_data_found
	    then
	    return 0;
    end can_change_base_channel;
    procedure set_custom_value(
    	server_id_in in number,
	user_id_in in number,
	key_label_in in varchar2,
	value_in in varchar2
    ) is
    	key_id_val number;
    begin
    	select CDK.id into key_id_val
	  from rhnCustomDataKey CDK,
	       rhnServer S
	 where S.id = server_id_in
	   and S.org_id = CDK.org_id
	   and CDK.label = key_label_in;
	begin
	    insert into rhnServerCustomDataValue (server_id, key_id, value, created_by, last_modified_by)
	    values (server_id_in, key_id_val, value_in, user_id_in, user_id_in);
	exception
	    when DUP_VAL_ON_INDEX
	    	then
		update rhnServerCustomDataValue
		   set value = value_in,
		       last_modified_by = user_id_in
		 where server_id = server_id_in
		   and key_id = key_id_val;		   
	end;
    end set_custom_value;
    procedure bulk_set_custom_value(
    	key_label_in in varchar2,
	value_in in varchar2,
	set_label_in in varchar2,
	set_uid_in in number
    ) is
    begin
    	for server in rhn_set.set_iterator(set_label_in, set_uid_in)
	loop
	    if rhn_server.system_service_level(server.element, 'provisioning') = 1 then
	    	rhn_server.set_custom_value(server.element, set_uid_in, key_label_in, value_in);
	    end if;
	end loop server;
    end bulk_set_custom_value;
    procedure bulk_snapshot_tag(
    	org_id_in in number,
        tagname_in in varchar2,
	set_label_in in varchar2,
	set_uid_in in number
    ) is
    	snapshot_id number;
    begin
    	for server in rhn_set.set_iterator(set_label_in, set_uid_in)
	loop
	    if rhn_server.system_service_level(server.element, 'provisioning') = 1 then
	    	begin
	    	    select max(id) into snapshot_id
	    	    from rhnSnapshot
	    	    where server_id = server.element;
	    	exception
	    	    when NO_DATA_FOUND then
		    	rhn_server.snapshot_server(server.element, 'tagging system:  ' || tagname_in);
			select max(id) into snapshot_id
			from rhnSnapshot
			where server_id = server.element;
		end;
		begin
		    rhn_server.tag_snapshot(snapshot_id, org_id_in, tagname_in);
		exception
		    when DUP_VAL_ON_INDEX
		    	then
			null;
		end;
	    end if;
	end loop server;    
    end bulk_snapshot_tag;
    procedure tag_snapshot(
        snapshot_id_in in number,
	org_id_in in number,
	tagname_in in varchar2
    ) is
    begin
    	insert into rhnSnapshotTag (snapshot_id, server_id, tag_id)
	select snapshot_id_in, server_id, lookup_tag(org_id_in, tagname_in)
	from rhnSnapshot
	where id = snapshot_id_in;
    end tag_snapshot;
    procedure bulk_snapshot(
    	reason_in in varchar2,
	set_label_in in varchar2,
	set_uid_in in number
    ) is
    begin
    	for server in rhn_set.set_iterator(set_label_in, set_uid_in)
	loop
    	    if rhn_server.system_service_level(server.element, 'provisioning') = 1 then
	    	rhn_server.snapshot_server(server.element, reason_in);
	    end if;
	end loop server;
    end bulk_snapshot;
    procedure snapshot_server(
    	server_id_in in number,
	reason_in in varchar2
    ) is
    	snapshot_id number;
	cursor revisions is
		select distinct
			cr.id
		from	rhnConfigRevision	cr,
			rhnConfigFileName	cfn,
			rhnConfigFile		cf,
			rhnConfigChannel	cc,
			rhnServerConfigChannel	scc
		where	1=1
			and scc.server_id = server_id_in
			and scc.config_channel_id = cc.id
			and cc.id = cf.config_channel_id
			and cf.id = cr.config_file_id
			and cr.id = cf.latest_config_revision_id
			and cf.config_file_name_id = cfn.id
			and cf.id = lookup_first_matching_cf(scc.server_id, cfn.path);
    begin
    	select rhn_snapshot_id_seq.nextval into snapshot_id from dual;
	insert into rhnSnapshot (id, org_id, server_id, reason) (
		select	snapshot_id,
			s.org_id,
			server_id_in,
			reason_in
		from	rhnServer s
		where	s.id = server_id_in
	);
	insert into rhnSnapshotChannel (snapshot_id, channel_id) (
		select	snapshot_id, sc.channel_id
		from	rhnServerChannel sc
		where	sc.server_id = server_id_in
	);
	insert into rhnSnapshotServerGroup (snapshot_id, server_group_id) (
		select	snapshot_id, sgm.server_group_id
		from	rhnServerGroupMembers sgm
		where	sgm.server_id = server_id_in
	);
	insert into rhnSnapshotPackage (snapshot_id, nevra_id) (
		select	snapshot_id,
			lookup_package_nevra(sp.name_id, sp.evr_id, null)
		from	rhnServerPackage sp
		where	sp.server_id = server_id_in
	);
	insert into rhnSnapshotConfigChannel ( snapshot_id, config_channel_id ) (
		select	snapshot_id, scc.config_channel_id
		from	rhnServerConfigChannel scc
		where	server_id = server_id_in
	);
	for revision in revisions loop
		insert into rhnSnapshotConfigRevision (
				snapshot_id, config_revision_id
			) values (
				snapshot_id, revision.id
			);
	end loop;
    end snapshot_server;
    procedure remove_action(
    	server_id_in in number,
	action_id_in in number
    ) is
    	cursor chained_actions is
		select	id, prerequisite
		from	rhnAction
		start with id = action_id_in
		connect by prior id = prerequisite
		order by prerequisite desc nulls last;
	prereq number := 1;
    begin
	select	prerequisite
	into	prereq
	from	rhnAction
	where	id = action_id_in;
	if prereq is not null then
		rhn_exception.raise_exception('action_is_child');
	end if;
	for action in chained_actions loop
		delete from rhnServerAction
			where server_id = server_id_in
			and action_id = action.id;
	end loop;
    end remove_action;
    function check_user_access(server_id_in in number, user_id_in in number)
    return number
    is
    	has_access number;
    begin
        select 1 into has_access
	  from rhnServer S,
	       web_contact wc
	 where wc.org_id = s.org_id
	   and s.id = server_id_in
	   and wc.id = user_id_in;
    	if rhn_user.check_role(user_id_in, 'org_admin') = 1
	then
	    return 1;
	end if;
    	select 1 into has_access
	  from rhnServerGroupMembers SGM,
	       rhnUserServerGroupPerms USG
	 where SGM.server_group_id = USG.server_group_id
	   and SGM.server_id = server_id_in
	   and USG.user_id = user_id_in
	   and rownum = 1;
	return 1;
    exception
    	when no_data_found
	    then
	    return 0;
    end check_user_access;
    procedure insert_into_servergroup (
		server_id_in in number,
		server_group_id_in in number
    ) is
		used_slots number;
		max_slots number;
		org_id number;
		mgmt_available number;
		mgmt_upgrade number;
		mgmt_sgid number;
		prov_available number;
		prov_upgrade number;
		prov_sgid number;
		group_label rhnServerGroupType.label%TYPE;
		group_type number;
	begin
		select	sg.group_type, sg.org_id, sg.current_members, sg.max_members
		into	group_type, org_id, used_slots, max_slots
		from	rhnServerGroup sg
		where	sg.id = server_group_id_in
		for update of sg.current_members;
		if group_type is null then
			if used_slots >= max_slots then
				rhn_exception.raise_exception('servergroup_max_members');
			end if;
			insert into rhnServerGroupMembers(
					server_id, server_group_id
				) values (
					server_id_in, server_group_id_in
				);
			update rhnServerGroup
				set current_members = current_members + 1
				where id = server_group_id_in;
			return;
		end if;
		select	label
		into	group_label
		from	rhnServerGroupType	sgt
		where	sgt.id = group_type;
		if group_label in ('sw_mgr_entitled','enterprise_entitled') then
			if used_slots >= max_slots then
				rhn_exception.raise_exception('servergroup_max_members');
			end if;
			insert into rhnServerGroupMembers(
					server_id, server_group_id
				) values (
					server_id_in, server_group_id_in
				);
			update rhnServerGroup
				set current_members = current_members + 1
				where id = server_group_id_in;
			return;
		else -- we're doing provisioning
			rhn_entitlements.get_available_slots(
					org_id, 'provisioning_entitled', prov_sgid,
					prov_available, prov_upgrade);
			rhn_entitlements.get_available_slots(
					org_id, 'enterprise_entitled', mgmt_sgid,
					mgmt_available, mgmt_upgrade);
			if prov_available < 1 then
				if prov_upgrade > 0 then
					rhn_exception.raise_exception('servergroup_use_upgrade');
				end if;
				rhn_exception.raise_exception('servergroup_max_members');
			end if;
			insert into rhnServerGroupMembers(
					server_id, server_group_id
				) values (
					server_id_in, server_group_id_in
				);
			update rhnServerGroup
				set current_members = current_members + 1
				where id = server_group_id_in;
			update rhnServerGroup
				set max_members = max_members - 1
				where id = mgmt_sgid;
		end if;
	end;
	function insert_into_servergroup_maybe (
		server_id_in in number,
		server_group_id_in in number
	) return number is 
		retval number := 0;
		cursor servergroups is
			select	s.id	server_id,
					sg.id	server_group_id
			from	rhnServerGroup	sg,
					rhnServer		s
			where	s.id = server_id_in
				and sg.id = server_group_id_in
				and s.org_id = sg.org_id
				and not exists (
					select	1
					from	rhnServerGroupMembers sgm
					where	sgm.server_id = s.id
						and sgm.server_group_id = sg.id
				);
	begin
		for sgm in servergroups loop
			rhn_server.insert_into_servergroup(sgm.server_id, sgm.server_group_id);
			retval := retval + 1;
		end loop;
		return retval;
	end insert_into_servergroup_maybe;
	procedure insert_set_into_servergroup (
		server_group_id_in in number,
		user_id_in in number,
		set_label_in in varchar2
	) is
		cursor servers is
			select	st.element	id
			from	rhnSet		st
			where	st.user_id = user_id_in
				and st.label = set_label_in
				and exists (
					select	1
					from	rhnUserManagedServerGroups umsg
					where	umsg.server_group_id = server_group_id_in
						and umsg.user_id = user_id_in
					)
				and not exists (
					select	1
					from	rhnServerGroupMembers sgm
					where	sgm.server_id = st.element
						and sgm.server_group_id = server_group_id_in
				);
	begin
		for s in servers loop
			rhn_server.insert_into_servergroup(s.id, server_group_id_in);
		end loop;
	end insert_set_into_servergroup;
    procedure delete_from_servergroup (
    	server_id_in in number,
		server_group_id_in in number
    ) is
		oid number;
		mgmt_sgid number;
		label rhnServerGroupType.label%TYPE;
		group_type number;
	begin
		begin
			select	sg.group_type, sg.org_id
			into	group_type,	oid
			from	rhnServerGroupMembers	sgm,
					rhnServerGroup			sg
			where	sg.id = server_group_id_in
				and sg.id = sgm.server_group_id
				and sgm.server_id = server_id_in
			for update of sg.current_members;
		exception
			when no_data_found then
				rhn_exception.raise_exception('server_not_in_group');
		end;
		if group_type is null then
			delete from rhnServerGroupMembers
				where server_group_id = server_group_id_in
				and	server_id = server_id_in;
			update rhnServerGroup
				set current_members = current_members - 1
				where id = server_group_id_in;
			return;
		end if;
		select	sgt.label
		into	label
		from	rhnServerGroupType sgt
		where	sgt.id = group_type;
		if label in ('sw_mgr_entitled','enterprise_entitled') then
			delete from rhnServerGroupMembers
				where server_group_id = server_group_id_in
				and	server_id = server_id_in;
			update rhnServerGroup
				set current_members = current_members - 1
				where id = server_group_id_in;
		else
			select	sg.id
			into	mgmt_sgid
			from	rhnServerGroupType	sgt,
					rhnServerGroup		sg
			where	sg.org_id = oid
				and sgt.label = 'enterprise_entitled'
				and sgt.id = sg.group_type
			for update of sg.max_members;
			delete from rhnServerGroupMembers
				where server_group_id = server_group_id_in
				and	server_id = server_id_in;
			update rhnServerGroup
				set max_members = max_members + 1
				where id = mgmt_sgid;
			update rhnServerGroup
				set current_members = current_members - 1
				where id = server_group_id_in;
		end if;
	end;
	procedure delete_set_from_servergroup (
		server_group_id_in in number,
		user_id_in in number,
		set_label_in in number
	) is
		cursor servergroups is
			select	sgm.server_id, sgm.server_group_id
			from	rhnSet st,
					rhnServerGroupMembers sgm
			where	sgm.server_group_id = server_group_id_in
				and st.user_id = user_id_in
				and st.label = set_label_in
				and sgm.server_id = st.element
				and exists (
					select	1
					from	rhnUserManagedServerGroups usgp
					where	usgp.server_group_id = server_group_id_in
						and usgp.user_id = user_id_in
				);
	begin
		for sgm in servergroups loop
			rhn_server.delete_from_servergroup(sgm.server_id, server_group_id_in);
		end loop;
	end delete_set_from_servergroup;
	procedure clear_servergroup (
		server_group_id_in in number
	) is
		cursor servers is
			select	sgm.server_id	id
			from	rhnServerGroupMembers sgm
			where	sgm.server_group_id = server_group_id_in;
	begin
		for s in servers loop
			rhn_server.delete_from_servergroup(s.id, server_group_id_in);
		end loop;
	end clear_servergroup;
	procedure delete_from_org_servergroups (
		server_id_in in number
	) is
		cursor servergroups is
			select	sgm.server_group_id id
			from	rhnServerGroup sg,
					rhnServerGroupMembers sgm
			where	sgm.server_id = server_id_in
				and sgm.server_group_id = sg.id
				and sg.group_type is null;
	begin
		for sg in servergroups loop
			rhn_server.delete_from_servergroup(server_id_in, sg.id);
		end loop;
	end delete_from_org_servergroups;
end rhn_server;
/
SHOW ERRORS

select '../rhn/packages/rhn_user.pkb' sql_file from dual;
-- SQL relevant contents from file ../rhn/packages/rhn_user.pkb
create or replace
package body rhn_user
is
    function check_role(user_id_in in number, role_in in varchar2)
    return number
    is
    	throwaway number;
    begin
	select 1 into throwaway
	  from rhnUserGroupType UGT,
	       rhnUserGroup UG,
	       rhnUserGroupMembers UGM
	 where UGM.user_id = user_id_in
	   and UGM.user_group_id = UG.id
	   and UG.group_type = UGT.id
	   and UGT.label = role_in;
	return 1;
    exception
    	when no_data_found
	    then
	    return 0;
    end check_role;
    function check_role_implied(user_id_in in number, role_in in varchar2)
    return number
    is
    	throwaway number;
    begin
    	if rhn_user.check_role(user_id_in, role_in) = 1
	then
	    return 1;
    	end if;
	if role_in = 'config_admin' and rhn_user.check_role(user_id_in, 'org_admin') = 1
	then
	    return 1;
	end if;
	if role_in = 'channel_admin' and rhn_user.check_role(user_id_in, 'org_admin') = 1
	then
	    return 1;
	end if;
	return 0;	
    end check_role_implied;
    function get_org_id(user_id_in in number)
    return number
    is
    	org_id_out number;
    begin
    	select org_id into org_id_out
	  from web_contact
	 where id = user_id_in;
	return org_id_out;
    end get_org_id;
end rhn_user;
/
SHOW ERRORS

select '../rhn/tables/rhnVersionInfo_data.sql' sql_file from dual;
-- SQL relevant contents from file ../rhn/tables/rhnVersionInfo_data.sql
select '' sql_file from dual;
delete
from rhnVersionInfo
where label = 'schema'
        and name_id = lookup_package_name('rhn-'|| 'satellite' ||'-schema');
insert into rhnVersionInfo(
        label,
        name_id,
        evr_id
) (
        select 'schema',
                lookup_package_name('rhn-' || 'satellite' || '-schema'),
                lookup_evr(null, '3.1' , '48' )
        from dual
);
commit;

select '../rhn/quit.sql' sql_file from dual;
-- SQL relevant contents from file ../rhn/quit.sql
quit;

